# -*- Autoconf -*-
#
# Copyright (c) 2005-2006 The ABINIT Group (Yann Pouillon)
# All rights reserved.
#
# This file is part of the ABINIT software package. For license information,
# please see the COPYING file in the top-level directory of the ABINIT source
# distribution.
#

#
# Octopus configuration variables used by the Nanoquanta XC library
#



# OCT_NQXC_POINTER_SIZE()
# -----------------------
#
# Checks size of pointers (as imported from Octopus).
#
AC_DEFUN([OCT_NQXC_POINTER_SIZE],
[AC_MSG_CHECKING([for the size of a pointer])
  AC_REQUIRE([AC_PROG_CC])
  if test -z "$POINTER_SIZE"; then
  cat >pointertest.c <<EOF
#include <stdio.h>
void main()
{
  printf("%ld", sizeof(void *));
}
EOF
  ac_try='$CC $CFLAGS -o pointertest.x pointertest.c 1>&AC_FD_CC'
  if AC_TRY_EVAL(ac_try); then
    ac_try=""
  else
    echo "configure: failed program was:" >&AC_FD_CC
    cat pointertest.c >&AC_FD_CC
    rm -f pointertest*
    AC_MSG_ERROR(failed to compile c program to find the size of a pointer)
  fi
  ac_pointersize=`./pointertest.x`;
  rm -f pointertest*
  AC_DEFINE_UNQUOTED(POINTER_SIZE, ${ac_pointersize}, [The size of a C pointer])
  AC_MSG_RESULT([${ac_pointersize} bytes])
fi
]) # OCT_NQXC_POINTER_SIZE



# OCT_NQXC_FLOAT()
# ----------------
#
# Maps the "FLOAT" macro to type Fortran 90 "double precision" type. This is
# specific to ABINIT.
#
AC_DEFUN([OCT_NQXC_FLOAT],
[AC_DEFINE_UNQUOTED(FLOAT, double precision, [Float type for the Nanoquanta exchange-correlation library])
]) # OCT_NQXC_FLOAT
