!{\src2tex{textfont=tt}}
!!****f* ABINIT/WffClose
!! NAME
!! WffClose
!!
!! FUNCTION
!! This subroutine closes a Wf file.
!!
!! COPYRIGHT
!! Copyright (C) 2004-2006 ABINIT group (MB)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!!
!! INPUTS
!! wff= structured info about the wavefunction file
!!
!! OUTPUT
!! ierr=error code
!!
!! PARENTS
!!      conducti,gstate,loop3dte,loper3,nonlinear,nstdy3,optic,respfn,scfcv3
!!      suscep,uderiv,wannier
!!
!! CHILDREN
!!      mpi_file_close
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine WffClose(wff,ier)

 use defs_basis
 use defs_datatypes

 implicit none

#if defined MPIO
           include 'mpif.h'
#endif
!Arguments ------------------------------------
 type(wffile_type), intent(inout) :: wff
 integer, intent(out) :: ier

!Local ------------------------------------

! *************************************************************************

 ier=0
 if(wff%accesswff==0)then

! All processors see a local file
  close(unit=wff%unwff)

 else if(wff%accesswff==-1)then

! Only the master processor see a local file
  if(wff%master==wff%me)then
   close (unit=wff%unwff)
  end if

#if defined MPIO
           else if(wff%accesswff==1)then
            call MPI_FILE_CLOSE(wff%fhwff,ier)
            if (wff%master==wff%me ) then
             close(unit=wff%unwff)
            end if
#endif

 end if

end subroutine WffClose
!!***
