!{\src2tex{textfont=tt}}
!!****f* ABINIT/wrtout
!! NAME
!! wrtout
!!
!! FUNCTION
!! Organizes the sequential or parallel version of the write intrinsic
!! Also allows to treat correctly the write operations for
!! Unix (+DOS) and MacOS.
!!
!! COPYRIGHT
!! Copyright (C) 1998-2006 ABINIT group (DCA, XG, GMR)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  unit=unit number for writing
!!  mode_paral='COLL' if all procs are calling the routine with the same message
!!           to be written once only
!!          or 'PERS' if the procs are calling the routine with different mesgs
!!           each to be written, or if one proc is calling the routine
!!
!! OUTPUT
!!  (only writing)
!!
!! SIDE EFFECTS
!!  message=(character(len=500)) message to be written
!!
!! PARENTS
!!      WffOpen,abinit,acfd_dyson,acfd_intexact,afterscfloop,anaddb,append_cml
!!      append_cml2,asria9,asrif9,berryphase,berryphase_new,besjm,bigbx9,bldgrp
!!      blok8,bonds_lgth_angles,bound,brdmin,canat9,ccfft,cchi0,cchi0q0,cgwf
!!      cgwf3,cgwf_htor,chkdilatmx,chkdpr,chkexi,chkgrp,chki8,chkilwf,chkin9
!!      chkinp,chkint,chkneu,chknm8,chkorthsy,chkpawovlp,chkph3,chkprimit,chkr8
!!      chkrp9,chneu9,clnup1,clnup2,cmpar8,constrf,contract_dp_ge_val
!!      contract_int_ge_val,contract_int_le_val,contract_int_list,cppm3par
!!      create_netcdf_file,cvxclda,d3output,ddkten,def_acfd_ncdf,def_den_ncdf
!!      def_dtset_ncdf,def_wfs_ncdf,delocint,der_int,diel9,dielmore9,dielmt
!!      dieltcel,distrb2,dos_hdr_write,dotprod_vn,dotprodm_vn,driver,drivergw
!!      drivexc,dsksta,dyson_sc,eig1fixed,elast9,electrooptic,elpolariz
!!      eltxccore,energy,ewald,ewald3,ewald4,ewald9,fconv,fftpac,fftw,filterpot
!!      findmin,fixsym,forstr,forstrnps,fourdp,fourwf,fresid,ftgam,ftgkk,ftiaf9
!!      fxphas,gensymshub,gensymshub4,gensymspgr,get_acfd_ncdf,get_den_ncdf
!!      get_dims_acfd_ncdf,get_dims_den_ncdf,get_dims_dtset_ncdf
!!      get_dims_wfs_ncdf,get_dtset_ncdf,get_full_kgrid,get_g_tiny,get_tetra
!!      get_wfs_ncdf,getattribute,getcut,getdim_nloc,getfreqsus,getghc,getgsc
!!      getkgrid,getlambda,getmpw,getnel,getng,getsc,getshell,getspinrot,gstate
!!      gtblk9,gtdyn9,handle_err_netcdf,handle_ncerr_new,hartre,hartre1
!!      hartrestr,hdr_check,hdr_init,hdr_io,hdr_io_netcdf,hermit,importcml
!!      inarray,incomprs,ingeo,ingeobld,init8,initang,initberry,initmpi_gs
!!      initmpi_respfn,initmv,initro,initwf,inkpts,inprep8,instr9,instrng,insy3
!!      int2char,int2char4,intagm,inupper,invars0,invars1,invars1m,invars2
!!      invars2m,invars9,invcb,inwffil,inwffil3,ioarr,ioddb8,iofn1,iofn2,irrzg
!!      isfile,klocal,kpgio,kpgsph,kpgstr,kxc_alda,kxc_eok,leave_new,leave_test
!!      lifetime_bn,lifetime_rpa,linemin,listkk,lobpcgIIwf,lobpcgccIIwf
!!      lobpcgccwf,lobpcgwf,loop3dte,loper3,lwf,matcginv,mati3inv,matrginv
!!      matrixelmt_g,mean_fftr,meanvalue_g,memana,memkss,memorf,memory,metcon
!!      metric,metstr,mka2f,mkcor3,mkcore,mkdenpos,mkeuler,mkffnl,mkfilename
!!      mkifc9,mkkpg,mklocl,mkph_linwid,mkrho,mkrho3,mkvxc3,mkvxcstr3,moddiel
!!      moldyn,move,mrgddb,mrgscr,mv_3dte,nanal9,nderiv_gen,newfermie1,newkpt
!!      newocc,newrho,newsp,newvtr,newvtr3,nhatgrid,nonlinear,nonlop
!!      nonlop_htor,nonlop_pl,nonlop_ylm,nselt3,nstdy3,nstwf3,occeig,operat
!!      opernl2,opernl3,opernl4b,out1dm,outkss,outqmc,outscfcv,outvars,outwant
!!      outwf,overlap_g,pareigocc,pawcorloc,pawdenpot,pawdij,pawmknhat,pawmkrhoij
!!      pawprt,pawxc,pawxcdenm,pawxcm,ph1d3d,phfrq3,piezo9
!!      plm_dphi,plm_dtheta,polcart,prcref,precon,print_ij,projbd,prt_cml
!!      prt_cml2,prteigrs,prtene,prtene3,prtocc,prtph3,prtrhomxmn,prtspgroup
!!      prttagm,prtxf,prtxvf,psddb8,psp1cc,psp1in,psp1nl,psp2in,psp3in,psp3nl
!!      psp4cc,psp5in,psp5nl,psp6in,psp7in,psp7nl,psp8cc,psp8in,psp9in,pspatm
!!      pspini,pstate,psxml2ab,put_acfd_ncdf,put_den_ncdf,put_dtset_ncdf
!!      put_wfs_ncdf,q0dy3,ramansus,randac,rdddb9,rdnpw,readeig,relaxpol,respfn
!!      rhofermi3,rhohxc,rhohxc_coll,rsiaf9,rwwan,rwwf,scalewf_nonlop,scfcge
!!      scfcv,scfcv3,scfeig,scfopt,scprqt,screening,setmesh,setshells,setup1
!!      setup2,sg_ctrig,sg_fft,sg_fftpad,sg_fftpx,sg_fftrisc,sg_fftx,sg_ffty
!!      sg_fftz,sg_fourwf,sigma,smallprim,smatrix,smpbz,sphere,sphereboundary
!!      sphericaldens,status,stress,subdiago,subdiago_htor,suscep,suscep_dyn
!!      suscep_kxc_dyn,suscep_stat,suskmm,suskmm_dyn,suskmm_kxc_dyn,sym_gkk
!!      symanal,symatm,symbrav,symdet,symdm9,symfind,symg,symkchk,symkpt
!!      symmultsg,symph3,symq3,symrelrot,symrhg,symrhoij,symspgr,tddft
!!      testkgrid,tetrahedron,thm9,timab,timana,time_accu,timein,transgrid
!!      uderiv,vlocalstr,vtorho,vtorho3,vtorhotf,vtowfk,vtowfk3,vtowfk_htor
!!      wannier,wfconv,wffile,wfkfermi3,wfsinp,wght9,write_netcdf_data
!!      wrtloctens,xcacfd,xcden,xchcth,xchelu,xcpot,xcpzca,xcspol,xctetr,xcwign
!!      xcxalp,xfpack,xredxcart
!!
!! CHILDREN
!!      mpi_comm_rank,timab
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine wrtout(unit,message,mode_paral)

 use defs_basis

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_00basis
#endif
!End of the abilint section

 implicit none

#if defined MPI  || defined MPI_FFT
           include 'mpif.h'
#endif
!Arguments ------------------------------------
 integer,intent(in) :: unit
 character(len=4),intent(in) :: mode_paral
 character(len=500),intent(inout) :: message

!Local variables-------------------------------
 integer,save :: iexit=0,ncomment=0,nwarning=0
 integer :: rtnpos
 real(dp) :: tsec(2)
 character(len=7) :: tag
 character(len=500) :: messtmp,string
 logical :: test_mpi
!no_abirules
#if defined MPI || defined MPI_FFT
          !Variables introduced for MPI version
           integer, save :: master
           integer :: ierr,me
           character(len=12) :: form,strfmt
#endif

!******************************************************************
!BEGIN EXECUTABLE SECTION

 call timab(49,1,tsec)

!Be careful with the coding  of the parallel case ...
 test_mpi=.false.
#if defined MPI || defined MPI_FFT
           test_mpi=.true.
          !Determine who I am
           call timab(48,1,tsec)
           call MPI_COMM_RANK(MPI_COMM_WORLD,me,ierr)
           call timab(48,2,tsec)
           if(mode_paral=='COLL') then
            if(me==master) then
#endif

 if(message/=' ') then
  messtmp=message
! Here, split the message, according to the char(10)
! characters (carriage return). This technique is
! portable accross different OS.
  rtnpos=index(messtmp,ch10)
  do while(rtnpos/=0)
   string=messtmp(1:rtnpos-1)
   write(unit, '(a)' ) trim(string)
   messtmp=messtmp(rtnpos+1:len(message))
   rtnpos=index(messtmp,ch10)
  end do
  write(unit, '(a)' ) trim(messtmp)
 else
  write(unit,*)
 end if

 if( index(trim(message),'BUG') /= 0 )then
  write(unit, '(a)' ) '  Action : contact ABINIT group.'
  write(unit,*)
 end if

 if( index(trim(message),'BUG') /= 0   .or. &
&    index(trim(message),'Calculation completed') /= 0 )then
  if(nwarning<10000 .and. ncomment<1000)then
   write(unit, '(a,i5,a,i4,a)' ) &
&    '.Delivered',nwarning,' WARNINGs and',ncomment,' COMMENTs to log file.'
  else
   write(unit, '(a,i6,a,i6,a)' ) &
&    '.Delivered',nwarning,' WARNINGs and',ncomment,' COMMENTs to log file.'
  end if
  if(iexit/=0)then
   write(unit, '(a)' ) ' Note : exit requested by the user.'
  end if
 end if

 if( index(trim(message),'Exit') /= 0 )then
  iexit=1
 end if

!Count the number of warnings and comments. Only take into
!account unit 6, in order not to duplicate these numbers.
 if( index(trim(message),'WARNING') /= 0 .and. unit==6 )then
   nwarning=nwarning+1
 end if
 if( index(trim(message),'COMMENT') /= 0 .and. unit==6 )then
   ncomment=ncomment+1
 end if

#if defined MPI || defined MPI_FFT
             end if
           elseif(mode_paral=='PERS') then
             if(me<10) then
               write(tag,'("-P-000",i1)') me
             elseif(me<100) then
               write(tag,'("-P-00",i2)') me
             elseif(me<1000) then
               write(tag,'("-P-0",i3)') me
             elseif(me<10000) then
               write(tag,'("-P-",i4)') me
             else
               tag=' ######'
             end if
             rtnpos=index(message,ch10)
#endif
!            It is not possible to use CPP, due to the // signs
             if(test_mpi)then
              do while(rtnpos/=0)
               string=tag//' '//message(1:rtnpos-1)
               write(unit, '(a)' ) trim(string)
               message=message(rtnpos+1:len(message))
               rtnpos=index(message,ch10)
              end do
              string=tag//' '//message
             end if
#if defined MPI || defined MPI_FFT
             write(unit, '(a)' ) trim(string)
           elseif(mode_paral=='INIT') then
             master=unit
           end if
#endif

 call timab(49,2,tsec)

end subroutine wrtout
!!***
