!{\src2tex{textfont=tt}}
!!****f* ABINIT/compmesh
!! NAME
!! compmesh
!!
!! FUNCTION
!! Compute all points of a radial mesh
!! Grid can be regular or logarithimc
!!
!! COPYRIGHT
!! Copyright (C) 1998-2006 ABINIT group (MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! SIDE EFFECTS
!!  mesh <type(pawrad_type)>=data containing radial grid information
!!
!! PARENTS
!!      psp7in
!!
!! CHILDREN
!!
!! NOTES
!!  Possible mesh types (mesh%mesh_type)
!!   mesh_type=1 (regular grid): rad(i)=(i-1)*AA
!!   mesh_type=2 (logari. grid): rad(i)=AA*(exp[BB*(i-1)]-1)
!!   mesh_type=3 (logari. grid): rad(i>1)=AA*exp[BB*(i-2)] and rad(1)=0
!!   mesh_type=4 (logari. grid): rad(i)=-AA*ln[1-BB*(i-1)] with BB=1/n
!!
!! INPUTS
!! mesh=data containing radial grid information
!!
!! OUTPUT
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine compmesh(mesh)

 use defs_basis
 use defs_datatypes

 implicit none

!Arguments ------------------------------------
!scalars
 type(pawrad_type),intent(inout) :: mesh

!Local variables-------------------------------
!scalars
 integer :: ir,ir_last,isim
 real(dp) :: hh

! *************************************************************************

 if (mesh%mesh_type==1) then
  isim=3
  mesh%stepint=mesh%rstep
  mesh%rad(1)=zero;mesh%radfact(1)=one
  do ir=2,mesh%mesh_size
   mesh%rad(ir) =mesh%rstep*dble(ir-1)
   mesh%radfact(ir)=one
  end do
 else if (mesh%mesh_type==2) then
  isim=3
  mesh%stepint=mesh%lstep
  mesh%rad(1)=zero;mesh%radfact(1)=mesh%rstep
  do ir=2,mesh%mesh_size
   mesh%rad(ir) =mesh%rstep*(exp(mesh%lstep*dble(ir-1))-one)
   mesh%radfact(ir)=mesh%rad(ir)+mesh%rstep
  end do
 else if (mesh%mesh_type==3) then
  isim=4
  mesh%stepint=mesh%lstep
  mesh%rad(1)=zero;mesh%radfact(1)=zero
  do ir=2,mesh%mesh_size
   mesh%rad(ir) =mesh%rstep*exp(mesh%lstep*dble(ir-2))
   mesh%radfact(ir)=mesh%rad(ir)
  end do
 else if (mesh%mesh_type==4) then
  isim=3
  mesh%lstep=one/dble(mesh%mesh_size)
  mesh%stepint=mesh%lstep
  mesh%rad(1)=zero;mesh%radfact(1)=mesh%rstep
  do ir=2,mesh%mesh_size
   mesh%rad(ir) =-mesh%rstep*log(one-mesh%lstep*dble(ir-1))
   mesh%radfact(ir)=mesh%rstep/(one-mesh%lstep*dble(ir-1))
  end do
 end if

 hh=mesh%stepint/3.d0
 mesh%simfact(mesh%mesh_size)=hh*mesh%radfact(mesh%mesh_size)
 mesh%simfact(1:isim-2)=zero
 ir_last=1
 do ir=mesh%mesh_size,isim,-2
  mesh%simfact(ir-1)=4.d0*hh*mesh%radfact(ir-1)
  mesh%simfact(ir-2)=2.d0*hh*mesh%radfact(ir-2)
  ir_last=ir-2
 end do
 mesh%simfact(ir_last)=half*mesh%simfact(ir_last)

 mesh%rmax=mesh%rad(mesh%mesh_size)

end subroutine compmesh
!!***
