!{\src2tex{textfont=tt}}
!!****f* ABINIT/dtsetcopy
!! NAME
!! dtsetcopy
!!
!! FUNCTION
!! Copy all values of dataset dtin to dataset dtout. Pointers of dtout are
!! allocated if required. Use dtsetFree() to free a dataset after use.
!!
!! COPYRIGHT
!! Copyright (C) 1998-2006 ABINIT group (DCA, XG, GMR, MF, GZ)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  dtin <type(dataset_type)>=all input variables in this dataset
!!
!! OUTPUT
!!  dtout <type(dataset_type)>
!!
!! PARENTS
!!      afterscfloop,cvxclda,kxc_alda
!!
!! CHILDREN
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine dtsetCopy(dtout, dtin)

 use defs_basis
  use defs_datatypes

 implicit none

!Arguments ------------------------------------
!scalars
 type(dataset_type),intent(in) :: dtin
 type(dataset_type),intent(out) :: dtout

!Local variables-------------------------------

! *************************************************************************

  !Copy integers from dtin to dtout
  dtout%accesswff          = dtin%accesswff
  dtout%berryopt           = dtin%berryopt
  dtout%brvltt             = dtin%brvltt
  dtout%ceksph             = dtin%ceksph
  dtout%chkexit            = dtin%chkexit
  dtout%chkprim            = dtin%chkprim
  dtout%delayperm          = dtin%delayperm
  dtout%enunit             = dtin%enunit
  dtout%exchn2n3           = dtin%exchn2n3
  dtout%fft_opt_lob        = dtin%fft_opt_lob
  dtout%freqremax          = dtin%freqremax
  dtout%freqspmax          = dtin%freqspmax
  dtout%frzfermi           = dtin%frzfermi
  dtout%getacfd            = dtin%getacfd
  dtout%getcell            = dtin%getcell
  dtout%getddk             = dtin%getddk
  dtout%getden             = dtin%getden
  dtout%getkss             = dtin%getkss
  dtout%getocc             = dtin%getocc
  dtout%getqps             = dtin%getqps
  dtout%getscr             = dtin%getscr
  dtout%getvel             = dtin%getvel
  dtout%getwfk             = dtin%getwfk
  dtout%getwfq             = dtin%getwfq
  dtout%getxcart           = dtin%getxcart
  dtout%getxred            = dtin%getxred
  dtout%get1den            = dtin%get1den
  dtout%get1wf             = dtin%get1wf
  dtout%gpara              = dtin%gpara
  dtout%gwcalctyp          = dtin%gwcalctyp
  dtout%iboxcut            = dtin%iboxcut
  dtout%icoultrtmt         = dtin%icoultrtmt
  dtout%idyson             = dtin%idyson
  dtout%ikhxc              = dtin%ikhxc
  dtout%inclvkb            = dtin%inclvkb
  dtout%intexact           = dtin%intexact
  dtout%intxc              = dtin%intxc
  dtout%ionmov             = dtin%ionmov
  dtout%iprcch             = dtin%iprcch
  dtout%iprcel             = dtin%iprcel
  dtout%iprctfvw           = dtin%iprctfvw
  dtout%iprcfc             = dtin%iprcfc
  dtout%irdddk             = dtin%irdddk
  dtout%irdkss             = dtin%irdkss
  dtout%irdqps             = dtin%irdqps
  dtout%irdscr             = dtin%irdscr
  dtout%irdwfk             = dtin%irdwfk
  dtout%irdwfq             = dtin%irdwfq
  dtout%ird1wf             = dtin%ird1wf
  dtout%iscf               = dtin%iscf
  dtout%isecur             = dtin%isecur
  dtout%istatr             = dtin%istatr
  dtout%istatshft          = dtin%istatshft
  dtout%ixc                = dtin%ixc
  dtout%ixcpositron        = dtin%ixcpositron
  dtout%jdtset             = dtin%jdtset
  dtout%kpara              = dtin%kpara
  dtout%kptopt             = dtin%kptopt
  dtout%kssform            = dtin%kssform
  dtout%ldgapp             = dtin%ldgapp
  dtout%localrdwf          = dtin%localrdwf
  dtout%lofwrite           = dtin%lofwrite
  dtout%mband              = dtin%mband
  dtout%mffmem             = dtin%mffmem
  dtout%mgfft              = dtin%mgfft
  dtout%mgfftdg            = dtin%mgfftdg
  dtout%mkmem              = dtin%mkmem
  dtout%mkqmem             = dtin%mkqmem
  dtout%mk1mem             = dtin%mk1mem
  dtout%mpw                = dtin%mpw
  dtout%mqgrid             = dtin%mqgrid
  dtout%mqgriddg           = dtin%mqgriddg
  dtout%natom              = dtin%natom
  dtout%natrd              = dtin%natrd
  dtout%natsph             = dtin%natsph
  dtout%nbandsus           = dtin%nbandsus
  dtout%nbdblock           = dtin%nbdblock
  dtout%nbdbuf             = dtin%nbdbuf
  dtout%nberry             = dtin%nberry
  dtout%nbandkss           = dtin%nbandkss
  dtout%ncenter            = dtin%ncenter
  dtout%nconeq             = dtin%nconeq
  dtout%nctime             = dtin%nctime
  dtout%ndtset             = dtin%ndtset
  dtout%ndyson             = dtin%ndyson
  dtout%nfft               = dtin%nfft
  dtout%nfftdg             = dtin%nfftdg
  dtout%nfreqim            = dtin%nfreqim
  dtout%nfreqre            = dtin%nfreqre
  dtout%nfreqsp            = dtin%nfreqsp
  dtout%nfreqsus           = dtin%nfreqsus
  dtout%ngroup_rf          = dtin%ngroup_rf
  dtout%nkptgw             = dtin%nkptgw
  dtout%nkpt               = dtin%nkpt
  dtout%nline              = dtin%nline
  dtout%nnsclo             = dtin%nnsclo
  dtout%nomegasrd          = dtin%nomegasrd
  dtout%norb               = dtin%norb
  dtout%npack              = dtin%npack
  dtout%npara              = dtin%npara
  dtout%npsp               = dtin%npsp
  dtout%npspalch           = dtin%npspalch
  dtout%npulayit           = dtin%npulayit
  dtout%npweps             = dtin%npweps
  dtout%npwkss             = dtin%npwkss
  dtout%npwsigx            = dtin%npwsigx
  dtout%npwwfn             = dtin%npwwfn
  dtout%nqpt               = dtin%nqpt
  dtout%nqptdm             = dtin%nqptdm
  dtout%nscforder          = dtin%nscforder
  dtout%nsheps             = dtin%nsheps
  dtout%nshiftk            = dtin%nshiftk
  dtout%nshsigx            = dtin%nshsigx
  dtout%nshwfn             = dtin%nshwfn
  dtout%nspden             = dtin%nspden
  dtout%nspinor            = dtin%nspinor
  dtout%nsppol             = dtin%nsppol
  dtout%nstep              = dtin%nstep
  dtout%nsym               = dtin%nsym
  dtout%ntime              = dtin%ntime
  dtout%ntypalch           = dtin%ntypalch
  dtout%ntypat             = dtin%ntypat
  dtout%ntyppure           = dtin%ntyppure
  dtout%occopt             = dtin%occopt
  dtout%optcell            = dtin%optcell
  dtout%optdriver          = dtin%optdriver
  dtout%optforces          = dtin%optforces
  dtout%optfreqsus         = dtin%optfreqsus
  dtout%optnlxccc          = dtin%optnlxccc
  dtout%optstress          = dtin%optstress
  dtout%ortalg             = dtin%ortalg
  dtout%outputXML          = dtin%outputXML
  dtout%paral_rf           = dtin%paral_rf
  dtout%parareel           = dtin%parareel
  dtout%pawlcutd           = dtin%pawlcutd
  dtout%pawlmix            = dtin%pawlmix
  dtout%pawnphi            = dtin%pawnphi
  dtout%pawntheta          = dtin%pawntheta
  dtout%pawnzlm            = dtin%pawnzlm
  dtout%pawoptmix          = dtin%pawoptmix
  dtout%pawprtvol          = dtin%pawprtvol
  dtout%pawxcdev           = dtin%pawxcdev
  dtout%positron           = dtin%positron
  dtout%ppmodel            = dtin%ppmodel
  dtout%prepanl            = dtin%prepanl
  dtout%prtacfd            = dtin%prtacfd
  dtout%prtbbb             = dtin%prtbbb
  dtout%prtcml             = dtin%prtcml
  dtout%prtden             = dtin%prtden
  dtout%prtdos             = dtin%prtdos
  dtout%prteig             = dtin%prteig
  dtout%prtfsurf           = dtin%prtfsurf
  dtout%prtgeo             = dtin%prtgeo
  dtout%prtgkk             = dtin%prtgkk
  dtout%prtkpt             = dtin%prtkpt
  dtout%prtpot             = dtin%prtpot
  dtout%prtstm             = dtin%prtstm
  dtout%prtvha             = dtin%prtvha
  dtout%prtvhxc            = dtin%prtvhxc
  dtout%prtvol             = dtin%prtvol
  dtout%prtvxc             = dtin%prtvxc
  dtout%prtwant            = dtin%prtwant
  dtout%prtwf              = dtin%prtwf
  dtout%prt1dm             = dtin%prt1dm
  dtout%ptgroupma          = dtin%ptgroupma
  dtout%restartxf          = dtin%restartxf
  dtout%rfasr              = dtin%rfasr
  dtout%rfelfd             = dtin%rfelfd
  dtout%rfmeth             = dtin%rfmeth
  dtout%rfphon             = dtin%rfphon
  dtout%rfstrs             = dtin%rfstrs
  dtout%rfthrd             = dtin%rfthrd
  dtout%rfuser             = dtin%rfuser
  dtout%rf1elfd            = dtin%rf1elfd
  dtout%rf1phon            = dtin%rf1phon
  dtout%rf2elfd            = dtin%rf2elfd
  dtout%rf2phon            = dtin%rf2phon
  dtout%rf3elfd            = dtin%rf3elfd
  dtout%rf3phon            = dtin%rf3phon
  dtout%signperm           = dtin%signperm
  dtout%spgaxor            = dtin%spgaxor
  dtout%spgorig            = dtin%spgorig
  dtout%spgroup            = dtin%spgroup
  dtout%splitsigc          = dtin%splitsigc
  dtout%suskxcrs           = dtin%suskxcrs
  dtout%symmorphi          = dtin%symmorphi
  dtout%td_mexcit          = dtin%td_mexcit
  dtout%tfkinfunc          = dtin%tfkinfunc
  dtout%timopt             = dtin%timopt
  dtout%usepaw             = dtin%usepaw
  dtout%useria             = dtin%useria
  dtout%userib             = dtin%userib
  dtout%useric             = dtin%useric
  dtout%userid             = dtin%userid
  dtout%userie             = dtin%userie
  dtout%useylm             = dtin%useylm
  dtout%vacnum             = dtin%vacnum
  dtout%wfoptalg           = dtin%wfoptalg
  !Copy allocated integer arrays from dtin to dtout
  dtout%bdberry(:)         = dtin%bdberry(:)
  dtout%dsifkpt(:)         = dtin%dsifkpt(:)
  dtout%kptrlatt(:,:)      = dtin%kptrlatt(:,:)
  dtout%ngfft(:)           = dtin%ngfft(:)
  dtout%ngfftdg(:)         = dtin%ngfftdg(:)
  dtout%nloalg(:)          = dtin%nloalg(:)
  dtout%qprtrb(:)          = dtin%qprtrb(:)
  dtout%rfatpol(:)         = dtin%rfatpol(:)
  dtout%rfdir(:)           = dtin%rfdir(:)
  dtout%rf1atpol(:)        = dtin%rf1atpol(:)
  dtout%rf1dir(:)          = dtin%rf1dir(:)
  dtout%rf2atpol(:)        = dtin%rf2atpol(:)
  dtout%rf2dir(:)          = dtin%rf2dir(:)
  dtout%rf3atpol(:)        = dtin%rf3atpol(:)
  dtout%rf3dir(:)          = dtin%rf3dir(:)
  dtout%supercell(:)       = dtin%supercell(:)
  !Copy reals from dtin to dtout
  dtout%alpha              = dtin%alpha
  dtout%boxcutmin          = dtin%boxcutmin
  dtout%bxctmindg          = dtin%bxctmindg
  dtout%charge             = dtin%charge
  dtout%cpus               = dtin%cpus
  dtout%dedlnn             = dtin%dedlnn
  dtout%diecut             = dtin%diecut
  dtout%diegap             = dtin%diegap
  dtout%dielam             = dtin%dielam
  dtout%dielng             = dtin%dielng
  dtout%diemac             = dtin%diemac
  dtout%diemix             = dtin%diemix
  dtout%dilatmx            = dtin%dilatmx
  dtout%dosdeltae          = dtin%dosdeltae
  dtout%dtion              = dtin%dtion
  dtout%ecut               = dtin%ecut
  dtout%ecuteps            = dtin%ecuteps
  dtout%ecutsigx           = dtin%ecutsigx
  dtout%ecutsm             = dtin%ecutsm
  dtout%ecutwfn            = dtin%ecutwfn
  dtout%effmass            = dtin%effmass
  dtout%eshift             = dtin%eshift
  dtout%fband              = dtin%fband
  dtout%fixmom             = dtin%fixmom
  dtout%freqsusin          = dtin%freqsusin
  dtout%freqsuslo          = dtin%freqsuslo
  dtout%friction           = dtin%friction
  dtout%kptnrm             = dtin%kptnrm
  dtout%kptrlen            = dtin%kptrlen
  dtout%mdftemp            = dtin%mdftemp
  dtout%mditemp            = dtin%mditemp
  dtout%mdwall             = dtin%mdwall
  dtout%nelect             = dtin%nelect
  dtout%noseinert          = dtin%noseinert
  dtout%omegasrdmax        = dtin%omegasrdmax
  dtout%pawecutdg          = dtin%pawecutdg
  dtout%pawovlp            = dtin%pawovlp
  dtout%pawsphmix          = dtin%pawsphmix
  dtout%ppmfrq             = dtin%ppmfrq
  dtout%qptnrm             = dtin%qptnrm
  dtout%ratsph             = dtin%ratsph
  dtout%sciss              = dtin%sciss
  dtout%soenergy           = dtin%soenergy
  dtout%stmbias            = dtin%stmbias
  dtout%strfact            = dtin%strfact
  dtout%strprecon          = dtin%strprecon
  dtout%td_maxene          = dtin%td_maxene
  dtout%tfnewton           = dtin%tfnewton
  dtout%toldfe             = dtin%toldfe
  dtout%toldff             = dtin%toldff
  dtout%tolmxf             = dtin%tolmxf
  dtout%tolvrs             = dtin%tolvrs
  dtout%tolwfr             = dtin%tolwfr
  dtout%tphysel            = dtin%tphysel
  dtout%tsmear             = dtin%tsmear
  dtout%userra             = dtin%userra
  dtout%userrb             = dtin%userrb
  dtout%userrc             = dtin%userrc
  dtout%userrd             = dtin%userrd
  dtout%userre             = dtin%userre
  dtout%vacwidth           = dtin%vacwidth
  dtout%vis                = dtin%vis
  dtout%zcut               = dtin%zcut
  !Copy allocated real arrays from dtin to dtout
  dtout%acell_orig(:)      = dtin%acell_orig(:)
  dtout%angdeg_orig(:)     = dtin%angdeg_orig(:)
  dtout%boxcenter(:)       = dtin%boxcenter(:)
  dtout%efield(:)          = dtin%efield(:)
  dtout%genafm(:)          = dtin%genafm(:)
  dtout%qpt(:)             = dtin%qpt(:)
  dtout%qptn(:)            = dtin%qptn(:)
  dtout%rprim_orig(:,:)    = dtin%rprim_orig(:,:)
  dtout%rprimd_orig(:,:)   = dtin%rprimd_orig(:,:)
  dtout%strtarget(:)       = dtin%strtarget(:)
  dtout%vprtrb(:)          = dtin%vprtrb(:)
  !Allocate and copy integer pointers
  if (associated(dtin%algalch)) then
    allocate(dtout%algalch( size(dtin%algalch, 1) ))
  end if
  dtout%algalch(:)         = dtin%algalch(:)
  if (associated(dtin%bdgw)) then
    allocate(dtout%bdgw( size(dtin%bdgw, 1) ,  size(dtin%bdgw, 2) ))
  end if
  dtout%bdgw(:,:)          = dtin%bdgw(:,:)
  if (associated(dtin%iatfix)) then
    allocate(dtout%iatfix( size(dtin%iatfix, 1) ,  size(dtin%iatfix, 2) ))
  end if
  dtout%iatfix(:,:)        = dtin%iatfix(:,:)
  if (associated(dtin%iatsph)) then
    allocate(dtout%iatsph( size(dtin%iatsph, 1) ))
  end if
  dtout%iatsph(:)          = dtin%iatsph(:)
  if (associated(dtin%istwfk)) then
    allocate(dtout%istwfk( size(dtin%istwfk, 1) ))
  end if
  dtout%istwfk(:)          = dtin%istwfk(:)
  if (associated(dtin%kberry)) then
    allocate(dtout%kberry( size(dtin%kberry, 1) ,  size(dtin%kberry, 2) ))
  end if
  dtout%kberry(:,:)        = dtin%kberry(:,:)
  if (associated(dtin%ltypeorb)) then
    allocate(dtout%ltypeorb( size(dtin%ltypeorb, 1) ))
  end if
  dtout%ltypeorb(:)        = dtin%ltypeorb(:)
  if (associated(dtin%nband)) then
    allocate(dtout%nband( size(dtin%nband, 1) ))
  end if
  dtout%nband(:)           = dtin%nband(:)
  if (associated(dtin%numorb)) then
    allocate(dtout%numorb( size(dtin%numorb, 1) ))
  end if
  dtout%numorb(:)          = dtin%numorb(:)
  if (associated(dtin%so_typat)) then
    allocate(dtout%so_typat( size(dtin%so_typat, 1) ))
  end if
  dtout%so_typat(:)        = dtin%so_typat(:)
  if (associated(dtin%symafm)) then
    allocate(dtout%symafm( size(dtin%symafm, 1) ))
  end if
  dtout%symafm(:)          = dtin%symafm(:)
  if (associated(dtin%symrel)) then
    allocate(dtout%symrel( size(dtin%symrel, 1) ,  size(dtin%symrel, 2) ,  size(dtin%symrel, 3) ))
  end if
  dtout%symrel(:,:,:)      = dtin%symrel(:,:,:)
  if (associated(dtin%typat)) then
    allocate(dtout%typat( size(dtin%typat, 1) ))
  end if
  dtout%typat(:)           = dtin%typat(:)
  !Allocate and copy real pointers
  if (associated(dtin%amu)) then
    allocate(dtout%amu( size(dtin%amu, 1) ))
  end if
  dtout%amu(:)             = dtin%amu(:)
  if (associated(dtin%densty)) then
    allocate(dtout%densty( size(dtin%densty, 1) ,  size(dtin%densty, 2) ))
  end if
  dtout%densty(:,:)        = dtin%densty(:,:)
  if (associated(dtin%kpt)) then
    allocate(dtout%kpt( size(dtin%kpt, 1) ,  size(dtin%kpt, 2) ))
  end if
  dtout%kpt(:,:)           = dtin%kpt(:,:)
  if (associated(dtin%kptgw)) then
    allocate(dtout%kptgw( size(dtin%kptgw, 1) ,  size(dtin%kptgw, 2) ))
  end if
  dtout%kptgw(:,:)         = dtin%kptgw(:,:)
  if (associated(dtin%kptns)) then
    allocate(dtout%kptns( size(dtin%kptns, 1) ,  size(dtin%kptns, 2) ))
  end if
  dtout%kptns(:,:)         = dtin%kptns(:,:)
  if (associated(dtin%mixalch)) then
    allocate(dtout%mixalch( size(dtin%mixalch, 1) ,  size(dtin%mixalch, 2) ))
  end if
  dtout%mixalch(:,:)       = dtin%mixalch(:,:)
  if (associated(dtin%occ_orig)) then
    allocate(dtout%occ_orig( size(dtin%occ_orig, 1) ))
  end if
  dtout%occ_orig(:)        = dtin%occ_orig(:)
  if (associated(dtin%qptdm)) then
    allocate(dtout%qptdm( size(dtin%qptdm, 1) ,  size(dtin%qptdm, 2) ))
  end if
  dtout%qptdm(:,:)         = dtin%qptdm(:,:)
  if (associated(dtin%rcoord)) then
    allocate(dtout%rcoord( size(dtin%rcoord, 1) ,  size(dtin%rcoord, 2) ))
  end if
  dtout%rcoord(:,:)        = dtin%rcoord(:,:)
  if (associated(dtin%rtheta)) then
    allocate(dtout%rtheta( size(dtin%rtheta, 1) ,  size(dtin%rtheta, 2) ))
  end if
  dtout%rtheta(:,:)        = dtin%rtheta(:,:)
  if (associated(dtin%shiftk)) then
    allocate(dtout%shiftk( size(dtin%shiftk, 1) ,  size(dtin%shiftk, 2) ))
  end if
  dtout%shiftk(:,:)        = dtin%shiftk(:,:)
  if (associated(dtin%spinat)) then
    allocate(dtout%spinat( size(dtin%spinat, 1) ,  size(dtin%spinat, 2) ))
  end if
  dtout%spinat(:,:)        = dtin%spinat(:,:)
  if (associated(dtin%tnons)) then
    allocate(dtout%tnons( size(dtin%tnons, 1) ,  size(dtin%tnons, 2) ))
  end if
  dtout%tnons(:,:)         = dtin%tnons(:,:)
  if (associated(dtin%vel_orig)) then
    allocate(dtout%vel_orig( size(dtin%vel_orig, 1) ,  size(dtin%vel_orig, 2) ))
  end if
  dtout%vel_orig(:,:)      = dtin%vel_orig(:,:)
  if (associated(dtin%wtatcon)) then
    allocate(dtout%wtatcon( size(dtin%wtatcon, 1) ,  size(dtin%wtatcon, 2) ,  size(dtin%wtatcon, 3) ))
  end if
  dtout%wtatcon(:,:,:)     = dtin%wtatcon(:,:,:)
  if (associated(dtin%wtk)) then
    allocate(dtout%wtk( size(dtin%wtk, 1) ))
  end if
  dtout%wtk(:)             = dtin%wtk(:)
  if (associated(dtin%xred_orig)) then
    allocate(dtout%xred_orig( size(dtin%xred_orig, 1) ,  size(dtin%xred_orig, 2) ))
  end if
  dtout%xred_orig(:,:)     = dtin%xred_orig(:,:)
  if (associated(dtin%ziontypat)) then
    allocate(dtout%ziontypat( size(dtin%ziontypat, 1) ))
  end if
  dtout%ziontypat(:)       = dtin%ziontypat(:)
  if (associated(dtin%znucl)) then
    allocate(dtout%znucl( size(dtin%znucl, 1) ))
  end if
  dtout%znucl(:)           = dtin%znucl(:)

end subroutine dtsetCopy
!!***
