!{\src2tex{textfont=tt}}
!!****f* ABINIT/print_ij
!! NAME
!! print_ij
!!
!! FUNCTION
!! Print ij_ symmetric matrixes in a "suitable" format
!! Data are "energy-like" in Hartree units.
!!
!! COPYRIGHT
!! Copyright (C) 1998-2006 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  a_ij(adim)= input symmetric square matrix
!!  adim= dimension of array a_ij:
!!        adim=ndim*(ndim+1)/2                   if opt_packed=0
!!        adim=number of non-zero values of a_ij if opt_packed=1
!!  ndim= dimension of input square matrix
!!  opt_io= if opt_io=1, output to standard output only
!!          if opt_io=2, output to standard output and ab_out file
!!  opt_pack= 1 if a_ij is in "packed storage"
!!              (i.e. only non-zero values are stored in array pr_dij)
!!  pack2ij(adim)= gives the (i,j) index of of packed value of rhoij
!!                 used only if opt_packed=1
!!  unt= unit of output: if 1, no change (output is in Hartree)
!!                       if 2, output is in eV
!!
!! OUTPUT
!!
!! SIDE EFFECTS
!!
!! PARENTS
!!      hdr_io,pawdij,pawmkrhoij,pawprt,symdij,symrhoij
!!
!! CHILDREN
!!      wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine print_ij(a_ij,adim,ndim,opt_io,opt_pack,pack2ij,unt)

 use defs_basis

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
#endif
!End of the abilint section

 implicit none

!Arguments ---------------------------------------------
!scalars
 integer,intent(in) :: adim,ndim,opt_io,opt_pack,unt
!arrays
 integer,intent(in) :: pack2ij(adim*opt_pack)
 real(dp),intent(in) :: a_ij(adim)

!Local variables ---------------------------------------
! Adjust format bellow according to maxprt
!scalars
 integer,parameter :: maxprt=12
 integer :: id,ilmn,j0lmn,jlmn,klmn,nmin
 character(len=500) :: message
!arrays
 real(dp),allocatable :: prtab(:,:)

! *************************************************************************

!Change this according to variable "maxprt"
10 format(12(1x,f9.5))
11 format(12(1x,f9.5),a)

 nmin=min(ndim,maxprt)
 allocate(prtab(nmin,nmin))

 id=1
 do jlmn=1,nmin
  j0lmn=jlmn*(jlmn-1)/2
  do ilmn=1,jlmn
   klmn=j0lmn+ilmn
   if (opt_pack==0) then
    prtab(jlmn,ilmn)=a_ij(klmn)
   elseif (klmn==pack2ij(id)) then
    prtab(jlmn,ilmn)=a_ij(id)
    id=id+1;if (id>adim+1) stop 'BUG in print_ij'
   else
    prtab(jlmn,ilmn)=zero
   end if
   prtab(ilmn,jlmn)=prtab(jlmn,ilmn)
  end do
 end do

 if (unt==2) prtab=prtab*Ha_eV
 if (ndim<=maxprt) then
  do ilmn=1,nmin
   write(message,fmt=10) prtab(ilmn,1:nmin)
   call wrtout(6,message,'COLL')
   if (opt_io==2) call wrtout(ab_out,message,'COLL')
  end do
 else
  do ilmn=1,nmin
   write(message,fmt=11) prtab(ilmn,1:nmin),' ...'
   call wrtout(6,message,'COLL')
   if (opt_io==2) call wrtout(ab_out,message,'COLL')
  end do
  write(message,'(3x,a,i2,a)') '...  only ',maxprt,'  components have been written...'
   call wrtout(6,message,'COLL')
   if (opt_io==2) call wrtout(ab_out,message,'COLL')
 end if

 deallocate(prtab)

end subroutine print_ij
!!***
