!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_data_read
!! NAME
!! netcdf_data_read
!!
!! FUNCTION
!!  Reads data from a specified NetCDF identifier.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (Y. Pouillon)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid   = identifier of the file to read
!!  blocks = logical OR combination of datatypes (see Src_defs/defs_netcdf)
!!             to get from the file
!!  dtset <type(dataset_type)> = dataset to get (optional)
!!  wfs(:,:)                   = set of wavefunctions to get (optional)
!!  den(:,:)                   = charge density to get (optional)
!!  acfd <type(ncacfd_type)>   = ACFD data block to get (optional)
!!
!! OUTPUT
!!  (no direct output : data written to a NetCDF file)
!!
!! NOTES
!!  With this implementation, you can build a modular file containing
!!  precisely what you need.
!!
!!  By default the routine will try to create the file. In case a file
!!  of the same name already exists, the program will stop.
!!
!!  The current implementation is very basic.
!!
!! PARENTS
!!      xcacfd
!!
!! CHILDREN
!!      netcdf_handle_error,leave_new,netcdf_put_acfd,netcdf_put_den,netcdf_put_dtset
!!      netcdf_put_wfs,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_data_read(ncid,blocks,dtset,wfs,den,acfd)

 use defs_basis
 use defs_datatypes
 use defs_netcdf

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_data_read
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: blocks,ncid
 type(dataset_type),intent(inout),optional :: dtset
 type(ncacfd_type),intent(inout),optional :: acfd
!arrays
 real(dp),intent(inout),optional :: den(:,:),wfs(:,:)

!Local variables-------------------------------
!scalars
 integer :: i
 character(len=500) :: message
 type(dataset_type),pointer :: my_dtset
 type(ncacfd_type),pointer :: my_acfd
!arrays
 real(dp),pointer :: my_den(:,:),my_wfs(:,:)

! ***************************************************************************

 ! Check arguments
 if ( present(dtset) ) then
  my_dtset = dtset
 else
  nullify(my_dtset)
 end if
 if ( present(wfs) ) then
  my_wfs(:,:) = wfs(:,:)
 else
  nullify(my_wfs)
 end if
 if ( present(den) ) then
  my_den(:,:) = den(:,:)
 else
  nullify(my_den)
 end if
 if ( present(acfd) ) then
  my_acfd = acfd
 else
  nullify(my_acfd)
 end if

 ! Read the specified blocks
 do i=0,NCBLKS-1
  select case ( iand(blocks,2**i) )

   case ( 0 )
    ! Do nothing

   !case ( NCBLK_HEADER )
   ! call netcdf_get_header(ncid)

   case ( NCBLK_DATASET )
    if ( associated(my_dtset) ) then
     call netcdf_get_dtset(ncid,my_dtset)
    end if

   !case ( NCBLK_SYSTEM )
   ! call netcdf_get_system(ncid,dims)

   case ( NCBLK_WFS )
    if ( associated(my_wfs) ) then
     call netcdf_get_wfs(ncid,my_wfs)
    end if

   case ( NCBLK_DENSITY )
    if ( associated(my_den) ) then
     call netcdf_get_den(ncid,my_den)
    end if

   case ( NCBLK_ACFD )
    if ( associated(my_acfd) ) then
     call netcdf_get_acfd(ncid,my_acfd)
    end if

   case default
    write(message,'(4a,i0)') ch10,' netcdf_data_read - ERROR',ch10,&
&    'Unknown datatype block value: ',2**i
    call wrtout(std_out,message,'COLL')
    call leave_new('COLL')

  end select
 end do

end subroutine netcdf_data_read
!!***
