!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_def_acfd
!! NAME
!! netcdf_def_acfd
!!
!! FUNCTION
!!  Prepares a specified NetCDF file to store ACFD data.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (YP)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!  filename = name of the file where data will be written
!!  acfd_dims(2) = dimensions of the ACFD data
!!   1: nfreqsus
!!  createfile = whether or not create the file
!!
!! OUTPUT
!!  (no direct output : data written to a NetCDF file)
!!
!! NOTES
!!  Pouring data into the file is performed by the netcdf_put_acfd routine.
!!
!! PARENTS
!!      netcdf_file_create
!!
!! CHILDREN
!!      netcdf_handle_error,leave_new,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_def_acfd(ncid,nfreqsus,npw_tiny)

 use defs_basis
#if defined HAVE_NETCDF
 use netcdf
#endif

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_def_acfd
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid,nfreqsus,npw_tiny

!Local variables-------------------------------
!scalars
 integer :: ncerr,ncvar
 character(len=500) :: message
!arrays
 integer :: ncdims(2)

! ***************************************************************************

#if defined HAVE_NETCDF
 ! Dimensions
 ncerr = nf90_def_dim(ncid,name='nfreqsus',len=nfreqsus,dimid=ncdims(1))
 call netcdf_handle_error('DEF','DIM','nfreqsus','netcdf_def_acfd',ncerr)
 ncerr = nf90_def_dim(ncid,name='npw_tiny',len=npw_tiny,dimid=ncdims(2))
 call netcdf_handle_error('DEF','DIM','npw_tiny','netcdf_def_acfd',ncerr)

 ! Frequency mesh
 ncerr = nf90_def_var(ncid,name='freqs',xtype=NF90_DOUBLE,dimids=ncdims(1),varid=ncvar)
 call netcdf_handle_error('DEF','VAR','freqs','netcdf_def_acfd',ncerr)
 ncerr = nf90_def_var(ncid,name='weights',xtype=NF90_DOUBLE,dimids=ncdims(1),varid=ncvar)
 call netcdf_handle_error('DEF','VAR','weights','netcdf_def_acfd',ncerr)

 ! Status
 ncerr = nf90_def_var(ncid,name='ifreq',xtype=NF90_INT,varid=ncvar)
 call netcdf_handle_error('DEF','VAR','ifreq','netcdf_def_acfd',ncerr)

 ! Energies: ex_cc,ecs_cc,ecgl_cc,ecs_uc,ecgl_uc,n_test
 ncerr = nf90_def_var(ncid,name='ex_cc',xtype=NF90_DOUBLE,varid=ncvar)
 call netcdf_handle_error('DEF','VAR','ex_cc','netcdf_def_acfd',ncerr)
 ncerr = nf90_def_var(ncid,name='ecs_cc',xtype=NF90_DOUBLE,varid=ncvar)
 call netcdf_handle_error('DEF','VAR','ecs_cc','netcdf_def_acfd',ncerr)
 ncerr = nf90_def_var(ncid,name='ecgl_cc',xtype=NF90_DOUBLE,varid=ncvar)
 call netcdf_handle_error('DEF','VAR','ecgl_cc','netcdf_def_acfd',ncerr)
 ncerr = nf90_def_var(ncid,name='ecs_uc',xtype=NF90_DOUBLE,dimids=ncdims(2),varid=ncvar)
 call netcdf_handle_error('DEF','VAR','ecs_uc','netcdf_def_acfd',ncerr)
 ncerr = nf90_def_var(ncid,name='ecgl_uc',xtype=NF90_DOUBLE,dimids=ncdims(2),varid=ncvar)
 call netcdf_handle_error('DEF','VAR','ecgl_uc','netcdf_def_acfd',ncerr)
 ncerr = nf90_def_var(ncid,name='n_test',xtype=NF90_DOUBLE,varid=ncvar)
 call netcdf_handle_error('DEF','VAR','n_test','netcdf_def_acfd',ncerr)
#else
 write(message,'(4a)') ch10,' netcdf_def_acfd - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_def_acfd
!!***
