!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_def_den
!! NAME
!! netcdf_def_den
!!
!! FUNCTION
!!  Prepares a specified NetCDF file to store a charge density.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (YP)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!  den_dims(2) = dimensions of the charge density
!!  createfile = whether or not create the file
!!
!! OUTPUT
!!  (no direct output : data written to a NetCDF file)
!!
!! NOTES
!!  Pouring data into the file is performed by the netcdf_put_den routine.
!!
!! PARENTS
!!      netcdf_file_create
!!
!! CHILDREN
!!      leave_new,netcdf_handle_error,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_def_den(ncid,nfft,nspden)

 use defs_basis
#if defined HAVE_NETCDF
 use netcdf
#endif

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_def_den
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid,nfft,nspden

!Local variables-------------------------------
!scalars
 integer :: ncerr,ncvar
 character(len=500) :: message
!arrays
 integer :: ncdims(2)

! ***************************************************************************
#if defined HAVE_NETCDF
 ! Dimensions
 ncerr = nf90_def_dim(ncid,name='nfft',len=nfft,dimid=ncdims(1))
 call netcdf_handle_error('DEF','DIM','nfft','netcdf_def_den',ncerr)
 ncerr = nf90_def_dim(ncid,name='nspden',len=nspden,dimid=ncdims(2))
 call netcdf_handle_error('DEF','DIM','nspden','netcdf_def_den',ncerr)

 ! Density
 ncerr = nf90_def_var(ncid,name='rhor',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
 call netcdf_handle_error('DEF','VAR','rhor','netcdf_def_den',ncerr)
#else
 write(message,'(4a)') ch10,' netcdf_def_den - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_def_den
!!***
