!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_def_dtset
!! NAME
!! netcdf_def_dtset
!!
!! FUNCTION
!!  Prepares a specified NetCDF file to store a dataset.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (Y. Pouillon)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!  dims <type(vardims_type)> = dimensions of dataset variables
!!
!! OUTPUT
!!  (no direct output : data written to a NetCDF file)
!!
!! NOTES
!!  Pouring data into the file is performed by the netcdf_put_dtset routine.
!!
!!  Please do not edit this file. Since it is automatically generated (see
!!  the makencdf script), your changes would be systematically overwritten.
!!  Instead you should directly modify the generating script itself
!!  (~abinit/scripts/netcdf/netcdf_def_dtset.pl) to suit your needs.
!!
!! PARENTS
!!
!! CHILDREN
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_def_dtset(ncid,dims)

#if defined HAVE_NETCDF
 use netcdf
#endif
 use defs_basis
 use defs_datatypes



!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_def_dtset
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid
 type(vardims_type),intent(in) :: dims

!Local variables-------------------------------
!scalars
 character(len=*),parameter :: my_name = 'netcdf_def_dtset'
 integer :: ncerr,ncvar
 character(len=500) :: message
!arrays
 integer,allocatable :: ncdims(:)

! ***************************************************************************

#if defined HAVE_NETCDF
  ! Define accesswff
  ncerr = nf90_def_var(ncid,name='accesswff',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','accesswff',my_name,ncerr)
  ! Define dimensions of acell_orig
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='acell_orig_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','acell_orig_dim1',my_name,ncerr)
  ! Define acell_orig
  ncerr = nf90_def_var(ncid,name='acell_orig',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','acell_orig',my_name,ncerr)
  ! Define dimensions of algalch
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='ntypalch',len=dims%ntypalch,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','ntypalch',my_name,ncerr)
  ! Define algalch
  ncerr = nf90_def_var(ncid,name='algalch',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','algalch',my_name,ncerr)
  ! Define alpha
  ncerr = nf90_def_var(ncid,name='alpha',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','alpha',my_name,ncerr)
  ! Define dimensions of amu
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='ntypat',len=dims%ntypat,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','ntypat',my_name,ncerr)
  ! Define amu
  ncerr = nf90_def_var(ncid,name='amu',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','amu',my_name,ncerr)
  ! Define dimensions of angdeg_orig
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='angdeg_orig_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','angdeg_orig_dim1',my_name,ncerr)
  ! Define angdeg_orig
  ncerr = nf90_def_var(ncid,name='angdeg_orig',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','angdeg_orig',my_name,ncerr)
  ! Define dimensions of bdberry
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='bdberry_dim1',len=4,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','bdberry_dim1',my_name,ncerr)
  ! Define bdberry
  ncerr = nf90_def_var(ncid,name='bdberry',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','bdberry',my_name,ncerr)
  ! Define dimensions of bdgw
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='bdgw_dim1',len=2,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','bdgw_dim1',my_name,ncerr)
  ncerr = nf90_def_dim(ncid,name='nkptgw',len=dims%nkptgw,dimid=ncdims(2))
  call netcdf_handle_error('DEF','DIM','nkptgw',my_name,ncerr)
  ! Define bdgw
  ncerr = nf90_def_var(ncid,name='bdgw',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','bdgw',my_name,ncerr)
  ! Define berryopt
  ncerr = nf90_def_var(ncid,name='berryopt',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','berryopt',my_name,ncerr)
  ! Define dimensions of boxcenter
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='boxcenter_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','boxcenter_dim1',my_name,ncerr)
  ! Define boxcenter
  ncerr = nf90_def_var(ncid,name='boxcenter',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','boxcenter',my_name,ncerr)
  ! Define boxcutmin
  ncerr = nf90_def_var(ncid,name='boxcutmin',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','boxcutmin',my_name,ncerr)
  ! Define brvltt
  ncerr = nf90_def_var(ncid,name='brvltt',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','brvltt',my_name,ncerr)
  ! Define bxctmindg
  ncerr = nf90_def_var(ncid,name='bxctmindg',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','bxctmindg',my_name,ncerr)
  ! Define ceksph
  ncerr = nf90_def_var(ncid,name='ceksph',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ceksph',my_name,ncerr)
  ! Define charge
  ncerr = nf90_def_var(ncid,name='charge',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','charge',my_name,ncerr)
  ! Define chkexit
  ncerr = nf90_def_var(ncid,name='chkexit',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','chkexit',my_name,ncerr)
  ! Define chkprim
  ncerr = nf90_def_var(ncid,name='chkprim',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','chkprim',my_name,ncerr)
  ! Define cpus
  ncerr = nf90_def_var(ncid,name='cpus',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','cpus',my_name,ncerr)
  ! Define dedlnn
  ncerr = nf90_def_var(ncid,name='dedlnn',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','dedlnn',my_name,ncerr)
  ! Define delayperm
  ncerr = nf90_def_var(ncid,name='delayperm',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','delayperm',my_name,ncerr)
  ! Define dimensions of densty
  allocate(ncdims(2))
  ncerr = nf90_inq_dimid(ncid,name='ntypat',dimid=ncdims(1))
  call netcdf_handle_error('INQ','DIM','ntypat',my_name,ncerr)
  ncerr = nf90_def_dim(ncid,name='densty_dim2',len=4,dimid=ncdims(2))
  call netcdf_handle_error('DEF','DIM','densty_dim2',my_name,ncerr)
  ! Define densty
  ncerr = nf90_def_var(ncid,name='densty',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','densty',my_name,ncerr)
  ! Define diecut
  ncerr = nf90_def_var(ncid,name='diecut',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','diecut',my_name,ncerr)
  ! Define diegap
  ncerr = nf90_def_var(ncid,name='diegap',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','diegap',my_name,ncerr)
  ! Define dielam
  ncerr = nf90_def_var(ncid,name='dielam',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','dielam',my_name,ncerr)
  ! Define dielng
  ncerr = nf90_def_var(ncid,name='dielng',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','dielng',my_name,ncerr)
  ! Define diemac
  ncerr = nf90_def_var(ncid,name='diemac',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','diemac',my_name,ncerr)
  ! Define diemix
  ncerr = nf90_def_var(ncid,name='diemix',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','diemix',my_name,ncerr)
  ! Define dilatmx
  ncerr = nf90_def_var(ncid,name='dilatmx',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','dilatmx',my_name,ncerr)
  ! Define dosdeltae
  ncerr = nf90_def_var(ncid,name='dosdeltae',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','dosdeltae',my_name,ncerr)
  ! Define dimensions of dsifkpt
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='dsifkpt_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','dsifkpt_dim1',my_name,ncerr)
  ! Define dsifkpt
  ncerr = nf90_def_var(ncid,name='dsifkpt',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','dsifkpt',my_name,ncerr)
  ! Define dtion
  ncerr = nf90_def_var(ncid,name='dtion',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','dtion',my_name,ncerr)
  ! Define ecut
  ncerr = nf90_def_var(ncid,name='ecut',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ecut',my_name,ncerr)
  ! Define ecuteps
  ncerr = nf90_def_var(ncid,name='ecuteps',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ecuteps',my_name,ncerr)
  ! Define ecutsigx
  ncerr = nf90_def_var(ncid,name='ecutsigx',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ecutsigx',my_name,ncerr)
  ! Define ecutsm
  ncerr = nf90_def_var(ncid,name='ecutsm',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ecutsm',my_name,ncerr)
  ! Define ecutwfn
  ncerr = nf90_def_var(ncid,name='ecutwfn',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ecutwfn',my_name,ncerr)
  ! Define effmass
  ncerr = nf90_def_var(ncid,name='effmass',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','effmass',my_name,ncerr)
  ! Define dimensions of efield
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='efield_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','efield_dim1',my_name,ncerr)
  ! Define efield
  ncerr = nf90_def_var(ncid,name='efield',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','efield',my_name,ncerr)
  ! Define enunit
  ncerr = nf90_def_var(ncid,name='enunit',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','enunit',my_name,ncerr)
  ! Define eshift
  ncerr = nf90_def_var(ncid,name='eshift',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','eshift',my_name,ncerr)
  ! Define exchn2n3
  ncerr = nf90_def_var(ncid,name='exchn2n3',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','exchn2n3',my_name,ncerr)
  ! Define fband
  ncerr = nf90_def_var(ncid,name='fband',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','fband',my_name,ncerr)
  ! Define fft_opt_lob
  ncerr = nf90_def_var(ncid,name='fft_opt_lob',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','fft_opt_lob',my_name,ncerr)
  ! Define fixmom
  ncerr = nf90_def_var(ncid,name='fixmom',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','fixmom',my_name,ncerr)
  ! Define freqremax
  ncerr = nf90_def_var(ncid,name='freqremax',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','freqremax',my_name,ncerr)
  ! Define freqspmax
  ncerr = nf90_def_var(ncid,name='freqspmax',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','freqspmax',my_name,ncerr)
  ! Define freqsusin
  ncerr = nf90_def_var(ncid,name='freqsusin',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','freqsusin',my_name,ncerr)
  ! Define freqsuslo
  ncerr = nf90_def_var(ncid,name='freqsuslo',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','freqsuslo',my_name,ncerr)
  ! Define friction
  ncerr = nf90_def_var(ncid,name='friction',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','friction',my_name,ncerr)
  ! Define frzfermi
  ncerr = nf90_def_var(ncid,name='frzfermi',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','frzfermi',my_name,ncerr)
  ! Define dimensions of genafm
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='genafm_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','genafm_dim1',my_name,ncerr)
  ! Define genafm
  ncerr = nf90_def_var(ncid,name='genafm',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','genafm',my_name,ncerr)
  ! Define get1den
  ncerr = nf90_def_var(ncid,name='get1den',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','get1den',my_name,ncerr)
  ! Define get1wf
  ncerr = nf90_def_var(ncid,name='get1wf',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','get1wf',my_name,ncerr)
  ! Define getacfd
  ncerr = nf90_def_var(ncid,name='getacfd',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getacfd',my_name,ncerr)
  ! Define getcell
  ncerr = nf90_def_var(ncid,name='getcell',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getcell',my_name,ncerr)
  ! Define getddk
  ncerr = nf90_def_var(ncid,name='getddk',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getddk',my_name,ncerr)
  ! Define getden
  ncerr = nf90_def_var(ncid,name='getden',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getden',my_name,ncerr)
  ! Define getkss
  ncerr = nf90_def_var(ncid,name='getkss',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getkss',my_name,ncerr)
  ! Define getocc
  ncerr = nf90_def_var(ncid,name='getocc',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getocc',my_name,ncerr)
  ! Define getqps
  ncerr = nf90_def_var(ncid,name='getqps',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getqps',my_name,ncerr)
  ! Define getscr
  ncerr = nf90_def_var(ncid,name='getscr',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getscr',my_name,ncerr)
  ! Define getvel
  ncerr = nf90_def_var(ncid,name='getvel',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getvel',my_name,ncerr)
  ! Define getwfk
  ncerr = nf90_def_var(ncid,name='getwfk',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getwfk',my_name,ncerr)
  ! Define getwfq
  ncerr = nf90_def_var(ncid,name='getwfq',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getwfq',my_name,ncerr)
  ! Define getxcart
  ncerr = nf90_def_var(ncid,name='getxcart',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getxcart',my_name,ncerr)
  ! Define getxred
  ncerr = nf90_def_var(ncid,name='getxred',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','getxred',my_name,ncerr)
  ! Define gpara
  ncerr = nf90_def_var(ncid,name='gpara',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','gpara',my_name,ncerr)
  ! Define gwcalctyp
  ncerr = nf90_def_var(ncid,name='gwcalctyp',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','gwcalctyp',my_name,ncerr)
  ! Define dimensions of iatfix
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='iatfix_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','iatfix_dim1',my_name,ncerr)
  ncerr = nf90_def_dim(ncid,name='natom',len=dims%natom,dimid=ncdims(2))
  call netcdf_handle_error('DEF','DIM','natom',my_name,ncerr)
  ! Define iatfix
  ncerr = nf90_def_var(ncid,name='iatfix',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','iatfix',my_name,ncerr)
  ! Define dimensions of iatsph
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='natsph',len=dims%natsph,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','natsph',my_name,ncerr)
  ! Define iatsph
  ncerr = nf90_def_var(ncid,name='iatsph',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','iatsph',my_name,ncerr)
  ! Define iboxcut
  ncerr = nf90_def_var(ncid,name='iboxcut',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','iboxcut',my_name,ncerr)
  ! Define icoultrtmt
  ncerr = nf90_def_var(ncid,name='icoultrtmt',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','icoultrtmt',my_name,ncerr)
  ! Define idyson
  ncerr = nf90_def_var(ncid,name='idyson',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','idyson',my_name,ncerr)
  ! Define ikhxc
  ncerr = nf90_def_var(ncid,name='ikhxc',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ikhxc',my_name,ncerr)
  ! Define inclvkb
  ncerr = nf90_def_var(ncid,name='inclvkb',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','inclvkb',my_name,ncerr)
  ! Define intexact
  ncerr = nf90_def_var(ncid,name='intexact',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','intexact',my_name,ncerr)
  ! Define intxc
  ncerr = nf90_def_var(ncid,name='intxc',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','intxc',my_name,ncerr)
  ! Define ionmov
  ncerr = nf90_def_var(ncid,name='ionmov',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ionmov',my_name,ncerr)
  ! Define iprcch
  ncerr = nf90_def_var(ncid,name='iprcch',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','iprcch',my_name,ncerr)
  ! Define iprcel
  ncerr = nf90_def_var(ncid,name='iprcel',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','iprcel',my_name,ncerr)
  ! Define iprcfc
  ncerr = nf90_def_var(ncid,name='iprcfc',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','iprcfc',my_name,ncerr)
  ! Define iprctfvw
  ncerr = nf90_def_var(ncid,name='iprctfvw',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','iprctfvw',my_name,ncerr)
  ! Define ird1wf
  ncerr = nf90_def_var(ncid,name='ird1wf',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ird1wf',my_name,ncerr)
  ! Define irdddk
  ncerr = nf90_def_var(ncid,name='irdddk',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','irdddk',my_name,ncerr)
  ! Define irdkss
  ncerr = nf90_def_var(ncid,name='irdkss',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','irdkss',my_name,ncerr)
  ! Define irdqps
  ncerr = nf90_def_var(ncid,name='irdqps',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','irdqps',my_name,ncerr)
  ! Define irdscr
  ncerr = nf90_def_var(ncid,name='irdscr',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','irdscr',my_name,ncerr)
  ! Define irdwfk
  ncerr = nf90_def_var(ncid,name='irdwfk',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','irdwfk',my_name,ncerr)
  ! Define irdwfq
  ncerr = nf90_def_var(ncid,name='irdwfq',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','irdwfq',my_name,ncerr)
  ! Define iscf
  ncerr = nf90_def_var(ncid,name='iscf',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','iscf',my_name,ncerr)
  ! Define isecur
  ncerr = nf90_def_var(ncid,name='isecur',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','isecur',my_name,ncerr)
  ! Define istatr
  ncerr = nf90_def_var(ncid,name='istatr',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','istatr',my_name,ncerr)
  ! Define istatshft
  ncerr = nf90_def_var(ncid,name='istatshft',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','istatshft',my_name,ncerr)
  ! Define dimensions of istwfk
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='nkpt',len=dims%nkpt,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','nkpt',my_name,ncerr)
  ! Define istwfk
  ncerr = nf90_def_var(ncid,name='istwfk',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','istwfk',my_name,ncerr)
  ! Define ixc
  ncerr = nf90_def_var(ncid,name='ixc',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ixc',my_name,ncerr)
  ! Define ixcpositron
  ncerr = nf90_def_var(ncid,name='ixcpositron',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ixcpositron',my_name,ncerr)
  ! Define jdtset
  ncerr = nf90_def_var(ncid,name='jdtset',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','jdtset',my_name,ncerr)
  ! Define dimensions of jpaw
  allocate(ncdims(1))
  ncerr = nf90_inq_dimid(ncid,name='ntypat',dimid=ncdims(1))
  call netcdf_handle_error('INQ','DIM','ntypat',my_name,ncerr)
  ! Define jpaw
  ncerr = nf90_def_var(ncid,name='jpaw',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','jpaw',my_name,ncerr)
  ! Define dimensions of kberry
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='kberry_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','kberry_dim1',my_name,ncerr)
  ncerr = nf90_def_dim(ncid,name='nberry',len=dims%nberry,dimid=ncdims(2))
  call netcdf_handle_error('DEF','DIM','nberry',my_name,ncerr)
  ! Define kberry
  ncerr = nf90_def_var(ncid,name='kberry',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','kberry',my_name,ncerr)
  ! Define kpara
  ncerr = nf90_def_var(ncid,name='kpara',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','kpara',my_name,ncerr)
  ! Define dimensions of kpt
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='kpt_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','kpt_dim1',my_name,ncerr)
  ncerr = nf90_inq_dimid(ncid,name='nkpt',dimid=ncdims(2))
  call netcdf_handle_error('INQ','DIM','nkpt',my_name,ncerr)
  ! Define kpt
  ncerr = nf90_def_var(ncid,name='kpt',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','kpt',my_name,ncerr)
  ! Define dimensions of kptgw
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='kptgw_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','kptgw_dim1',my_name,ncerr)
  ncerr = nf90_inq_dimid(ncid,name='nkptgw',dimid=ncdims(2))
  call netcdf_handle_error('INQ','DIM','nkptgw',my_name,ncerr)
  ! Define kptgw
  ncerr = nf90_def_var(ncid,name='kptgw',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','kptgw',my_name,ncerr)
  ! Define kptnrm
  ncerr = nf90_def_var(ncid,name='kptnrm',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','kptnrm',my_name,ncerr)
  ! Define dimensions of kptns
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='kptns_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','kptns_dim1',my_name,ncerr)
  ncerr = nf90_inq_dimid(ncid,name='nkpt',dimid=ncdims(2))
  call netcdf_handle_error('INQ','DIM','nkpt',my_name,ncerr)
  ! Define kptns
  ncerr = nf90_def_var(ncid,name='kptns',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','kptns',my_name,ncerr)
  ! Define kptopt
  ncerr = nf90_def_var(ncid,name='kptopt',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','kptopt',my_name,ncerr)
  ! Define dimensions of kptrlatt
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='kptrlatt_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','kptrlatt_dim1',my_name,ncerr)
  ncerr = nf90_def_dim(ncid,name='kptrlatt_dim2',len=3,dimid=ncdims(2))
  call netcdf_handle_error('DEF','DIM','kptrlatt_dim2',my_name,ncerr)
  ! Define kptrlatt
  ncerr = nf90_def_var(ncid,name='kptrlatt',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','kptrlatt',my_name,ncerr)
  ! Define kptrlen
  ncerr = nf90_def_var(ncid,name='kptrlen',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','kptrlen',my_name,ncerr)
  ! Define kssform
  ncerr = nf90_def_var(ncid,name='kssform',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','kssform',my_name,ncerr)
  ! Define ldgapp
  ncerr = nf90_def_var(ncid,name='ldgapp',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ldgapp',my_name,ncerr)
  ! Define localrdwf
  ncerr = nf90_def_var(ncid,name='localrdwf',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','localrdwf',my_name,ncerr)
  ! Define lofwrite
  ncerr = nf90_def_var(ncid,name='lofwrite',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','lofwrite',my_name,ncerr)
  ! Define dimensions of lpawu
  allocate(ncdims(1))
  ncerr = nf90_inq_dimid(ncid,name='ntypat',dimid=ncdims(1))
  call netcdf_handle_error('INQ','DIM','ntypat',my_name,ncerr)
  ! Define lpawu
  ncerr = nf90_def_var(ncid,name='lpawu',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','lpawu',my_name,ncerr)
  ! Define dimensions of ltypeorb
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='norb',len=dims%norb,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','norb',my_name,ncerr)
  ! Define ltypeorb
  ncerr = nf90_def_var(ncid,name='ltypeorb',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','ltypeorb',my_name,ncerr)
  ! Define mband
  ncerr = nf90_def_var(ncid,name='mband',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mband',my_name,ncerr)
  ! Define mdftemp
  ncerr = nf90_def_var(ncid,name='mdftemp',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mdftemp',my_name,ncerr)
  ! Define mditemp
  ncerr = nf90_def_var(ncid,name='mditemp',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mditemp',my_name,ncerr)
  ! Define mdwall
  ncerr = nf90_def_var(ncid,name='mdwall',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mdwall',my_name,ncerr)
  ! Define mffmem
  ncerr = nf90_def_var(ncid,name='mffmem',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mffmem',my_name,ncerr)
  ! Define mgfft
  ncerr = nf90_def_var(ncid,name='mgfft',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mgfft',my_name,ncerr)
  ! Define mgfftdg
  ncerr = nf90_def_var(ncid,name='mgfftdg',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mgfftdg',my_name,ncerr)
  ! Define dimensions of mixalch
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='npspalch',len=dims%npspalch,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','npspalch',my_name,ncerr)
  ncerr = nf90_inq_dimid(ncid,name='ntypalch',dimid=ncdims(2))
  call netcdf_handle_error('INQ','DIM','ntypalch',my_name,ncerr)
  ! Define mixalch
  ncerr = nf90_def_var(ncid,name='mixalch',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','mixalch',my_name,ncerr)
  ! Define mk1mem
  ncerr = nf90_def_var(ncid,name='mk1mem',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mk1mem',my_name,ncerr)
  ! Define mkmem
  ncerr = nf90_def_var(ncid,name='mkmem',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mkmem',my_name,ncerr)
  ! Define mkqmem
  ncerr = nf90_def_var(ncid,name='mkqmem',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mkqmem',my_name,ncerr)
  ! Define mpw
  ncerr = nf90_def_var(ncid,name='mpw',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mpw',my_name,ncerr)
  ! Define mqgrid
  ncerr = nf90_def_var(ncid,name='mqgrid',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mqgrid',my_name,ncerr)
  ! Define mqgriddg
  ncerr = nf90_def_var(ncid,name='mqgriddg',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','mqgriddg',my_name,ncerr)
  ! Define natom
  ncerr = nf90_def_var(ncid,name='natom',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','natom',my_name,ncerr)
  ! Define natrd
  ncerr = nf90_def_var(ncid,name='natrd',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','natrd',my_name,ncerr)
  ! Define natsph
  ncerr = nf90_def_var(ncid,name='natsph',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','natsph',my_name,ncerr)
  ! Define dimensions of nband
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='nkpt_nsppol',len=dims%nkpt*dims%nsppol,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','nkpt_nsppol',my_name,ncerr)
  ! Define nband
  ncerr = nf90_def_var(ncid,name='nband',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','nband',my_name,ncerr)
  ! Define nbandkss
  ncerr = nf90_def_var(ncid,name='nbandkss',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nbandkss',my_name,ncerr)
  ! Define nbandsus
  ncerr = nf90_def_var(ncid,name='nbandsus',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nbandsus',my_name,ncerr)
  ! Define nbdblock
  ncerr = nf90_def_var(ncid,name='nbdblock',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nbdblock',my_name,ncerr)
  ! Define nbdbuf
  ncerr = nf90_def_var(ncid,name='nbdbuf',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nbdbuf',my_name,ncerr)
  ! Define nberry
  ncerr = nf90_def_var(ncid,name='nberry',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nberry',my_name,ncerr)
  ! Define ncenter
  ncerr = nf90_def_var(ncid,name='ncenter',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ncenter',my_name,ncerr)
  ! Define nconeq
  ncerr = nf90_def_var(ncid,name='nconeq',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nconeq',my_name,ncerr)
  ! Define nctime
  ncerr = nf90_def_var(ncid,name='nctime',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nctime',my_name,ncerr)
  ! Define ndtset
  ncerr = nf90_def_var(ncid,name='ndtset',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ndtset',my_name,ncerr)
  ! Define ndyson
  ncerr = nf90_def_var(ncid,name='ndyson',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ndyson',my_name,ncerr)
  ! Define nelect
  ncerr = nf90_def_var(ncid,name='nelect',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nelect',my_name,ncerr)
  ! Define nfft
  ncerr = nf90_def_var(ncid,name='nfft',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nfft',my_name,ncerr)
  ! Define nfftdg
  ncerr = nf90_def_var(ncid,name='nfftdg',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nfftdg',my_name,ncerr)
  ! Define nfreqim
  ncerr = nf90_def_var(ncid,name='nfreqim',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nfreqim',my_name,ncerr)
  ! Define nfreqre
  ncerr = nf90_def_var(ncid,name='nfreqre',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nfreqre',my_name,ncerr)
  ! Define nfreqsp
  ncerr = nf90_def_var(ncid,name='nfreqsp',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nfreqsp',my_name,ncerr)
  ! Define nfreqsus
  ncerr = nf90_def_var(ncid,name='nfreqsus',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nfreqsus',my_name,ncerr)
  ! Define dimensions of ngfft
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='ngfft_dim1',len=18,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','ngfft_dim1',my_name,ncerr)
  ! Define ngfft
  ncerr = nf90_def_var(ncid,name='ngfft',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','ngfft',my_name,ncerr)
  ! Define dimensions of ngfftdg
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='ngfftdg_dim1',len=18,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','ngfftdg_dim1',my_name,ncerr)
  ! Define ngfftdg
  ncerr = nf90_def_var(ncid,name='ngfftdg',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','ngfftdg',my_name,ncerr)
  ! Define ngroup_rf
  ncerr = nf90_def_var(ncid,name='ngroup_rf',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ngroup_rf',my_name,ncerr)
  ! Define nkpt
  ncerr = nf90_def_var(ncid,name='nkpt',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nkpt',my_name,ncerr)
  ! Define nkptgw
  ncerr = nf90_def_var(ncid,name='nkptgw',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nkptgw',my_name,ncerr)
  ! Define nline
  ncerr = nf90_def_var(ncid,name='nline',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nline',my_name,ncerr)
  ! Define dimensions of nloalg
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='nloalg_dim1',len=5,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','nloalg_dim1',my_name,ncerr)
  ! Define nloalg
  ncerr = nf90_def_var(ncid,name='nloalg',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','nloalg',my_name,ncerr)
  ! Define nnsclo
  ncerr = nf90_def_var(ncid,name='nnsclo',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nnsclo',my_name,ncerr)
  ! Define nomegasrd
  ncerr = nf90_def_var(ncid,name='nomegasrd',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nomegasrd',my_name,ncerr)
  ! Define norb
  ncerr = nf90_def_var(ncid,name='norb',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','norb',my_name,ncerr)
  ! Define noseinert
  ncerr = nf90_def_var(ncid,name='noseinert',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','noseinert',my_name,ncerr)
  ! Define npack
  ncerr = nf90_def_var(ncid,name='npack',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','npack',my_name,ncerr)
  ! Define npara
  ncerr = nf90_def_var(ncid,name='npara',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','npara',my_name,ncerr)
  ! Define npband
  ncerr = nf90_def_var(ncid,name='npband',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','npband',my_name,ncerr)
  ! Define npfft
  ncerr = nf90_def_var(ncid,name='npfft',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','npfft',my_name,ncerr)
  ! Define npsp
  ncerr = nf90_def_var(ncid,name='npsp',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','npsp',my_name,ncerr)
  ! Define npspalch
  ncerr = nf90_def_var(ncid,name='npspalch',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','npspalch',my_name,ncerr)
  ! Define npulayit
  ncerr = nf90_def_var(ncid,name='npulayit',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','npulayit',my_name,ncerr)
  ! Define npweps
  ncerr = nf90_def_var(ncid,name='npweps',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','npweps',my_name,ncerr)
  ! Define npwkss
  ncerr = nf90_def_var(ncid,name='npwkss',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','npwkss',my_name,ncerr)
  ! Define npwsigx
  ncerr = nf90_def_var(ncid,name='npwsigx',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','npwsigx',my_name,ncerr)
  ! Define npwwfn
  ncerr = nf90_def_var(ncid,name='npwwfn',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','npwwfn',my_name,ncerr)
  ! Define nqpt
  ncerr = nf90_def_var(ncid,name='nqpt',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nqpt',my_name,ncerr)
  ! Define nqptdm
  ncerr = nf90_def_var(ncid,name='nqptdm',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nqptdm',my_name,ncerr)
  ! Define nscforder
  ncerr = nf90_def_var(ncid,name='nscforder',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nscforder',my_name,ncerr)
  ! Define nsheps
  ncerr = nf90_def_var(ncid,name='nsheps',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nsheps',my_name,ncerr)
  ! Define nshiftk
  ncerr = nf90_def_var(ncid,name='nshiftk',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nshiftk',my_name,ncerr)
  ! Define nshsigx
  ncerr = nf90_def_var(ncid,name='nshsigx',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nshsigx',my_name,ncerr)
  ! Define nshwfn
  ncerr = nf90_def_var(ncid,name='nshwfn',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nshwfn',my_name,ncerr)
  ! Define nspden
  ncerr = nf90_def_var(ncid,name='nspden',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nspden',my_name,ncerr)
  ! Define nspinor
  ncerr = nf90_def_var(ncid,name='nspinor',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nspinor',my_name,ncerr)
  ! Define nsppol
  ncerr = nf90_def_var(ncid,name='nsppol',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nsppol',my_name,ncerr)
  ! Define nstep
  ncerr = nf90_def_var(ncid,name='nstep',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nstep',my_name,ncerr)
  ! Define nsym
  ncerr = nf90_def_var(ncid,name='nsym',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','nsym',my_name,ncerr)
  ! Define ntime
  ncerr = nf90_def_var(ncid,name='ntime',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ntime',my_name,ncerr)
  ! Define ntypalch
  ncerr = nf90_def_var(ncid,name='ntypalch',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ntypalch',my_name,ncerr)
  ! Define ntypat
  ncerr = nf90_def_var(ncid,name='ntypat',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ntypat',my_name,ncerr)
  ! Define ntyppure
  ncerr = nf90_def_var(ncid,name='ntyppure',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ntyppure',my_name,ncerr)
  ! Define dimensions of numorb
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='ncenter',len=dims%ncenter,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','ncenter',my_name,ncerr)
  ! Define numorb
  ncerr = nf90_def_var(ncid,name='numorb',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','numorb',my_name,ncerr)
  ! Define dimensions of occ_orig
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='mband_nkpt_nsppol',len=dims%mband*dims%nkpt*dims%nsppol,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','mband_nkpt_nsppol',my_name,ncerr)
  ! Define occ_orig
  ncerr = nf90_def_var(ncid,name='occ_orig',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','occ_orig',my_name,ncerr)
  ! Define occopt
  ncerr = nf90_def_var(ncid,name='occopt',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','occopt',my_name,ncerr)
  ! Define omegasrdmax
  ncerr = nf90_def_var(ncid,name='omegasrdmax',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','omegasrdmax',my_name,ncerr)
  ! Define optcell
  ncerr = nf90_def_var(ncid,name='optcell',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','optcell',my_name,ncerr)
  ! Define optdriver
  ncerr = nf90_def_var(ncid,name='optdriver',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','optdriver',my_name,ncerr)
  ! Define optforces
  ncerr = nf90_def_var(ncid,name='optforces',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','optforces',my_name,ncerr)
  ! Define optfreqsus
  ncerr = nf90_def_var(ncid,name='optfreqsus',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','optfreqsus',my_name,ncerr)
  ! Define optnlxccc
  ncerr = nf90_def_var(ncid,name='optnlxccc',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','optnlxccc',my_name,ncerr)
  ! Define optstress
  ncerr = nf90_def_var(ncid,name='optstress',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','optstress',my_name,ncerr)
  ! Define ortalg
  ncerr = nf90_def_var(ncid,name='ortalg',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ortalg',my_name,ncerr)
  ! Define outputXML
  ncerr = nf90_def_var(ncid,name='outputXML',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','outputXML',my_name,ncerr)
  ! Define paral_rf
  ncerr = nf90_def_var(ncid,name='paral_rf',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','paral_rf',my_name,ncerr)
  ! Define parareel
  ncerr = nf90_def_var(ncid,name='parareel',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','parareel',my_name,ncerr)
  ! Define pawecutdg
  ncerr = nf90_def_var(ncid,name='pawecutdg',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','pawecutdg',my_name,ncerr)
  ! Define pawlcutd
  ncerr = nf90_def_var(ncid,name='pawlcutd',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','pawlcutd',my_name,ncerr)
  ! Define pawlmix
  ncerr = nf90_def_var(ncid,name='pawlmix',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','pawlmix',my_name,ncerr)
  ! Define pawmixdg
  ncerr = nf90_def_var(ncid,name='pawmixdg',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','pawmixdg',my_name,ncerr)
  ! Define pawnphi
  ncerr = nf90_def_var(ncid,name='pawnphi',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','pawnphi',my_name,ncerr)
  ! Define pawntheta
  ncerr = nf90_def_var(ncid,name='pawntheta',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','pawntheta',my_name,ncerr)
  ! Define pawnzlm
  ncerr = nf90_def_var(ncid,name='pawnzlm',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','pawnzlm',my_name,ncerr)
  ! Define pawoptmix
  ncerr = nf90_def_var(ncid,name='pawoptmix',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','pawoptmix',my_name,ncerr)
  ! Define pawovlp
  ncerr = nf90_def_var(ncid,name='pawovlp',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','pawovlp',my_name,ncerr)
  ! Define pawprtvol
  ncerr = nf90_def_var(ncid,name='pawprtvol',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','pawprtvol',my_name,ncerr)
  ! Define pawsphmix
  ncerr = nf90_def_var(ncid,name='pawsphmix',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','pawsphmix',my_name,ncerr)
  ! Define pawxcdev
  ncerr = nf90_def_var(ncid,name='pawxcdev',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','pawxcdev',my_name,ncerr)
  ! Define positron
  ncerr = nf90_def_var(ncid,name='positron',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','positron',my_name,ncerr)
  ! Define ppmfrq
  ncerr = nf90_def_var(ncid,name='ppmfrq',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ppmfrq',my_name,ncerr)
  ! Define ppmodel
  ncerr = nf90_def_var(ncid,name='ppmodel',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ppmodel',my_name,ncerr)
  ! Define prepanl
  ncerr = nf90_def_var(ncid,name='prepanl',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prepanl',my_name,ncerr)
  ! Define prt1dm
  ncerr = nf90_def_var(ncid,name='prt1dm',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prt1dm',my_name,ncerr)
  ! Define prtacfd
  ncerr = nf90_def_var(ncid,name='prtacfd',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtacfd',my_name,ncerr)
  ! Define prtbbb
  ncerr = nf90_def_var(ncid,name='prtbbb',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtbbb',my_name,ncerr)
  ! Define prtcml
  ncerr = nf90_def_var(ncid,name='prtcml',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtcml',my_name,ncerr)
  ! Define prtden
  ncerr = nf90_def_var(ncid,name='prtden',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtden',my_name,ncerr)
  ! Define prtdos
  ncerr = nf90_def_var(ncid,name='prtdos',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtdos',my_name,ncerr)
  ! Define prteig
  ncerr = nf90_def_var(ncid,name='prteig',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prteig',my_name,ncerr)
  ! Define prtfsurf
  ncerr = nf90_def_var(ncid,name='prtfsurf',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtfsurf',my_name,ncerr)
  ! Define prtgeo
  ncerr = nf90_def_var(ncid,name='prtgeo',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtgeo',my_name,ncerr)
  ! Define prtgkk
  ncerr = nf90_def_var(ncid,name='prtgkk',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtgkk',my_name,ncerr)
  ! Define prtkpt
  ncerr = nf90_def_var(ncid,name='prtkpt',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtkpt',my_name,ncerr)
  ! Define prtnabla
  ncerr = nf90_def_var(ncid,name='prtnabla',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtnabla',my_name,ncerr)
  ! Define prtpot
  ncerr = nf90_def_var(ncid,name='prtpot',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtpot',my_name,ncerr)
  ! Define prtstm
  ncerr = nf90_def_var(ncid,name='prtstm',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtstm',my_name,ncerr)
  ! Define prtvha
  ncerr = nf90_def_var(ncid,name='prtvha',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtvha',my_name,ncerr)
  ! Define prtvhxc
  ncerr = nf90_def_var(ncid,name='prtvhxc',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtvhxc',my_name,ncerr)
  ! Define prtvol
  ncerr = nf90_def_var(ncid,name='prtvol',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtvol',my_name,ncerr)
  ! Define prtvxc
  ncerr = nf90_def_var(ncid,name='prtvxc',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtvxc',my_name,ncerr)
  ! Define prtwant
  ncerr = nf90_def_var(ncid,name='prtwant',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtwant',my_name,ncerr)
  ! Define prtwf
  ncerr = nf90_def_var(ncid,name='prtwf',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','prtwf',my_name,ncerr)
  ! Define ptgroupma
  ncerr = nf90_def_var(ncid,name='ptgroupma',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ptgroupma',my_name,ncerr)
  ! Define dimensions of qprtrb
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='qprtrb_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','qprtrb_dim1',my_name,ncerr)
  ! Define qprtrb
  ncerr = nf90_def_var(ncid,name='qprtrb',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','qprtrb',my_name,ncerr)
  ! Define dimensions of qpt
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='qpt_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','qpt_dim1',my_name,ncerr)
  ! Define qpt
  ncerr = nf90_def_var(ncid,name='qpt',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','qpt',my_name,ncerr)
  ! Define dimensions of qptdm
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='qptdm_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','qptdm_dim1',my_name,ncerr)
  ncerr = nf90_def_dim(ncid,name='nqptdm',len=dims%nqptdm,dimid=ncdims(2))
  call netcdf_handle_error('DEF','DIM','nqptdm',my_name,ncerr)
  ! Define qptdm
  ncerr = nf90_def_var(ncid,name='qptdm',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','qptdm',my_name,ncerr)
  ! Define dimensions of qptn
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='qptn_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','qptn_dim1',my_name,ncerr)
  ! Define qptn
  ncerr = nf90_def_var(ncid,name='qptn',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','qptn',my_name,ncerr)
  ! Define qptnrm
  ncerr = nf90_def_var(ncid,name='qptnrm',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','qptnrm',my_name,ncerr)
  ! Define ratsph
  ncerr = nf90_def_var(ncid,name='ratsph',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','ratsph',my_name,ncerr)
  ! Define dimensions of rcoord
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='rcoord_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','rcoord_dim1',my_name,ncerr)
  ncerr = nf90_inq_dimid(ncid,name='ncenter',dimid=ncdims(2))
  call netcdf_handle_error('INQ','DIM','ncenter',my_name,ncerr)
  ! Define rcoord
  ncerr = nf90_def_var(ncid,name='rcoord',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','rcoord',my_name,ncerr)
  ! Define restartxf
  ncerr = nf90_def_var(ncid,name='restartxf',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','restartxf',my_name,ncerr)
  ! Define dimensions of rf1atpol
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='rf1atpol_dim1',len=2,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','rf1atpol_dim1',my_name,ncerr)
  ! Define rf1atpol
  ncerr = nf90_def_var(ncid,name='rf1atpol',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','rf1atpol',my_name,ncerr)
  ! Define dimensions of rf1dir
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='rf1dir_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','rf1dir_dim1',my_name,ncerr)
  ! Define rf1dir
  ncerr = nf90_def_var(ncid,name='rf1dir',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','rf1dir',my_name,ncerr)
  ! Define rf1elfd
  ncerr = nf90_def_var(ncid,name='rf1elfd',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rf1elfd',my_name,ncerr)
  ! Define rf1phon
  ncerr = nf90_def_var(ncid,name='rf1phon',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rf1phon',my_name,ncerr)
  ! Define dimensions of rf2atpol
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='rf2atpol_dim1',len=2,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','rf2atpol_dim1',my_name,ncerr)
  ! Define rf2atpol
  ncerr = nf90_def_var(ncid,name='rf2atpol',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','rf2atpol',my_name,ncerr)
  ! Define dimensions of rf2dir
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='rf2dir_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','rf2dir_dim1',my_name,ncerr)
  ! Define rf2dir
  ncerr = nf90_def_var(ncid,name='rf2dir',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','rf2dir',my_name,ncerr)
  ! Define rf2elfd
  ncerr = nf90_def_var(ncid,name='rf2elfd',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rf2elfd',my_name,ncerr)
  ! Define rf2phon
  ncerr = nf90_def_var(ncid,name='rf2phon',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rf2phon',my_name,ncerr)
  ! Define dimensions of rf3atpol
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='rf3atpol_dim1',len=2,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','rf3atpol_dim1',my_name,ncerr)
  ! Define rf3atpol
  ncerr = nf90_def_var(ncid,name='rf3atpol',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','rf3atpol',my_name,ncerr)
  ! Define dimensions of rf3dir
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='rf3dir_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','rf3dir_dim1',my_name,ncerr)
  ! Define rf3dir
  ncerr = nf90_def_var(ncid,name='rf3dir',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','rf3dir',my_name,ncerr)
  ! Define rf3elfd
  ncerr = nf90_def_var(ncid,name='rf3elfd',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rf3elfd',my_name,ncerr)
  ! Define rf3phon
  ncerr = nf90_def_var(ncid,name='rf3phon',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rf3phon',my_name,ncerr)
  ! Define rfasr
  ncerr = nf90_def_var(ncid,name='rfasr',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rfasr',my_name,ncerr)
  ! Define dimensions of rfatpol
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='rfatpol_dim1',len=2,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','rfatpol_dim1',my_name,ncerr)
  ! Define rfatpol
  ncerr = nf90_def_var(ncid,name='rfatpol',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','rfatpol',my_name,ncerr)
  ! Define dimensions of rfdir
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='rfdir_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','rfdir_dim1',my_name,ncerr)
  ! Define rfdir
  ncerr = nf90_def_var(ncid,name='rfdir',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','rfdir',my_name,ncerr)
  ! Define rfelfd
  ncerr = nf90_def_var(ncid,name='rfelfd',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rfelfd',my_name,ncerr)
  ! Define rfmeth
  ncerr = nf90_def_var(ncid,name='rfmeth',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rfmeth',my_name,ncerr)
  ! Define rfphon
  ncerr = nf90_def_var(ncid,name='rfphon',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rfphon',my_name,ncerr)
  ! Define rfstrs
  ncerr = nf90_def_var(ncid,name='rfstrs',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rfstrs',my_name,ncerr)
  ! Define rfthrd
  ncerr = nf90_def_var(ncid,name='rfthrd',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rfthrd',my_name,ncerr)
  ! Define rfuser
  ncerr = nf90_def_var(ncid,name='rfuser',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','rfuser',my_name,ncerr)
  ! Define dimensions of rprim_orig
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='rprim_orig_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','rprim_orig_dim1',my_name,ncerr)
  ncerr = nf90_def_dim(ncid,name='rprim_orig_dim2',len=3,dimid=ncdims(2))
  call netcdf_handle_error('DEF','DIM','rprim_orig_dim2',my_name,ncerr)
  ! Define rprim_orig
  ncerr = nf90_def_var(ncid,name='rprim_orig',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','rprim_orig',my_name,ncerr)
  ! Define dimensions of rprimd_orig
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='rprimd_orig_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','rprimd_orig_dim1',my_name,ncerr)
  ncerr = nf90_def_dim(ncid,name='rprimd_orig_dim2',len=3,dimid=ncdims(2))
  call netcdf_handle_error('DEF','DIM','rprimd_orig_dim2',my_name,ncerr)
  ! Define rprimd_orig
  ncerr = nf90_def_var(ncid,name='rprimd_orig',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','rprimd_orig',my_name,ncerr)
  ! Define dimensions of rtheta
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='rtheta_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','rtheta_dim1',my_name,ncerr)
  ncerr = nf90_inq_dimid(ncid,name='norb',dimid=ncdims(2))
  call netcdf_handle_error('INQ','DIM','norb',my_name,ncerr)
  ! Define rtheta
  ncerr = nf90_def_var(ncid,name='rtheta',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','rtheta',my_name,ncerr)
  ! Define sciss
  ncerr = nf90_def_var(ncid,name='sciss',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','sciss',my_name,ncerr)
  ! Define dimensions of shiftk
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='shiftk_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','shiftk_dim1',my_name,ncerr)
  ncerr = nf90_def_dim(ncid,name='nshiftk',len=dims%nshiftk,dimid=ncdims(2))
  call netcdf_handle_error('DEF','DIM','nshiftk',my_name,ncerr)
  ! Define shiftk
  ncerr = nf90_def_var(ncid,name='shiftk',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','shiftk',my_name,ncerr)
  ! Define signperm
  ncerr = nf90_def_var(ncid,name='signperm',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','signperm',my_name,ncerr)
  ! Define dimensions of so_typat
  allocate(ncdims(1))
  ncerr = nf90_inq_dimid(ncid,name='ntypat',dimid=ncdims(1))
  call netcdf_handle_error('INQ','DIM','ntypat',my_name,ncerr)
  ! Define so_typat
  ncerr = nf90_def_var(ncid,name='so_typat',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','so_typat',my_name,ncerr)
  ! Define soenergy
  ncerr = nf90_def_var(ncid,name='soenergy',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','soenergy',my_name,ncerr)
  ! Define spgaxor
  ncerr = nf90_def_var(ncid,name='spgaxor',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','spgaxor',my_name,ncerr)
  ! Define spgorig
  ncerr = nf90_def_var(ncid,name='spgorig',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','spgorig',my_name,ncerr)
  ! Define spgroup
  ncerr = nf90_def_var(ncid,name='spgroup',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','spgroup',my_name,ncerr)
  ! Define dimensions of spinat
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='spinat_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','spinat_dim1',my_name,ncerr)
  ncerr = nf90_inq_dimid(ncid,name='natom',dimid=ncdims(2))
  call netcdf_handle_error('INQ','DIM','natom',my_name,ncerr)
  ! Define spinat
  ncerr = nf90_def_var(ncid,name='spinat',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','spinat',my_name,ncerr)
  ! Define splitsigc
  ncerr = nf90_def_var(ncid,name='splitsigc',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','splitsigc',my_name,ncerr)
  ! Define stmbias
  ncerr = nf90_def_var(ncid,name='stmbias',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','stmbias',my_name,ncerr)
  ! Define strfact
  ncerr = nf90_def_var(ncid,name='strfact',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','strfact',my_name,ncerr)
  ! Define strprecon
  ncerr = nf90_def_var(ncid,name='strprecon',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','strprecon',my_name,ncerr)
  ! Define dimensions of strtarget
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='strtarget_dim1',len=6,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','strtarget_dim1',my_name,ncerr)
  ! Define strtarget
  ncerr = nf90_def_var(ncid,name='strtarget',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','strtarget',my_name,ncerr)
  ! Define dimensions of supercell
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='supercell_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','supercell_dim1',my_name,ncerr)
  ! Define supercell
  ncerr = nf90_def_var(ncid,name='supercell',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','supercell',my_name,ncerr)
  ! Define suskxcrs
  ncerr = nf90_def_var(ncid,name='suskxcrs',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','suskxcrs',my_name,ncerr)
  ! Define dimensions of symafm
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='nsym',len=dims%nsym,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','nsym',my_name,ncerr)
  ! Define symafm
  ncerr = nf90_def_var(ncid,name='symafm',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','symafm',my_name,ncerr)
  ! Define symmorphi
  ncerr = nf90_def_var(ncid,name='symmorphi',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','symmorphi',my_name,ncerr)
  ! Define dimensions of symrel
  allocate(ncdims(3))
  ncerr = nf90_def_dim(ncid,name='symrel_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','symrel_dim1',my_name,ncerr)
  ncerr = nf90_def_dim(ncid,name='symrel_dim2',len=3,dimid=ncdims(2))
  call netcdf_handle_error('DEF','DIM','symrel_dim2',my_name,ncerr)
  ncerr = nf90_inq_dimid(ncid,name='nsym',dimid=ncdims(3))
  call netcdf_handle_error('INQ','DIM','nsym',my_name,ncerr)
  ! Define symrel
  ncerr = nf90_def_var(ncid,name='symrel',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','symrel',my_name,ncerr)
  ! Define td_maxene
  ncerr = nf90_def_var(ncid,name='td_maxene',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','td_maxene',my_name,ncerr)
  ! Define td_mexcit
  ncerr = nf90_def_var(ncid,name='td_mexcit',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','td_mexcit',my_name,ncerr)
  ! Define tfkinfunc
  ncerr = nf90_def_var(ncid,name='tfkinfunc',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','tfkinfunc',my_name,ncerr)
  ! Define tfnewton
  ncerr = nf90_def_var(ncid,name='tfnewton',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','tfnewton',my_name,ncerr)
  ! Define timopt
  ncerr = nf90_def_var(ncid,name='timopt',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','timopt',my_name,ncerr)
  ! Define dimensions of tnons
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='tnons_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','tnons_dim1',my_name,ncerr)
  ncerr = nf90_inq_dimid(ncid,name='nsym',dimid=ncdims(2))
  call netcdf_handle_error('INQ','DIM','nsym',my_name,ncerr)
  ! Define tnons
  ncerr = nf90_def_var(ncid,name='tnons',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','tnons',my_name,ncerr)
  ! Define toldfe
  ncerr = nf90_def_var(ncid,name='toldfe',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','toldfe',my_name,ncerr)
  ! Define toldff
  ncerr = nf90_def_var(ncid,name='toldff',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','toldff',my_name,ncerr)
  ! Define tolmxf
  ncerr = nf90_def_var(ncid,name='tolmxf',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','tolmxf',my_name,ncerr)
  ! Define tolvrs
  ncerr = nf90_def_var(ncid,name='tolvrs',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','tolvrs',my_name,ncerr)
  ! Define tolwfr
  ncerr = nf90_def_var(ncid,name='tolwfr',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','tolwfr',my_name,ncerr)
  ! Define tphysel
  ncerr = nf90_def_var(ncid,name='tphysel',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','tphysel',my_name,ncerr)
  ! Define tsmear
  ncerr = nf90_def_var(ncid,name='tsmear',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','tsmear',my_name,ncerr)
  ! Define dimensions of typat
  allocate(ncdims(1))
  ncerr = nf90_inq_dimid(ncid,name='natom',dimid=ncdims(1))
  call netcdf_handle_error('INQ','DIM','natom',my_name,ncerr)
  ! Define typat
  ncerr = nf90_def_var(ncid,name='typat',xtype=NF90_INT,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','typat',my_name,ncerr)
  ! Define dimensions of upaw
  allocate(ncdims(1))
  ncerr = nf90_inq_dimid(ncid,name='ntypat',dimid=ncdims(1))
  call netcdf_handle_error('INQ','DIM','ntypat',my_name,ncerr)
  ! Define upaw
  ncerr = nf90_def_var(ncid,name='upaw',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','upaw',my_name,ncerr)
  ! Define usepaw
  ncerr = nf90_def_var(ncid,name='usepaw',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','usepaw',my_name,ncerr)
  ! Define usepawu
  ncerr = nf90_def_var(ncid,name='usepawu',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','usepawu',my_name,ncerr)
  ! Define useria
  ncerr = nf90_def_var(ncid,name='useria',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','useria',my_name,ncerr)
  ! Define userib
  ncerr = nf90_def_var(ncid,name='userib',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','userib',my_name,ncerr)
  ! Define useric
  ncerr = nf90_def_var(ncid,name='useric',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','useric',my_name,ncerr)
  ! Define userid
  ncerr = nf90_def_var(ncid,name='userid',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','userid',my_name,ncerr)
  ! Define userie
  ncerr = nf90_def_var(ncid,name='userie',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','userie',my_name,ncerr)
  ! Define userra
  ncerr = nf90_def_var(ncid,name='userra',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','userra',my_name,ncerr)
  ! Define userrb
  ncerr = nf90_def_var(ncid,name='userrb',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','userrb',my_name,ncerr)
  ! Define userrc
  ncerr = nf90_def_var(ncid,name='userrc',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','userrc',my_name,ncerr)
  ! Define userrd
  ncerr = nf90_def_var(ncid,name='userrd',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','userrd',my_name,ncerr)
  ! Define userre
  ncerr = nf90_def_var(ncid,name='userre',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','userre',my_name,ncerr)
  ! Define useylm
  ncerr = nf90_def_var(ncid,name='useylm',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','useylm',my_name,ncerr)
  ! Define vacnum
  ncerr = nf90_def_var(ncid,name='vacnum',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','vacnum',my_name,ncerr)
  ! Define vacwidth
  ncerr = nf90_def_var(ncid,name='vacwidth',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','vacwidth',my_name,ncerr)
  ! Define dimensions of vel_orig
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='vel_orig_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','vel_orig_dim1',my_name,ncerr)
  ncerr = nf90_inq_dimid(ncid,name='natom',dimid=ncdims(2))
  call netcdf_handle_error('INQ','DIM','natom',my_name,ncerr)
  ! Define vel_orig
  ncerr = nf90_def_var(ncid,name='vel_orig',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','vel_orig',my_name,ncerr)
  ! Define vis
  ncerr = nf90_def_var(ncid,name='vis',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','vis',my_name,ncerr)
  ! Define dimensions of vprtrb
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='vprtrb_dim1',len=2,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','vprtrb_dim1',my_name,ncerr)
  ! Define vprtrb
  ncerr = nf90_def_var(ncid,name='vprtrb',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','vprtrb',my_name,ncerr)
  ! Define wfoptalg
  ncerr = nf90_def_var(ncid,name='wfoptalg',xtype=NF90_INT,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','wfoptalg',my_name,ncerr)
  ! Define dimensions of wtatcon
  allocate(ncdims(3))
  ncerr = nf90_def_dim(ncid,name='wtatcon_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','wtatcon_dim1',my_name,ncerr)
  ncerr = nf90_inq_dimid(ncid,name='natom',dimid=ncdims(2))
  call netcdf_handle_error('INQ','DIM','natom',my_name,ncerr)
  ncerr = nf90_def_dim(ncid,name='nconeq',len=dims%nconeq,dimid=ncdims(3))
  call netcdf_handle_error('DEF','DIM','nconeq',my_name,ncerr)
  ! Define wtatcon
  ncerr = nf90_def_var(ncid,name='wtatcon',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','wtatcon',my_name,ncerr)
  ! Define dimensions of wtk
  allocate(ncdims(1))
  ncerr = nf90_inq_dimid(ncid,name='nkpt',dimid=ncdims(1))
  call netcdf_handle_error('INQ','DIM','nkpt',my_name,ncerr)
  ! Define wtk
  ncerr = nf90_def_var(ncid,name='wtk',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','wtk',my_name,ncerr)
  ! Define dimensions of xred_orig
  allocate(ncdims(2))
  ncerr = nf90_def_dim(ncid,name='xred_orig_dim1',len=3,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','xred_orig_dim1',my_name,ncerr)
  ncerr = nf90_inq_dimid(ncid,name='natom',dimid=ncdims(2))
  call netcdf_handle_error('INQ','DIM','natom',my_name,ncerr)
  ! Define xred_orig
  ncerr = nf90_def_var(ncid,name='xred_orig',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','xred_orig',my_name,ncerr)
  ! Define zcut
  ncerr = nf90_def_var(ncid,name='zcut',xtype=NF90_DOUBLE,varid=ncvar)
  call netcdf_handle_error('DEF','VAR','zcut',my_name,ncerr)
  ! Define dimensions of ziontypat
  allocate(ncdims(1))
  ncerr = nf90_inq_dimid(ncid,name='ntypat',dimid=ncdims(1))
  call netcdf_handle_error('INQ','DIM','ntypat',my_name,ncerr)
  ! Define ziontypat
  ncerr = nf90_def_var(ncid,name='ziontypat',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','ziontypat',my_name,ncerr)
  ! Define dimensions of znucl
  allocate(ncdims(1))
  ncerr = nf90_def_dim(ncid,name='npsp',len=dims%npsp,dimid=ncdims(1))
  call netcdf_handle_error('DEF','DIM','npsp',my_name,ncerr)
  ! Define znucl
  ncerr = nf90_def_var(ncid,name='znucl',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
  deallocate(ncdims)
  call netcdf_handle_error('DEF','VAR','znucl',my_name,ncerr)
#else
 write(message,'(4a)') ch10,' netcdf_def_dtset - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_def_dtset
!!***
