!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_def_wfs
!! NAME
!! netcdf_def_wfs
!!
!! FUNCTION
!!  Prepares a specified NetCDF file to store wavefunctions.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (YP)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!  wfs_dims(2) = dimensions of the wavefunctions
!!  createfile = whether or not create the file
!!
!! OUTPUT
!!  (no direct output : data written to a NetCDF file)
!!
!! NOTES
!!  Pouring data into the file is performed by the netcdf_put_wfs routine.
!!
!! PARENTS
!!      netcdf_file_create
!!
!! CHILDREN
!!      netcdf_handle_error,leave_new,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_def_wfs(ncid,wfs_dim1,wfs_dim2)

 use defs_basis
#if defined HAVE_NETCDF
 use netcdf
#endif

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_def_wfs
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid,wfs_dim1,wfs_dim2

!Local variables-------------------------------
!scalars
 integer :: ncerr,ncvar
 character(len=500) :: message
!arrays
 integer :: ncdims(2)

! ***************************************************************************
#if defined HAVE_NETCDF
 ! Dimensions
 ncerr = nf90_def_dim(ncid,name='wfs_dim1',len=wfs_dim1,dimid=ncdims(1))
 call netcdf_handle_error('DEF','DIM','wfs_dim1','netcdf_def_wfs',ncerr)
 ncerr = nf90_def_dim(ncid,name='wfs_dim2',len=wfs_dim2,dimid=ncdims(2))
 call netcdf_handle_error('DEF','DIM','wfs_dim2','netcdf_def_wfs',ncerr)

 ! Wavefunctions
 ncerr = nf90_def_var(ncid,name='wfs',xtype=NF90_DOUBLE,dimids=ncdims,varid=ncvar)
 call netcdf_handle_error('DEF','VAR','wfs','netcdf_def_wfs',ncerr)
#else
 write(message,'(4a)') ch10,' netcdf_def_wfs - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_def_wfs
!!***
