!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_dims_read
!! NAME
!! netcdf_dims_read
!!
!! FUNCTION
!!  Reads dimensions from a specified NetCDF identifier.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (Y. Pouillon)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid   = identifier of the file to read
!!  blocks = logical OR combination of datatypes (see Src_defs/defs_netcdf)
!!             to read from the file
!!  dims <type(vardims_type)> = dimension holder
!!
!! OUTPUT
!!  (no direct output : data written to a NetCDF file)
!!
!! NOTES
!!  With this implementation, you can build a modular file containing
!!  precisely what you need.
!!
!! PARENTS
!!      xcacfd
!!
!! CHILDREN
!!      netcdf_handle_error,leave_new,netcdf_put_acfd,netcdf_put_den,netcdf_put_dtset
!!      netcdf_put_wfs,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_dims_read(ncid,blocks,dims)

 use defs_basis
 use defs_datatypes
 use defs_netcdf

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_dims_read
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: blocks,ncid
 type(vardims_type),intent(out) :: dims

!Local variables-------------------------------
!scalars
 integer :: i
 character(len=500) :: message

! ***************************************************************************

 ! Read the dimensions of the specified blocks
 do i=0,NCBLKS-1
  select case ( iand(blocks,2**i) )

   case ( 0 )
    ! Do nothing

   case ( NCBLK_DATASET )
    call netcdf_get_dims_dtset(ncid,dims)

   !case ( NCBLK_SYSTEM )
   ! call netcdf_get_system(ncid,dims)

   case ( NCBLK_WFS )
    call netcdf_get_dims_wfs(ncid,dims)

   case ( NCBLK_DENSITY )
    call netcdf_get_dims_den(ncid,dims)

   case ( NCBLK_ACFD )
    call netcdf_get_dims_acfd(ncid,dims)

   case default
    write(message,'(4a,i0)') ch10,' netcdf_dims_read - ERROR',ch10,&
&    'Unknown datatype block value: ',2**i
    call wrtout(std_out,message,'COLL')
    call leave_new('COLL')

  end select
 end do

end subroutine netcdf_dims_read
!!***
