!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_file_create
!! NAME
!! netcdf_file_create
!!
!! FUNCTION
!!  Creates a NetCDF file and prepares it to store specified data.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (YP)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  filename = name of the file where the data will be stored
!!  blocks   = logical OR combination of datatypes (see Src_defs/defs_netcdf)
!!             to store into the file
!!  dims     = dimensions of the variables to store (see Src_defs/defs_netcdf)
!!  create   = whether or not create the file (optional)
!!
!! OUTPUT
!!  (no direct output : data written to a NetCDF file)
!!
!! NOTES
!!  With this implementation, you can build a modular file containing
!!  precisely what you need.
!!
!!  By default the routine will try to create the file. In case a file
!!  of the same name already exists, the program will stop.
!!
!!  The current implementation is very basic.
!!
!! PARENTS
!!      xcacfd
!!
!! CHILDREN
!!      netcdf_def_acfd,netcdf_def_den,netcdf_def_dtset,netcdf_def_wfs,netcdf_handle_error
!!      leave_new,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_file_create(ncid,filename,blocks,dims)

 use defs_basis
#if defined HAVE_NETCDF
 use netcdf
#endif
 use defs_datatypes
 use defs_netcdf

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_file_create
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: blocks
 integer,intent(inout) :: ncid
 character(len=*),intent(in) :: filename
 type(vardims_type),intent(in) :: dims

!Local variables-------------------------------
!scalars
 integer :: i,ncerr
 character(len=500) :: message

! ***************************************************************************

#if defined HAVE_NETCDF
 ! Create the file
 ncerr = nf90_create(path=filename,cmode=NF90_NOCLOBBER,ncid=ncid)
 call netcdf_handle_error('I/O','CRE',filename,'netcdf_file_create',ncerr)

 ! Define the file structure
 do i=0,NCBLKS-1
  select case ( iand(blocks,2**i) )

   case ( 0 )
    ! Do nothing

   !case ( NCBLK_HEADER )
   ! call netcdf_def_header(ncid)

   case ( NCBLK_DATASET )
    call netcdf_def_dtset(ncid,dims)

   !case ( NCBLK_SYSTEM )
   ! call netcdf_def_system(ncid,dims)

   case ( NCBLK_WFS )
    call netcdf_def_wfs(ncid,dims%wfs_dim1,dims%wfs_dim2)

   case ( NCBLK_DENSITY )
    call netcdf_def_den(ncid,dims%nfft,dims%nspden)

   case ( NCBLK_ACFD )
    call netcdf_def_acfd(ncid,dims%nfreqsus,dims%npw_tiny)

   case default
    write(message,'(4a,i)') ch10,' netcdf_file_create - ERROR',ch10,&
&    'Unknown datatype block value: ',2**i
    call wrtout(std_out,message,'COLL')
    call leave_new('COLL')

  end select
 end do

 ! The end
 ncerr = nf90_enddef(ncid)
 call netcdf_handle_error('DEF','END','-','netcdf_file_create',ncerr)
#else
 write(message,'(4a)') ch10,' netcdf_file_create - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_file_create
!!***
