!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_get_acfd
!! NAME
!! netcdf_get_acfd
!!
!! FUNCTION
!!  Reads an ACFD data block from a specified NetCDF file.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (YP)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!
!! OUTPUT
!!  acfd <type(ncacfd_type)> = ACFD data block where the data will be stored
!!   (see Src_defs/defs_netcdf.F90)
!!
!! NOTES
!!  This routines assumes that all arrays have already been allocated
!!  (array sizes are obtained through netcdf_get_dims_acfd).
!!
!! PARENTS
!!      netcdf_data_read
!!
!! CHILDREN
!!      leave_new,netcdf_handle_error,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_get_acfd(ncid,acfd)

 use defs_basis
#if defined HAVE_NETCDF
 use netcdf
#endif
 use defs_netcdf

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_get_acfd
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid
 type(ncacfd_type),intent(out) :: acfd

!Local variables-------------------------------
!scalars
 integer :: ncerr,ncvar
 character(len=500) :: message

! ***************************************************************************
#if defined HAVE_NETCDF
 ! Get freqs
 ncerr = nf90_inq_varid(ncid,name='freqs',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','freqs','netcdf_get_acfd',ncerr)
 ncerr = nf90_get_var(ncid,ncvar,acfd%freqs)
 call netcdf_handle_error('GET','VAR','freqs','netcdf_get_acfd',ncerr)
 ! Get weights
 ncerr = nf90_inq_varid(ncid,name='weights',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','weights','netcdf_get_acfd',ncerr)
 ncerr = nf90_get_var(ncid,ncvar,acfd%weights)
 call netcdf_handle_error('GET','VAR','weights','netcdf_get_acfd',ncerr)
 ! Get status
 ncerr = nf90_inq_varid(ncid,name='ifreq',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','ifreq','netcdf_get_acfd',ncerr)
 ncerr = nf90_get_var(ncid,ncvar,acfd%ifreq)
 call netcdf_handle_error('GET','VAR','ifreq','netcdf_get_acfd',ncerr)
 ! Get ex_cc
 ncerr = nf90_inq_varid(ncid,name='ex_cc',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','ex_cc','netcdf_get_acfd',ncerr)
 ncerr = nf90_get_var(ncid,ncvar,acfd%ex_cc)
 call netcdf_handle_error('GET','VAR','ex_cc','netcdf_get_acfd',ncerr)
 ! Get ecs_cc
 ncerr = nf90_inq_varid(ncid,name='ecs_cc',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','ecs_cc','netcdf_get_acfd',ncerr)
 ncerr = nf90_get_var(ncid,ncvar,acfd%ecs_cc)
 call netcdf_handle_error('GET','VAR','ecs_cc','netcdf_get_acfd',ncerr)
 ! Get ecgl_cc
 ncerr = nf90_inq_varid(ncid,name='ecgl_cc',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','ecgl_cc','netcdf_get_acfd',ncerr)
 ncerr = nf90_get_var(ncid,ncvar,acfd%ecgl_cc)
 call netcdf_handle_error('GET','VAR','ecgl_cc','netcdf_get_acfd',ncerr)
 ! Get ecs_uc
 ncerr = nf90_inq_varid(ncid,name='ecs_uc',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','ecs_uc','netcdf_get_acfd',ncerr)
 ncerr = nf90_get_var(ncid,ncvar,acfd%ecs_uc)
 call netcdf_handle_error('GET','VAR','ecs_uc','netcdf_get_acfd',ncerr)
 ! Get ecgl_uc
 ncerr = nf90_inq_varid(ncid,name='ecgl_uc',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','ecgl_uc','netcdf_get_acfd',ncerr)
 ncerr = nf90_get_var(ncid,ncvar,acfd%ecgl_uc)
 call netcdf_handle_error('GET','VAR','ecgl_uc','netcdf_get_acfd',ncerr)
 ! Get n_test
 ncerr = nf90_inq_varid(ncid,name='n_test',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','n_test','netcdf_get_acfd',ncerr)
 ncerr = nf90_get_var(ncid,ncvar,acfd%n_test)
 call netcdf_handle_error('GET','VAR','n_test','netcdf_get_acfd',ncerr)
#else
 write(message,'(4a)') ch10,' netcdf_get_acfd - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_get_acfd
!!***
