!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_get_dims_den
!! NAME
!! netcdf_get_dims_den
!!
!! FUNCTION
!!  Reads the dimensions of a charge density from a
!!  specified NetCDF file.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (YP)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!
!! OUTPUT
!!  den_dims(:) = dimensions of the charge density
!!
!! PARENTS
!!
!! CHILDREN
!!      netcdf_handle_error,leave_new,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_get_dims_den(ncid,dims)

 use defs_basis
 use defs_datatypes
#if defined HAVE_NETCDF
 use netcdf
#endif

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_get_dims_den
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid
 type(vardims_type),intent(out) :: dims

!Local variables-------------------------------
!scalars
 integer :: ncdim,ncerr,ncvar
 character(len=500) :: message

! ***************************************************************************
#if defined HAVE_NETCDF
 ! Get nfft
 ncerr = nf90_inq_dimid(ncid,name='nfft',dimid=ncdim)
 call netcdf_handle_error('INQ','DIM','nfft','netcdf_get_dims_den',ncerr)
 ncerr = nf90_inquire_dimension(ncid,dimid=ncdim,len=dims%nfft)
 call netcdf_handle_error('GET','DIM','nfft','netcdf_get_dims_den',ncerr)

 ! Get nspden
 ncerr = nf90_inq_dimid(ncid,name='nspden',dimid=ncdim)
 call netcdf_handle_error('INQ','DIM','nspden','netcdf_get_dims_den',ncerr)
 ncerr = nf90_inquire_dimension(ncid,dimid=ncdim,len=dims%nspden)
 call netcdf_handle_error('GET','DIM','nspden','netcdf_get_dims_den',ncerr)
#else
 dims%nfft = 0
 dims%nspden = 0
 write(message,'(4a)') ch10,' netcdf_get_dims_den - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_get_dims_den
!!***
