!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_get_dims_wfs
!! NAME
!! netcdf_get_dims_wfs
!!
!! FUNCTION
!!  Reads the dimensions of a set of wavefunctions from a
!!  specified NetCDF file.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (YP)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!
!! OUTPUT
!!  wfs_dims(:) = dimensions of the set of wavefunctions
!!
!! PARENTS
!!      netcdf_dims_read
!!
!! CHILDREN
!!      leave_new,netcdf_handle_error,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_get_dims_wfs(ncid,dims)

 use defs_basis
 use defs_datatypes
#if defined HAVE_NETCDF
 use netcdf
#endif

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_get_dims_wfs
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid
 type(vardims_type),intent(out) :: dims

!Local variables-------------------------------
!scalars
 integer :: ncdim,ncerr,ncvar
 character(len=500) :: message

! ***************************************************************************
#if defined HAVE_NETCDF
 ! Get wfs_dim(1)
 ncerr = nf90_inq_dimid(ncid,name='wfs_dim1',dimid=ncdim)
 call netcdf_handle_error('INQ','DIM','wfs_dim1','netcdf_get_dims_wfs',ncerr)
 ncerr = nf90_inquire_dimension(ncid,dimid=ncdim,len=dims%wfs_dim1)
 call netcdf_handle_error('GET','DIM','wfs_dim1','netcdf_get_dims_wfs',ncerr)

 ! Get wfs_dim(2)
 ncerr = nf90_inq_dimid(ncid,name='wfs_dim2',dimid=ncdim)
 call netcdf_handle_error('INQ','DIM','wfs_dim2','netcdf_get_dims_wfs',ncerr)
 ncerr = nf90_inquire_dimension(ncid,dimid=ncdim,len=dims%wfs_dim2)
 call netcdf_handle_error('GET','DIM','wfs_dim2','netcdf_get_dims_wfs',ncerr)
#else
 dims%wfs_dim1 = 0
 dims%wfs_dim2 = 0
 write(message,'(4a)') ch10,' netcdf_get_dims_wfs - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_get_dims_wfs
!!***
