!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_get_wfs
!! NAME
!! netcdf_get_wfs
!!
!! FUNCTION
!!  Reads a set of wavefunctions from a specified NetCDF file.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (YP)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!
!! OUTPUT
!!  wfs(:,:) = the set of wavefunctions where the data will be stored
!!
!! NOTES
!!  This routines assumes that all arrays have already been allocated
!!  (array sizes are obtained through netcdf_get_dims_wfs).
!!
!! PARENTS
!!
!! CHILDREN
!!      netcdf_handle_error,leave_new,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_get_wfs(ncid,wfs)

 use defs_basis
#if defined HAVE_NETCDF
 use netcdf
#endif

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_get_wfs
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid
!arrays
 real(dp),intent(out) :: wfs(:,:)

!Local variables-------------------------------
!scalars
 integer :: ncerr,ncvar
 character(len=500) :: message

! ***************************************************************************
#if defined HAVE_NETCDF
 ncerr = nf90_inq_varid(ncid,name='wfs',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','wfs','netcdf_get_wfs',ncerr)
 ncerr = nf90_get_var(ncid,ncvar,wfs)
 call netcdf_handle_error('GET','VAR','wfs','netcdf_get_wfs',ncerr)
#else
 wfs(:,:) = zero
 write(message,'(4a)') ch10,' netcdf_get_wfs - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_get_wfs
!!***
