!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_handle_error
!! NAME
!! netcdf_handle_error
!!
!! FUNCTION
!!  Provides basic error handling for routines using NetCDF.
!!
!! COPYRIGHT
!!  Copyright (C) 2004-2006 ABINIT group (YP)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors.
!!
!! INPUTS
!!  omode = 3-letter code describing the operation being done
!!   (DEF,GET,I/O,INQ,PUT)
!!  otype = 3-letter describing the type of the target
!!   (CLO,DIM,END,INI,OPN,VAR)
!!  tgt = name of the target
!!  ncerr = error code return by the operation
!!
!! OUTPUT
!!  (only writing)
!!
!! NOTES
!!  The routine stops execution if ncerr is not equal to NF90_NOERR.
!!
!! PARENTS
!!      netcdf_file_create,netcdf_def_acfd,netcdf_def_den,netcdf_def_dtset
!!      netcdf_def_wfs,netcdf_get_acfd,netcdf_get_den,netcdf_get_dims_acfd
!!      netcdf_get_dims_den,netcdf_get_dims_dtset,netcdf_get_dims_wfs,netcdf_get_dtset
!!      netcdf_get_wfs,netcdf_put_acfd,netcdf_put_den,netcdf_put_dtset,netcdf_put_wfs
!!      netcdf_file_write
!!
!! CHILDREN
!!      leave_new,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_handle_error(omode,otype,tgt,parent,ncerr)

 use defs_basis
#if defined HAVE_NETCDF
 use netcdf
#endif

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncerr
 character(len=*),intent(in) :: parent,tgt
 character(len=3),intent(in) :: omode,otype

!Local variables-------------------------------
!scalars
 character(len=500) :: message

! ***************************************************************************
#if defined HAVE_NETCDF
 if ( ncerr /= NF90_NOERR ) then
  write (message,'(13a)') ch10,' ',tgt,' <',omode,'#',otype,&
&  '> (',tgt,'): ',ch10,'  ',trim(nf90_strerror(ncerr))
  call wrtout(ab_out,message,'COLL')
  call wrtout(std_out,message,'COLL')
  call leave_new('COLL')
 end if
#else
 write(message,'(4a)') ch10,' netcdf_def_acfd - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_handle_error
!!***
