!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_put_acfd
!! NAME
!! netcdf_put_acfd
!!
!! FUNCTION
!!  Stores a specified ACFD data block into a NetCDF file.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (YP)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!  acfd <type(ncacfd_type)> = ACFD data block to store
!!   (see Src_defs/defs_netcdf)
!!
!! OUTPUT
!!  (no direct output : data written to a NetCDF file)
!!
!! NOTES
!!  This routines assumes that all arrays have already been allocated
!!  (array sizes are obtained through netcdf_put_dims_acfd).
!!
!! PARENTS
!!      netcdf_data_write
!!
!! CHILDREN
!!      leave_new,netcdf_handle_error,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_put_acfd(ncid,acfd)

 use defs_basis
 use defs_netcdf
#if defined HAVE_NETCDF
 use netcdf
#endif

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_put_acfd
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid
 type(ncacfd_type),intent(in) :: acfd

!Local variables-------------------------------
!scalars
 integer :: ncerr,ncvar
 character(len=500) :: message

! ***************************************************************************

#if defined HAVE_NETCDF
 ! Put freqs
 ncerr = nf90_inq_varid(ncid,name='freqs',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','freqs','netcdf_put_acfd',ncerr)
 ncerr = nf90_put_var(ncid,ncvar,acfd%freqs)
 call netcdf_handle_error('PUT','VAR','freqs','netcdf_put_acfd',ncerr)
 ! Put weights
 ncerr = nf90_inq_varid(ncid,name='weights',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','weights','netcdf_put_acfd',ncerr)
 ncerr = nf90_put_var(ncid,ncvar,acfd%weights)
 call netcdf_handle_error('PUT','VAR','weights','netcdf_put_acfd',ncerr)
 ! Put status
 ncerr = nf90_inq_varid(ncid,name='ifreq',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','ifreq','netcdf_put_acfd',ncerr)
 ncerr = nf90_put_var(ncid,ncvar,acfd%ifreq)
 call netcdf_handle_error('PUT','VAR','ifreq','netcdf_put_acfd',ncerr)
 ! Put ex_cc
 ncerr = nf90_inq_varid(ncid,name='ex_cc',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','ex_cc','netcdf_put_acfd',ncerr)
 ncerr = nf90_put_var(ncid,ncvar,acfd%ex_cc)
 call netcdf_handle_error('PUT','VAR','ex_cc','netcdf_put_acfd',ncerr)
 ! Put ecs_cc
 ncerr = nf90_inq_varid(ncid,name='ecs_cc',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','ecs_cc','netcdf_put_acfd',ncerr)
 ncerr = nf90_put_var(ncid,ncvar,acfd%ecs_cc)
 call netcdf_handle_error('PUT','VAR','ecs_cc','netcdf_put_acfd',ncerr)
 ! Put ecgl_cc
 ncerr = nf90_inq_varid(ncid,name='ecgl_cc',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','ecgl_cc','netcdf_put_acfd',ncerr)
 ncerr = nf90_put_var(ncid,ncvar,acfd%ecgl_cc)
 call netcdf_handle_error('PUT','VAR','ecgl_cc','netcdf_put_acfd',ncerr)
 ! Put ecs_uc
 ncerr = nf90_inq_varid(ncid,name='ecs_uc',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','ecs_uc','netcdf_put_acfd',ncerr)
 ncerr = nf90_put_var(ncid,ncvar,acfd%ecs_uc)
 call netcdf_handle_error('PUT','VAR','ecs_uc','netcdf_put_acfd',ncerr)
 ! Put ecgl_uc
 ncerr = nf90_inq_varid(ncid,name='ecgl_uc',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','ecgl_uc','netcdf_put_acfd',ncerr)
 ncerr = nf90_put_var(ncid,ncvar,acfd%ecgl_uc)
 call netcdf_handle_error('PUT','VAR','ecgl_uc','netcdf_put_acfd',ncerr)
 ! Put n_test
 ncerr = nf90_inq_varid(ncid,name='n_test',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','n_test','netcdf_put_acfd',ncerr)
 ncerr = nf90_put_var(ncid,ncvar,acfd%n_test)
 call netcdf_handle_error('PUT','VAR','n_test','netcdf_put_acfd',ncerr)
#else
 write(message,'(4a)') ch10,' netcdf_put_acfd - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_put_acfd
!!***
