!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_put_dtset
!! NAME
!! netcdf_put_dtset
!!
!! FUNCTION
!!  Stores a specified dataset into a NetCDF file.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (Y. Pouillon)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!  dtset <type(dataset_type)> = all input variables in this dataset
!!
!! OUTPUT
!!  (no direct output : data written to a NetCDF file)
!!
!! NOTES
!!  Please do not edit this file. Since it is automatically generated (see
!!  the makencdf script), your changes would be systematically overwritten.
!!  Instead you should directly modify the generating script itself
!!  (~abinit/scripts/netcdf/netcdf_put_dtset.pl) to suit your needs.
!!
!! PARENTS
!!
!! CHILDREN
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_put_dtset(ncid,dtset)

#if defined HAVE_NETCDF
 use netcdf
#endif
 use defs_basis
 use defs_datatypes



!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_put_dtset
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid
 type(dataset_type),intent(in) :: dtset

!Local variables-------------------------------
!scalars
 character(len=*),parameter :: my_name = 'netcdf_put_dtset'
 integer :: ncerr,ncvar
 character(len=500) :: message

! ***************************************************************************

#if defined HAVE_NETCDF
 ! Put accesswff
 ncerr = nf90_inq_varid(ncid,name='accesswff',varid=ncvar)
 call netcdf_handle_error('INQ','VID','accesswff',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%accesswff)
 call netcdf_handle_error('PUT','VAR','accesswff',my_name,ncerr)
 ! Put acell_orig
 ncerr = nf90_inq_varid(ncid,name='acell_orig',varid=ncvar)
 call netcdf_handle_error('INQ','VID','acell_orig',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%acell_orig)
 call netcdf_handle_error('PUT','VAR','acell_orig',my_name,ncerr)
 ! Put algalch
 ncerr = nf90_inq_varid(ncid,name='algalch',varid=ncvar)
 call netcdf_handle_error('INQ','VID','algalch',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%algalch)
 call netcdf_handle_error('PUT','VAR','algalch',my_name,ncerr)
 ! Put alpha
 ncerr = nf90_inq_varid(ncid,name='alpha',varid=ncvar)
 call netcdf_handle_error('INQ','VID','alpha',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%alpha)
 call netcdf_handle_error('PUT','VAR','alpha',my_name,ncerr)
 ! Put amu
 ncerr = nf90_inq_varid(ncid,name='amu',varid=ncvar)
 call netcdf_handle_error('INQ','VID','amu',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%amu)
 call netcdf_handle_error('PUT','VAR','amu',my_name,ncerr)
 ! Put angdeg_orig
 ncerr = nf90_inq_varid(ncid,name='angdeg_orig',varid=ncvar)
 call netcdf_handle_error('INQ','VID','angdeg_orig',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%angdeg_orig)
 call netcdf_handle_error('PUT','VAR','angdeg_orig',my_name,ncerr)
 ! Put bdberry
 ncerr = nf90_inq_varid(ncid,name='bdberry',varid=ncvar)
 call netcdf_handle_error('INQ','VID','bdberry',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%bdberry)
 call netcdf_handle_error('PUT','VAR','bdberry',my_name,ncerr)
 ! Put bdgw
 ncerr = nf90_inq_varid(ncid,name='bdgw',varid=ncvar)
 call netcdf_handle_error('INQ','VID','bdgw',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%bdgw)
 call netcdf_handle_error('PUT','VAR','bdgw',my_name,ncerr)
 ! Put berryopt
 ncerr = nf90_inq_varid(ncid,name='berryopt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','berryopt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%berryopt)
 call netcdf_handle_error('PUT','VAR','berryopt',my_name,ncerr)
 ! Put boxcenter
 ncerr = nf90_inq_varid(ncid,name='boxcenter',varid=ncvar)
 call netcdf_handle_error('INQ','VID','boxcenter',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%boxcenter)
 call netcdf_handle_error('PUT','VAR','boxcenter',my_name,ncerr)
 ! Put boxcutmin
 ncerr = nf90_inq_varid(ncid,name='boxcutmin',varid=ncvar)
 call netcdf_handle_error('INQ','VID','boxcutmin',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%boxcutmin)
 call netcdf_handle_error('PUT','VAR','boxcutmin',my_name,ncerr)
 ! Put brvltt
 ncerr = nf90_inq_varid(ncid,name='brvltt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','brvltt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%brvltt)
 call netcdf_handle_error('PUT','VAR','brvltt',my_name,ncerr)
 ! Put bxctmindg
 ncerr = nf90_inq_varid(ncid,name='bxctmindg',varid=ncvar)
 call netcdf_handle_error('INQ','VID','bxctmindg',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%bxctmindg)
 call netcdf_handle_error('PUT','VAR','bxctmindg',my_name,ncerr)
 ! Put ceksph
 ncerr = nf90_inq_varid(ncid,name='ceksph',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ceksph',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ceksph)
 call netcdf_handle_error('PUT','VAR','ceksph',my_name,ncerr)
 ! Put charge
 ncerr = nf90_inq_varid(ncid,name='charge',varid=ncvar)
 call netcdf_handle_error('INQ','VID','charge',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%charge)
 call netcdf_handle_error('PUT','VAR','charge',my_name,ncerr)
 ! Put chkexit
 ncerr = nf90_inq_varid(ncid,name='chkexit',varid=ncvar)
 call netcdf_handle_error('INQ','VID','chkexit',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%chkexit)
 call netcdf_handle_error('PUT','VAR','chkexit',my_name,ncerr)
 ! Put chkprim
 ncerr = nf90_inq_varid(ncid,name='chkprim',varid=ncvar)
 call netcdf_handle_error('INQ','VID','chkprim',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%chkprim)
 call netcdf_handle_error('PUT','VAR','chkprim',my_name,ncerr)
 ! Put cpus
 ncerr = nf90_inq_varid(ncid,name='cpus',varid=ncvar)
 call netcdf_handle_error('INQ','VID','cpus',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%cpus)
 call netcdf_handle_error('PUT','VAR','cpus',my_name,ncerr)
 ! Put dedlnn
 ncerr = nf90_inq_varid(ncid,name='dedlnn',varid=ncvar)
 call netcdf_handle_error('INQ','VID','dedlnn',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%dedlnn)
 call netcdf_handle_error('PUT','VAR','dedlnn',my_name,ncerr)
 ! Put delayperm
 ncerr = nf90_inq_varid(ncid,name='delayperm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','delayperm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%delayperm)
 call netcdf_handle_error('PUT','VAR','delayperm',my_name,ncerr)
 ! Put densty
 ncerr = nf90_inq_varid(ncid,name='densty',varid=ncvar)
 call netcdf_handle_error('INQ','VID','densty',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%densty)
 call netcdf_handle_error('PUT','VAR','densty',my_name,ncerr)
 ! Put diecut
 ncerr = nf90_inq_varid(ncid,name='diecut',varid=ncvar)
 call netcdf_handle_error('INQ','VID','diecut',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%diecut)
 call netcdf_handle_error('PUT','VAR','diecut',my_name,ncerr)
 ! Put diegap
 ncerr = nf90_inq_varid(ncid,name='diegap',varid=ncvar)
 call netcdf_handle_error('INQ','VID','diegap',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%diegap)
 call netcdf_handle_error('PUT','VAR','diegap',my_name,ncerr)
 ! Put dielam
 ncerr = nf90_inq_varid(ncid,name='dielam',varid=ncvar)
 call netcdf_handle_error('INQ','VID','dielam',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%dielam)
 call netcdf_handle_error('PUT','VAR','dielam',my_name,ncerr)
 ! Put dielng
 ncerr = nf90_inq_varid(ncid,name='dielng',varid=ncvar)
 call netcdf_handle_error('INQ','VID','dielng',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%dielng)
 call netcdf_handle_error('PUT','VAR','dielng',my_name,ncerr)
 ! Put diemac
 ncerr = nf90_inq_varid(ncid,name='diemac',varid=ncvar)
 call netcdf_handle_error('INQ','VID','diemac',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%diemac)
 call netcdf_handle_error('PUT','VAR','diemac',my_name,ncerr)
 ! Put diemix
 ncerr = nf90_inq_varid(ncid,name='diemix',varid=ncvar)
 call netcdf_handle_error('INQ','VID','diemix',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%diemix)
 call netcdf_handle_error('PUT','VAR','diemix',my_name,ncerr)
 ! Put dilatmx
 ncerr = nf90_inq_varid(ncid,name='dilatmx',varid=ncvar)
 call netcdf_handle_error('INQ','VID','dilatmx',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%dilatmx)
 call netcdf_handle_error('PUT','VAR','dilatmx',my_name,ncerr)
 ! Put dosdeltae
 ncerr = nf90_inq_varid(ncid,name='dosdeltae',varid=ncvar)
 call netcdf_handle_error('INQ','VID','dosdeltae',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%dosdeltae)
 call netcdf_handle_error('PUT','VAR','dosdeltae',my_name,ncerr)
 ! Put dsifkpt
 ncerr = nf90_inq_varid(ncid,name='dsifkpt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','dsifkpt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%dsifkpt)
 call netcdf_handle_error('PUT','VAR','dsifkpt',my_name,ncerr)
 ! Put dtion
 ncerr = nf90_inq_varid(ncid,name='dtion',varid=ncvar)
 call netcdf_handle_error('INQ','VID','dtion',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%dtion)
 call netcdf_handle_error('PUT','VAR','dtion',my_name,ncerr)
 ! Put ecut
 ncerr = nf90_inq_varid(ncid,name='ecut',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ecut',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ecut)
 call netcdf_handle_error('PUT','VAR','ecut',my_name,ncerr)
 ! Put ecuteps
 ncerr = nf90_inq_varid(ncid,name='ecuteps',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ecuteps',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ecuteps)
 call netcdf_handle_error('PUT','VAR','ecuteps',my_name,ncerr)
 ! Put ecutsigx
 ncerr = nf90_inq_varid(ncid,name='ecutsigx',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ecutsigx',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ecutsigx)
 call netcdf_handle_error('PUT','VAR','ecutsigx',my_name,ncerr)
 ! Put ecutsm
 ncerr = nf90_inq_varid(ncid,name='ecutsm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ecutsm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ecutsm)
 call netcdf_handle_error('PUT','VAR','ecutsm',my_name,ncerr)
 ! Put ecutwfn
 ncerr = nf90_inq_varid(ncid,name='ecutwfn',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ecutwfn',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ecutwfn)
 call netcdf_handle_error('PUT','VAR','ecutwfn',my_name,ncerr)
 ! Put effmass
 ncerr = nf90_inq_varid(ncid,name='effmass',varid=ncvar)
 call netcdf_handle_error('INQ','VID','effmass',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%effmass)
 call netcdf_handle_error('PUT','VAR','effmass',my_name,ncerr)
 ! Put efield
 ncerr = nf90_inq_varid(ncid,name='efield',varid=ncvar)
 call netcdf_handle_error('INQ','VID','efield',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%efield)
 call netcdf_handle_error('PUT','VAR','efield',my_name,ncerr)
 ! Put enunit
 ncerr = nf90_inq_varid(ncid,name='enunit',varid=ncvar)
 call netcdf_handle_error('INQ','VID','enunit',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%enunit)
 call netcdf_handle_error('PUT','VAR','enunit',my_name,ncerr)
 ! Put eshift
 ncerr = nf90_inq_varid(ncid,name='eshift',varid=ncvar)
 call netcdf_handle_error('INQ','VID','eshift',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%eshift)
 call netcdf_handle_error('PUT','VAR','eshift',my_name,ncerr)
 ! Put exchn2n3
 ncerr = nf90_inq_varid(ncid,name='exchn2n3',varid=ncvar)
 call netcdf_handle_error('INQ','VID','exchn2n3',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%exchn2n3)
 call netcdf_handle_error('PUT','VAR','exchn2n3',my_name,ncerr)
 ! Put fband
 ncerr = nf90_inq_varid(ncid,name='fband',varid=ncvar)
 call netcdf_handle_error('INQ','VID','fband',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%fband)
 call netcdf_handle_error('PUT','VAR','fband',my_name,ncerr)
 ! Put fft_opt_lob
 ncerr = nf90_inq_varid(ncid,name='fft_opt_lob',varid=ncvar)
 call netcdf_handle_error('INQ','VID','fft_opt_lob',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%fft_opt_lob)
 call netcdf_handle_error('PUT','VAR','fft_opt_lob',my_name,ncerr)
 ! Put fixmom
 ncerr = nf90_inq_varid(ncid,name='fixmom',varid=ncvar)
 call netcdf_handle_error('INQ','VID','fixmom',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%fixmom)
 call netcdf_handle_error('PUT','VAR','fixmom',my_name,ncerr)
 ! Put freqremax
 ncerr = nf90_inq_varid(ncid,name='freqremax',varid=ncvar)
 call netcdf_handle_error('INQ','VID','freqremax',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%freqremax)
 call netcdf_handle_error('PUT','VAR','freqremax',my_name,ncerr)
 ! Put freqspmax
 ncerr = nf90_inq_varid(ncid,name='freqspmax',varid=ncvar)
 call netcdf_handle_error('INQ','VID','freqspmax',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%freqspmax)
 call netcdf_handle_error('PUT','VAR','freqspmax',my_name,ncerr)
 ! Put freqsusin
 ncerr = nf90_inq_varid(ncid,name='freqsusin',varid=ncvar)
 call netcdf_handle_error('INQ','VID','freqsusin',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%freqsusin)
 call netcdf_handle_error('PUT','VAR','freqsusin',my_name,ncerr)
 ! Put freqsuslo
 ncerr = nf90_inq_varid(ncid,name='freqsuslo',varid=ncvar)
 call netcdf_handle_error('INQ','VID','freqsuslo',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%freqsuslo)
 call netcdf_handle_error('PUT','VAR','freqsuslo',my_name,ncerr)
 ! Put friction
 ncerr = nf90_inq_varid(ncid,name='friction',varid=ncvar)
 call netcdf_handle_error('INQ','VID','friction',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%friction)
 call netcdf_handle_error('PUT','VAR','friction',my_name,ncerr)
 ! Put frzfermi
 ncerr = nf90_inq_varid(ncid,name='frzfermi',varid=ncvar)
 call netcdf_handle_error('INQ','VID','frzfermi',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%frzfermi)
 call netcdf_handle_error('PUT','VAR','frzfermi',my_name,ncerr)
 ! Put genafm
 ncerr = nf90_inq_varid(ncid,name='genafm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','genafm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%genafm)
 call netcdf_handle_error('PUT','VAR','genafm',my_name,ncerr)
 ! Put get1den
 ncerr = nf90_inq_varid(ncid,name='get1den',varid=ncvar)
 call netcdf_handle_error('INQ','VID','get1den',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%get1den)
 call netcdf_handle_error('PUT','VAR','get1den',my_name,ncerr)
 ! Put get1wf
 ncerr = nf90_inq_varid(ncid,name='get1wf',varid=ncvar)
 call netcdf_handle_error('INQ','VID','get1wf',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%get1wf)
 call netcdf_handle_error('PUT','VAR','get1wf',my_name,ncerr)
 ! Put getacfd
 ncerr = nf90_inq_varid(ncid,name='getacfd',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getacfd',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getacfd)
 call netcdf_handle_error('PUT','VAR','getacfd',my_name,ncerr)
 ! Put getcell
 ncerr = nf90_inq_varid(ncid,name='getcell',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getcell',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getcell)
 call netcdf_handle_error('PUT','VAR','getcell',my_name,ncerr)
 ! Put getddk
 ncerr = nf90_inq_varid(ncid,name='getddk',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getddk',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getddk)
 call netcdf_handle_error('PUT','VAR','getddk',my_name,ncerr)
 ! Put getden
 ncerr = nf90_inq_varid(ncid,name='getden',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getden',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getden)
 call netcdf_handle_error('PUT','VAR','getden',my_name,ncerr)
 ! Put getkss
 ncerr = nf90_inq_varid(ncid,name='getkss',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getkss',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getkss)
 call netcdf_handle_error('PUT','VAR','getkss',my_name,ncerr)
 ! Put getocc
 ncerr = nf90_inq_varid(ncid,name='getocc',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getocc',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getocc)
 call netcdf_handle_error('PUT','VAR','getocc',my_name,ncerr)
 ! Put getqps
 ncerr = nf90_inq_varid(ncid,name='getqps',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getqps',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getqps)
 call netcdf_handle_error('PUT','VAR','getqps',my_name,ncerr)
 ! Put getscr
 ncerr = nf90_inq_varid(ncid,name='getscr',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getscr',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getscr)
 call netcdf_handle_error('PUT','VAR','getscr',my_name,ncerr)
 ! Put getvel
 ncerr = nf90_inq_varid(ncid,name='getvel',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getvel',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getvel)
 call netcdf_handle_error('PUT','VAR','getvel',my_name,ncerr)
 ! Put getwfk
 ncerr = nf90_inq_varid(ncid,name='getwfk',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getwfk',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getwfk)
 call netcdf_handle_error('PUT','VAR','getwfk',my_name,ncerr)
 ! Put getwfq
 ncerr = nf90_inq_varid(ncid,name='getwfq',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getwfq',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getwfq)
 call netcdf_handle_error('PUT','VAR','getwfq',my_name,ncerr)
 ! Put getxcart
 ncerr = nf90_inq_varid(ncid,name='getxcart',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getxcart',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getxcart)
 call netcdf_handle_error('PUT','VAR','getxcart',my_name,ncerr)
 ! Put getxred
 ncerr = nf90_inq_varid(ncid,name='getxred',varid=ncvar)
 call netcdf_handle_error('INQ','VID','getxred',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%getxred)
 call netcdf_handle_error('PUT','VAR','getxred',my_name,ncerr)
 ! Put gpara
 ncerr = nf90_inq_varid(ncid,name='gpara',varid=ncvar)
 call netcdf_handle_error('INQ','VID','gpara',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%gpara)
 call netcdf_handle_error('PUT','VAR','gpara',my_name,ncerr)
 ! Put gwcalctyp
 ncerr = nf90_inq_varid(ncid,name='gwcalctyp',varid=ncvar)
 call netcdf_handle_error('INQ','VID','gwcalctyp',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%gwcalctyp)
 call netcdf_handle_error('PUT','VAR','gwcalctyp',my_name,ncerr)
 ! Put iatfix
 ncerr = nf90_inq_varid(ncid,name='iatfix',varid=ncvar)
 call netcdf_handle_error('INQ','VID','iatfix',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%iatfix)
 call netcdf_handle_error('PUT','VAR','iatfix',my_name,ncerr)
 ! Put iatsph
 ncerr = nf90_inq_varid(ncid,name='iatsph',varid=ncvar)
 call netcdf_handle_error('INQ','VID','iatsph',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%iatsph)
 call netcdf_handle_error('PUT','VAR','iatsph',my_name,ncerr)
 ! Put iboxcut
 ncerr = nf90_inq_varid(ncid,name='iboxcut',varid=ncvar)
 call netcdf_handle_error('INQ','VID','iboxcut',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%iboxcut)
 call netcdf_handle_error('PUT','VAR','iboxcut',my_name,ncerr)
 ! Put icoultrtmt
 ncerr = nf90_inq_varid(ncid,name='icoultrtmt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','icoultrtmt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%icoultrtmt)
 call netcdf_handle_error('PUT','VAR','icoultrtmt',my_name,ncerr)
 ! Put idyson
 ncerr = nf90_inq_varid(ncid,name='idyson',varid=ncvar)
 call netcdf_handle_error('INQ','VID','idyson',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%idyson)
 call netcdf_handle_error('PUT','VAR','idyson',my_name,ncerr)
 ! Put ikhxc
 ncerr = nf90_inq_varid(ncid,name='ikhxc',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ikhxc',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ikhxc)
 call netcdf_handle_error('PUT','VAR','ikhxc',my_name,ncerr)
 ! Put inclvkb
 ncerr = nf90_inq_varid(ncid,name='inclvkb',varid=ncvar)
 call netcdf_handle_error('INQ','VID','inclvkb',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%inclvkb)
 call netcdf_handle_error('PUT','VAR','inclvkb',my_name,ncerr)
 ! Put intexact
 ncerr = nf90_inq_varid(ncid,name='intexact',varid=ncvar)
 call netcdf_handle_error('INQ','VID','intexact',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%intexact)
 call netcdf_handle_error('PUT','VAR','intexact',my_name,ncerr)
 ! Put intxc
 ncerr = nf90_inq_varid(ncid,name='intxc',varid=ncvar)
 call netcdf_handle_error('INQ','VID','intxc',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%intxc)
 call netcdf_handle_error('PUT','VAR','intxc',my_name,ncerr)
 ! Put ionmov
 ncerr = nf90_inq_varid(ncid,name='ionmov',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ionmov',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ionmov)
 call netcdf_handle_error('PUT','VAR','ionmov',my_name,ncerr)
 ! Put iprcch
 ncerr = nf90_inq_varid(ncid,name='iprcch',varid=ncvar)
 call netcdf_handle_error('INQ','VID','iprcch',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%iprcch)
 call netcdf_handle_error('PUT','VAR','iprcch',my_name,ncerr)
 ! Put iprcel
 ncerr = nf90_inq_varid(ncid,name='iprcel',varid=ncvar)
 call netcdf_handle_error('INQ','VID','iprcel',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%iprcel)
 call netcdf_handle_error('PUT','VAR','iprcel',my_name,ncerr)
 ! Put iprcfc
 ncerr = nf90_inq_varid(ncid,name='iprcfc',varid=ncvar)
 call netcdf_handle_error('INQ','VID','iprcfc',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%iprcfc)
 call netcdf_handle_error('PUT','VAR','iprcfc',my_name,ncerr)
 ! Put iprctfvw
 ncerr = nf90_inq_varid(ncid,name='iprctfvw',varid=ncvar)
 call netcdf_handle_error('INQ','VID','iprctfvw',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%iprctfvw)
 call netcdf_handle_error('PUT','VAR','iprctfvw',my_name,ncerr)
 ! Put ird1wf
 ncerr = nf90_inq_varid(ncid,name='ird1wf',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ird1wf',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ird1wf)
 call netcdf_handle_error('PUT','VAR','ird1wf',my_name,ncerr)
 ! Put irdddk
 ncerr = nf90_inq_varid(ncid,name='irdddk',varid=ncvar)
 call netcdf_handle_error('INQ','VID','irdddk',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%irdddk)
 call netcdf_handle_error('PUT','VAR','irdddk',my_name,ncerr)
 ! Put irdkss
 ncerr = nf90_inq_varid(ncid,name='irdkss',varid=ncvar)
 call netcdf_handle_error('INQ','VID','irdkss',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%irdkss)
 call netcdf_handle_error('PUT','VAR','irdkss',my_name,ncerr)
 ! Put irdqps
 ncerr = nf90_inq_varid(ncid,name='irdqps',varid=ncvar)
 call netcdf_handle_error('INQ','VID','irdqps',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%irdqps)
 call netcdf_handle_error('PUT','VAR','irdqps',my_name,ncerr)
 ! Put irdscr
 ncerr = nf90_inq_varid(ncid,name='irdscr',varid=ncvar)
 call netcdf_handle_error('INQ','VID','irdscr',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%irdscr)
 call netcdf_handle_error('PUT','VAR','irdscr',my_name,ncerr)
 ! Put irdwfk
 ncerr = nf90_inq_varid(ncid,name='irdwfk',varid=ncvar)
 call netcdf_handle_error('INQ','VID','irdwfk',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%irdwfk)
 call netcdf_handle_error('PUT','VAR','irdwfk',my_name,ncerr)
 ! Put irdwfq
 ncerr = nf90_inq_varid(ncid,name='irdwfq',varid=ncvar)
 call netcdf_handle_error('INQ','VID','irdwfq',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%irdwfq)
 call netcdf_handle_error('PUT','VAR','irdwfq',my_name,ncerr)
 ! Put iscf
 ncerr = nf90_inq_varid(ncid,name='iscf',varid=ncvar)
 call netcdf_handle_error('INQ','VID','iscf',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%iscf)
 call netcdf_handle_error('PUT','VAR','iscf',my_name,ncerr)
 ! Put isecur
 ncerr = nf90_inq_varid(ncid,name='isecur',varid=ncvar)
 call netcdf_handle_error('INQ','VID','isecur',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%isecur)
 call netcdf_handle_error('PUT','VAR','isecur',my_name,ncerr)
 ! Put istatr
 ncerr = nf90_inq_varid(ncid,name='istatr',varid=ncvar)
 call netcdf_handle_error('INQ','VID','istatr',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%istatr)
 call netcdf_handle_error('PUT','VAR','istatr',my_name,ncerr)
 ! Put istatshft
 ncerr = nf90_inq_varid(ncid,name='istatshft',varid=ncvar)
 call netcdf_handle_error('INQ','VID','istatshft',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%istatshft)
 call netcdf_handle_error('PUT','VAR','istatshft',my_name,ncerr)
 ! Put istwfk
 ncerr = nf90_inq_varid(ncid,name='istwfk',varid=ncvar)
 call netcdf_handle_error('INQ','VID','istwfk',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%istwfk)
 call netcdf_handle_error('PUT','VAR','istwfk',my_name,ncerr)
 ! Put ixc
 ncerr = nf90_inq_varid(ncid,name='ixc',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ixc',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ixc)
 call netcdf_handle_error('PUT','VAR','ixc',my_name,ncerr)
 ! Put ixcpositron
 ncerr = nf90_inq_varid(ncid,name='ixcpositron',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ixcpositron',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ixcpositron)
 call netcdf_handle_error('PUT','VAR','ixcpositron',my_name,ncerr)
 ! Put jdtset
 ncerr = nf90_inq_varid(ncid,name='jdtset',varid=ncvar)
 call netcdf_handle_error('INQ','VID','jdtset',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%jdtset)
 call netcdf_handle_error('PUT','VAR','jdtset',my_name,ncerr)
 ! Put jpaw
 ncerr = nf90_inq_varid(ncid,name='jpaw',varid=ncvar)
 call netcdf_handle_error('INQ','VID','jpaw',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%jpaw)
 call netcdf_handle_error('PUT','VAR','jpaw',my_name,ncerr)
 ! Put kberry
 ncerr = nf90_inq_varid(ncid,name='kberry',varid=ncvar)
 call netcdf_handle_error('INQ','VID','kberry',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%kberry)
 call netcdf_handle_error('PUT','VAR','kberry',my_name,ncerr)
 ! Put kpara
 ncerr = nf90_inq_varid(ncid,name='kpara',varid=ncvar)
 call netcdf_handle_error('INQ','VID','kpara',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%kpara)
 call netcdf_handle_error('PUT','VAR','kpara',my_name,ncerr)
 ! Put kpt
 ncerr = nf90_inq_varid(ncid,name='kpt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','kpt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%kpt)
 call netcdf_handle_error('PUT','VAR','kpt',my_name,ncerr)
 ! Put kptgw
 ncerr = nf90_inq_varid(ncid,name='kptgw',varid=ncvar)
 call netcdf_handle_error('INQ','VID','kptgw',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%kptgw)
 call netcdf_handle_error('PUT','VAR','kptgw',my_name,ncerr)
 ! Put kptnrm
 ncerr = nf90_inq_varid(ncid,name='kptnrm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','kptnrm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%kptnrm)
 call netcdf_handle_error('PUT','VAR','kptnrm',my_name,ncerr)
 ! Put kptns
 ncerr = nf90_inq_varid(ncid,name='kptns',varid=ncvar)
 call netcdf_handle_error('INQ','VID','kptns',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%kptns)
 call netcdf_handle_error('PUT','VAR','kptns',my_name,ncerr)
 ! Put kptopt
 ncerr = nf90_inq_varid(ncid,name='kptopt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','kptopt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%kptopt)
 call netcdf_handle_error('PUT','VAR','kptopt',my_name,ncerr)
 ! Put kptrlatt
 ncerr = nf90_inq_varid(ncid,name='kptrlatt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','kptrlatt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%kptrlatt)
 call netcdf_handle_error('PUT','VAR','kptrlatt',my_name,ncerr)
 ! Put kptrlen
 ncerr = nf90_inq_varid(ncid,name='kptrlen',varid=ncvar)
 call netcdf_handle_error('INQ','VID','kptrlen',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%kptrlen)
 call netcdf_handle_error('PUT','VAR','kptrlen',my_name,ncerr)
 ! Put kssform
 ncerr = nf90_inq_varid(ncid,name='kssform',varid=ncvar)
 call netcdf_handle_error('INQ','VID','kssform',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%kssform)
 call netcdf_handle_error('PUT','VAR','kssform',my_name,ncerr)
 ! Put ldgapp
 ncerr = nf90_inq_varid(ncid,name='ldgapp',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ldgapp',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ldgapp)
 call netcdf_handle_error('PUT','VAR','ldgapp',my_name,ncerr)
 ! Put localrdwf
 ncerr = nf90_inq_varid(ncid,name='localrdwf',varid=ncvar)
 call netcdf_handle_error('INQ','VID','localrdwf',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%localrdwf)
 call netcdf_handle_error('PUT','VAR','localrdwf',my_name,ncerr)
 ! Put lofwrite
 ncerr = nf90_inq_varid(ncid,name='lofwrite',varid=ncvar)
 call netcdf_handle_error('INQ','VID','lofwrite',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%lofwrite)
 call netcdf_handle_error('PUT','VAR','lofwrite',my_name,ncerr)
 ! Put lpawu
 ncerr = nf90_inq_varid(ncid,name='lpawu',varid=ncvar)
 call netcdf_handle_error('INQ','VID','lpawu',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%lpawu)
 call netcdf_handle_error('PUT','VAR','lpawu',my_name,ncerr)
 ! Put ltypeorb
 ncerr = nf90_inq_varid(ncid,name='ltypeorb',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ltypeorb',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ltypeorb)
 call netcdf_handle_error('PUT','VAR','ltypeorb',my_name,ncerr)
 ! Put mband
 ncerr = nf90_inq_varid(ncid,name='mband',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mband',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mband)
 call netcdf_handle_error('PUT','VAR','mband',my_name,ncerr)
 ! Put mdftemp
 ncerr = nf90_inq_varid(ncid,name='mdftemp',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mdftemp',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mdftemp)
 call netcdf_handle_error('PUT','VAR','mdftemp',my_name,ncerr)
 ! Put mditemp
 ncerr = nf90_inq_varid(ncid,name='mditemp',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mditemp',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mditemp)
 call netcdf_handle_error('PUT','VAR','mditemp',my_name,ncerr)
 ! Put mdwall
 ncerr = nf90_inq_varid(ncid,name='mdwall',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mdwall',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mdwall)
 call netcdf_handle_error('PUT','VAR','mdwall',my_name,ncerr)
 ! Put mffmem
 ncerr = nf90_inq_varid(ncid,name='mffmem',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mffmem',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mffmem)
 call netcdf_handle_error('PUT','VAR','mffmem',my_name,ncerr)
 ! Put mgfft
 ncerr = nf90_inq_varid(ncid,name='mgfft',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mgfft',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mgfft)
 call netcdf_handle_error('PUT','VAR','mgfft',my_name,ncerr)
 ! Put mgfftdg
 ncerr = nf90_inq_varid(ncid,name='mgfftdg',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mgfftdg',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mgfftdg)
 call netcdf_handle_error('PUT','VAR','mgfftdg',my_name,ncerr)
 ! Put mixalch
 ncerr = nf90_inq_varid(ncid,name='mixalch',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mixalch',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mixalch)
 call netcdf_handle_error('PUT','VAR','mixalch',my_name,ncerr)
 ! Put mk1mem
 ncerr = nf90_inq_varid(ncid,name='mk1mem',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mk1mem',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mk1mem)
 call netcdf_handle_error('PUT','VAR','mk1mem',my_name,ncerr)
 ! Put mkmem
 ncerr = nf90_inq_varid(ncid,name='mkmem',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mkmem',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mkmem)
 call netcdf_handle_error('PUT','VAR','mkmem',my_name,ncerr)
 ! Put mkqmem
 ncerr = nf90_inq_varid(ncid,name='mkqmem',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mkqmem',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mkqmem)
 call netcdf_handle_error('PUT','VAR','mkqmem',my_name,ncerr)
 ! Put mpw
 ncerr = nf90_inq_varid(ncid,name='mpw',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mpw',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mpw)
 call netcdf_handle_error('PUT','VAR','mpw',my_name,ncerr)
 ! Put mqgrid
 ncerr = nf90_inq_varid(ncid,name='mqgrid',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mqgrid',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mqgrid)
 call netcdf_handle_error('PUT','VAR','mqgrid',my_name,ncerr)
 ! Put mqgriddg
 ncerr = nf90_inq_varid(ncid,name='mqgriddg',varid=ncvar)
 call netcdf_handle_error('INQ','VID','mqgriddg',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%mqgriddg)
 call netcdf_handle_error('PUT','VAR','mqgriddg',my_name,ncerr)
 ! Put natom
 ncerr = nf90_inq_varid(ncid,name='natom',varid=ncvar)
 call netcdf_handle_error('INQ','VID','natom',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%natom)
 call netcdf_handle_error('PUT','VAR','natom',my_name,ncerr)
 ! Put natrd
 ncerr = nf90_inq_varid(ncid,name='natrd',varid=ncvar)
 call netcdf_handle_error('INQ','VID','natrd',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%natrd)
 call netcdf_handle_error('PUT','VAR','natrd',my_name,ncerr)
 ! Put natsph
 ncerr = nf90_inq_varid(ncid,name='natsph',varid=ncvar)
 call netcdf_handle_error('INQ','VID','natsph',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%natsph)
 call netcdf_handle_error('PUT','VAR','natsph',my_name,ncerr)
 ! Put nband
 ncerr = nf90_inq_varid(ncid,name='nband',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nband',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nband)
 call netcdf_handle_error('PUT','VAR','nband',my_name,ncerr)
 ! Put nbandkss
 ncerr = nf90_inq_varid(ncid,name='nbandkss',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nbandkss',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nbandkss)
 call netcdf_handle_error('PUT','VAR','nbandkss',my_name,ncerr)
 ! Put nbandsus
 ncerr = nf90_inq_varid(ncid,name='nbandsus',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nbandsus',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nbandsus)
 call netcdf_handle_error('PUT','VAR','nbandsus',my_name,ncerr)
 ! Put nbdblock
 ncerr = nf90_inq_varid(ncid,name='nbdblock',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nbdblock',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nbdblock)
 call netcdf_handle_error('PUT','VAR','nbdblock',my_name,ncerr)
 ! Put nbdbuf
 ncerr = nf90_inq_varid(ncid,name='nbdbuf',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nbdbuf',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nbdbuf)
 call netcdf_handle_error('PUT','VAR','nbdbuf',my_name,ncerr)
 ! Put nberry
 ncerr = nf90_inq_varid(ncid,name='nberry',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nberry',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nberry)
 call netcdf_handle_error('PUT','VAR','nberry',my_name,ncerr)
 ! Put ncenter
 ncerr = nf90_inq_varid(ncid,name='ncenter',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ncenter',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ncenter)
 call netcdf_handle_error('PUT','VAR','ncenter',my_name,ncerr)
 ! Put nconeq
 ncerr = nf90_inq_varid(ncid,name='nconeq',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nconeq',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nconeq)
 call netcdf_handle_error('PUT','VAR','nconeq',my_name,ncerr)
 ! Put nctime
 ncerr = nf90_inq_varid(ncid,name='nctime',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nctime',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nctime)
 call netcdf_handle_error('PUT','VAR','nctime',my_name,ncerr)
 ! Put ndtset
 ncerr = nf90_inq_varid(ncid,name='ndtset',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ndtset',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ndtset)
 call netcdf_handle_error('PUT','VAR','ndtset',my_name,ncerr)
 ! Put ndyson
 ncerr = nf90_inq_varid(ncid,name='ndyson',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ndyson',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ndyson)
 call netcdf_handle_error('PUT','VAR','ndyson',my_name,ncerr)
 ! Put nelect
 ncerr = nf90_inq_varid(ncid,name='nelect',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nelect',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nelect)
 call netcdf_handle_error('PUT','VAR','nelect',my_name,ncerr)
 ! Put nfft
 ncerr = nf90_inq_varid(ncid,name='nfft',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nfft',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nfft)
 call netcdf_handle_error('PUT','VAR','nfft',my_name,ncerr)
 ! Put nfftdg
 ncerr = nf90_inq_varid(ncid,name='nfftdg',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nfftdg',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nfftdg)
 call netcdf_handle_error('PUT','VAR','nfftdg',my_name,ncerr)
 ! Put nfreqim
 ncerr = nf90_inq_varid(ncid,name='nfreqim',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nfreqim',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nfreqim)
 call netcdf_handle_error('PUT','VAR','nfreqim',my_name,ncerr)
 ! Put nfreqre
 ncerr = nf90_inq_varid(ncid,name='nfreqre',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nfreqre',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nfreqre)
 call netcdf_handle_error('PUT','VAR','nfreqre',my_name,ncerr)
 ! Put nfreqsp
 ncerr = nf90_inq_varid(ncid,name='nfreqsp',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nfreqsp',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nfreqsp)
 call netcdf_handle_error('PUT','VAR','nfreqsp',my_name,ncerr)
 ! Put nfreqsus
 ncerr = nf90_inq_varid(ncid,name='nfreqsus',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nfreqsus',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nfreqsus)
 call netcdf_handle_error('PUT','VAR','nfreqsus',my_name,ncerr)
 ! Put ngfft
 ncerr = nf90_inq_varid(ncid,name='ngfft',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ngfft',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ngfft)
 call netcdf_handle_error('PUT','VAR','ngfft',my_name,ncerr)
 ! Put ngfftdg
 ncerr = nf90_inq_varid(ncid,name='ngfftdg',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ngfftdg',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ngfftdg)
 call netcdf_handle_error('PUT','VAR','ngfftdg',my_name,ncerr)
 ! Put ngroup_rf
 ncerr = nf90_inq_varid(ncid,name='ngroup_rf',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ngroup_rf',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ngroup_rf)
 call netcdf_handle_error('PUT','VAR','ngroup_rf',my_name,ncerr)
 ! Put nkpt
 ncerr = nf90_inq_varid(ncid,name='nkpt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nkpt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nkpt)
 call netcdf_handle_error('PUT','VAR','nkpt',my_name,ncerr)
 ! Put nkptgw
 ncerr = nf90_inq_varid(ncid,name='nkptgw',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nkptgw',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nkptgw)
 call netcdf_handle_error('PUT','VAR','nkptgw',my_name,ncerr)
 ! Put nline
 ncerr = nf90_inq_varid(ncid,name='nline',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nline',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nline)
 call netcdf_handle_error('PUT','VAR','nline',my_name,ncerr)
 ! Put nloalg
 ncerr = nf90_inq_varid(ncid,name='nloalg',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nloalg',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nloalg)
 call netcdf_handle_error('PUT','VAR','nloalg',my_name,ncerr)
 ! Put nnsclo
 ncerr = nf90_inq_varid(ncid,name='nnsclo',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nnsclo',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nnsclo)
 call netcdf_handle_error('PUT','VAR','nnsclo',my_name,ncerr)
 ! Put nomegasrd
 ncerr = nf90_inq_varid(ncid,name='nomegasrd',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nomegasrd',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nomegasrd)
 call netcdf_handle_error('PUT','VAR','nomegasrd',my_name,ncerr)
 ! Put norb
 ncerr = nf90_inq_varid(ncid,name='norb',varid=ncvar)
 call netcdf_handle_error('INQ','VID','norb',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%norb)
 call netcdf_handle_error('PUT','VAR','norb',my_name,ncerr)
 ! Put noseinert
 ncerr = nf90_inq_varid(ncid,name='noseinert',varid=ncvar)
 call netcdf_handle_error('INQ','VID','noseinert',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%noseinert)
 call netcdf_handle_error('PUT','VAR','noseinert',my_name,ncerr)
 ! Put npack
 ncerr = nf90_inq_varid(ncid,name='npack',varid=ncvar)
 call netcdf_handle_error('INQ','VID','npack',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%npack)
 call netcdf_handle_error('PUT','VAR','npack',my_name,ncerr)
 ! Put npara
 ncerr = nf90_inq_varid(ncid,name='npara',varid=ncvar)
 call netcdf_handle_error('INQ','VID','npara',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%npara)
 call netcdf_handle_error('PUT','VAR','npara',my_name,ncerr)
 ! Put npband
 ncerr = nf90_inq_varid(ncid,name='npband',varid=ncvar)
 call netcdf_handle_error('INQ','VID','npband',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%npband)
 call netcdf_handle_error('PUT','VAR','npband',my_name,ncerr)
 ! Put npfft
 ncerr = nf90_inq_varid(ncid,name='npfft',varid=ncvar)
 call netcdf_handle_error('INQ','VID','npfft',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%npfft)
 call netcdf_handle_error('PUT','VAR','npfft',my_name,ncerr)
 ! Put npsp
 ncerr = nf90_inq_varid(ncid,name='npsp',varid=ncvar)
 call netcdf_handle_error('INQ','VID','npsp',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%npsp)
 call netcdf_handle_error('PUT','VAR','npsp',my_name,ncerr)
 ! Put npspalch
 ncerr = nf90_inq_varid(ncid,name='npspalch',varid=ncvar)
 call netcdf_handle_error('INQ','VID','npspalch',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%npspalch)
 call netcdf_handle_error('PUT','VAR','npspalch',my_name,ncerr)
 ! Put npulayit
 ncerr = nf90_inq_varid(ncid,name='npulayit',varid=ncvar)
 call netcdf_handle_error('INQ','VID','npulayit',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%npulayit)
 call netcdf_handle_error('PUT','VAR','npulayit',my_name,ncerr)
 ! Put npweps
 ncerr = nf90_inq_varid(ncid,name='npweps',varid=ncvar)
 call netcdf_handle_error('INQ','VID','npweps',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%npweps)
 call netcdf_handle_error('PUT','VAR','npweps',my_name,ncerr)
 ! Put npwkss
 ncerr = nf90_inq_varid(ncid,name='npwkss',varid=ncvar)
 call netcdf_handle_error('INQ','VID','npwkss',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%npwkss)
 call netcdf_handle_error('PUT','VAR','npwkss',my_name,ncerr)
 ! Put npwsigx
 ncerr = nf90_inq_varid(ncid,name='npwsigx',varid=ncvar)
 call netcdf_handle_error('INQ','VID','npwsigx',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%npwsigx)
 call netcdf_handle_error('PUT','VAR','npwsigx',my_name,ncerr)
 ! Put npwwfn
 ncerr = nf90_inq_varid(ncid,name='npwwfn',varid=ncvar)
 call netcdf_handle_error('INQ','VID','npwwfn',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%npwwfn)
 call netcdf_handle_error('PUT','VAR','npwwfn',my_name,ncerr)
 ! Put nqpt
 ncerr = nf90_inq_varid(ncid,name='nqpt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nqpt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nqpt)
 call netcdf_handle_error('PUT','VAR','nqpt',my_name,ncerr)
 ! Put nqptdm
 ncerr = nf90_inq_varid(ncid,name='nqptdm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nqptdm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nqptdm)
 call netcdf_handle_error('PUT','VAR','nqptdm',my_name,ncerr)
 ! Put nscforder
 ncerr = nf90_inq_varid(ncid,name='nscforder',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nscforder',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nscforder)
 call netcdf_handle_error('PUT','VAR','nscforder',my_name,ncerr)
 ! Put nsheps
 ncerr = nf90_inq_varid(ncid,name='nsheps',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nsheps',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nsheps)
 call netcdf_handle_error('PUT','VAR','nsheps',my_name,ncerr)
 ! Put nshiftk
 ncerr = nf90_inq_varid(ncid,name='nshiftk',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nshiftk',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nshiftk)
 call netcdf_handle_error('PUT','VAR','nshiftk',my_name,ncerr)
 ! Put nshsigx
 ncerr = nf90_inq_varid(ncid,name='nshsigx',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nshsigx',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nshsigx)
 call netcdf_handle_error('PUT','VAR','nshsigx',my_name,ncerr)
 ! Put nshwfn
 ncerr = nf90_inq_varid(ncid,name='nshwfn',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nshwfn',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nshwfn)
 call netcdf_handle_error('PUT','VAR','nshwfn',my_name,ncerr)
 ! Put nspden
 ncerr = nf90_inq_varid(ncid,name='nspden',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nspden',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nspden)
 call netcdf_handle_error('PUT','VAR','nspden',my_name,ncerr)
 ! Put nspinor
 ncerr = nf90_inq_varid(ncid,name='nspinor',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nspinor',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nspinor)
 call netcdf_handle_error('PUT','VAR','nspinor',my_name,ncerr)
 ! Put nsppol
 ncerr = nf90_inq_varid(ncid,name='nsppol',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nsppol',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nsppol)
 call netcdf_handle_error('PUT','VAR','nsppol',my_name,ncerr)
 ! Put nstep
 ncerr = nf90_inq_varid(ncid,name='nstep',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nstep',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nstep)
 call netcdf_handle_error('PUT','VAR','nstep',my_name,ncerr)
 ! Put nsym
 ncerr = nf90_inq_varid(ncid,name='nsym',varid=ncvar)
 call netcdf_handle_error('INQ','VID','nsym',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%nsym)
 call netcdf_handle_error('PUT','VAR','nsym',my_name,ncerr)
 ! Put ntime
 ncerr = nf90_inq_varid(ncid,name='ntime',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ntime',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ntime)
 call netcdf_handle_error('PUT','VAR','ntime',my_name,ncerr)
 ! Put ntypalch
 ncerr = nf90_inq_varid(ncid,name='ntypalch',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ntypalch',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ntypalch)
 call netcdf_handle_error('PUT','VAR','ntypalch',my_name,ncerr)
 ! Put ntypat
 ncerr = nf90_inq_varid(ncid,name='ntypat',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ntypat',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ntypat)
 call netcdf_handle_error('PUT','VAR','ntypat',my_name,ncerr)
 ! Put ntyppure
 ncerr = nf90_inq_varid(ncid,name='ntyppure',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ntyppure',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ntyppure)
 call netcdf_handle_error('PUT','VAR','ntyppure',my_name,ncerr)
 ! Put numorb
 ncerr = nf90_inq_varid(ncid,name='numorb',varid=ncvar)
 call netcdf_handle_error('INQ','VID','numorb',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%numorb)
 call netcdf_handle_error('PUT','VAR','numorb',my_name,ncerr)
 ! Put occ_orig
 ncerr = nf90_inq_varid(ncid,name='occ_orig',varid=ncvar)
 call netcdf_handle_error('INQ','VID','occ_orig',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%occ_orig)
 call netcdf_handle_error('PUT','VAR','occ_orig',my_name,ncerr)
 ! Put occopt
 ncerr = nf90_inq_varid(ncid,name='occopt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','occopt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%occopt)
 call netcdf_handle_error('PUT','VAR','occopt',my_name,ncerr)
 ! Put omegasrdmax
 ncerr = nf90_inq_varid(ncid,name='omegasrdmax',varid=ncvar)
 call netcdf_handle_error('INQ','VID','omegasrdmax',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%omegasrdmax)
 call netcdf_handle_error('PUT','VAR','omegasrdmax',my_name,ncerr)
 ! Put optcell
 ncerr = nf90_inq_varid(ncid,name='optcell',varid=ncvar)
 call netcdf_handle_error('INQ','VID','optcell',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%optcell)
 call netcdf_handle_error('PUT','VAR','optcell',my_name,ncerr)
 ! Put optdriver
 ncerr = nf90_inq_varid(ncid,name='optdriver',varid=ncvar)
 call netcdf_handle_error('INQ','VID','optdriver',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%optdriver)
 call netcdf_handle_error('PUT','VAR','optdriver',my_name,ncerr)
 ! Put optforces
 ncerr = nf90_inq_varid(ncid,name='optforces',varid=ncvar)
 call netcdf_handle_error('INQ','VID','optforces',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%optforces)
 call netcdf_handle_error('PUT','VAR','optforces',my_name,ncerr)
 ! Put optfreqsus
 ncerr = nf90_inq_varid(ncid,name='optfreqsus',varid=ncvar)
 call netcdf_handle_error('INQ','VID','optfreqsus',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%optfreqsus)
 call netcdf_handle_error('PUT','VAR','optfreqsus',my_name,ncerr)
 ! Put optnlxccc
 ncerr = nf90_inq_varid(ncid,name='optnlxccc',varid=ncvar)
 call netcdf_handle_error('INQ','VID','optnlxccc',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%optnlxccc)
 call netcdf_handle_error('PUT','VAR','optnlxccc',my_name,ncerr)
 ! Put optstress
 ncerr = nf90_inq_varid(ncid,name='optstress',varid=ncvar)
 call netcdf_handle_error('INQ','VID','optstress',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%optstress)
 call netcdf_handle_error('PUT','VAR','optstress',my_name,ncerr)
 ! Put ortalg
 ncerr = nf90_inq_varid(ncid,name='ortalg',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ortalg',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ortalg)
 call netcdf_handle_error('PUT','VAR','ortalg',my_name,ncerr)
 ! Put outputXML
 ncerr = nf90_inq_varid(ncid,name='outputXML',varid=ncvar)
 call netcdf_handle_error('INQ','VID','outputXML',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%outputXML)
 call netcdf_handle_error('PUT','VAR','outputXML',my_name,ncerr)
 ! Put paral_rf
 ncerr = nf90_inq_varid(ncid,name='paral_rf',varid=ncvar)
 call netcdf_handle_error('INQ','VID','paral_rf',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%paral_rf)
 call netcdf_handle_error('PUT','VAR','paral_rf',my_name,ncerr)
 ! Put parareel
 ncerr = nf90_inq_varid(ncid,name='parareel',varid=ncvar)
 call netcdf_handle_error('INQ','VID','parareel',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%parareel)
 call netcdf_handle_error('PUT','VAR','parareel',my_name,ncerr)
 ! Put pawecutdg
 ncerr = nf90_inq_varid(ncid,name='pawecutdg',varid=ncvar)
 call netcdf_handle_error('INQ','VID','pawecutdg',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%pawecutdg)
 call netcdf_handle_error('PUT','VAR','pawecutdg',my_name,ncerr)
 ! Put pawlcutd
 ncerr = nf90_inq_varid(ncid,name='pawlcutd',varid=ncvar)
 call netcdf_handle_error('INQ','VID','pawlcutd',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%pawlcutd)
 call netcdf_handle_error('PUT','VAR','pawlcutd',my_name,ncerr)
 ! Put pawlmix
 ncerr = nf90_inq_varid(ncid,name='pawlmix',varid=ncvar)
 call netcdf_handle_error('INQ','VID','pawlmix',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%pawlmix)
 call netcdf_handle_error('PUT','VAR','pawlmix',my_name,ncerr)
 ! Put pawmixdg
 ncerr = nf90_inq_varid(ncid,name='pawmixdg',varid=ncvar)
 call netcdf_handle_error('INQ','VID','pawmixdg',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%pawmixdg)
 call netcdf_handle_error('PUT','VAR','pawmixdg',my_name,ncerr)
 ! Put pawnphi
 ncerr = nf90_inq_varid(ncid,name='pawnphi',varid=ncvar)
 call netcdf_handle_error('INQ','VID','pawnphi',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%pawnphi)
 call netcdf_handle_error('PUT','VAR','pawnphi',my_name,ncerr)
 ! Put pawntheta
 ncerr = nf90_inq_varid(ncid,name='pawntheta',varid=ncvar)
 call netcdf_handle_error('INQ','VID','pawntheta',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%pawntheta)
 call netcdf_handle_error('PUT','VAR','pawntheta',my_name,ncerr)
 ! Put pawnzlm
 ncerr = nf90_inq_varid(ncid,name='pawnzlm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','pawnzlm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%pawnzlm)
 call netcdf_handle_error('PUT','VAR','pawnzlm',my_name,ncerr)
 ! Put pawoptmix
 ncerr = nf90_inq_varid(ncid,name='pawoptmix',varid=ncvar)
 call netcdf_handle_error('INQ','VID','pawoptmix',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%pawoptmix)
 call netcdf_handle_error('PUT','VAR','pawoptmix',my_name,ncerr)
 ! Put pawovlp
 ncerr = nf90_inq_varid(ncid,name='pawovlp',varid=ncvar)
 call netcdf_handle_error('INQ','VID','pawovlp',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%pawovlp)
 call netcdf_handle_error('PUT','VAR','pawovlp',my_name,ncerr)
 ! Put pawprtvol
 ncerr = nf90_inq_varid(ncid,name='pawprtvol',varid=ncvar)
 call netcdf_handle_error('INQ','VID','pawprtvol',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%pawprtvol)
 call netcdf_handle_error('PUT','VAR','pawprtvol',my_name,ncerr)
 ! Put pawsphmix
 ncerr = nf90_inq_varid(ncid,name='pawsphmix',varid=ncvar)
 call netcdf_handle_error('INQ','VID','pawsphmix',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%pawsphmix)
 call netcdf_handle_error('PUT','VAR','pawsphmix',my_name,ncerr)
 ! Put pawxcdev
 ncerr = nf90_inq_varid(ncid,name='pawxcdev',varid=ncvar)
 call netcdf_handle_error('INQ','VID','pawxcdev',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%pawxcdev)
 call netcdf_handle_error('PUT','VAR','pawxcdev',my_name,ncerr)
 ! Put positron
 ncerr = nf90_inq_varid(ncid,name='positron',varid=ncvar)
 call netcdf_handle_error('INQ','VID','positron',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%positron)
 call netcdf_handle_error('PUT','VAR','positron',my_name,ncerr)
 ! Put ppmfrq
 ncerr = nf90_inq_varid(ncid,name='ppmfrq',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ppmfrq',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ppmfrq)
 call netcdf_handle_error('PUT','VAR','ppmfrq',my_name,ncerr)
 ! Put ppmodel
 ncerr = nf90_inq_varid(ncid,name='ppmodel',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ppmodel',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ppmodel)
 call netcdf_handle_error('PUT','VAR','ppmodel',my_name,ncerr)
 ! Put prepanl
 ncerr = nf90_inq_varid(ncid,name='prepanl',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prepanl',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prepanl)
 call netcdf_handle_error('PUT','VAR','prepanl',my_name,ncerr)
 ! Put prt1dm
 ncerr = nf90_inq_varid(ncid,name='prt1dm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prt1dm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prt1dm)
 call netcdf_handle_error('PUT','VAR','prt1dm',my_name,ncerr)
 ! Put prtacfd
 ncerr = nf90_inq_varid(ncid,name='prtacfd',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtacfd',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtacfd)
 call netcdf_handle_error('PUT','VAR','prtacfd',my_name,ncerr)
 ! Put prtbbb
 ncerr = nf90_inq_varid(ncid,name='prtbbb',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtbbb',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtbbb)
 call netcdf_handle_error('PUT','VAR','prtbbb',my_name,ncerr)
 ! Put prtcml
 ncerr = nf90_inq_varid(ncid,name='prtcml',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtcml',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtcml)
 call netcdf_handle_error('PUT','VAR','prtcml',my_name,ncerr)
 ! Put prtden
 ncerr = nf90_inq_varid(ncid,name='prtden',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtden',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtden)
 call netcdf_handle_error('PUT','VAR','prtden',my_name,ncerr)
 ! Put prtdos
 ncerr = nf90_inq_varid(ncid,name='prtdos',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtdos',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtdos)
 call netcdf_handle_error('PUT','VAR','prtdos',my_name,ncerr)
 ! Put prteig
 ncerr = nf90_inq_varid(ncid,name='prteig',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prteig',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prteig)
 call netcdf_handle_error('PUT','VAR','prteig',my_name,ncerr)
 ! Put prtfsurf
 ncerr = nf90_inq_varid(ncid,name='prtfsurf',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtfsurf',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtfsurf)
 call netcdf_handle_error('PUT','VAR','prtfsurf',my_name,ncerr)
 ! Put prtgeo
 ncerr = nf90_inq_varid(ncid,name='prtgeo',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtgeo',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtgeo)
 call netcdf_handle_error('PUT','VAR','prtgeo',my_name,ncerr)
 ! Put prtgkk
 ncerr = nf90_inq_varid(ncid,name='prtgkk',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtgkk',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtgkk)
 call netcdf_handle_error('PUT','VAR','prtgkk',my_name,ncerr)
 ! Put prtkpt
 ncerr = nf90_inq_varid(ncid,name='prtkpt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtkpt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtkpt)
 call netcdf_handle_error('PUT','VAR','prtkpt',my_name,ncerr)
 ! Put prtnabla
 ncerr = nf90_inq_varid(ncid,name='prtnabla',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtnabla',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtnabla)
 call netcdf_handle_error('PUT','VAR','prtnabla',my_name,ncerr)
 ! Put prtpot
 ncerr = nf90_inq_varid(ncid,name='prtpot',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtpot',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtpot)
 call netcdf_handle_error('PUT','VAR','prtpot',my_name,ncerr)
 ! Put prtstm
 ncerr = nf90_inq_varid(ncid,name='prtstm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtstm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtstm)
 call netcdf_handle_error('PUT','VAR','prtstm',my_name,ncerr)
 ! Put prtvha
 ncerr = nf90_inq_varid(ncid,name='prtvha',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtvha',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtvha)
 call netcdf_handle_error('PUT','VAR','prtvha',my_name,ncerr)
 ! Put prtvhxc
 ncerr = nf90_inq_varid(ncid,name='prtvhxc',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtvhxc',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtvhxc)
 call netcdf_handle_error('PUT','VAR','prtvhxc',my_name,ncerr)
 ! Put prtvol
 ncerr = nf90_inq_varid(ncid,name='prtvol',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtvol',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtvol)
 call netcdf_handle_error('PUT','VAR','prtvol',my_name,ncerr)
 ! Put prtvxc
 ncerr = nf90_inq_varid(ncid,name='prtvxc',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtvxc',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtvxc)
 call netcdf_handle_error('PUT','VAR','prtvxc',my_name,ncerr)
 ! Put prtwant
 ncerr = nf90_inq_varid(ncid,name='prtwant',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtwant',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtwant)
 call netcdf_handle_error('PUT','VAR','prtwant',my_name,ncerr)
 ! Put prtwf
 ncerr = nf90_inq_varid(ncid,name='prtwf',varid=ncvar)
 call netcdf_handle_error('INQ','VID','prtwf',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%prtwf)
 call netcdf_handle_error('PUT','VAR','prtwf',my_name,ncerr)
 ! Put ptgroupma
 ncerr = nf90_inq_varid(ncid,name='ptgroupma',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ptgroupma',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ptgroupma)
 call netcdf_handle_error('PUT','VAR','ptgroupma',my_name,ncerr)
 ! Put qprtrb
 ncerr = nf90_inq_varid(ncid,name='qprtrb',varid=ncvar)
 call netcdf_handle_error('INQ','VID','qprtrb',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%qprtrb)
 call netcdf_handle_error('PUT','VAR','qprtrb',my_name,ncerr)
 ! Put qpt
 ncerr = nf90_inq_varid(ncid,name='qpt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','qpt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%qpt)
 call netcdf_handle_error('PUT','VAR','qpt',my_name,ncerr)
 ! Put qptdm
 ncerr = nf90_inq_varid(ncid,name='qptdm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','qptdm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%qptdm)
 call netcdf_handle_error('PUT','VAR','qptdm',my_name,ncerr)
 ! Put qptn
 ncerr = nf90_inq_varid(ncid,name='qptn',varid=ncvar)
 call netcdf_handle_error('INQ','VID','qptn',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%qptn)
 call netcdf_handle_error('PUT','VAR','qptn',my_name,ncerr)
 ! Put qptnrm
 ncerr = nf90_inq_varid(ncid,name='qptnrm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','qptnrm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%qptnrm)
 call netcdf_handle_error('PUT','VAR','qptnrm',my_name,ncerr)
 ! Put ratsph
 ncerr = nf90_inq_varid(ncid,name='ratsph',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ratsph',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ratsph)
 call netcdf_handle_error('PUT','VAR','ratsph',my_name,ncerr)
 ! Put rcoord
 ncerr = nf90_inq_varid(ncid,name='rcoord',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rcoord',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rcoord)
 call netcdf_handle_error('PUT','VAR','rcoord',my_name,ncerr)
 ! Put restartxf
 ncerr = nf90_inq_varid(ncid,name='restartxf',varid=ncvar)
 call netcdf_handle_error('INQ','VID','restartxf',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%restartxf)
 call netcdf_handle_error('PUT','VAR','restartxf',my_name,ncerr)
 ! Put rf1atpol
 ncerr = nf90_inq_varid(ncid,name='rf1atpol',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rf1atpol',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rf1atpol)
 call netcdf_handle_error('PUT','VAR','rf1atpol',my_name,ncerr)
 ! Put rf1dir
 ncerr = nf90_inq_varid(ncid,name='rf1dir',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rf1dir',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rf1dir)
 call netcdf_handle_error('PUT','VAR','rf1dir',my_name,ncerr)
 ! Put rf1elfd
 ncerr = nf90_inq_varid(ncid,name='rf1elfd',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rf1elfd',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rf1elfd)
 call netcdf_handle_error('PUT','VAR','rf1elfd',my_name,ncerr)
 ! Put rf1phon
 ncerr = nf90_inq_varid(ncid,name='rf1phon',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rf1phon',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rf1phon)
 call netcdf_handle_error('PUT','VAR','rf1phon',my_name,ncerr)
 ! Put rf2atpol
 ncerr = nf90_inq_varid(ncid,name='rf2atpol',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rf2atpol',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rf2atpol)
 call netcdf_handle_error('PUT','VAR','rf2atpol',my_name,ncerr)
 ! Put rf2dir
 ncerr = nf90_inq_varid(ncid,name='rf2dir',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rf2dir',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rf2dir)
 call netcdf_handle_error('PUT','VAR','rf2dir',my_name,ncerr)
 ! Put rf2elfd
 ncerr = nf90_inq_varid(ncid,name='rf2elfd',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rf2elfd',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rf2elfd)
 call netcdf_handle_error('PUT','VAR','rf2elfd',my_name,ncerr)
 ! Put rf2phon
 ncerr = nf90_inq_varid(ncid,name='rf2phon',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rf2phon',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rf2phon)
 call netcdf_handle_error('PUT','VAR','rf2phon',my_name,ncerr)
 ! Put rf3atpol
 ncerr = nf90_inq_varid(ncid,name='rf3atpol',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rf3atpol',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rf3atpol)
 call netcdf_handle_error('PUT','VAR','rf3atpol',my_name,ncerr)
 ! Put rf3dir
 ncerr = nf90_inq_varid(ncid,name='rf3dir',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rf3dir',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rf3dir)
 call netcdf_handle_error('PUT','VAR','rf3dir',my_name,ncerr)
 ! Put rf3elfd
 ncerr = nf90_inq_varid(ncid,name='rf3elfd',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rf3elfd',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rf3elfd)
 call netcdf_handle_error('PUT','VAR','rf3elfd',my_name,ncerr)
 ! Put rf3phon
 ncerr = nf90_inq_varid(ncid,name='rf3phon',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rf3phon',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rf3phon)
 call netcdf_handle_error('PUT','VAR','rf3phon',my_name,ncerr)
 ! Put rfasr
 ncerr = nf90_inq_varid(ncid,name='rfasr',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rfasr',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rfasr)
 call netcdf_handle_error('PUT','VAR','rfasr',my_name,ncerr)
 ! Put rfatpol
 ncerr = nf90_inq_varid(ncid,name='rfatpol',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rfatpol',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rfatpol)
 call netcdf_handle_error('PUT','VAR','rfatpol',my_name,ncerr)
 ! Put rfdir
 ncerr = nf90_inq_varid(ncid,name='rfdir',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rfdir',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rfdir)
 call netcdf_handle_error('PUT','VAR','rfdir',my_name,ncerr)
 ! Put rfelfd
 ncerr = nf90_inq_varid(ncid,name='rfelfd',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rfelfd',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rfelfd)
 call netcdf_handle_error('PUT','VAR','rfelfd',my_name,ncerr)
 ! Put rfmeth
 ncerr = nf90_inq_varid(ncid,name='rfmeth',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rfmeth',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rfmeth)
 call netcdf_handle_error('PUT','VAR','rfmeth',my_name,ncerr)
 ! Put rfphon
 ncerr = nf90_inq_varid(ncid,name='rfphon',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rfphon',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rfphon)
 call netcdf_handle_error('PUT','VAR','rfphon',my_name,ncerr)
 ! Put rfstrs
 ncerr = nf90_inq_varid(ncid,name='rfstrs',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rfstrs',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rfstrs)
 call netcdf_handle_error('PUT','VAR','rfstrs',my_name,ncerr)
 ! Put rfthrd
 ncerr = nf90_inq_varid(ncid,name='rfthrd',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rfthrd',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rfthrd)
 call netcdf_handle_error('PUT','VAR','rfthrd',my_name,ncerr)
 ! Put rfuser
 ncerr = nf90_inq_varid(ncid,name='rfuser',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rfuser',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rfuser)
 call netcdf_handle_error('PUT','VAR','rfuser',my_name,ncerr)
 ! Put rprim_orig
 ncerr = nf90_inq_varid(ncid,name='rprim_orig',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rprim_orig',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rprim_orig)
 call netcdf_handle_error('PUT','VAR','rprim_orig',my_name,ncerr)
 ! Put rprimd_orig
 ncerr = nf90_inq_varid(ncid,name='rprimd_orig',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rprimd_orig',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rprimd_orig)
 call netcdf_handle_error('PUT','VAR','rprimd_orig',my_name,ncerr)
 ! Put rtheta
 ncerr = nf90_inq_varid(ncid,name='rtheta',varid=ncvar)
 call netcdf_handle_error('INQ','VID','rtheta',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%rtheta)
 call netcdf_handle_error('PUT','VAR','rtheta',my_name,ncerr)
 ! Put sciss
 ncerr = nf90_inq_varid(ncid,name='sciss',varid=ncvar)
 call netcdf_handle_error('INQ','VID','sciss',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%sciss)
 call netcdf_handle_error('PUT','VAR','sciss',my_name,ncerr)
 ! Put shiftk
 ncerr = nf90_inq_varid(ncid,name='shiftk',varid=ncvar)
 call netcdf_handle_error('INQ','VID','shiftk',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%shiftk)
 call netcdf_handle_error('PUT','VAR','shiftk',my_name,ncerr)
 ! Put signperm
 ncerr = nf90_inq_varid(ncid,name='signperm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','signperm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%signperm)
 call netcdf_handle_error('PUT','VAR','signperm',my_name,ncerr)
 ! Put so_typat
 ncerr = nf90_inq_varid(ncid,name='so_typat',varid=ncvar)
 call netcdf_handle_error('INQ','VID','so_typat',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%so_typat)
 call netcdf_handle_error('PUT','VAR','so_typat',my_name,ncerr)
 ! Put soenergy
 ncerr = nf90_inq_varid(ncid,name='soenergy',varid=ncvar)
 call netcdf_handle_error('INQ','VID','soenergy',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%soenergy)
 call netcdf_handle_error('PUT','VAR','soenergy',my_name,ncerr)
 ! Put spgaxor
 ncerr = nf90_inq_varid(ncid,name='spgaxor',varid=ncvar)
 call netcdf_handle_error('INQ','VID','spgaxor',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%spgaxor)
 call netcdf_handle_error('PUT','VAR','spgaxor',my_name,ncerr)
 ! Put spgorig
 ncerr = nf90_inq_varid(ncid,name='spgorig',varid=ncvar)
 call netcdf_handle_error('INQ','VID','spgorig',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%spgorig)
 call netcdf_handle_error('PUT','VAR','spgorig',my_name,ncerr)
 ! Put spgroup
 ncerr = nf90_inq_varid(ncid,name='spgroup',varid=ncvar)
 call netcdf_handle_error('INQ','VID','spgroup',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%spgroup)
 call netcdf_handle_error('PUT','VAR','spgroup',my_name,ncerr)
 ! Put spinat
 ncerr = nf90_inq_varid(ncid,name='spinat',varid=ncvar)
 call netcdf_handle_error('INQ','VID','spinat',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%spinat)
 call netcdf_handle_error('PUT','VAR','spinat',my_name,ncerr)
 ! Put splitsigc
 ncerr = nf90_inq_varid(ncid,name='splitsigc',varid=ncvar)
 call netcdf_handle_error('INQ','VID','splitsigc',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%splitsigc)
 call netcdf_handle_error('PUT','VAR','splitsigc',my_name,ncerr)
 ! Put stmbias
 ncerr = nf90_inq_varid(ncid,name='stmbias',varid=ncvar)
 call netcdf_handle_error('INQ','VID','stmbias',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%stmbias)
 call netcdf_handle_error('PUT','VAR','stmbias',my_name,ncerr)
 ! Put strfact
 ncerr = nf90_inq_varid(ncid,name='strfact',varid=ncvar)
 call netcdf_handle_error('INQ','VID','strfact',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%strfact)
 call netcdf_handle_error('PUT','VAR','strfact',my_name,ncerr)
 ! Put strprecon
 ncerr = nf90_inq_varid(ncid,name='strprecon',varid=ncvar)
 call netcdf_handle_error('INQ','VID','strprecon',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%strprecon)
 call netcdf_handle_error('PUT','VAR','strprecon',my_name,ncerr)
 ! Put strtarget
 ncerr = nf90_inq_varid(ncid,name='strtarget',varid=ncvar)
 call netcdf_handle_error('INQ','VID','strtarget',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%strtarget)
 call netcdf_handle_error('PUT','VAR','strtarget',my_name,ncerr)
 ! Put supercell
 ncerr = nf90_inq_varid(ncid,name='supercell',varid=ncvar)
 call netcdf_handle_error('INQ','VID','supercell',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%supercell)
 call netcdf_handle_error('PUT','VAR','supercell',my_name,ncerr)
 ! Put suskxcrs
 ncerr = nf90_inq_varid(ncid,name='suskxcrs',varid=ncvar)
 call netcdf_handle_error('INQ','VID','suskxcrs',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%suskxcrs)
 call netcdf_handle_error('PUT','VAR','suskxcrs',my_name,ncerr)
 ! Put symafm
 ncerr = nf90_inq_varid(ncid,name='symafm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','symafm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%symafm)
 call netcdf_handle_error('PUT','VAR','symafm',my_name,ncerr)
 ! Put symmorphi
 ncerr = nf90_inq_varid(ncid,name='symmorphi',varid=ncvar)
 call netcdf_handle_error('INQ','VID','symmorphi',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%symmorphi)
 call netcdf_handle_error('PUT','VAR','symmorphi',my_name,ncerr)
 ! Put symrel
 ncerr = nf90_inq_varid(ncid,name='symrel',varid=ncvar)
 call netcdf_handle_error('INQ','VID','symrel',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%symrel)
 call netcdf_handle_error('PUT','VAR','symrel',my_name,ncerr)
 ! Put td_maxene
 ncerr = nf90_inq_varid(ncid,name='td_maxene',varid=ncvar)
 call netcdf_handle_error('INQ','VID','td_maxene',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%td_maxene)
 call netcdf_handle_error('PUT','VAR','td_maxene',my_name,ncerr)
 ! Put td_mexcit
 ncerr = nf90_inq_varid(ncid,name='td_mexcit',varid=ncvar)
 call netcdf_handle_error('INQ','VID','td_mexcit',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%td_mexcit)
 call netcdf_handle_error('PUT','VAR','td_mexcit',my_name,ncerr)
 ! Put tfkinfunc
 ncerr = nf90_inq_varid(ncid,name='tfkinfunc',varid=ncvar)
 call netcdf_handle_error('INQ','VID','tfkinfunc',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%tfkinfunc)
 call netcdf_handle_error('PUT','VAR','tfkinfunc',my_name,ncerr)
 ! Put tfnewton
 ncerr = nf90_inq_varid(ncid,name='tfnewton',varid=ncvar)
 call netcdf_handle_error('INQ','VID','tfnewton',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%tfnewton)
 call netcdf_handle_error('PUT','VAR','tfnewton',my_name,ncerr)
 ! Put timopt
 ncerr = nf90_inq_varid(ncid,name='timopt',varid=ncvar)
 call netcdf_handle_error('INQ','VID','timopt',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%timopt)
 call netcdf_handle_error('PUT','VAR','timopt',my_name,ncerr)
 ! Put tnons
 ncerr = nf90_inq_varid(ncid,name='tnons',varid=ncvar)
 call netcdf_handle_error('INQ','VID','tnons',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%tnons)
 call netcdf_handle_error('PUT','VAR','tnons',my_name,ncerr)
 ! Put toldfe
 ncerr = nf90_inq_varid(ncid,name='toldfe',varid=ncvar)
 call netcdf_handle_error('INQ','VID','toldfe',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%toldfe)
 call netcdf_handle_error('PUT','VAR','toldfe',my_name,ncerr)
 ! Put toldff
 ncerr = nf90_inq_varid(ncid,name='toldff',varid=ncvar)
 call netcdf_handle_error('INQ','VID','toldff',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%toldff)
 call netcdf_handle_error('PUT','VAR','toldff',my_name,ncerr)
 ! Put tolmxf
 ncerr = nf90_inq_varid(ncid,name='tolmxf',varid=ncvar)
 call netcdf_handle_error('INQ','VID','tolmxf',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%tolmxf)
 call netcdf_handle_error('PUT','VAR','tolmxf',my_name,ncerr)
 ! Put tolvrs
 ncerr = nf90_inq_varid(ncid,name='tolvrs',varid=ncvar)
 call netcdf_handle_error('INQ','VID','tolvrs',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%tolvrs)
 call netcdf_handle_error('PUT','VAR','tolvrs',my_name,ncerr)
 ! Put tolwfr
 ncerr = nf90_inq_varid(ncid,name='tolwfr',varid=ncvar)
 call netcdf_handle_error('INQ','VID','tolwfr',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%tolwfr)
 call netcdf_handle_error('PUT','VAR','tolwfr',my_name,ncerr)
 ! Put tphysel
 ncerr = nf90_inq_varid(ncid,name='tphysel',varid=ncvar)
 call netcdf_handle_error('INQ','VID','tphysel',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%tphysel)
 call netcdf_handle_error('PUT','VAR','tphysel',my_name,ncerr)
 ! Put tsmear
 ncerr = nf90_inq_varid(ncid,name='tsmear',varid=ncvar)
 call netcdf_handle_error('INQ','VID','tsmear',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%tsmear)
 call netcdf_handle_error('PUT','VAR','tsmear',my_name,ncerr)
 ! Put typat
 ncerr = nf90_inq_varid(ncid,name='typat',varid=ncvar)
 call netcdf_handle_error('INQ','VID','typat',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%typat)
 call netcdf_handle_error('PUT','VAR','typat',my_name,ncerr)
 ! Put upaw
 ncerr = nf90_inq_varid(ncid,name='upaw',varid=ncvar)
 call netcdf_handle_error('INQ','VID','upaw',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%upaw)
 call netcdf_handle_error('PUT','VAR','upaw',my_name,ncerr)
 ! Put usepaw
 ncerr = nf90_inq_varid(ncid,name='usepaw',varid=ncvar)
 call netcdf_handle_error('INQ','VID','usepaw',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%usepaw)
 call netcdf_handle_error('PUT','VAR','usepaw',my_name,ncerr)
 ! Put usepawu
 ncerr = nf90_inq_varid(ncid,name='usepawu',varid=ncvar)
 call netcdf_handle_error('INQ','VID','usepawu',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%usepawu)
 call netcdf_handle_error('PUT','VAR','usepawu',my_name,ncerr)
 ! Put useria
 ncerr = nf90_inq_varid(ncid,name='useria',varid=ncvar)
 call netcdf_handle_error('INQ','VID','useria',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%useria)
 call netcdf_handle_error('PUT','VAR','useria',my_name,ncerr)
 ! Put userib
 ncerr = nf90_inq_varid(ncid,name='userib',varid=ncvar)
 call netcdf_handle_error('INQ','VID','userib',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%userib)
 call netcdf_handle_error('PUT','VAR','userib',my_name,ncerr)
 ! Put useric
 ncerr = nf90_inq_varid(ncid,name='useric',varid=ncvar)
 call netcdf_handle_error('INQ','VID','useric',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%useric)
 call netcdf_handle_error('PUT','VAR','useric',my_name,ncerr)
 ! Put userid
 ncerr = nf90_inq_varid(ncid,name='userid',varid=ncvar)
 call netcdf_handle_error('INQ','VID','userid',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%userid)
 call netcdf_handle_error('PUT','VAR','userid',my_name,ncerr)
 ! Put userie
 ncerr = nf90_inq_varid(ncid,name='userie',varid=ncvar)
 call netcdf_handle_error('INQ','VID','userie',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%userie)
 call netcdf_handle_error('PUT','VAR','userie',my_name,ncerr)
 ! Put userra
 ncerr = nf90_inq_varid(ncid,name='userra',varid=ncvar)
 call netcdf_handle_error('INQ','VID','userra',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%userra)
 call netcdf_handle_error('PUT','VAR','userra',my_name,ncerr)
 ! Put userrb
 ncerr = nf90_inq_varid(ncid,name='userrb',varid=ncvar)
 call netcdf_handle_error('INQ','VID','userrb',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%userrb)
 call netcdf_handle_error('PUT','VAR','userrb',my_name,ncerr)
 ! Put userrc
 ncerr = nf90_inq_varid(ncid,name='userrc',varid=ncvar)
 call netcdf_handle_error('INQ','VID','userrc',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%userrc)
 call netcdf_handle_error('PUT','VAR','userrc',my_name,ncerr)
 ! Put userrd
 ncerr = nf90_inq_varid(ncid,name='userrd',varid=ncvar)
 call netcdf_handle_error('INQ','VID','userrd',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%userrd)
 call netcdf_handle_error('PUT','VAR','userrd',my_name,ncerr)
 ! Put userre
 ncerr = nf90_inq_varid(ncid,name='userre',varid=ncvar)
 call netcdf_handle_error('INQ','VID','userre',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%userre)
 call netcdf_handle_error('PUT','VAR','userre',my_name,ncerr)
 ! Put useylm
 ncerr = nf90_inq_varid(ncid,name='useylm',varid=ncvar)
 call netcdf_handle_error('INQ','VID','useylm',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%useylm)
 call netcdf_handle_error('PUT','VAR','useylm',my_name,ncerr)
 ! Put vacnum
 ncerr = nf90_inq_varid(ncid,name='vacnum',varid=ncvar)
 call netcdf_handle_error('INQ','VID','vacnum',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%vacnum)
 call netcdf_handle_error('PUT','VAR','vacnum',my_name,ncerr)
 ! Put vacwidth
 ncerr = nf90_inq_varid(ncid,name='vacwidth',varid=ncvar)
 call netcdf_handle_error('INQ','VID','vacwidth',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%vacwidth)
 call netcdf_handle_error('PUT','VAR','vacwidth',my_name,ncerr)
 ! Put vel_orig
 ncerr = nf90_inq_varid(ncid,name='vel_orig',varid=ncvar)
 call netcdf_handle_error('INQ','VID','vel_orig',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%vel_orig)
 call netcdf_handle_error('PUT','VAR','vel_orig',my_name,ncerr)
 ! Put vis
 ncerr = nf90_inq_varid(ncid,name='vis',varid=ncvar)
 call netcdf_handle_error('INQ','VID','vis',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%vis)
 call netcdf_handle_error('PUT','VAR','vis',my_name,ncerr)
 ! Put vprtrb
 ncerr = nf90_inq_varid(ncid,name='vprtrb',varid=ncvar)
 call netcdf_handle_error('INQ','VID','vprtrb',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%vprtrb)
 call netcdf_handle_error('PUT','VAR','vprtrb',my_name,ncerr)
 ! Put wfoptalg
 ncerr = nf90_inq_varid(ncid,name='wfoptalg',varid=ncvar)
 call netcdf_handle_error('INQ','VID','wfoptalg',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%wfoptalg)
 call netcdf_handle_error('PUT','VAR','wfoptalg',my_name,ncerr)
 ! Put wtatcon
 ncerr = nf90_inq_varid(ncid,name='wtatcon',varid=ncvar)
 call netcdf_handle_error('INQ','VID','wtatcon',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%wtatcon)
 call netcdf_handle_error('PUT','VAR','wtatcon',my_name,ncerr)
 ! Put wtk
 ncerr = nf90_inq_varid(ncid,name='wtk',varid=ncvar)
 call netcdf_handle_error('INQ','VID','wtk',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%wtk)
 call netcdf_handle_error('PUT','VAR','wtk',my_name,ncerr)
 ! Put xred_orig
 ncerr = nf90_inq_varid(ncid,name='xred_orig',varid=ncvar)
 call netcdf_handle_error('INQ','VID','xred_orig',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%xred_orig)
 call netcdf_handle_error('PUT','VAR','xred_orig',my_name,ncerr)
 ! Put zcut
 ncerr = nf90_inq_varid(ncid,name='zcut',varid=ncvar)
 call netcdf_handle_error('INQ','VID','zcut',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%zcut)
 call netcdf_handle_error('PUT','VAR','zcut',my_name,ncerr)
 ! Put ziontypat
 ncerr = nf90_inq_varid(ncid,name='ziontypat',varid=ncvar)
 call netcdf_handle_error('INQ','VID','ziontypat',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%ziontypat)
 call netcdf_handle_error('PUT','VAR','ziontypat',my_name,ncerr)
 ! Put znucl
 ncerr = nf90_inq_varid(ncid,name='znucl',varid=ncvar)
 call netcdf_handle_error('INQ','VID','znucl',my_name,ncerr)
 ncerr = nf90_put_var(ncid,ncvar,dtset%znucl)
 call netcdf_handle_error('PUT','VAR','znucl',my_name,ncerr)
#else
 write(message,'(4a)') ch10,' netcdf_put_dtset - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_put_dtset
!!***
