!{\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_put_wfs
!! NAME
!! netcdf_put_wfs
!!
!! FUNCTION
!!  Stores a specified set of wavefunctions into a NetCDF file.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (YP)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!  wfs(:,:) = set of wavefunctions
!!
!! OUTPUT
!!  (no direct output : data written to a NetCDF file)
!!
!! PARENTS
!!      netcdf_file_write
!!
!! CHILDREN
!!      netcdf_handle_error,leave_new,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_put_wfs(ncid,wfs)

 use defs_basis
#if defined HAVE_NETCDF
 use netcdf
#endif

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_03ionetcdf, except_this_one => netcdf_put_wfs
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid
!arrays
 real(dp),intent(in) :: wfs(:,:)

!Local variables-------------------------------
!scalars
 integer :: ncerr,ncvar
 character(len=500) :: message

! ***************************************************************************
#if defined HAVE_NETCDF
 ncerr = nf90_inq_varid(ncid,name='wfs',varid=ncvar)
 call netcdf_handle_error('INQ','VAR','wfs','netcdf_put_wfs',ncerr)
 ncerr = nf90_put_var(ncid,ncvar,wfs)
 call netcdf_handle_error('PUT','VAR','wfs','netcdf_put_wfs',ncerr)
#else
 write(message,'(4a)') ch10,' netcdf_put_wfs - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_put_wfs
!!***
