!{\src2tex{textfont=tt}}
!!****f* ABINIT/opernla_ylm
!! NAME
!! opernla_ylm
!!
!! FUNCTION
!! Operate with the non-local part of the hamiltonian,
!! from reciprocal space to projected quantities
!! (opernlb is from projected quantities to reciprocal space)
!!
!! COPYRIGHT
!! Copyright (C) 1998-2006 ABINIT group (MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors.
!!
!! INPUTS
!!  choice=chooses possible output (see below):
!!         1 : compute projected scalars
!!         2 : compute projected scalars and derivatives wrt atm pos.
!!         3 : compute projected scalars and derivatives wrt strains
!!         23: compute projected scalars, derivatives wrt atm pos. and derivatives wrt strains
!!         4 : compute projected scalars, derivatives wrt atm pos. and 2nd derivatives wrt atm pos.
!!         5 : compute projected scalars and derivatives wrt wave vector k
!!         6 : compute projected scalars, derivatives wrt atm pos., 2nd derivatives wrt 2 atm pos.,
!!           and 2nd derivatives wrt atm. and strains
!!  dimffnl=second dimension of ffnl
!!  ffnl(npw,dimffnl,nlmn)= nonlocal quantities containing nonlocal form factors
!!  ia3=gives the number of the first atom in the subset presently treated
!!  idir=direction of the - atom to be moved in the case (choice=2,signs=2),
!!        - k point direction in the case (choice=5,signs=2)
!!        - strain component (1:6) in the case (choice=2,signs=2) or (choice=6,signs=1)
!!  indlmn(6,nlmn)= array giving l,m,n,ln,lm,s for i=lmn
!!  istwf_k=option parameter that describes the storage of wfs
!!  kpg(npw,nkpg)=(k+G) components          for ikpg=1...3   (if nkpg=3 or 9)
!!       [(k+G)_a].[(k+G)_b] quantities for ikpg=4...9   (if nkpg=9)
!!  matblk=dimension of the array ph3d
!!  ndgxdt=second dimension of dgxdt
!!  nd2gxdt=second dimension of d2gxdt
!!  nincat=number of atoms in the subset here treated
!!  nkpg=second dimension of array kpg (0, 3 or 9)
!!  nlmn=number of (l,m,n) numbers for current type of atom
!!  nloalg(5)=governs the choice of the algorithm for non-local operator.
!!  npw=number of plane waves in reciprocal space
!!  ph3d(2,npw,matblk)=three-dimensional phase factors
!!  signs=chooses possible output (see below)
!!  vect(2*npw)=starting vector in reciprocal space
!!
!! OUTPUT
!!  gx(2,nlmn,nincat)= projected scalars
!!  if (choice>1) dgxdt(2,ndgxdt,nlmn,nincat)=
!!     gradients of projected scalars wrt coords  (choice=2, 4, 6 or 23)
!!       wrt strains (choice=3 or 23)
!!       wrt k       (choice=5)
!!  if (choice=4 or 6) d2gxdt(2,nd2gxdt,nlmn,nincat)=
!!     2nd grads of projected scalars wrt 2 coords         (choice=4)
!!       wrt coords & strains (choice=6)
!!
!! NOTES
!! Operate for one type of atom, and within this given type of atom,
!! for a subset of at most nincat atoms.
!!
!! PARENTS
!!      nonlop_ylm
!!
!! CHILDREN
!!      timab,xcomm_init,xsum_mpi
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine opernla_ylm(choice,dimffnl,d2gxdt,dgxdt,ffnl,gx,ia3,idir,&
&       indlmn,istwf_k,kpg,matblk,mpi_enreg,nd2gxdt,ndgxdt,&
&       nincat,nkpg,nlmn,nloalg,npw,ph3d,signs,vect)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_00basis
 use interfaces_01managempi
#else
 use defs_xfuncmpi
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: choice,dimffnl,ia3,idir,istwf_k,matblk,nd2gxdt,ndgxdt
 integer,intent(in) :: nincat,nkpg,nlmn,npw,signs
 type(MPI_type),intent(inout) :: mpi_enreg
!arrays
 integer,intent(in) :: indlmn(6,nlmn),nloalg(5)
 real(dp),intent(in) :: ffnl(npw,dimffnl,nlmn),kpg(npw,nkpg),ph3d(2,npw,matblk)
 real(dp),intent(in) :: vect(2,npw)
 real(dp),intent(out) :: d2gxdt(2,nd2gxdt,nlmn,nincat)
 real(dp),intent(out) :: dgxdt(2,ndgxdt,nlmn,nincat),gx(2,nlmn,nincat)

!Local variables-------------------------------
!no_abirules
 integer :: gama,gamb,gamc,gamd,ia,iaph3d,ierr,ilmn,ipw,ipw0,ishift,mu
 integer :: mua,mub,nua1,nua2,nub1,nub2,old_paral_level,spaceComm
 real(dp), parameter :: two_pi2=two_pi*two_pi
 real(dp) :: aux_i,aux_i1,aux_i2,aux_i3,aux_i4
 real(dp) :: aux_r,aux_r1,aux_r2,aux_r3,aux_r4
 real(dp) :: buffer_i,buffer_i1,buffer_i2,buffer_i3,buffer_i4,buffer_i5,buffer_i6
 real(dp) :: buffer_ia,buffer_ib,buffer_ic,buffer_id,buffer_ie,buffer_if
 real(dp) :: buffer_r,buffer_r1,buffer_r2,buffer_r3,buffer_r4,buffer_r5,buffer_r6
 real(dp) :: buffer_ra,buffer_rb,buffer_rc,buffer_rd,buffer_re,buffer_rf
 real(dp) :: kpga,kpgb,kpgc,kpgd
 logical :: noparity,parity
 integer,parameter :: alpha(6)=(/1,2,3,3,3,2/),beta(6)=(/1,2,3,2,1,1/)
 integer,parameter :: gamma(3,3)=reshape((/1,6,5,6,2,4,5,4,3/),(/3,3/))
 real(dp) :: tsec(2)
 real(dp),allocatable :: scali(:),scalr(:),scalari(:,:),scalarr(:,:)

! *************************************************************************

!Allocate work space
 allocate(scali(npw),scalr(npw))

!Set parity infos
 noparity=(istwf_k==1)
 ipw0=1;if (istwf_k==2.and.mpi_enreg%me_g0==1) ipw0=2

!Loops (blocking)
!$OMP PARALLEL DEFAULT(PRIVATE) &
!$OMP&SHARED(nincat,nloalg,npw,nlmn,indlmn,istwf_k,ia3)
!$OMP&SHARED(idir,ipw0,choice,signs,ndgxdt,nd2gxdt,alpha,beta)
!$OMP&SHARED(vect,ph3d,ffnl,scalr,scali)
!$OMP&SHARED(noparity,gx,dgxdt,d2gxdt,kpg)
!$OMP DO

!Loop on atoms
 do ia=1,nincat
  iaph3d=ia;if (nloalg(1)>0) iaph3d=ia+ia3-1

! Store WF component
  do ipw=ipw0,npw
   scalr(ipw)=(vect(1,ipw)*ph3d(1,ipw,iaph3d)-vect(2,ipw)*ph3d(2,ipw,iaph3d))
   scali(ipw)=(vect(2,ipw)*ph3d(1,ipw,iaph3d)+vect(1,ipw)*ph3d(2,ipw,iaph3d))
  end do
  if (ipw0==2) then
   scalr(1)=half*vect(1,1)*ph3d(1,1,iaph3d)
   scali(1)=half*vect(1,1)*ph3d(2,1,iaph3d)
  end if

! --------------------------------------------------------------------
! CHOICE 1:
!          Accumulate Gx
! --------------------------------------------------------------------
  if (choice==1) then
   do ilmn=1,nlmn
    if (noparity) then
     buffer_r = zero ; buffer_i = zero
     do ipw=1,npw
      buffer_r = buffer_r + scalr(ipw)*ffnl(ipw,1,ilmn)
      buffer_i = buffer_i + scali(ipw)*ffnl(ipw,1,ilmn)
     end do
     gx(1,ilmn,ia) = buffer_r ; gx(2,ilmn,ia) = buffer_i
    else
     parity=(mod(indlmn(1,ilmn),2)==0)
     if (parity) then
      buffer_r =  zero
      do ipw=1,npw
       buffer_r = buffer_r + scalr(ipw)*ffnl(ipw,1,ilmn)
      end do
      gx(1,ilmn,ia) = buffer_r ; gx(2,ilmn,ia) = zero
     else
      buffer_i = zero
      do ipw=1,npw
       buffer_i = buffer_i + scali(ipw)*ffnl(ipw,1,ilmn)
      end do
      gx(2,ilmn,ia) = buffer_i ; gx(1,ilmn,ia) = zero
     end if
    end if
   end do

! --------------------------------------------------------------------
! CHOICE 2:
!          Accumulate Gx
!          Accumulate dGxdt --- derivative wrt atm pos. ---
! --------------------------------------------------------------------
  else if (choice==2) then
   if (signs==1) then
    do ilmn=1,nlmn
     if (noparity) then
      buffer_r  = zero ; buffer_i  = zero
      buffer_r1 = zero ; buffer_r2 = zero
      buffer_r3 = zero ; buffer_i1 = zero
      buffer_i2 = zero ; buffer_i3 = zero
      do ipw=1,npw
       aux_r = scalr(ipw)*ffnl(ipw,1,ilmn)
       aux_i = scali(ipw)*ffnl(ipw,1,ilmn)
       buffer_r  = buffer_r  + aux_r
       buffer_i  = buffer_i  + aux_i
       buffer_r1 = buffer_r1 - aux_i*kpg(ipw,1)
       buffer_r2 = buffer_r2 - aux_i*kpg(ipw,2)
       buffer_r3 = buffer_r3 - aux_i*kpg(ipw,3)
       buffer_i1 = buffer_i1 + aux_r*kpg(ipw,1)
       buffer_i2 = buffer_i2 + aux_r*kpg(ipw,2)
       buffer_i3 = buffer_i3 + aux_r*kpg(ipw,3)
      end do
      gx(1,ilmn,ia)      = buffer_r
      gx(2,ilmn,ia)      = buffer_i
      dgxdt(1,1,ilmn,ia) = two_pi*buffer_r1
      dgxdt(1,2,ilmn,ia) = two_pi*buffer_r2
      dgxdt(1,3,ilmn,ia) = two_pi*buffer_r3
      dgxdt(2,1,ilmn,ia) = two_pi*buffer_i1
      dgxdt(2,2,ilmn,ia) = two_pi*buffer_i2
      dgxdt(2,3,ilmn,ia) = two_pi*buffer_i3
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       buffer_r  = zero ; buffer_r1 = zero
       buffer_r2 = zero ; buffer_r3 = zero
       do ipw=1,npw
        aux_r = scalr(ipw)*ffnl(ipw,1,ilmn)
        aux_i = scali(ipw)*ffnl(ipw,1,ilmn)
        buffer_r  = buffer_r  + aux_r
        buffer_r1 = buffer_r1 - aux_i*kpg(ipw,1)
        buffer_r2 = buffer_r2 - aux_i*kpg(ipw,2)
        buffer_r3 = buffer_r3 - aux_i*kpg(ipw,3)
       end do
       gx(1,ilmn,ia)      = buffer_r
       gx(2,ilmn,ia)      = zero
       dgxdt(1,1,ilmn,ia) = two_pi*buffer_r1
       dgxdt(1,2,ilmn,ia) = two_pi*buffer_r2
       dgxdt(1,3,ilmn,ia) = two_pi*buffer_r3
       dgxdt(2,1,ilmn,ia) = zero
       dgxdt(2,2,ilmn,ia) = zero
       dgxdt(2,3,ilmn,ia) = zero
      else
       buffer_i  = zero ; buffer_i1 = zero
       buffer_i2 = zero ; buffer_i3 = zero
       do ipw=1,npw
        aux_r = scalr(ipw)*ffnl(ipw,1,ilmn)
        aux_i = scali(ipw)*ffnl(ipw,1,ilmn)
        buffer_i  = buffer_i  + aux_i
        buffer_i1 = buffer_i1 + aux_r*kpg(ipw,1)
        buffer_i2 = buffer_i2 + aux_r*kpg(ipw,2)
        buffer_i3 = buffer_i3 + aux_r*kpg(ipw,3)
       end do
       gx(2,ilmn,ia)      = buffer_i
       gx(1,ilmn,ia)      = zero
       dgxdt(2,1,ilmn,ia) = two_pi*buffer_i1
       dgxdt(2,2,ilmn,ia) = two_pi*buffer_i2
       dgxdt(2,3,ilmn,ia) = two_pi*buffer_i3
       dgxdt(1,1,ilmn,ia) = zero
       dgxdt(1,2,ilmn,ia) = zero
       dgxdt(1,3,ilmn,ia) = zero
      end if
     end if
    end do
   end if

!  ------------------------------------------
   if (signs==2) then
    do ilmn=1,nlmn
     if (noparity) then
      buffer_r  = zero ; buffer_i  = zero
      buffer_r1 = zero ; buffer_i1 = zero
      do ipw=1,npw
       aux_r = scalr(ipw)*ffnl(ipw,1,ilmn)
       aux_i = scali(ipw)*ffnl(ipw,1,ilmn)
       buffer_r  = buffer_r  + aux_r
       buffer_i  = buffer_i  + aux_i
       buffer_r1 = buffer_r1 - aux_i*kpg(ipw,idir)
       buffer_i1 = buffer_i1 + aux_r*kpg(ipw,idir)
      end do
      gx(1,ilmn,ia)      = buffer_r
      gx(2,ilmn,ia)      = buffer_i
      dgxdt(1,1,ilmn,ia) = two_pi*buffer_r1
      dgxdt(2,1,ilmn,ia) = two_pi*buffer_i1
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       buffer_r  = zero ; buffer_r1 = zero
       do ipw=1,npw
        buffer_r  = buffer_r  + scalr(ipw)*ffnl(ipw,1,ilmn)
        buffer_r1 = buffer_r1 - scali(ipw)*ffnl(ipw,1,ilmn)*kpg(ipw,idir)
       end do
       gx(1,ilmn,ia)      = buffer_r
       gx(2,ilmn,ia)      = zero
       dgxdt(1,1,ilmn,ia) = two_pi*buffer_r1
       dgxdt(2,1,ilmn,ia) = zero
      else
       buffer_i  = zero ; buffer_i1 = zero
       do ipw=1,npw
        buffer_i  = buffer_i  + scali(ipw)*ffnl(ipw,1,ilmn)
        buffer_i1 = buffer_i1 + scalr(ipw)*ffnl(ipw,1,ilmn)*kpg(ipw,idir)
       end do
       gx(2,ilmn,ia)      = buffer_i
       gx(1,ilmn,ia)      = zero
       dgxdt(2,1,ilmn,ia) = two_pi*buffer_i1
       dgxdt(1,1,ilmn,ia) = zero
      end if
     end if
    end do
   end if

! --------------------------------------------------------------------
! CHOICE 3:
!          Accumulate Gx
!          Accumulate dGxdt --- derivative wrt strain ---
! --------------------------------------------------------------------
  else if (choice==3) then
   if (signs==1) then
    do ilmn=1,nlmn
     if (noparity) then
      buffer_r  = zero ; buffer_i  = zero
      buffer_r1 = zero ; buffer_r2 = zero
      buffer_r3 = zero ; buffer_r4 = zero
      buffer_r5 = zero ; buffer_r6 = zero
      buffer_i1 = zero ; buffer_i2 = zero
      buffer_i3 = zero ; buffer_i4 = zero
      buffer_i5 = zero ; buffer_i6 = zero
      do ipw=1,npw
       aux_r2 = scalr(ipw)*ffnl(ipw,2,ilmn)
       aux_r3 = scalr(ipw)*ffnl(ipw,3,ilmn)
       aux_r4 = scalr(ipw)*ffnl(ipw,4,ilmn)
       aux_i2 = scali(ipw)*ffnl(ipw,2,ilmn)
       aux_i3 = scali(ipw)*ffnl(ipw,3,ilmn)
       aux_i4 = scali(ipw)*ffnl(ipw,4,ilmn)
       buffer_r  = buffer_r  + scalr(ipw)*ffnl(ipw,1,ilmn)
       buffer_r1 = buffer_r1 + aux_r2*kpg(ipw,1)
       buffer_r2 = buffer_r2 + aux_r3*kpg(ipw,2)
       buffer_r3 = buffer_r3 + aux_r4*kpg(ipw,3)
       buffer_r4 = buffer_r4 + aux_r4*kpg(ipw,2) + aux_r3*kpg(ipw,3)
       buffer_r5 = buffer_r5 + aux_r4*kpg(ipw,1) + aux_r2*kpg(ipw,3)
       buffer_r6 = buffer_r6 + aux_r3*kpg(ipw,1) + aux_r2*kpg(ipw,2)
       buffer_i  = buffer_i  + scali(ipw)*ffnl(ipw,1,ilmn)
       buffer_i1 = buffer_i1 + aux_i2*kpg(ipw,1)
       buffer_i2 = buffer_i2 + aux_i3*kpg(ipw,2)
       buffer_i3 = buffer_i3 + aux_i4*kpg(ipw,3)
       buffer_i4 = buffer_i4 + aux_i4*kpg(ipw,2) + aux_i3*kpg(ipw,3)
       buffer_i5 = buffer_i5 + aux_i4*kpg(ipw,1) + aux_i2*kpg(ipw,3)
       buffer_i6 = buffer_i6 + aux_i3*kpg(ipw,1) + aux_i2*kpg(ipw,2)
      end do
      gx(1,ilmn,ia) = buffer_r
      gx(2,ilmn,ia) = buffer_i
      dgxdt(1,1,ilmn,ia) = -buffer_r1
      dgxdt(1,2,ilmn,ia) = -buffer_r2
      dgxdt(1,3,ilmn,ia) = -buffer_r3
      dgxdt(1,4,ilmn,ia) = -half*buffer_r4
      dgxdt(1,5,ilmn,ia) = -half*buffer_r5
      dgxdt(1,6,ilmn,ia) = -half*buffer_r6
      dgxdt(2,1,ilmn,ia) = -buffer_i1
      dgxdt(2,2,ilmn,ia) = -buffer_i2
      dgxdt(2,3,ilmn,ia) = -buffer_i3
      dgxdt(2,4,ilmn,ia) = -half*buffer_i4
      dgxdt(2,5,ilmn,ia) = -half*buffer_i5
      dgxdt(2,6,ilmn,ia) = -half*buffer_i6
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       buffer_r  = zero
       buffer_r1 = zero ; buffer_r2 = zero
       buffer_r3 = zero ; buffer_r4 = zero
       buffer_r5 = zero ; buffer_r6 = zero
       do ipw=1,npw
        aux_r2 = scalr(ipw)*ffnl(ipw,2,ilmn)
        aux_r3 = scalr(ipw)*ffnl(ipw,3,ilmn)
        aux_r4 = scalr(ipw)*ffnl(ipw,4,ilmn)
        buffer_r = buffer_r + scalr(ipw)*ffnl(ipw,1,ilmn)
        buffer_r1 = buffer_r1 + aux_r2*kpg(ipw,1)
        buffer_r2 = buffer_r2 + aux_r3*kpg(ipw,2)
        buffer_r3 = buffer_r3 + aux_r4*kpg(ipw,3)
        buffer_r4 = buffer_r4 + aux_r4*kpg(ipw,2) + aux_r3*kpg(ipw,3)
        buffer_r5 = buffer_r5 + aux_r4*kpg(ipw,1) + aux_r2*kpg(ipw,3)
        buffer_r6 = buffer_r6 + aux_r3*kpg(ipw,1) + aux_r2*kpg(ipw,2)
       end do
       gx(1,ilmn,ia) = buffer_r
       gx(2,ilmn,ia) = zero
       dgxdt(1,1,ilmn,ia) = -buffer_r1
       dgxdt(1,2,ilmn,ia) = -buffer_r2
       dgxdt(1,3,ilmn,ia) = -buffer_r3
       dgxdt(1,4,ilmn,ia) = -half*buffer_r4
       dgxdt(1,5,ilmn,ia) = -half*buffer_r5
       dgxdt(1,6,ilmn,ia) = -half*buffer_r6
       dgxdt(2,1,ilmn,ia) = zero
       dgxdt(2,2,ilmn,ia) = zero
       dgxdt(2,3,ilmn,ia) = zero
       dgxdt(2,4,ilmn,ia) = zero
       dgxdt(2,5,ilmn,ia) = zero
       dgxdt(2,6,ilmn,ia) = zero
      else
       buffer_i  = zero
       buffer_i1 = zero ; buffer_i2 = zero
       buffer_i3 = zero ; buffer_i4 = zero
       buffer_i5 = zero ; buffer_i6 = zero
       do ipw=1,npw
        aux_i2 = scali(ipw)*ffnl(ipw,2,ilmn)
        aux_i3 = scali(ipw)*ffnl(ipw,3,ilmn)
        aux_i4 = scali(ipw)*ffnl(ipw,4,ilmn)
        buffer_i  = buffer_i  + scali(ipw)*ffnl(ipw,1,ilmn)
        buffer_i1 = buffer_i1 + aux_i2*kpg(ipw,1)
        buffer_i2 = buffer_i2 + aux_i3*kpg(ipw,2)
        buffer_i3 = buffer_i3 + aux_i4*kpg(ipw,3)
        buffer_i4 = buffer_i4 + aux_i4*kpg(ipw,2) + aux_i3*kpg(ipw,3)
        buffer_i5 = buffer_i5 + aux_i4*kpg(ipw,1) + aux_i2*kpg(ipw,3)
        buffer_i6 = buffer_i6 + aux_i3*kpg(ipw,1) + aux_i2*kpg(ipw,2)
       end do
       gx(2,ilmn,ia) = buffer_i
       gx(1,ilmn,ia) = zero
       dgxdt(2,1,ilmn,ia) =  -buffer_i1
       dgxdt(2,2,ilmn,ia) =  -buffer_i2
       dgxdt(2,3,ilmn,ia) =  -buffer_i3
       dgxdt(2,4,ilmn,ia) =  -half*buffer_i4
       dgxdt(2,5,ilmn,ia) =  -half*buffer_i5
       dgxdt(2,6,ilmn,ia) =  -half*buffer_i6
       dgxdt(1,1,ilmn,ia) = zero
       dgxdt(1,2,ilmn,ia) = zero
       dgxdt(1,3,ilmn,ia) = zero
       dgxdt(1,4,ilmn,ia) = zero
       dgxdt(1,5,ilmn,ia) = zero
       dgxdt(1,6,ilmn,ia) = zero
      end if
     end if
    end do
   end if

!  ------------------------------------------
   if (signs==2) then
    do ilmn=1,nlmn
     if (noparity) then
      buffer_r  = zero ; buffer_i  = zero
      buffer_r1 = zero ; buffer_i1 = zero
      do ipw=1,npw
       buffer_r  = buffer_r  + scalr(ipw)*ffnl(ipw,1,ilmn)
       buffer_i  = buffer_i  + scali(ipw)*ffnl(ipw,1,ilmn)
       buffer_r1 = buffer_r1 - scalr(ipw)*ffnl(ipw,2,ilmn)
       buffer_i1 = buffer_i1 - scali(ipw)*ffnl(ipw,2,ilmn)
      end do
      gx(1,ilmn,ia) = buffer_r
      gx(2,ilmn,ia) = buffer_i
      dgxdt(1,1,ilmn,ia) = buffer_r1
      dgxdt(2,1,ilmn,ia) = buffer_i1
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       buffer_r  = zero ; buffer_r1 = zero
       do ipw=1,npw
        buffer_r  = buffer_r  + scalr(ipw)*ffnl(ipw,1,ilmn)
        buffer_r1 = buffer_r1 - scalr(ipw)*ffnl(ipw,2,ilmn)
       end do
       gx(1,ilmn,ia) = buffer_r
       gx(2,ilmn,ia) = zero
       dgxdt(1,1,ilmn,ia) = buffer_r1
       dgxdt(2,1,ilmn,ia) = zero
      else
       buffer_i  = zero ; buffer_i1 = zero
       do ipw=1,npw
        buffer_i  = buffer_i  + scali(ipw)*ffnl(ipw,1,ilmn)
        buffer_i1 = buffer_i1 - scali(ipw)*ffnl(ipw,2,ilmn)
       end do
       gx(2,ilmn,ia) = buffer_i
       gx(1,ilmn,ia) = zero
       dgxdt(2,1,ilmn,ia) = buffer_i1
       dgxdt(1,1,ilmn,ia) = zero
      end if
     end if
    end do
   end if

! --------------------------------------------------------------------
! CHOICE 23:
!      Accumulate Gx
!      Accumulate dGxdt --- derivative wrt atm pos. ---
!      Accumulate dGxdt --- derivative wrt strain ---
! --------------------------------------------------------------------
  else if (choice==23) then
   if (signs==1) then
    do ilmn=1,nlmn
     if (noparity) then
      buffer_r  = zero ; buffer_r1 = zero
      buffer_r2 = zero ; buffer_r3 = zero
      buffer_ra = zero ; buffer_rb = zero
      buffer_rc = zero ; buffer_rd = zero
      buffer_re = zero ; buffer_rf = zero
      buffer_i  = zero ; buffer_i1 = zero
      buffer_i2 = zero ; buffer_i3 = zero
      buffer_ia = zero ; buffer_ib = zero
      buffer_ic = zero ; buffer_id = zero
      buffer_ie = zero ; buffer_if = zero
      do ipw=1,npw
       aux_r1 = scalr(ipw)*ffnl(ipw,1,ilmn)
       aux_r2 = scalr(ipw)*ffnl(ipw,2,ilmn)
       aux_r3 = scalr(ipw)*ffnl(ipw,3,ilmn)
       aux_r4 = scalr(ipw)*ffnl(ipw,4,ilmn)
       aux_i1 = scali(ipw)*ffnl(ipw,1,ilmn)
       aux_i2 = scali(ipw)*ffnl(ipw,2,ilmn)
       aux_i3 = scali(ipw)*ffnl(ipw,3,ilmn)
       aux_i4 = scali(ipw)*ffnl(ipw,4,ilmn)
       buffer_r  = buffer_r  + aux_r1
       buffer_i  = buffer_i  + aux_i1
       buffer_r1 = buffer_r1 - aux_i1*kpg(ipw,1)
       buffer_r2 = buffer_r2 - aux_i1*kpg(ipw,2)
       buffer_r3 = buffer_r3 - aux_i1*kpg(ipw,3)
       buffer_ra = buffer_ra + aux_r2*kpg(ipw,1)
       buffer_rb = buffer_rb + aux_r3*kpg(ipw,2)
       buffer_rc = buffer_rc + aux_r4*kpg(ipw,3)
       buffer_rd = buffer_rd + aux_r4*kpg(ipw,2) + aux_r3*kpg(ipw,3)
       buffer_re = buffer_re + aux_r4*kpg(ipw,1) + aux_r2*kpg(ipw,3)
       buffer_rf = buffer_rf + aux_r3*kpg(ipw,1) + aux_r2*kpg(ipw,2)
       buffer_i1 = buffer_i1 + aux_r1*kpg(ipw,1)
       buffer_i2 = buffer_i2 + aux_r1*kpg(ipw,2)
       buffer_i3 = buffer_i3 + aux_r1*kpg(ipw,3)
       buffer_ia = buffer_ia + aux_i2*kpg(ipw,1)
       buffer_ib = buffer_ib + aux_i3*kpg(ipw,2)
       buffer_ic = buffer_ic + aux_i4*kpg(ipw,3)
       buffer_id = buffer_id + aux_i4*kpg(ipw,2) + aux_i3*kpg(ipw,3)
       buffer_ie = buffer_ie + aux_i4*kpg(ipw,1) + aux_i2*kpg(ipw,3)
       buffer_if = buffer_if + aux_i3*kpg(ipw,1) + aux_i2*kpg(ipw,2)
      end do
      gx(1,ilmn,ia) = buffer_r
      gx(2,ilmn,ia) = buffer_i
      dgxdt(1,1,ilmn,ia) = -buffer_ra
      dgxdt(1,2,ilmn,ia) = -buffer_rb
      dgxdt(1,3,ilmn,ia) = -buffer_rc
      dgxdt(1,4,ilmn,ia) = -half*buffer_rd
      dgxdt(1,5,ilmn,ia) = -half*buffer_re
      dgxdt(1,6,ilmn,ia) = -half*buffer_rf
      dgxdt(1,7,ilmn,ia) = two_pi*buffer_r1
      dgxdt(1,8,ilmn,ia) = two_pi*buffer_r2
      dgxdt(1,9,ilmn,ia) = two_pi*buffer_r3
      dgxdt(2,1,ilmn,ia) = -buffer_ia
      dgxdt(2,2,ilmn,ia) = -buffer_ib
      dgxdt(2,3,ilmn,ia) = -buffer_ic
      dgxdt(2,4,ilmn,ia) = -half*buffer_id
      dgxdt(2,5,ilmn,ia) = -half*buffer_ie
      dgxdt(2,6,ilmn,ia) = -half*buffer_if
      dgxdt(2,7,ilmn,ia) = two_pi*buffer_i1
      dgxdt(2,8,ilmn,ia) = two_pi*buffer_i2
      dgxdt(2,9,ilmn,ia) = two_pi*buffer_i3
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       buffer_r  = zero ; buffer_r1 = zero
       buffer_r2 = zero ; buffer_r3 = zero
       buffer_ra = zero ; buffer_rb = zero
       buffer_rc = zero ; buffer_rd = zero
       buffer_re = zero ; buffer_rf = zero
       do ipw=1,npw
        aux_r2 = scalr(ipw)*ffnl(ipw,2,ilmn)
        aux_r3 = scalr(ipw)*ffnl(ipw,3,ilmn)
        aux_r4 = scalr(ipw)*ffnl(ipw,4,ilmn)
        aux_i1 = scali(ipw)*ffnl(ipw,1,ilmn)
        buffer_r  = buffer_r + scalr(ipw)*ffnl(ipw,1,ilmn)
        buffer_r1 = buffer_r1 - aux_i1*kpg(ipw,1)
        buffer_r2 = buffer_r2 - aux_i1*kpg(ipw,2)
        buffer_r3 = buffer_r3 - aux_i1*kpg(ipw,3)
        buffer_ra = buffer_ra + aux_r2*kpg(ipw,1)
        buffer_rb = buffer_rb + aux_r3*kpg(ipw,2)
        buffer_rc = buffer_rc + aux_r4*kpg(ipw,3)
        buffer_rd = buffer_rd + aux_r4*kpg(ipw,2) + aux_r3*kpg(ipw,3)
        buffer_re = buffer_re + aux_r4*kpg(ipw,1) + aux_r2*kpg(ipw,3)
        buffer_rf = buffer_rf + aux_r3*kpg(ipw,1) + aux_r2*kpg(ipw,2)
       end do
       gx(1,ilmn,ia) = buffer_r
       gx(2,ilmn,ia) = zero
       dgxdt(1,1,ilmn,ia) = -buffer_ra
       dgxdt(1,2,ilmn,ia) = -buffer_rb
       dgxdt(1,3,ilmn,ia) = -buffer_rc
       dgxdt(1,4,ilmn,ia) = -half*buffer_rd
       dgxdt(1,5,ilmn,ia) = -half*buffer_re
       dgxdt(1,6,ilmn,ia) = -half*buffer_rf
       dgxdt(1,7,ilmn,ia) = two_pi*buffer_r1
       dgxdt(1,8,ilmn,ia) = two_pi*buffer_r2
       dgxdt(1,9,ilmn,ia) = two_pi*buffer_r3
       dgxdt(2,1,ilmn,ia) = zero
       dgxdt(2,2,ilmn,ia) = zero
       dgxdt(2,3,ilmn,ia) = zero
       dgxdt(2,4,ilmn,ia) = zero
       dgxdt(2,5,ilmn,ia) = zero
       dgxdt(2,6,ilmn,ia) = zero
       dgxdt(2,7,ilmn,ia) = zero
       dgxdt(2,8,ilmn,ia) = zero
       dgxdt(2,9,ilmn,ia) = zero
      else
       buffer_i  = zero ; buffer_i1 = zero
       buffer_i2 = zero ; buffer_i3 = zero
       buffer_ia = zero ; buffer_ib = zero
       buffer_ic = zero ; buffer_id = zero
       buffer_ie = zero ; buffer_if = zero
       do ipw=1,npw
        aux_r1 = scalr(ipw)*ffnl(ipw,1,ilmn)
        aux_i2 = scali(ipw)*ffnl(ipw,2,ilmn)
        aux_i3 = scali(ipw)*ffnl(ipw,3,ilmn)
        aux_i4 = scali(ipw)*ffnl(ipw,4,ilmn)
        buffer_i  = buffer_i  + scali(ipw)*ffnl(ipw,1,ilmn)
        buffer_i1 = buffer_i1 + aux_r1*kpg(ipw,1)
        buffer_i2 = buffer_i2 + aux_r1*kpg(ipw,2)
        buffer_i3 = buffer_i3 + aux_r1*kpg(ipw,3)
        buffer_ia = buffer_ia + aux_i2*kpg(ipw,1)
        buffer_ib = buffer_ib + aux_i3*kpg(ipw,2)
        buffer_ic = buffer_ic + aux_i4*kpg(ipw,3)
        buffer_id = buffer_id + aux_i4*kpg(ipw,2) + aux_i3*kpg(ipw,3)
        buffer_ie = buffer_ie + aux_i4*kpg(ipw,1) + aux_i2*kpg(ipw,3)
        buffer_if = buffer_if + aux_i3*kpg(ipw,1) + aux_i2*kpg(ipw,2)
       end do
       gx(2,ilmn,ia) = buffer_i
       gx(1,ilmn,ia) = zero
       dgxdt(2,1,ilmn,ia) = -buffer_ia
       dgxdt(2,2,ilmn,ia) = -buffer_ib
       dgxdt(2,3,ilmn,ia) = -buffer_ic
       dgxdt(2,4,ilmn,ia) = -half*buffer_id
       dgxdt(2,5,ilmn,ia) = -half*buffer_ie
       dgxdt(2,6,ilmn,ia) = -half*buffer_if
       dgxdt(2,7,ilmn,ia) = two_pi*buffer_i1
       dgxdt(2,8,ilmn,ia) = two_pi*buffer_i2
       dgxdt(2,9,ilmn,ia) = two_pi*buffer_i3
       dgxdt(1,1,ilmn,ia) = zero
       dgxdt(1,2,ilmn,ia) = zero
       dgxdt(1,3,ilmn,ia) = zero
       dgxdt(1,4,ilmn,ia) = zero
       dgxdt(1,5,ilmn,ia) = zero
       dgxdt(1,6,ilmn,ia) = zero
       dgxdt(1,7,ilmn,ia) = zero
       dgxdt(1,8,ilmn,ia) = zero
       dgxdt(1,9,ilmn,ia) = zero
      end if
     end if
    end do
   end if

!  ------------------------------------------
   if (signs==2) then
    do ilmn=1,nlmn
     if (noparity) then
      buffer_r  = zero ; buffer_i  = zero
      buffer_ra = zero ; buffer_ia = zero
      do ipw=1,npw
       buffer_r  = buffer_r  + scalr(ipw)*ffnl(ipw,1,ilmn)
       buffer_i  = buffer_i  + scali(ipw)*ffnl(ipw,1,ilmn)
       buffer_ra = buffer_ra - scalr(ipw)*ffnl(ipw,2,ilmn)
       buffer_ia = buffer_ia - scali(ipw)*ffnl(ipw,2,ilmn)
      end do
      gx(1,ilmn,ia)      = buffer_r
      gx(2,ilmn,ia)      = buffer_i
      dgxdt(1,1,ilmn,ia) = buffer_ra
      dgxdt(2,1,ilmn,ia) = buffer_ia
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       buffer_r  = zero ; buffer_ra = zero
       do ipw=1,npw
        buffer_r  = buffer_r  + scalr(ipw)*ffnl(ipw,1,ilmn)
        buffer_ra = buffer_ra - scalr(ipw)*ffnl(ipw,2,ilmn)
       end do
       gx(1,ilmn,ia) = buffer_r
       gx(2,ilmn,ia) = zero
       dgxdt(1,1,ilmn,ia) = buffer_ra
       dgxdt(2,1,ilmn,ia) = zero
      else
       buffer_i  = zero ; buffer_ia = zero
       do ipw=1,npw
        buffer_i  = buffer_i  + scali(ipw)*ffnl(ipw,1,ilmn)
        buffer_ia = buffer_ia - scali(ipw)*ffnl(ipw,2,ilmn)
       end do
       gx(2,ilmn,ia) = buffer_i
       gx(1,ilmn,ia) = zero
       dgxdt(2,1,ilmn,ia) = buffer_ia
       dgxdt(1,1,ilmn,ia) = zero
      end if
     end if
    end do
   end if

! --------------------------------------------------------------------
! CHOICE 4:
!      Accumulate Gx
!      Accumulate dGxdt --- derivative wrt atm pos. ---
!      Accumulate d2Gxdt --- 2nd derivative wrt 2 atm pos. ---
! --------------------------------------------------------------------
  else if (choice==4) then
   if (signs==1) then
    do ilmn=1,nlmn
     if (noparity) then
      buffer_r  = zero ; buffer_r1 = zero
      buffer_r2 = zero ; buffer_r3 = zero
      buffer_ra = zero ; buffer_rb = zero
      buffer_rc = zero ; buffer_rd = zero
      buffer_re = zero ; buffer_rf = zero
      buffer_i  = zero ; buffer_i1 = zero
      buffer_i2 = zero ; buffer_i3 = zero
      buffer_ia = zero ; buffer_ib = zero
      buffer_ic = zero ; buffer_id = zero
      buffer_ie = zero ; buffer_if = zero
      do ipw=1,npw
       aux_r = scalr(ipw)*ffnl(ipw,1,ilmn)
       aux_i = scali(ipw)*ffnl(ipw,1,ilmn)
       buffer_r = buffer_r + aux_r
       buffer_i = buffer_i + aux_i
       buffer_r1 = buffer_r1 - aux_i*kpg(ipw,1)
       buffer_r2 = buffer_r2 - aux_i*kpg(ipw,2)
       buffer_r3 = buffer_r3 - aux_i*kpg(ipw,3)
       buffer_i1 = buffer_i1 + aux_r*kpg(ipw,1)
       buffer_i2 = buffer_i2 + aux_r*kpg(ipw,2)
       buffer_i3 = buffer_i3 + aux_r*kpg(ipw,3)
       buffer_ra = buffer_ra - aux_r*kpg(ipw,4)
       buffer_rb = buffer_rb - aux_r*kpg(ipw,5)
       buffer_rc = buffer_rc - aux_r*kpg(ipw,6)
       buffer_rd = buffer_rd - aux_r*kpg(ipw,7)
       buffer_re = buffer_re - aux_r*kpg(ipw,8)
       buffer_rf = buffer_rf - aux_r*kpg(ipw,9)
       buffer_ia = buffer_ia - aux_i*kpg(ipw,4)
       buffer_ib = buffer_ib - aux_i*kpg(ipw,5)
       buffer_ic = buffer_ic - aux_i*kpg(ipw,6)
       buffer_id = buffer_id - aux_i*kpg(ipw,7)
       buffer_ie = buffer_ie - aux_i*kpg(ipw,8)
       buffer_if = buffer_if - aux_i*kpg(ipw,9)
      end do
      gx(1,ilmn,ia) = buffer_r
      gx(2,ilmn,ia) = buffer_i
      dgxdt(1,1,ilmn,ia) = two_pi*buffer_r1
      dgxdt(1,2,ilmn,ia) = two_pi*buffer_r2
      dgxdt(1,3,ilmn,ia) = two_pi*buffer_r3
      dgxdt(2,1,ilmn,ia) = two_pi*buffer_i1
      dgxdt(2,2,ilmn,ia) = two_pi*buffer_i2
      dgxdt(2,3,ilmn,ia) = two_pi*buffer_i3
      d2gxdt(1,1,ilmn,ia) = two_pi2*buffer_ra
      d2gxdt(1,2,ilmn,ia) = two_pi2*buffer_rb
      d2gxdt(1,3,ilmn,ia) = two_pi2*buffer_rc
      d2gxdt(1,4,ilmn,ia) = two_pi2*buffer_rd
      d2gxdt(1,5,ilmn,ia) = two_pi2*buffer_re
      d2gxdt(1,6,ilmn,ia) = two_pi2*buffer_rf
      d2gxdt(2,1,ilmn,ia) = two_pi2*buffer_ia
      d2gxdt(2,2,ilmn,ia) = two_pi2*buffer_ib
      d2gxdt(2,3,ilmn,ia) = two_pi2*buffer_ic
      d2gxdt(2,4,ilmn,ia) = two_pi2*buffer_id
      d2gxdt(2,5,ilmn,ia) = two_pi2*buffer_ie
      d2gxdt(2,6,ilmn,ia) = two_pi2*buffer_if
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       buffer_r = zero ; buffer_r1 = zero
       buffer_r2 = zero ; buffer_r3 = zero
       buffer_ra = zero ; buffer_rb = zero
       buffer_rc = zero ; buffer_rd = zero
       buffer_re = zero ; buffer_rf = zero
       do ipw=1,npw
        aux_r = scalr(ipw)*ffnl(ipw,1,ilmn)
        aux_i = scali(ipw)*ffnl(ipw,1,ilmn)
        buffer_r = buffer_r + aux_r
        buffer_r1 = buffer_r1 - aux_i*kpg(ipw,1)
        buffer_r2 = buffer_r2 - aux_i*kpg(ipw,2)
        buffer_r3 = buffer_r3 - aux_i*kpg(ipw,3)
        buffer_ra = buffer_ra - aux_r*kpg(ipw,4)
        buffer_rb = buffer_rb - aux_r*kpg(ipw,5)
        buffer_rc = buffer_rc - aux_r*kpg(ipw,6)
        buffer_rd = buffer_rd - aux_r*kpg(ipw,7)
        buffer_re = buffer_re - aux_r*kpg(ipw,8)
        buffer_rf = buffer_rf - aux_r*kpg(ipw,9)
       end do
       gx(1,ilmn,ia) = buffer_r
       gx(2,ilmn,ia) = zero
       dgxdt(1,1,ilmn,ia)  = two_pi*buffer_r1
       dgxdt(1,2,ilmn,ia)  = two_pi*buffer_r2
       dgxdt(1,3,ilmn,ia)  = two_pi*buffer_r3
       dgxdt(2,1,ilmn,ia)  = zero
       dgxdt(2,2,ilmn,ia)  = zero
       dgxdt(2,3,ilmn,ia)  = zero
       d2gxdt(1,1,ilmn,ia) = two_pi2*buffer_ra
       d2gxdt(1,2,ilmn,ia) = two_pi2*buffer_rb
       d2gxdt(1,3,ilmn,ia) = two_pi2*buffer_rc
       d2gxdt(1,4,ilmn,ia) = two_pi2*buffer_rd
       d2gxdt(1,5,ilmn,ia) = two_pi2*buffer_re
       d2gxdt(1,6,ilmn,ia) = two_pi2*buffer_rf
       d2gxdt(2,1,ilmn,ia) = zero
       d2gxdt(2,2,ilmn,ia) = zero
       d2gxdt(2,3,ilmn,ia) = zero
       d2gxdt(2,4,ilmn,ia) = zero
       d2gxdt(2,5,ilmn,ia) = zero
       d2gxdt(2,6,ilmn,ia) = zero
      else
       buffer_i = zero ; buffer_i1 = zero
       buffer_i2 = zero ; buffer_i3 = zero
       buffer_ia = zero ; buffer_ib = zero
       buffer_ic = zero ; buffer_id = zero
       buffer_ie = zero ; buffer_if = zero
       do ipw=1,npw
        aux_r = scalr(ipw)*ffnl(ipw,1,ilmn)
        aux_i = scali(ipw)*ffnl(ipw,1,ilmn)
        buffer_i = buffer_i + aux_i
        buffer_i1 = buffer_i1 + aux_r*kpg(ipw,1)
        buffer_i2 = buffer_i2 + aux_r*kpg(ipw,2)
        buffer_i3 = buffer_i3 + aux_r*kpg(ipw,3)
        buffer_ia = buffer_ia - aux_i*kpg(ipw,4)
        buffer_ib = buffer_ib - aux_i*kpg(ipw,5)
        buffer_ic = buffer_ic - aux_i*kpg(ipw,6)
        buffer_id = buffer_id - aux_i*kpg(ipw,7)
        buffer_ie = buffer_ie - aux_i*kpg(ipw,8)
        buffer_if = buffer_if - aux_i*kpg(ipw,9)
       end do
       gx(2,ilmn,ia) = buffer_i
       gx(1,ilmn,ia) = zero
       dgxdt(2,1,ilmn,ia) = two_pi*buffer_i1
       dgxdt(2,2,ilmn,ia) = two_pi*buffer_i2
       dgxdt(2,3,ilmn,ia) = two_pi*buffer_i3
       dgxdt(1,1,ilmn,ia) = zero
       dgxdt(1,2,ilmn,ia) = zero
       dgxdt(1,3,ilmn,ia) = zero
       d2gxdt(2,1,ilmn,ia) = two_pi2*buffer_ia
       d2gxdt(2,2,ilmn,ia) = two_pi2*buffer_ib
       d2gxdt(2,3,ilmn,ia) = two_pi2*buffer_ic
       d2gxdt(2,4,ilmn,ia) = two_pi2*buffer_id
       d2gxdt(2,5,ilmn,ia) = two_pi2*buffer_ie
       d2gxdt(2,6,ilmn,ia) = two_pi2*buffer_if
       d2gxdt(1,1,ilmn,ia) = zero
       d2gxdt(1,2,ilmn,ia) = zero
       d2gxdt(1,3,ilmn,ia) = zero
       d2gxdt(1,4,ilmn,ia) = zero
       d2gxdt(1,5,ilmn,ia) = zero
       d2gxdt(1,6,ilmn,ia) = zero
      end if
     end if
    end do
   end if

! --------------------------------------------------------------------
! CHOICE 5:
!          Accumulate Gx
!          Accumulate dGxdt --- derivative wrt k ---
! --------------------------------------------------------------------
  else if (choice==5) then
   if (signs==2) then
    do ilmn=1,nlmn
     if (noparity) then
      buffer_r  = zero ; buffer_i  = zero
      buffer_r1 = zero ; buffer_i1 = zero
      do ipw=1,npw
       buffer_r  = buffer_r  + scalr(ipw)*ffnl(ipw,1,ilmn)
       buffer_i  = buffer_i  + scali(ipw)*ffnl(ipw,1,ilmn)
       buffer_r1 = buffer_r1 + scalr(ipw)*ffnl(ipw,2,ilmn)
       buffer_i1 = buffer_i1 + scali(ipw)*ffnl(ipw,2,ilmn)
      end do
      gx(1,ilmn,ia)      = buffer_r
      gx(2,ilmn,ia)      = buffer_i
      dgxdt(1,1,ilmn,ia) = buffer_r1
      dgxdt(2,1,ilmn,ia) = buffer_i1
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       buffer_r  = zero ; buffer_r1 = zero
       do ipw=1,npw
          buffer_r  = buffer_r  + scalr(ipw)*ffnl(ipw,1,ilmn)
          buffer_r1 = buffer_r1 + scalr(ipw)*ffnl(ipw,2,ilmn)
       end do
       gx(1,ilmn,ia)      = buffer_r
       gx(2,ilmn,ia)      = zero
       dgxdt(1,1,ilmn,ia) = buffer_r1
       dgxdt(2,1,ilmn,ia) = zero
      else
       buffer_i  = zero ; buffer_i1 = zero
       do ipw=1,npw
        buffer_i  = buffer_i  + scali(ipw)*ffnl(ipw,1,ilmn)
        buffer_i1 = buffer_i1 + scali(ipw)*ffnl(ipw,2,ilmn)
       end do
       gx(2,ilmn,ia)      = buffer_i
       gx(1,ilmn,ia)      = zero
       dgxdt(2,1,ilmn,ia) = buffer_i1
       dgxdt(1,1,ilmn,ia) = zero
      end if
     end if
    end do
   end if

! --------------------------------------------------------------------
! CHOICE 6:
!          Accumulate Gx
!          Accumulate dGxdt --- derivative wrt atm pos. ---
!          Accumulate dGxdt --- derivative wrt strain ---
!          Accumulate d2Gxdt --- 2nd derivative wrt 2 strains ---
!          Accumulate d2Gxdt --- 2nd derivative wrt strain and atm. pos ---
!  --------------------------------------------------------------------
  else if (choice==6) then
   if (signs==1) then

    allocate(scalarr(npw,10),scalari(npw,10))
    do ilmn=1,nlmn

     do mu=1,10
      do ipw=1,npw
       scalarr(ipw,mu)=scalr(ipw)*ffnl(ipw,mu,ilmn)
       scalari(ipw,mu)=scali(ipw)*ffnl(ipw,mu,ilmn)
      end do
     end do

!    ===== Accumulate Gx =====
     if (noparity) then
      buffer_r = zero ; buffer_i = zero
      do ipw=1,npw
       buffer_r = buffer_r + scalarr(ipw,1)
       buffer_i = buffer_i + scalari(ipw,1)
      end do
      gx(1,ilmn,ia) = buffer_r ; gx(2,ilmn,ia) = buffer_i
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       buffer_r = zero
       do ipw=1,npw
        buffer_r = buffer_r + scalarr(ipw,1)
       end do
       gx(1,ilmn,ia) = buffer_r ; gx(2,ilmn,ia) = zero
      else
       buffer_i = zero
       do ipw=1,npw
        buffer_i = buffer_i + scalari(ipw,1)
       end do
       gx(2,ilmn,ia) = buffer_i ; gx(1,ilmn,ia) = zero
      end if
     end if

!    ===== Accumulate derivative of Gx wrt atm pos. =====
     ishift=6
     if (noparity) then
      do mu=1,3
       buffer_r = zero ; buffer_i = zero
       do ipw=1,npw
        buffer_r = buffer_r - scalari(ipw,1)*kpg(ipw,mu)
        buffer_i = buffer_i + scalarr(ipw,1)*kpg(ipw,mu)
       end do
       dgxdt(1,ishift+mu,ilmn,ia) = two_pi*buffer_r
       dgxdt(2,ishift+mu,ilmn,ia) = two_pi*buffer_i
      end do
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       do mu=1,3
        buffer_r = zero
        do ipw=1,npw
         buffer_r = buffer_r - scalari(ipw,1)*kpg(ipw,mu)
        end do
        dgxdt(1,ishift+mu,ilmn,ia) = two_pi*buffer_r
        dgxdt(2,ishift+mu,ilmn,ia) = zero
       end do
      else
       do mu=1,3
        buffer_i = zero
        do ipw=1,npw
         buffer_i = buffer_i + scalarr(ipw,1)*kpg(ipw,mu)
        end do
        dgxdt(2,ishift+mu,ilmn,ia) = two_pi*buffer_i
        dgxdt(1,ishift+mu,ilmn,ia) = zero
       end do
      end if
     end if

!    ===== Accumulate derivative of Gx wrt strain =====
     if(noparity) then
      do mu=1,6
       mua=alpha(mu);mub=beta(mu)
       buffer_r = zero ; buffer_i = zero
       do ipw=1,npw
        buffer_r = buffer_r + scalarr(ipw,1+mua)*kpg(ipw,mub) &
             &              + scalarr(ipw,1+mub)*kpg(ipw,mua)
        buffer_i = buffer_i + scalari(ipw,1+mua)*kpg(ipw,mub) &
             &              + scalari(ipw,1+mub)*kpg(ipw,mua)
       end do
       dgxdt(1,mu,ilmn,ia) =  -half*buffer_r
       dgxdt(2,mu,ilmn,ia) =  -half*buffer_i
      end do
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       do mu=1,6
        mua=alpha(mu);mub=beta(mu)
        buffer_r = zero
        do ipw=1,npw
         buffer_r = buffer_r + scalarr(ipw,1+mua)*kpg(ipw,mub) &
              &              + scalarr(ipw,1+mub)*kpg(ipw,mua)
        end do
        dgxdt(1,mu,ilmn,ia) = -half*buffer_r
        dgxdt(2,mu,ilmn,ia) = zero
       end do
      else
       do mu=1,6
        mua=alpha(mu);mub=beta(mu)
        buffer_i = zero
        do ipw=1,npw
         buffer_i = buffer_i + scalari(ipw,1+mua)*kpg(ipw,mub) &
              &              + scalari(ipw,1+mub)*kpg(ipw,mua)
        end do
        dgxdt(2,mu,ilmn,ia) = -half*buffer_i
        dgxdt(1,mu,ilmn,ia) = zero
       end do
      end if
     end if

!    ===== Accumulate 2nd derivative of Gx wrt two strains =====
     if(noparity) then
      do mub=1,6
       nub1=alpha(mub);nub2=beta(mub)
       do mua=1,6
        mu=mua+6*(mub-1)
        nua1=alpha(mua);nua2=beta(mua)
        gama=gamma(nub1,nua1)
        gamb=gamma(nub2,nua1)
        gamc=gamma(nub1,nua2)
        gamd=gamma(nub2,nua2)
        buffer_r = zero ; buffer_i = zero
        do ipw=1,npw
         kpga=kpg(ipw,nub1)
         kpgb=kpg(ipw,nub2)
         kpgc=kpg(ipw,nua1)
         kpgd=kpg(ipw,nua2)
         buffer_r = buffer_r + scalarr(ipw,4+gama)*kpgb*kpgd+scalarr(ipw,4+gamb)*kpga*kpgd &
              &              + scalarr(ipw,4+gamc)*kpgb*kpgc+scalarr(ipw,4+gamd)*kpga*kpgc
         buffer_i = buffer_i + scalari(ipw,4+gama)*kpgb*kpgd+scalari(ipw,4+gamb)*kpga*kpgd &
              &              + scalari(ipw,4+gamc)*kpgb*kpgc+scalari(ipw,4+gamd)*kpga*kpgc
        end do
        d2gxdt(1,mu,ilmn,ia) =  quarter*buffer_r
        d2gxdt(2,mu,ilmn,ia) =  quarter*buffer_i
       end do
      end do
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       do mub=1,6
        nub1=alpha(mub);nub2=beta(mub)
        do mua=1,6
         mu=mua+6*(mub-1)
         nua1=alpha(mua);nua2=beta(mua)
         gama=gamma(nub1,nua1)
         gamb=gamma(nub2,nua1)
         gamc=gamma(nub1,nua2)
         gamd=gamma(nub2,nua2)
         buffer_r = zero
         do ipw=1,npw
          kpga=kpg(ipw,nub1)
          kpgb=kpg(ipw,nub2)
          kpgc=kpg(ipw,nua1)
          kpgd=kpg(ipw,nua2)
          buffer_r = buffer_r + scalarr(ipw,4+gama)*kpgb*kpgd+scalarr(ipw,4+gamb)*kpga*kpgd &
               &              + scalarr(ipw,4+gamc)*kpgb*kpgc+scalarr(ipw,4+gamd)*kpga*kpgc
         end do
         d2gxdt(1,mu,ilmn,ia) =  quarter*buffer_r
         d2gxdt(2,mu,ilmn,ia) =  zero
        end do
       end do
      else
       do mub=1,6
        nub1=alpha(mub);nub2=beta(mub)
        do mua=1,6
         mu=mua+6*(mub-1)
         nua1=alpha(mua);nua2=beta(mua)
         gama=gamma(nub1,nua1)
         gamb=gamma(nub2,nua1)
         gamc=gamma(nub1,nua2)
         gamd=gamma(nub2,nua2)
         buffer_i = zero
         do ipw=1,npw
          kpga=kpg(ipw,nub1)
          kpgb=kpg(ipw,nub2)
          kpgc=kpg(ipw,nua1)
          kpgd=kpg(ipw,nua2)
          buffer_i = buffer_i + scalari(ipw,4+gama)*kpgb*kpgd+scalari(ipw,4+gamb)*kpga*kpgd &
               &              + scalari(ipw,4+gamc)*kpgb*kpgc+scalari(ipw,4+gamd)*kpga*kpgc
         end do
         d2gxdt(2,mu,ilmn,ia) = quarter*buffer_i
         d2gxdt(1,mu,ilmn,ia) = zero
        end do
       end do
      end if
     end if

!    ===== Accumulate 2nd derivative of Gx wrt strain and atm pos. =====
     ishift=36
     if(noparity) then
      do mub=1,6
       nub1=alpha(mub);nub2=beta(mub)
       do mua=1,3
        mu=ishift+mua+3*(mub-1)
        buffer_r = zero ; buffer_i = zero
        do ipw=1,npw
         buffer_r = buffer_r + kpg(ipw,mua)*(scalari(ipw,1+nub1)*kpg(ipw,nub2) + &
              &                              scalari(ipw,1+nub2)*kpg(ipw,nub1))
         buffer_i = buffer_i + kpg(ipw,mua)*(scalarr(ipw,1+nub1)*kpg(ipw,nub2) + &
              &                              scalarr(ipw,1+nub2)*kpg(ipw,nub1))
        end do
        d2gxdt(1,mu,ilmn,ia) =  pi*buffer_r
        d2gxdt(2,mu,ilmn,ia) = -pi*buffer_i
       end do
      end do
     else
      parity=(mod(indlmn(1,ilmn),2)==0)
      if (parity) then
       do mub=1,6
        nub1=alpha(mub);nub2=beta(mub)
        do mua=1,3
         mu=ishift+mua+3*(mub-1)
         buffer_r = zero
         do ipw=1,npw
          buffer_r = buffer_r + kpg(ipw,mua)*(scalari(ipw,1+nub1)*kpg(ipw,nub2) + &
               &                              scalari(ipw,1+nub2)*kpg(ipw,nub1))
         end do
         d2gxdt(1,mu,ilmn,ia) =  pi*buffer_r
         d2gxdt(2,mu,ilmn,ia) =  zero
        end do
       end do
      else
       do mub=1,6
        nub1=alpha(mub);nub2=beta(mub)
        do mua=1,3
         mu=ishift+mua+3*(mub-1)
         buffer_i = zero
         do ipw=1,npw
          buffer_i = buffer_i + kpg(ipw,mua)*(scalarr(ipw,1+nub1)*kpg(ipw,nub2) + &
               &                              scalarr(ipw,1+nub2)*kpg(ipw,nub1))
         end do
         d2gxdt(2,mu,ilmn,ia) =  -pi*buffer_i
         d2gxdt(1,mu,ilmn,ia) =  zero
        end do
       end do
      end if
     end if
    end do
    deallocate(scalarr,scalari)
   end if

! --------------------------------------------------------------------
! END CHOICES
! --------------------------------------------------------------------
  end if

!End loop on atoms
 end do
!$OMP END DO
!$OMP END PARALLEL

!Has to reduce arrays in case of FFT parallelization
 if(mpi_enreg%paral_compil_fft==1)then
  old_paral_level=mpi_enreg%paral_level
  mpi_enreg%paral_level=3
  call xcomm_init(mpi_enreg,spaceComm)
  if(mpi_enreg%mode_para=='b') spaceComm=mpi_enreg%comm_fft
  call timab(48,1,tsec)
  call xsum_mpi(gx,spaceComm,ierr)
  if (choice>1) call xsum_mpi(dgxdt,spaceComm,ierr)
  if (choice==4.or.choice==6) call xsum_mpi(d2gxdt,spaceComm,ierr)
  call timab(48,2,tsec)
  mpi_enreg%paral_level=old_paral_level
 end if

!Deallocate temporary space
 deallocate(scali,scalr)

end subroutine opernla_ylm
!!***
