!{\src2tex{textfont=tt}}
!!****f* ABINIT/initrhoij
!! NAME
!! initrhoij
!!
!! FUNCTION
!! Initialize PAW rhoij occupancies (in packed storage)
!! from atomic ones
!!
!! COPYRIGHT
!! Copyright (C) 1998-2006 ABINIT group (MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors.
!!
!! INPUTS
!!  natom=number of atoms
!!  nspden=number of spin-density components
!!  ntypat=number of atom types
!!  pawtab(ntypat) <type(pawtab_type)>=paw tabulated starting data
!!                                     (containing initial rhoij)
!!  typat(natom)=type of each atom
!!
!! OUTPUT
!!  atmrhoij(natom) <type(atmrhoij_type)>=rhoij quantities for each atom
!!                                        in packed storage
!!
!! PARENTS
!!      gstate
!!
!! CHILDREN
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine initrhoij(atmrhoij,natom,nspden,ntypat,pawtab,typat)

 use defs_basis
 use defs_datatypes

 implicit none

!Arguments ---------------------------------------------
!scalars
 integer,intent(in) :: natom,nspden,ntypat
!arrays
 integer,intent(in) :: typat(natom)
 type(atmrhoij_type),intent(out) :: atmrhoij(natom)
 type(pawtab_type),intent(in) :: pawtab(ntypat)

!Local variables ---------------------------------------
!scalars
 integer :: iatom,ispden,itypat,klmn,nselect
 real(dp) :: ratio

!************************************************************************

 ratio=1.d0;if (nspden==2) ratio=0.5d0
 do iatom=1,natom
  itypat=typat(iatom)
  atmrhoij(iatom)%nspden=nspden
  atmrhoij(iatom)%lmn2_size=pawtab(itypat)%lmn2_size
  allocate(atmrhoij(iatom)%nrhoijsel(nspden))
  allocate(atmrhoij(iatom)%rhoij(pawtab(itypat)%lmn2_size,nspden))
  allocate(atmrhoij(iatom)%rhoijselect(pawtab(itypat)%lmn2_size,nspden))
  nselect=0
  do klmn=1,pawtab(itypat)%lmn2_size
   if (abs(pawtab(itypat)%rhoij0(klmn))>tol10) then
    nselect=nselect+1
    do ispden=1,nspden
     atmrhoij(iatom)%rhoijselect(nselect,ispden)=klmn
     atmrhoij(iatom)%rhoij(nselect,ispden)=ratio*pawtab(itypat)%rhoij0(klmn)
    end do
   end if
  end do
  atmrhoij(iatom)%nrhoijsel(1:nspden)=nselect
 end do

end subroutine initrhoij
!!***
