!{\src2tex{textfont=tt}}
!!****f* ABINIT/pawprt
!! NAME
!! pawprt
!!
!! FUNCTION
!! Print out data concerning PAW formalism
!! (pseudopotential strenght, augmentation occupancies...)
!! To be called at the end of the SCF cycle
!!
!! COPYRIGHT
!! Copyright (C) 1998-2006 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors.
!!
!! INPUTS
!!  enunit=parameter determining units of output energies
!!  natom=number of atoms in cell.
!!  paw_ij(natom) <type(paw_ij_type)>=paw arrays given on (i,j) channels
!!
!! OUTPUT
!!  (only printing)
!!
!! PARENTS
!!      outscfcv
!!
!! CHILDREN
!!      print_ij,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine pawprt(enunit,natom,paw_ij)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_01util
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: enunit,natom
!arrays
 type(paw_ij_type),intent(in) :: paw_ij(natom)

!Local variables-------------------------------
!scalars
 integer :: lmn2size1,lmn2sizen,lmnsize1,lmnsizen,unt
 character(len=500) :: message
!arrays
 integer :: idum(1)

! *********************************************************************

 lmnsize1 =paw_ij(1)%lmn_size
 lmnsizen =paw_ij(natom)%lmn_size
 lmn2size1=paw_ij(1)%lmn2_size
 lmn2sizen=paw_ij(natom)%lmn2_size

 write(message, '(2a)' ) ch10,&
&   ' ==== Results concerning PAW augmentation regions ===='
 call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')

!Print out pseudopotential strength
!----------------------------------
 message=' ';call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
 do unt=1,2
  if ((unt==1).and.(enunit==0.or.enunit==2)) then
   write(message, '(a)' ) &
&   ' Total pseudopotential strength Dij (hartree):'
   call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
  else if ((unt==2).and.(enunit==1.or.enunit==2)) then
   write(message, '(a)' ) &
&   ' Total pseudopotential strength Dij (eV):'
   call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
  end if
  if (((unt==1).and.(enunit==0.or.enunit==2)).or.&
&     ((unt==2).and.(enunit==1.or.enunit==2))) then
   message=''
   if (natom>1) write(message, '(a)' ) ' Atom #  1'
   if (paw_ij(1)%nspden>1) &
&    write(message, '(2a)' ) trim(message),' - Density component 1'
   if (natom>1.or.paw_ij(1)%nspden>1) then
    call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
   end if
   call print_ij(paw_ij(1)%dij(:,1),lmn2size1,lmnsize1,2,0,idum,unt)
   if (paw_ij(1)%nspden>1) then
    message=''
    if (natom>1) write(message, '(a)' ) ' Atom #  1'
    write(message, '(2a)' ) trim(message),' - Density component 2'
    call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
    call print_ij(paw_ij(1)%dij(:,2),lmn2size1,lmnsize1,2,0,idum,unt)
   end if
   if (natom>1) then
    write(message, '(a,i3)' ) ' Atom #',natom
    if (paw_ij(natom)%nspden>1) &
&      write(message, '(a,a)' ) trim(message),' - Density component 1'
    call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
    call print_ij(paw_ij(natom)%dij(:,1),lmn2sizen,lmnsizen,2,0,idum,unt)
    if (paw_ij(natom)%nspden>1) then
     write(message, '(a,i3,a)' ) ' Atom #',natom,' - Density component 2'
     call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
     call print_ij(paw_ij(natom)%dij(:,2),lmn2sizen,lmnsizen,2,0,idum,unt)
    end if
   end if
  end if
  message=' ';call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
 end do

!Print out NON-SYMMETRIZED occupancies of the partial waves
!----------------------------------------------------------
 write(message, '(a)' ) &
&   ' NON-SYMMETRIZED (augmentation) waves occupancies Rhoij:'
 call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
 message=''
 if (natom>1) write(message, '(a)' ) ' Atom #  1'
 if (paw_ij(1)%nspden>1) &
&  write(message, '(2a)' ) trim(message),' - Density component 1'
 if (natom>1.or.paw_ij(1)%nspden>1) then
  call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
 end if
 call print_ij(paw_ij(1)%rhoij_(:,1),lmn2size1,lmnsize1,2,0,idum,1)
 if (paw_ij(1)%nspden>1) then
  message=''
  if (natom>1) write(message, '(a)' ) ' Atom #  1'
  write(message, '(2a)' ) trim(message),' - Density component 2'
  call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
  call print_ij(paw_ij(1)%rhoij_(:,2),lmn2size1,lmnsize1,2,0,idum,1)
 end if
 if (natom>1) then
  write(message, '(a,i3)' ) ' Atom #',natom
  if (paw_ij(natom)%nspden>1) &
&   write(message, '(a,a)' ) trim(message),' - Density component 1'
  call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
  call print_ij(paw_ij(natom)%rhoij_(:,1),lmn2sizen,lmnsizen,2,0,idum,1)
  if (paw_ij(natom)%nspden>1) then
   write(message, '(a,i3,a)' ) ' Atom #',natom,' - Density component 2'
   call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
   call print_ij(paw_ij(natom)%rhoij_(:,2),lmn2sizen,lmnsizen,2,0,idum,1)
  end if
 end if
 message=' ';call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')

!Print out SYMMETRIZED occupancies of the partial waves
!------------------------------------------------------
 write(message, '(a)' ) &
&   ' SYMMETRIZED (augmentation) waves occupancies Rhoij:'
 call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
 message=''
 if (natom>1) write(message, '(a)' ) ' Atom #  1'
 if (paw_ij(1)%nspden>1) &
&  write(message, '(2a)' ) trim(message),' - Density component 1'
 if (natom>1.or.paw_ij(1)%nspden>1) then
  call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
 end if
 call print_ij(paw_ij(1)%rhoij(:,1),lmn2size1,lmnsize1,2,0,idum,1)
 if (paw_ij(1)%nspden>1) then
  message=''
  if (natom>1) write(message, '(a)' ) ' Atom #  1'
  write(message, '(2a)' ) trim(message),' - Density component 2'
  call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
  call print_ij(paw_ij(1)%rhoij(:,2),lmn2size1,lmnsize1,2,0,idum,1)
 end if
 if (natom>1) then
  write(message, '(a,i3)' ) ' Atom #',natom
  if (paw_ij(natom)%nspden>1) &
&   write(message, '(a,a)' ) trim(message),' - Density component 1'
  call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
  call print_ij(paw_ij(natom)%rhoij(:,1),lmn2sizen,lmnsizen,2,0,idum,1)
  if (paw_ij(natom)%nspden>1) then
   write(message, '(a,i3,a)' ) ' Atom #',natom,' - Density component 2'
   call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')
   call print_ij(paw_ij(natom)%rhoij(:,2),lmn2sizen,lmnsizen,2,0,idum,1)
  end if
 end if
 message=' ';call wrtout(ab_out,message,'COLL');call wrtout(6,message,'COLL')

end subroutine pawprt

!!***
