!{\src2tex{textfont=tt}}
!!****f* ABINIT/pawpupot
!! NAME
!! pawpupot
!!
!! FUNCTION
!! Compute occupation matrix, LDA+U potential, and Contributions to energy
!! for PAW+U calculations
!!
!! A-Compute LDA+U Potential
!! B-Compute Contributions to energy
!!
!! COPYRIGHT
!! Copyright (C) 1998-2006 ABINIT group (BA, FJ)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors.
!!
!! INPUTS
!!  pawprtvol=control print volume and debugging output for PAW

!!  paw_ij(natom) <type(paw_ij_type)>=paw arrays given on (i,j) channels
!!  %noccmmp(2*pawtab(itypat)%lpawu+1,2*pawtab(itypat)%lpawu+1,nspden)
!!     density matrix in the sphere
!!  %nocctot(nspden) number of electrons in the correlated subspace
!!  pawtab(ntypat) <type(pawtab_type)>=paw tabulated starting data:
!!     %lpawu=l used for lda+u
!!     %vee(2*lpawu+1*4)=screened coulomb matrix
!!  VUKS= Kohn Sham potential for LDA+U (for test only)
!!
!! OUTPUT
!!  vpawu(pawtab%lpawu*2+1,pawtab%lpawu*2+1,nspden)=lda+u potential
!!       (see eg PRB 52m 5467 (1995))
!!
!! PARENTS
!!      pawdij
!!
!! CHILDREN
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

 subroutine pawpupot(ispden,nspden, paw_ij,pawprtvol,pawtab,vpawu,VUKS)

 use defs_basis
 use defs_datatypes

 implicit none

!Arguments ---------------------------------------------
!scalars
 integer,intent(in) :: ispden,nspden,pawprtvol
 type(paw_ij_type),intent(in) :: paw_ij
 type(pawtab_type),intent(in) :: pawtab
!arrays
 real(dp),intent(inout) :: vpawu(pawtab%lpawu*2+1,pawtab%lpawu*2+1,nspden)

!Local variables ---------------------------------------
!scalars
 integer :: lpawu,m1,m11,m2,m21,m3,m31,m4,m41
 real(dp) :: VUKS,VUKStemp
 character(len=500) :: message

! *****************************************************
 lpawu=pawtab%lpawu

!======================================================
! Compute LDA+U Potential on the basis of projectors.
! cf PRB 52 5467 (1995)
! -----------------------------------------------------

 vpawu=zero
 do m1=-lpawu,lpawu
  m11=m1+lpawu+1
  do m2=-lpawu,lpawu
   m21=m2+lpawu+1
   do m3=-lpawu,lpawu
    m31=m3+lpawu+1
    do m4=-lpawu,lpawu
     m41=m4+lpawu+1
     vpawu(m11,m21,ispden)=vpawu(m11,m21,ispden)+&
&    pawtab%vee(m11,m31,m21,m41)*paw_ij%noccmmp(m31,m41,nspden-ispden+1)+&
&    (pawtab%vee(m11,m31,m21,m41)-pawtab%vee(m11,m31,m41,m21))&
&    *paw_ij%noccmmp(m31,m41,ispden) 
    end do
   end do
   if(m11/=m21) write(6,*) "vu",m11,m21,vpawu(m11,m21,ispden)
   if(m11/=m21) write(6,*) "vupred",-pawtab%upaw*paw_ij%noccmmp(m21,m11,ispden)
  end do ! m2
  if(pawtab%usepawu==1) then
   vpawu(m11,m11,ispden)=vpawu(m11,m11,ispden)-&
&  pawtab%upaw*(paw_ij%nocctot(ispden)+paw_ij%nocctot(nspden-ispden+1)-One/Two)+&
&  pawtab%jpaw*(paw_ij%nocctot(ispden)             -One/Two)
  elseif(pawtab%usepawu==2) then
   vpawu(m11,m11,ispden)=vpawu(m11,m11,ispden)-&
&  pawtab%upaw*(paw_ij%nocctot(nspden-ispden+1))-&
&  (pawtab%upaw-pawtab%jpaw)*(paw_ij%nocctot(ispden)*&
&  (Two*dfloat(lpawu))/(Two*dfloat(lpawu)+One))
  end if
  if (pawprtvol>=1) then
   write(6,*) "vudiag",m11,m11,vpawu(m11,m11,ispden)
   write(6,*) "vudiagpred",pawtab%upaw*(0.5d0-paw_ij%noccmmp(m11,m11,ispden))
  end if
 end do ! m1

 if (pawprtvol>=1) then
  VUKStemp=zero
  do m1=-lpawu,lpawu
   m11=m1+lpawu+1
   do m2=-lpawu,lpawu
    m21=m2+lpawu+1
    VUKStemp=VUKStemp+vpawu(m11,m21,ispden)*paw_ij%noccmmp(m11,m21,ispden)
    write(6,*) "vuks,m1,m2,vpawu,noccmmp",vpawu(m11,m21,ispden)&
&   ,paw_ij%noccmmp(m11,m21,ispden)
   end do
  end do
  VUKS=VUKS+VUKStemp
  write(6,*) "pawpupot: VUKStemp",ispden,VUKStemp
  write(6,*) "pawpupot: VUKS",ispden,VUKS
 end if
 
 end subroutine pawpupot
!!***
