!{\src2tex{textfont=tt}}
!!****f* ABINIT/prtene
!!
!! NAME
!! prtene
!!
!! FUNCTION
!! Print components of total energy in nice format
!!
!! COPYRIGHT
!! Copyright (C) 1998-2006 ABINIT group (DCA, XG, GMR, LBoeri, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  berryopt=4 for calculation in a homogeneous electric field
!!  eei=local pseudopotential energy
!!  eeig=sum of eigenvalues energy
!!  eew=Ewald energy
!!  ehart=Hartree energy
!!  eii=pseudocore correction energy
!!  ek=electron kinetic energy
!!  enl=nonlocal pseudopotential energy
!!  enefield=the term of the energy functional that depends
!!                  explicitely on the electric field
!!                  enefield = -ucvol*E*P
!!  entropy=entropy due to the occupation number smearing (if metal)
!!  enxc=exchange and correlation energy
!!  enxcdc=exchange and correlation double-counting energy
!!  epawsph=spherical energy in case of PAW
!!  epawsphdc=spherical "double counting" energy in case of PAW
!!  epulay=correction energy for basis set error (Francis-Payne)
!!  icoultrtmt=0 for periodic Fourier calculation of Hartree potential; 1 for isolated system using Poisson solver.
!!  iout=unit number to which output is written
!!  occopt=option for occupancies
!!  tphysel="physical" electronic temperature with FD occupations
!!  tsmear=smearing energy or temperature (if metal)
!!  usepaw= 0 for non paw calculation; =1 for paw calculation
!!
!! OUTPUT
!!  (only writing)
!!
!! PARENTS
!!      gstate
!!
!! CHILDREN
!!      wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine prtene(berryopt,eei,eeig,eew,ehart,eii,ek,enefield,&
& enl,entropy,enxc,enxcdc,epawsph,epawsphdc,epulay,icoultrtmt,&
& iout,occopt,tphysel,tsmear,usepaw)

 use defs_basis

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: berryopt,icoultrtmt,iout,occopt,usepaw
 real(dp),intent(in) :: eei,eeig,eew,ehart,eii,ek,enefield,enl,entropy,enxc
 real(dp),intent(in) :: enxcdc,epawsph,epawsphdc,epulay,tphysel,tsmear

!Local variables-------------------------------
! Do not modify the length of this string
!scalars
 integer :: mu,optdc
 real(dp) :: eent,eintern,einterndc,etotal,etotaldc
 character(len=22) :: eneName
 character(len=500) :: message

! *************************************************************************

 optdc=-1
 if (abs(eei)>1.d-15.and.abs(enxcdc)<1.d-15) optdc=0
 if (abs(eei)<1.d-15.and.abs(enxcdc)>1.d-15) optdc=1
 if (abs(eei)>1.d-15.and.abs(enxcdc)>1.d-15) optdc=2

! ============= Evaluate some parts of the energy ===========

!Here, treat the case of metals
!In re-smeared case the free energy is defined with tphysel
 if(occopt>=3 .and. occopt<=7)then
  if (abs(tphysel) < tol10) then
   eent=-tsmear*entropy
  else
   eent=-tphysel*entropy
  end if
 else
  eent=zero
 end if

 if (optdc==0.or.optdc==2) then
  etotal=ek+ehart+enxc+eei+eew+eii+eent
  if (usepaw==0) etotal=etotal+enl
  if (usepaw==1) etotal=etotal+epawsph
  if (berryopt==4) etotal=etotal+enefield
 end if
 if (optdc>=1) then
  etotaldc=eeig-ehart+enxc-enxcdc+eew+eii+eent
  if (usepaw==1) etotaldc=etotaldc+epawsphdc
  if (berryopt==4) etotaldc=etotaldc+enefield
 end if

 write(message,'(a,80a)') ch10,('-',mu=1,80)
 call wrtout(iout,message,'COLL')

! ============= Old version of printing (for tests) ===========

!XG030503 Back to the old version
 if(.false.)then     ! XG030503
  if(occopt>=3 .and. occopt<=7)then
   write(message, '(a,a)' ) ch10,&
&   ' Eight components of total free energy (hartree) are '
  else
   write(message, '(a,a)' ) ch10,&
&   ' Seven components of total energy (hartree) are '
  end if
  call wrtout(iout,message,'COLL')
  write(message, '(a,1p,e21.14,a,e21.14)' ) &
&  ' kinetic=',ek,' Hartree=',ehart
  call wrtout(iout,message,'COLL')
  write(message, '(a,1p,e21.14,a,e21.14)' ) &
&  '      xc=',enxc,' loc psp=',eei
  call wrtout(iout,message,'COLL')
  write(message, '(a,1p,e21.14,a,e21.14)' ) &
&  ' nl psp =',enl,' pspcore=',eii
  call wrtout(iout,message,'COLL')
! Here, treat the case of metals
  if(occopt>=3 .and. occopt<=7)then
!  Redefine etotal as the total free energy
!  in re-smeared case the free energy is defined with tphysel
   if ( abs(tphysel) < tol10) then
    write(message, '(a,1p,e21.14,a,e21.14,a)' ) &
&    ' -kT*entropy =',-tsmear*entropy,' (internal energy=',eintern,' )'
   else
     write(message, '(a,1p,e21.14,a,e21.14,a)' ) &
&   ' -kT*entropy =',-tphysel*entropy,' (internal energy=',eintern,' )'
   end if
   call wrtout(iout,message,'COLL')
  end if
  write(message, '(a,1p,e21.14,a,e21.14,a)' ) &
&  ' Ewald  =',eew,' resulting in Etotal=',etotal,' hartree'
  call wrtout(iout,message,'COLL')
  if(abs(epulay) >=1.0d-12)then
   write(message, '(a,1p,e21.14,a)' ) &
&   ' with Pulay finite basis set correction,    Etotal=',&
&   etotal+epulay,' hartree'
   call wrtout(iout,message,'COLL')
  end if
  write(message,'(a,1p,e22.14,a,e18.10,a)' ) &
&   ' Also Etotal=',etotal*Ha_eV,' eV ; Eeig (band energy)=',eeig,' Ha'
  call wrtout(iout,message,'COLL')
 end if ! XG030503

! ============= Printing of Etotal by direct scheme ===========

  if (icoultrtmt == 1) then
    write(eneName, "(A)") "    Ion-ion energy  = "
  else
    write(eneName, "(A)") "    Ewald energy    = "
  end if

 if (optdc==0.or.optdc==2) then

  write(message, '(2a)' ) &
&  ' Components of total free energy (in Hartree) :',ch10
  call wrtout(iout,message,'COLL')
  write(message, '(5(a,es21.14,a),a,es21.14)' ) &
&  '    Kinetic energy  = ',ek,ch10,&
&  '    Hartree energy  = ',ehart,ch10,&
&  '    XC energy       = ',enxc,ch10,&
&  eneName,                 eew,ch10,&
&  '    PspCore energy  = ',eii,ch10,&
&  '    Loc. psp. energy= ',eei
  call wrtout(iout,message,'COLL')
  if (berryopt == 4) then
   write(message, '(a,es21.14)' ) &
&   '    Electric field  = ',enefield
   call wrtout(iout,message,'COLL')
  end if
  if (usepaw==0) then
   write(message, '(a,es21.14)' ) &
&   '    NL   psp  energy= ',enl
  else
   write(message, '(a,es21.14)' ) &
&   '    Spherical terms = ',epawsph
  end if
  call wrtout(iout,message,'COLL')
  if(occopt>=3 .and. occopt<=7) then
   write(message, '(a,es21.14,a,a,a,es21.14)' ) &
&   '    >>>>> Internal E= ',etotal-eent,ch10,ch10,&
&   '    -kT*entropy     = ',eent
   call wrtout(iout,message,'COLL')
  end if
  write(message, '(a,es21.14)' ) &
&  '    >>>>>>>>> Etotal= ',etotal
  call wrtout(iout,message,'COLL')
  if (abs(epulay) >=1.0d-12) then
   write(message, '(a,a,es21.14,a,a,es21.14)' ) ch10,&
&  '    Pulay correction= ',epulay,ch10,&
&  '    >Etot with Pulay= ',etotal+epulay
   call wrtout(iout,message,'COLL')
  end if
 end if

! ============= Printing of Etotal by double-counting scheme ===========

 if (optdc>=1) then

  write(message, '(a,a,a,3(a,es21.14,a),a,es21.14)' ) ch10,&
&   ' "Double-counting" decomposition of free energy:',ch10,&
&   '    Band energy     = ',eeig,ch10,&
&   eneName,                 eew,ch10,&
&   '    PspCore energy  = ',eii,ch10,&
&   '    Dble-C XC-energy= ',-ehart+enxc-enxcdc
  call wrtout(iout,message,'COLL')
  if (berryopt == 4) then
   write(message, '(a,es21.14)' ) &
&   '    Electric field  = ',enefield
   call wrtout(iout,message,'COLL')
  end if
  if (usepaw==1) then
   write(message, '(a,es21.14)' ) &
&   '    Spherical terms = ',epawsphdc
   call wrtout(iout,message,'COLL')
  end if
  if(occopt>=3 .and. occopt<=7) then
   write(message, '(a,es21.14,a,a,a,es21.14)' ) &
&   '    >>>>> Internal E= ',etotaldc-eent,ch10,ch10,&
&   '    -kT*entropy     = ',eent
   call wrtout(iout,message,'COLL')
  end if
  write(message, '(a,es21.14)' ) &
&   '    >>>> Etotal (DC)= ',etotaldc
  call wrtout(iout,message,'COLL')
  if (abs(epulay) >=1.0d-12) then
   write(message, '(a,a,es21.14,a,a,es21.14)' ) ch10,&
&  '    Pulay correction= ',epulay,ch10,&
&  '    >EDC with Pulay= ',etotaldc+epulay
   call wrtout(iout,message,'COLL')
  end if
 end if

! ======= Additional printing for compatibility  ==========

 if (usepaw==0.and.optdc==0) then
  write(message, '(a,a,a,a,es21.14,a,es18.10)' ) ch10,&
&  ' Other information on the energy :',ch10,&
&  '    Total energy(eV)= ',etotal*Ha_eV,' ; Band energy (Ha)= ',eeig
  call wrtout(iout,message,'COLL')
 end if

 if (usepaw==1) then
  if (optdc==0.or.optdc==2) then
   write(message, '(a,a,es21.14)' ) ch10,&
&   '  >Total energy in eV           = ',etotal*Ha_eV
   call wrtout(iout,message,'COLL')
  end if
  if (optdc>=1) then
   if (optdc==1) write(message, '(a)') ch10
   if (optdc==2) message=""
   write(message, '(a,a,es21.14)' ) trim(message),&
&   '  >Total DC energy in eV        = ',etotaldc*Ha_eV
   call wrtout(iout,message,'COLL')
  end if
 end if

! =============
 write(message,'(a,80a)')('-',mu=1,80)
 call wrtout(iout,message,'COLL')

end subroutine prtene
!!***
