!{\src2tex{textfont=tt}}
!!****f* ABINIT/cchi0
!! NAME
!! cchi0
!!
!! FUNCTION
!! Main calculation of the independent-particle susceptibility chi0 for qq!=0
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (GMR, VO, LR, RWG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  energy(nkibzm,nbnds)=KS energies
!!  gwenergy(nkibzm,nbnds)=GW energies, for self-consistency purposes
!!  igfft(npwvec,5,5,5)=index of G-G0 planewaves (see cigfft routine)
!!  kbz(3,nkbz)=k-point coordinates, full Brillouin zone
!!  ktab(nkbz)=(to be described)
!!  ktabi(nkbz)=(to be described)
!!  ktabr(nkbz)=(to be described)
!!  nbnds=number of bands
!!  nbv=number of valence bands
!!  ngfft1,ngfft1a,ngfft2,ngfft3=FFT grid dimensions
!!  nkbz=number of k points in full Brillouin zone
!!  nkibz=number of k points in irreducible Brillouin zone
!!  nkibzm=maximum number of k points in irreducible Brillouin zone
!!  nomega=number of frequencies
!!  npwsigx=number of planewaves for sigma exchange (input variable)
!!  npwvec=dimension of igfft
!!  npwwfn=number of planewaves for wavefunctions (input variable)
!!  nr=number of points of FFT grid
!!  occ(nkibzm,nbnds)=occupation numbers, for each k point in IBZ, and each band
!!  omega(nomega)=frequencies
!!  qq(3)=reciprocal space coordinates of the q wavevector
!!
!! OUTPUT
!!  chi0(npwsigx,npwsigx,nomega)=independent-particle susceptibility matrix for wavevector qq,
!!   and frequencies defined by omega
!!
!! TODO
!!  suppress the use of nkibzm, should be actually equal to nkibz
!!  eliminate energy (superceded by gwenergy)
!!
!! PARENTS
!!      screening
!!
!! CHILDREN
!!      assemblychi0,leave_new,rho_tw_g,timab,wrtout,xcomm_init
!!      xmaster_init,xme_init,xsum_master
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine cchi0(qq,nomega,omega,npwvec,npwsigx,npwwfn,nkibz,nkibzm,nbnds,&
& nbv,occ,ktab,ktabr,ktabi,kbz,nkbz,ngfft1,ngfft1a,ngfft2,ngfft3,igfft,&
& nr,energy,gwenergy,etadelta,chi0,mpi_enreg)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_00basis
 use interfaces_01managempi
 use interfaces_05gw, except_this_one => cchi0
#else
 use defs_xfuncmpi
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: nbnds,nbv,ngfft1,ngfft1a,ngfft2,ngfft3,nkbz,nkibz,nkibzm
 integer,intent(in) :: nomega,npwsigx,npwvec,npwwfn,nr
 real(dp),intent(in) :: etadelta
 type(MPI_type),intent(inout) :: mpi_enreg
!arrays
 integer,intent(in) :: igfft(npwvec,5,5,5),ktab(nkbz),ktabi(nkbz)
 integer,intent(in) :: ktabr(nr,nkbz)
 real(dp),intent(in) :: energy(nkibzm,nbnds),gwenergy(nkibzm,nbnds),kbz(3,nkbz)
 real(dp),intent(in) :: occ(nkibzm,nbnds),qq(3)
 complex,intent(in) :: omega(nomega)
 complex,intent(out) :: chi0(npwsigx,npwsigx,nomega)

!Local variables ------------------------------
!scalars
 integer,parameter :: unitwfr=26
 integer :: i,ib,ibc,ibv,ig,ig01a,ig02a,ig03a,igp,ik,ikibz,ikp,ikpibz,io,ir
 integer :: istat,nrb,tim_fourdp
 real(dp) :: eckp,factocc,ockp,weight
 complex :: dd
 logical :: wfnr_not_in_memory
!arrays
 integer :: g0(3)
 real(dp) :: kmq(3),tsec(2)
 complex,allocatable :: rhotw(:),rhotwg(:),rhotwgs(:)
 complex,allocatable,target :: wfnr(:,:,:),wfnrk(:,:),wfnrkp(:,:)
 complex,pointer :: wfnrckp(:),wfnrvk(:)
!no_abirules
 complex (kind(0.0d0)) :: ediff,egwdiff
 complex (kind(0.0d0)),allocatable :: den(:)
 character(len=500)::message
 integer::master,spaceComm,ierr,me

! *************************************************************************

!DEBUG
!write(6,*)' cchi0 : enter '
!ENDDEBUG

!! These lines added by Shaltaf for parallelization 10/08/05
!! parallization is on k points only, one must include the bands
!! too in the future

!Init mpi_comm
!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifndef HAVE_FORTRAN_INTERFACES
 logical :: findkp
#endif
!End of the abilint section

     call xcomm_init(mpi_enreg,spaceComm)
!Init me
     call xme_init(mpi_enreg,me)
!Init master
     call xmaster_init(mpi_enreg,master)

 call timab(331,1,tsec)

 tim_fourdp=1

 allocate(den(nomega),rhotw(nr),rhotwg(npwsigx),rhotwgs(npwsigx))
 write(message,'(a,a)') 'calculating chi0(q,omega,G,G")',ch10
 call wrtout(06,message,'COLL')

 write(message,'(a)')'trying to allocate wavefunctions in real space'
 call wrtout(06,message,'COLL')

 allocate(wfnr(nr,nbnds,nkibz),stat=istat)
 if(istat==0) then
   write(message,'(a)')'allocated'
   call wrtout(06,message,'COLL')
   wfnr_not_in_memory=.false.
   do ikibz=1,nkibz
     read(unitwfr,rec=ikibz) ((wfnr(ir,ib,ikibz),ir=1,nr),ib=1,nbnds)
   end do
 else
   write(message,'(a)')'not allocated'
    call wrtout(06,message,'COLL')
   wfnr_not_in_memory=.true.
   write(message,'(a)')'allocate only for each k-point'
   call wrtout(06,message,'COLL')
   allocate(wfnrk(nr,nbnds),stat=istat)
   if(istat/=0) then
    write(message,'(a)') 'out of memory'
    call wrtout(06,message,'COLL')
    call leave_new('COLL')
   end if
   allocate(wfnrkp(nr,nbnds),stat=istat)
   if(istat/=0)then
    write(message,'(a)') 'out of memory'
    call wrtout(06,message,'COLL')
    call leave_new('COLL')
   end if
 end if


!set up fft factor
 nrb=ngfft1*ngfft2*ngfft3

!zero chi0
 chi0(:,:,:)=(0.0,0.0)


!weight (2 is for spin)
 weight=2.0/nkbz

!loop over k-points in BZ
 do ik=1,nkbz

! These lines added by Shaltaf for parallelization 10/08/05

  if(mpi_enreg%nproc>1)then
   if(minval(abs(mpi_enreg%proc_distrb(ik,:,:)-mpi_enreg%me))/=0)cycle
  end if


   ikibz=ktab(ik)

!  identify k' and G0 where k'=k-q-G0
!  form k-q
   kmq(:)=kbz(:,ik)-qq(:)
!  find k''=k-q-G0 and G0 also
   if(.not. findkp(nkbz,kbz,ikp,kmq,g0)) then
     write(message,'(a)') 'warning: cchi0 2: k"=k-q-g0 not found;'
     call wrtout(06,message,'COLL')
     write(message,'(a,i4,a,3f12.6,/,a,6x,3f12.6)')&
&     ' ik = ',ik,' k = ',(kbz(i,ik),i=1,3),' k-q = ',(kmq(i),i=1,3)
      call wrtout(06,message,'COLL')
     cycle
   end if

   ikpibz=ktab(ikp)
   ig01a=g0(1)+3
   ig02a=g0(2)+3
   ig03a=g0(3)+3

   if(wfnr_not_in_memory) then
     read(unitwfr,rec=ikibz) ((wfnrk(ir,ib),ir=1,nr),ib=1,nbnds)
     read(unitwfr,rec=ikpibz) ((wfnrkp(ir,ib),ir=1,nr),ib=1,nbnds)
   end if

!  loop over bands
   do ibc=1,nbnds
     eckp=gwenergy(ikpibz,ibc)
     ockp=occ(ikpibz,ibc)
     if(wfnr_not_in_memory) then
       wfnrckp=>wfnrkp(:,ibc)
     else
       wfnrckp=>wfnr(:,ibc,ikpibz)
     end if

     do ibv=1,nbnds
       factocc=0.5*(ockp-occ(ikibz,ibv))
!      we continue the loop only if abs(factocc)/=0. !!!
       if(abs(factocc)<0.01) cycle

       egwdiff=eckp-gwenergy(ikibz,ibv)
! add the small imaginary of the time-ordered response function
       egwdiff= egwdiff - (0.,1.)*egwdiff/abs(egwdiff)*etadelta
       do io=1,nomega
        den(io)=factocc/(omega(io)+egwdiff)
       end do
       if(wfnr_not_in_memory) then
         wfnrvk=>wfnrk(:,ibv)
       else
         wfnrvk=>wfnr(:,ibv,ikibz)
       end if

!      The calls to timab inside these loops are very time-consuming !
!      one will rely only on the timing inside rho_tw_g, when calling fourdp.
!      call timab(332,1,tsec)

!      form rho-twiddle(r)=u^*_ck''(r)*u_vk(r)
       call rho_tw_g(npwsigx,nr,nrb,ngfft1a,ngfft1,ngfft2,ngfft3,&
&       igfft(:,ig01a,ig02a,ig03a),wfnrckp,ktabi(ikp),ktabr(:,ikp),&
&       wfnrvk,ktabi(ik),ktabr(:,ik),rhotwg,tim_fourdp)

!      call timab(332,2,tsec)
!      call timab(333,1,tsec)

!      chi0(G,G'',io)=chi0(G,G'',io)+(rhotwg(G)*rhotwg(G''))*den(io)
       call assemblychi0(npwsigx,nomega,chi0,rhotwg,den)

!      One could call immediately cgerc : Rank-1 update of chi0
!      do io=1,nomega
!       dd=den(io)
!       call cgerc(npwsigx,npwsigx,dd,rhotwg,1,rhotwg,1,chi0(:,:,io),npwsigx)
!      end do

!      call timab(333,2,tsec)

     end do
   end do
 end do

! These lines added by Shaltaf for parallelization 10/08/05
! Rewritten using upper level primitives by MB 20060830
   call xsum_master(chi0,master,spaceComm,ierr)

 chi0(:,:,:)=weight*chi0(:,:,:)

!fill in the missing half of chi (G,G'') using Hermiticity
!Hermitianness is no longer valid for omega complex (not 0 not pure imag)
 do io=1,nomega
   if(real(omega(io))<0.00001) then
     do igp=1,npwsigx
       do ig=1,igp-1
         chi0(igp,ig,io)=conjg(chi0(ig,igp,io))
       end do
     end do
   end if
 end do

 if(wfnr_not_in_memory) then
   deallocate(wfnrk)
   deallocate(wfnrkp)
 else
   deallocate(wfnr)
 end if

!now we have chi0(q,G,G'',omega)
 deallocate(rhotw,rhotwg,rhotwgs)
 deallocate(den)  !! added by MM

 call timab(331,2,tsec)

end subroutine cchi0
!!***
