!{\src2tex{textfont=tt}}
!!****f* ABINIT/cchi0q0
!! NAME
!! cchi0q0
!!
!! FUNCTION
!! Calculate chi0 in the limit q->0
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (GMR, VO, LR, RWG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  b1(3),b2(3),b3(3)=the three primitive vectors in reciprocal space
!!  energy(nkibzm,nbnds)=KS energies
!!  gradvnl =(grad_K + grad_K') Vnl(K,K') in reciprocal lattice units
!!  grottb(npwvec,2,nop)= (to be described)
!!  gwenergy(nkibzm,nbnds)=GW energies, for self-consistency purposes
!!  igfft(npwvec,5,5,5)=index of G-G0 planewaves (see cigfft routine)
!!  inclvkb=flag to include (or not) the grad of Vkb
!!  irottb(nr,nop)= (to be described)
!!  kbz(3,nkbz)=k-point coordinates, full Brillouin zone
!!  ktab(nkbz)=(to be described)
!!  ktabi(nkbz)=(to be described)
!!  ktabo(nkbz)=(to be described)
!!  nbnds=number of bands
!!  nbv=number of valence bands
!!  ngfft1,ngfft1a,ngfft2,ngfft3=FFT grid dimensions
!!  nkbz=number of k points in full Brillouin zone
!!  nkibz=number of k points in irreducible Brillouin zone
!!  nkibzm=maximum number of k points in irreducible Brillouin zone
!!  nomega=number of frequencies
!!  nop=number of symmetry operations
!!  npwsigx=number of planewaves for sigma exchange (input variable)
!!  npwvec=dimension of igfft
!!  npwwfn=number of planewaves for wavefunctions (input variable)
!!  nr=number of points of FFT grid
!!  occ(nkibzm,nbnds)=occupation numbers, for each k point in IBZ, and each band
!!  omega(nomega)=frequencies
!!  op(3,3,nop)=symmetry operations in reciprocal space
!!  qq(3)=reciprocal space coordinates of the q wavevector
!!  ucvol=unit cell volume
!!  wtk(nkibz)=weights for k points (input variable)
!!
!! OUTPUT
!!  chi0(npwsigx,npwsigx,nomega)=independent-particle susceptibility matrix for wavevector qq,
!!   and frequencies defined by omega
!!
!! NOTES
!! The terms "head", "wings" and "body" of chi(G,G'') refer to
!! G=G''=0, either G or G''=0, and neither=0 respectively
!!
!! PARENTS
!!      screening
!!
!! CHILDREN
!!      assemblychi0,dosym,matrginv,pclock,rho_tw_g,wrtout
!!      xcomm_init,xmaster_init,xme_init,xsum_master
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine cchi0q0(qq,nomega,omega,gvec,npwvec,npwsigx,npwwfn,op,nop,kibz,&
& nkibz,nkibzm,nbnds,nbv,occ,ktab,ktabr,ktabi,ktabo,kbz,nkbz,irottb,&
& ngfft1,ngfft1a,ngfft2,ngfft3,igfft,nr,energy,gwenergy,etadelta,chi0,b1,b2,b3,ucvol,&
& wtk,grottb,inclvkb,gradvnl,mpi_enreg)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_01util
 use interfaces_05gw, except_this_one => cchi0q0
#else
 use defs_xfuncmpi
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: inclvkb,nbnds,nbv,ngfft1,ngfft1a,ngfft2,ngfft3,nkbz
 integer,intent(in) :: nkibz,nkibzm,nomega,nop,npwsigx,npwvec,npwwfn,nr
 real(dp),intent(in) :: etadelta,ucvol
 type(MPI_type),intent(inout) :: mpi_enreg
!arrays
 integer,intent(in) :: grottb(npwvec,2,nop),gvec(3,npwvec),igfft(npwvec,5,5,5)
 integer,intent(in) :: irottb(nr,nop),ktab(nkbz),ktabi(nkbz),ktabo(nkbz)
 integer,intent(in) :: ktabr(nr,nkbz)
 real(dp),intent(in) :: b1(3),b2(3),b3(3),energy(nkibzm,nbnds)
 real(dp),intent(in) :: gwenergy(nkibzm,nbnds),kbz(3,nkbz),kibz(3,nkibz)
 real(dp),intent(in) :: occ(nkibzm,nbnds),op(3,3,nop),qq(3),wtk(nkibz)
 complex,intent(in) :: gradvnl(3,npwwfn,npwwfn,nkibz),omega(nomega)
 complex,intent(out) :: chi0(npwsigx,npwsigx,nomega)

!Local variables ------------------------------
!scalars
 integer,parameter :: unitwfg=25,unitwfr=26
 integer :: ib,ibc,ibv,ig,igp,iinv,ik,ikbz,ikibz,iop,ir,istat,nrb,tim_fourdp
 real(dp) :: factocc,rtemp,weight
 complex :: cauxil,ct,ct2,ctemp,rhotmp
 logical,parameter :: onlyantiresonant=.false.
 logical :: ltemp,noantiresonant=.false.
!arrays
 real(dp) :: opinv(3,3),qcart(3),qrot(3)
 complex :: cv(3),rhotwx(3),rhotwxc(3)
 complex,allocatable :: rhotw(:),rhotwg(:),wfng(:,:),wfnrk(:,:)
!no_abirules
 complex (kind(0.0d0)):: ediff,egwdiff
 complex (kind(0.0d0)),allocatable :: den(:)
 character(len=500)::message
 integer::master,spaceComm,ierr,me

! *************************************************************************
!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifndef HAVE_FORTRAN_INTERFACES
 complex :: dotproductqrc
#endif
!End of the abilint section

 write(message,'(a,a)') 'calculating chi0(q=(0,0,0),omega,G,G")',ch10
 call wrtout(06,message,'COLL')

!! These lines added by Shaltaf for parallelization 10/08/05
!! parallization is on k points only, one must include the bands
!! too in the future

!Init mpi_comm
     call xcomm_init(mpi_enreg,spaceComm)
!Init me
     call xme_init(mpi_enreg,me)
!Init master
     call xmaster_init(mpi_enreg,master)


 tim_fourdp=1
 nrb=ngfft1*ngfft2*ngfft3
 weight=2.0/nkbz

 allocate(wfng(npwwfn,nbnds),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(wfnrk(nr,nbnds),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(den(nomega),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(rhotwg(npwsigx),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(rhotw(nr),stat=istat)
 if(istat/=0) stop 'out of memory'

!zero chi0
 chi0(:,:,:)=zero


!loop over k-points in IBZ
 do ikbz=1,nkbz

! These lines added by Shaltaf for parallelization 10/08/05

 if(mpi_enreg%nproc>1)then
   if(minval(abs(mpi_enreg%proc_distrb(ikbz,:,:)-mpi_enreg%me))/=0)cycle
  end if

   ikibz=ktab(ikbz)
   iop=ktabo(ikbz)
   iinv=(3-ktabi(ikbz))/2

!  read wfn(G) and wfn(r) for the associated ibz k-point
   read(unitwfg,rec=ikibz) ((wfng(ig,ib),ig=1,npwwfn),ib=1,nbnds)
   read(unitwfr,rec=ikibz) ((wfnrk(ir,ib),ir=1,nr),ib=1,nbnds)
!  the wavefunctions for the k-point in the bz are:
!  wfn(G,b,kbz)=wfn(R^-1G,b,kibz) (=wfn*(R^-1G,b,kibz) for inversion)
!  wfn(r,b,kbz)=wfn(R^-1r,b,kibz) (=wfn*(R^-1r,b,kibz) for inversion)
!  the gradient of the Vnl(K,K'') for the k-point in the bz should be:
!  gradvnl(G,G'',kbz)=R gradvnl(R^-1G,R^-1G'',kibz)

!  now loop over bands
   do ibv=1,nbnds
     do ibc=1,nbnds
       factocc=0.5*(occ(ikibz,ibc)-occ(ikibz,ibv))
!      we continue the loop only if factocc !=0
       if(abs(factocc)<0.01) cycle
       if(noantiresonant .and. factocc<tol8) cycle
       if(onlyantiresonant .and. factocc>tol8) cycle

       ediff=energy(ikibz,ibc)-energy(ikibz,ibv)
       egwdiff=gwenergy(ikibz,ibc)-gwenergy(ikibz,ibv)
! add the small imaginary of the time-ordered response function
       egwdiff= egwdiff - (0.,1.)*egwdiff/abs(egwdiff)*etadelta

       den(:)=factocc/(omega(:)+egwdiff)

!      calculate rho-twiddle(G)
       call rho_tw_g(npwsigx,nr,nrb,ngfft1a,ngfft1,ngfft2,ngfft3,&
&        igfft(:,3,3,3),wfnrk(:,ibc),iinv,ktabr(:,ikbz),&
&        wfnrk(:,ibv),iinv,ktabr(:,ikbz),rhotwg,tim_fourdp)

!      set up rho-twiddle(G=0) using small vector q instead of zero
!      and k.p perturbation theory
       rhotwx(:)=0.0
!      first term<c,k|-iq*grad|v,k>
       do ig=1,npwwfn
         ct=conjg(wfng(ig,ibc))*wfng(ig,ibv)
         rhotwx(:)=rhotwx(:)+gvec(:,ig)*ct
       end do
!      second term<c,k|[Vnl,iqr]|v,k>
       if(inclvkb==1) then
         do ig=1,npwwfn
           do igp=1,npwwfn
             ct=conjg(wfng(ig,ibc))*wfng(igp,ibv)
!            must multiply by ucvol because yet gradvnl contain 1/ucvol
             rhotwx(:)=rhotwx(:)+ct*gradvnl(:,ig,igp,ikibz)
            end do
         end do
       end if
       rhotwx(:)=-rhotwx(:)/ediff

!      rhotwg(1)=R^-1q*rhotwx_ibz
!      rhotwg(1)=-R^-1q*conjg(rhotwx_ibz) for inversion
       opinv(:,:)=op(:,:,iop)
       call matrginv(opinv,3,3)
       call dosym(opinv,iinv,qq,qrot)
       rhotwg(1)=dotproductqrc(qrot,rhotwx,b1,b2,b3)
       if(iinv==2) rhotwg(1)=conjg(rhotwg(1))

       call assemblychi0(npwsigx,nomega,chi0,rhotwg,den)

     end do ! ibc
   end do ! ibv
 end do ! ikbz
call pclock(180)

! These lines added by Shaltaf for parallelization 10/08/05
! Rewritten using upper level primitives by MB 20060830
 call xsum_master(chi0,master,spaceComm,ierr)

 call pclock(180)

 weight=2.0/nkbz
 chi0(:,:,:)=weight*chi0(:,:,:)

 deallocate(wfng)
 deallocate(wfnrk)
 deallocate(den,rhotwg,rhotw)
!now we have chi0

end subroutine cchi0q0
!!***
