!{\src2tex{textfont=tt}}
!!****f* ABINIT/fermi
!! NAME
!! fermi
!!
!! FUNCTION
!! Calculate the Fermi level and occupation numbers
!! (This routine should be cleaned !!)
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (GMR, VO, LR, RWG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  en(nk,nb)=KS energies, for different k points and bands
!!  hdr=header of previously read file, containing many variables
!!  nb=number of bands
!!  nk=number of k points
!!  ns=number of spins (should be changed to nsppol)
!!  wtk(nk)=weights for k points (input variable)
!!
!! OUTPUT
!!  nbv=number of valence bands (non-spin-polarized)
!!  fermie=Fermi energy
!!
!! SIDE EFFECTS
!!  nel= at input, if nel==0, recalculate nelect from occupation numbers
!!  occ(nk,nb)=occupation numbers, for each k point, and each band
!!
!! TODO
!!  check the value of nel from calling routine
!!
!! PARENTS
!!      screening,sigma
!!
!! CHILDREN
!!      newocc
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine fermi(hdr,nb,nk,ns,wtk,en,occ,nel,nbv,fermie)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_04occeig
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: nb,nk,ns
 integer,intent(inout) :: nel
 integer,intent(out) :: nbv
 real(dp),intent(out) :: fermie
 type(hdr_type),intent(in) :: hdr
!arrays
 real(dp),intent(in) :: en(nk,nb),wtk(nk)
 real(dp),intent(inout) :: occ(nk,nb)

!Local variables-------------------------------
!scalars
 integer :: ib,ik,index,is
 real(dp) :: condbottom,entropy,nelect,valencetop
!arrays
 integer :: nbandt(nk*ns)
 real(dp) :: doccdet(nb*nk*ns),eigent(nb*nk*ns),occt(nb*nk*ns),wtk_norm(nk)

! *************************************************************************

 do ik=1,nk
  wtk_norm(ik)=wtk(ik)/sum(wtk(:))
 end do
 if(nel==0) then
  do ik=1,nk
   do ib=1,nb
    nelect=nelect+wtk_norm(ik)*occ(ik,ib)
   end do
  end do
  nel=int(nelect)
 else
  nelect=nel
 end if
 write(*,*) 'total number of electrons = ',nel
 nbv=nel/2

 if(hdr%occopt<3.or.hdr%occopt>7) then
  valencetop=en(1,1)
  condbottom=en(1,nb)
  do ik=1,nk
    do ib=1,nbv
      if(valencetop<en(ik,ib)) valencetop=en(ik,ib)
    end do
    do ib=nbv+1,nb
      if(condbottom>en(ik,ib)) condbottom=en(ik,ib)
    end do
  end do
  write(*,'(" top of valence       [eV] ",f6.2)') valencetop*Ha_eV
  write(*,'(" bottom of conduction [eV] ",f6.2)') condbottom*Ha_eV
! fermie=valencetop ! the analytic result depends on position of the energy 0
  fermie=(valencetop+condbottom)/2 ! this is better
  if(abs(condbottom-valencetop)<1.d-4) fermie=valencetop ! to avoid error on the last digit
 else
  index=0
  do is=1,ns
   do ik=1,nk
    do ib=1,nb
     index=index+1
     eigent(index)=en(ik,ib)
    end do
   end do
  end do
  nbandt(:)=nb
  call newocc(doccdet,eigent,entropy,fermie,-99.99d0,nb,nbandt,&
&  nelect,nk,ns,ns,occt,hdr%occopt,1,&
&  hdr%stmbias,hdr%tphysel,hdr%tsmear,wtk_norm)
  index=0
  do is=1,ns
   do ik=1,nk
    do ib=1,nb
     index=index+1
     if(abs(occt(index)-occ(ik,ib))>1.d-2) then
      write(*,*) 'Occupation number of band',ib,'for kpt',ik
      write(*,*) 'changed with respect to kss file'
     end if
     occ(ik,ib)=occt(index)
    end do
   end do
  end do
 end if

 write(*,'(" Fermi energy         [eV] ",f6.2)') fermie*Ha_eV
 print *

end subroutine fermi
!!***
