!{\src2tex{textfont=tt}}
!!****f* ABINIT/fftwfn
!! NAME
!! fftwfn
!!
!! FUNCTION
!! Calculate LDA wavefunctions in real space using FFT
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (GMR, VO, LR, RWG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  igfft(npwwfn)=index of each plane wave in FFT grid
!!  nb=number of bands
!!  ngfft1,ngfft1a,ngfft2,ngfft3=FFT grid dimensions
!!  nk=number of k points
!!  npwwfn=number of plane waves
!!  nr=number of FFT grid points
!!  tim_fourdp=4 if called from within screening ; =5 if called from within sigma
!!  wfg(npwwfn,nb,nk)=wavefunctions in reciprocal space, for each band and k point
!!
!! OUTPUT
!!  wfr(nr,nb,nk)=wavefunctions in real space, for each band and k point
!!
!! PARENTS
!!      screening,sigma
!!
!! CHILDREN
!!      fourdp
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine fftwfn(npwwfn,nb,nk,nr,wfg,wfr,igfft,ngfft1,ngfft1a,ngfft2,ngfft3,tim_fourdp)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_02ffts
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: nb,ngfft1,ngfft1a,ngfft2,ngfft3,nk,npwwfn,nr,tim_fourdp
!arrays
 integer,intent(in) :: igfft(npwwfn)
 complex,intent(in) :: wfg(npwwfn,nb,nk)
 complex,intent(out) :: wfr(nr,nb,nk)

!Local variables-------------------------------
!scalars
 integer :: ib,ig,ik,ir,istat
 type(MPI_type) :: mpi_enreg
!arrays
 integer :: ngfft(18)
 real(dp),allocatable :: wfg_dp(:,:),wfr_dp(:,:)

! *************************************************************************

 allocate(wfg_dp(2,nr),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(wfr_dp(2,nr),stat=istat)
 if(istat/=0) stop 'out of memory'

 write(*,*) 'FFT wavefunctions to real space'
!wfr(:,:,:)=zero
 do ik=1,nk
   do ib=1,nb
!    fill FFT array from PW array
     wfg_dp(:,:)=zero
     do ig=1,npwwfn
       wfg_dp(1,igfft(ig))=real(wfg(ig,ib,ik))
       wfg_dp(2,igfft(ig))=aimag(wfg(ig,ib,ik))
     end do
     ngfft(1)=ngfft1
     ngfft(2)=ngfft2
     ngfft(3)=ngfft3
!    ngfft(4)=ngfft1a
!    ngfft(5)=ngfft2
!    ngfft(6)=ngfft3
     ngfft(4)=2*(ngfft(1)/2)+1
     ngfft(5)=2*(ngfft(2)/2)+1
     ngfft(6)=ngfft(3)
     ngfft(7)=200
     ngfft(8)=256
     ngfft(9)=0
     ngfft(10)=1
     ngfft(11)=0
     ngfft(12)=ngfft2
     ngfft(13)=ngfft3
     ngfft(14)=0

!    take FFT to give wfn in real space
!    wfr_dp(:,:)=zero
     mpi_enreg%me_fft=0
     mpi_enreg%nproc_fft=1
     call fourdp(2,wfg_dp(:,:),wfr_dp(:,:),+1,mpi_enreg,nr,ngfft,tim_fourdp)
     wfr(:,ib,ik)=cmplx(wfr_dp(1,:),wfr_dp(2,:))
   end do
 end do
 write(*,*) 'done'
 write(*,*)

 deallocate(wfg_dp,wfr_dp)

end subroutine fftwfn
!!***
