!{\src2tex{textfont=tt}}
!!****f* ABINIT/findk
!! NAME
!! findk
!!
!! FUNCTION
!! Check whether the k-point is in the set of the kbz
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (GMR, VO, LR, RWG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  kbz(3,nkbz)=coordinates of k points in BZ
!!  nkcalc= number of k points for GW calculation (input variable)
!!  nkbz=number of k points in Brillouin zone
!!  xkcalc(3,nkcalc)= coordinates of the k points
!!
!! OUTPUT
!!  kcalc=index of the k points inside kbz
!!
!! PARENTS
!!      sigma
!!
!! CHILDREN
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine findk(nkcalc,nkbz,xkcalc,kbz,kcalc)

 use defs_basis

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: nkbz,nkcalc
!arrays
 integer,intent(out) :: kcalc(nkcalc)
 real(dp),intent(in) :: kbz(3,nkbz),xkcalc(3,nkcalc)

!Local variables-------------------------------
!scalars
 integer :: ik,jj

! *************************************************************************

 write(*,*) 'check if the k-points for sigma are in the set of BZ'
 do jj=1,nkcalc
   kcalc(jj)=0
   do ik=1,nkbz
     if(all(abs(xkcalc(:,jj)-kbz(:,ik))<1.e-3)) kcalc(jj)=ik
   end do
   if(kcalc(jj)==0) then
     write(*,*) '**error findk 1: k-point not in the set of kbz;'
     stop
   end if
 end do

 write(*,*) 'check ok!'
 write(*,*)

end subroutine findk
!!***
