!{\src2tex{textfont=tt}}
!!****f* ABINIT/findshells
!! NAME
!! findshells
!!
!! FUNCTION
!! Find the g-vector numbers that close a shell
!! Check if ngs closes a shell
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (GMR, VO, LR, RWG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  b1(3),b2(3),b3(3)=the three primitive vectors in reciprocal space
!!  gvec(3,ng)=coordinated of G vectors
!!  ng=number of G vectors
!!  ngs=tentative number of G vectors at which a shell is closed
!!
!!
!! OUTPUT
!!  (only checking)
!!
!! PARENTS
!!      screening
!!
!! CHILDREN
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine findshells(b1,b2,b3,ng,ngs,gvec)

 use defs_basis

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_05gw, except_this_one => findshells
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer :: ng,ngs
!arrays
 integer :: gvec(3,ng)
 real(dp) :: b1(3),b2(3),b3(3)

!Local variables ------------------------------
!scalars
 integer :: ig,s
 real(dp) :: l,lold
 logical :: shellclosed=.false.
!arrays
 real(dp) :: g(3)

! *************************************************************************
!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifndef HAVE_FORTRAN_INTERFACES
 real(dp) :: vlngth
#endif
!End of the abilint section

 write(*,*) 'shell  g-vector     radius [au]'
 s=0
 g(:)=gvec(:,1)
 lold=vlngth(g,b1,b2,b3)
 do ig=2,ng
   g(:)=gvec(:,ig)
   l=vlngth(g,b1,b2,b3)
   if((l-lold)>0.000001) then
     write(6,'(i6,i10,f11.6)') s,ig-1,lold
     lold=l
     s=s+1
     if(ngs==ig-1) shellclosed=.true.
   end if
 end do
 if(shellclosed) then
   write(*,*) 'shell closed at ',ngs
 else if(ngs==ng) then
   write(*,*) 'shell probably closed at ',ngs
 else
   write(*,*) 'error,findshell 1: shell not closed'
   write(*,*) 'npwsigx = ',ngs
   stop 'shell not closed'
 end if
 write(*,*)

end subroutine findshells
!!***
