!{\src2tex{textfont=tt}}
!!****f* ABINIT/iosig
!! NAME
!! iosig
!!
!! FUNCTION
!! input/output sigma results
!! This file contains 3 routines : write_sigma_results_header,
!!  write_sigma_results, rdgw,calc_wf_qp
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (GMR, VO, LR, RWG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ep=epsilonm1_parameters
!!  sp=sigma_parameters
!!
!! OUTPUT
!!  (for writing routines, no output)
!!  otherwise, should be described
!!
!! NOTES
!!
!!
!! PARENTS
!!      sigma
!!
!! CHILDREN
!!      cgemm
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine write_sigma_results_header(sp,ep)

 use defs_basis
 use defs_datatypes

 implicit none

!Arguments ------------------------------------
!scalars
 type(epsilonm1_parameters),intent(in) :: ep
 type(sigma_parameters),intent(in) :: sp

!Local variables-------------------------------

! *************************************************************************

 write(6,*) 'SIGMA fundamental parameters:'
 write(6,*) 'calculation type                        ',sp%gwcalctyp
 write(6,*) 'number of plane-waves for SigmaX        ',sp%npwx
 write(6,*) 'number of plane-waves for SigmaC and W  ',sp%npwc
 write(6,*) 'number of plane-waves for wavefunctions ',sp%npwwfn
 write(6,*) 'number of bands                         ',sp%nb
 write(6,*) 'number of k-points in IBZ               ',sp%nk
 write(6,*) 'number of q-points in IBZ               ',sp%nq
 write(6,*) 'number of symmetry operations           ',sp%nop
 write(6,*) 'number of k-points in BZ                ',sp%nkbz
 write(6,*) 'number of q-points in BZ                ',sp%nqbz
 write(6,*) 'number of omega for sigma on real axis  ',sp%nomegasrd
 write(6,'(a,f12.2)') ' deltae [eV]                             ',sp%deltae*Ha_eV
 write(6,*) 'number of omega for sigma on real axis  ',sp%nomegasr
 write(6,'(a,f12.2)') ' max omega for sigma on real axis  [eV]  ',sp%omegasrmax*Ha_eV
 write(6,*)
 write(6,*) 'EPSILON^-1 parameters (SCR file):'
! write(6,*) titem1(2)(1:79)
 write(6,*) 'dimension of the eps^-1 matrix          ',ep%npwe
 write(6,*) 'number of plane-waves for wavefunctions ',ep%npwwfn
 write(6,*) 'number of bands                         ',ep%nb
 write(6,*) 'number of q-points in IBZ               ',ep%nq
 write(6,*) 'number of frequencies                   ',ep%nomega
 write(6,*)
 write(6,*) 'matrix elements of self-energy operator (all in [eV])'
 write(6,*)

 write(ab_out,*) 'SIGMA fundamental parameters:'
 if(sp%gwcalctyp==0) then
   write(ab_out,*) 'PLASMON POLE MODEL'
 else if(sp%gwcalctyp==1) then
   write(ab_out,*) 'ANALYTIC CONTINUATION'
 else if(sp%gwcalctyp==2) then
   write(ab_out,*) 'CONTOUR DEFORMATION'
 else if(mod(sp%gwcalctyp,10)==5) then
   write(ab_out,*) 'Hartree-Fock'
 else if(mod(sp%gwcalctyp,10)==6) then
   write(ab_out,*) 'Screened Exchange'
 else if(mod(sp%gwcalctyp,10)==7) then
   write(ab_out,*) 'COHSEX'
 else if(mod(sp%gwcalctyp,10)==8) then
   write(ab_out,*) 'MODEL GW with PLASMON POLE MODEL'
 else if(mod(sp%gwcalctyp,10)==9) then
   write(ab_out,*) 'MODEL GW without PLASMON POLE MODEL'
 end if
 if(sp%gwcalctyp<10) then
  write(*,*) 'Perturbative Calculation'
 else if(sp%gwcalctyp<20) then
  write(*,*) 'Self-Consistent on Energies only'
 else
  write(*,*) 'Self-Consistent on Energies and Wavefunctions'
 end if

 write(ab_out,*) 'number of plane-waves for SigmaX        ',sp%npwx
 write(ab_out,*) 'number of plane-waves for SigmaC and W  ',sp%npwc
 write(ab_out,*) 'number of plane-waves for wavefunctions ',sp%npwwfn
 write(ab_out,*) 'number of bands                         ',sp%nb
 write(ab_out,*) 'number of k-points in IBZ               ',sp%nk
 write(ab_out,*) 'number of q-points in IBZ               ',sp%nq
 write(ab_out,*) 'number of symmetry operations           ',sp%nop
 write(ab_out,*) 'number of k-points in BZ                ',sp%nkbz
 write(ab_out,*) 'number of q-points in BZ                ',sp%nqbz
 write(ab_out,*) 'number of omega for sigma on real axis  ',sp%nomegasrd
 write(ab_out,'(a,f12.2)') ' deltae [eV]                             ',sp%deltae*Ha_eV
 write(ab_out,*) 'number of omega for sigma on real axis  ',sp%nomegasr
 write(ab_out,'(a,f12.2)') ' max omega for sigma on real axis  [eV]  ',sp%omegasrmax*Ha_eV
 write(ab_out,*)
 write(ab_out,*) 'EPSILON^-1 parameters (SCR file):'
! write(ab_out,*) titem1(2)(1:79)
 write(ab_out,*) 'dimension of the eps^-1 matrix          ',ep%npwe
 write(ab_out,*) 'number of plane-waves for wavefunctions ',ep%npwwfn
 write(ab_out,*) 'number of bands                         ',ep%nb
 write(ab_out,*) 'number of q-points in IBZ               ',ep%nq
 write(ab_out,*) 'number of frequencies                   ',ep%nomega
 write(ab_out,*) 'number of real frequencies              ',ep%nomegaer
 write(ab_out,*) 'number of imag frequencies              ',ep%nomegaei
 write(ab_out,*)
 write(ab_out,*) 'matrix elements of self-energy operator (all in [eV])'
 write(ab_out,*)

 ! open output file for <Sigma>
 open(21,file='out.gw',status='unknown',form='formatted')
 open(22,file='out.sig',status='unknown',form='formatted')
 open(23,file='out.sgr',status='unknown',form='formatted')

 write(21,*) sp%nkcalc

 return
end subroutine write_sigma_results_header
!!***


!!****m* ABINIT/write_sigma_results
!! NAME
!! write_sigma_results
!!
!! FUNCTION
!!
!! PARENTS
!!      sigma
!!
!! CHILDREN
!!      cgemm
!!
!! INPUTS
!!
!! OUTPUT
!!
!! SOURCE
!!

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine write_sigma_results(sp,sr,ikcalc,ikibz,en_lda)

 use defs_basis
 use defs_datatypes

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ikcalc,ikibz
 type(sigma_parameters),intent(in) :: sp
 type(sigma_results),intent(in) :: sr
!arrays
 real(dp),intent(in) :: en_lda(sp%nk,sp%nb)

!Local variables-------------------------------
!scalars
 integer :: i,ib,io

! *************************************************************************

   write(6,'(/,a,3f8.3)') ' k = ',sp%xkcalc(:,ikcalc)
   write(ab_out,'(/,a,3f8.3)') ' k = ',sp%xkcalc(:,ikcalc)

   if(sp%gwcalctyp>=10) then
!for self-consistent calculations, output much more
    write(6,'(a)')&
&  ' Band     E_lda   <Vxclda>   E(N-1)  <Hhartree>   SigX  SigC[E(N-1)]    Z     dSigC/dE  Sig[E(N)]  DeltaE  E(N)_pert E(N)_diago'
    write(ab_out,'(a)')&
&  ' Band     E_lda   <Vxclda>   E(N-1)  <Hhartree>   SigX  SigC[E(N-1)]    Z     dSigC/dE  Sig[E(N)]  DeltaE  E(N)_pert E(N)_diago'
   else
    write(6,'(a)')&
&  ' Band     E0 <VxcLDA>   SigX SigC(E0)      Z dSigC/dE  Sig(E)    E-E0       E'
    write(ab_out,'(a)')&
&  ' Band     E0 <VxcLDA>   SigX SigC(E0)      Z dSigC/dE  Sig(E)    E-E0       E'
   end if

   write(21,'(3f10.6)') sp%xkcalc(:,ikcalc)
   write(21,'(i4)') sp%maxbnd(ikcalc)-sp%minbnd(ikcalc)+1

   write(22,'("# k = ",3f10.6)') sp%xkcalc(:,ikcalc)
   write(22,'("# b = ",2i10)') sp%minbnd(ikcalc), sp%maxbnd(ikcalc)

   write(23,'("# k = ",3f10.6)') sp%xkcalc(:,ikcalc)
   write(23,'("# b = ",2i10)') sp%minbnd(ikcalc), sp%maxbnd(ikcalc)


   do ib=sp%minbnd(ikcalc),sp%maxbnd(ikcalc)

    if(sp%gwcalctyp>=10) then
!for self-consistent calculations, output much more
     write (6,'(i5,12(2x,f8.3))') ib,&
&     en_lda(ikibz,ib)*Ha_eV,&
&     sr%vxcme(ib,ikibz)*Ha_eV,&
&     sr%e0(ib,ikibz)*Ha_eV,&
&     real(sr%hhartree(ib,ib,ikibz))*Ha_eV,&
&     sr%sigxme(ib,ikibz)*Ha_eV,&
&     real(sr%sigcmee0(ib,ikibz))*Ha_eV,&
&     real(sr%ze0(ib,ikibz)),&
&     real(sr%dsigmee0(ib,ikibz)),&
&     real(sr%sigmee(ib,ikibz))*Ha_eV,&
&     real(sr%degw(ib,ikibz))*Ha_eV,&
&     real(sr%egw(ib,ikibz))*Ha_eV,&
&     sr%en_qp_diago(ib,ikibz)*Ha_eV
     write (ab_out,'(i5,12(2x,f8.3))') ib,&
&     en_lda(ikibz,ib)*Ha_eV,&
&     sr%vxcme(ib,ikibz)*Ha_eV,&
&     sr%e0(ib,ikibz)*Ha_eV,&
&     real(sr%hhartree(ib,ib,ikibz))*Ha_eV,&
&     sr%sigxme(ib,ikibz)*Ha_eV,&
&     real(sr%sigcmee0(ib,ikibz))*Ha_eV,&
&     real(sr%ze0(ib,ikibz)),&
&     real(sr%dsigmee0(ib,ikibz)),&
&     real(sr%sigmee(ib,ikibz))*Ha_eV,&
&     real(sr%degw(ib,ikibz))*Ha_eV,&
&     real(sr%egw(ib,ikibz))*Ha_eV,&
&     sr%en_qp_diago(ib,ikibz)*Ha_eV
    else
!for perturbative calculations, output a few quantities
     write (6,'(i5,9f8.3)') ib,&
&     sr%e0(ib,ikibz)*Ha_eV,&
&     sr%vxcme(ib,ikibz)*Ha_eV,&
&     sr%sigxme(ib,ikibz)*Ha_eV,&
&     real(sr%sigcmee0(ib,ikibz))*Ha_eV,&
&     real(sr%ze0(ib,ikibz)),&
&     real(sr%dsigmee0(ib,ikibz)),&
&     real(sr%sigmee(ib,ikibz))*Ha_eV,&
&     real(sr%degw(ib,ikibz))*Ha_eV,&
&     real(sr%egw(ib,ikibz))*Ha_eV
     write (ab_out,'(i5,9f8.3)') ib,&
&     sr%e0(ib,ikibz)*Ha_eV,&
&     sr%vxcme(ib,ikibz)*Ha_eV,&
&     sr%sigxme(ib,ikibz)*Ha_eV,&
&     real(sr%sigcmee0(ib,ikibz))*Ha_eV,&
&     real(sr%ze0(ib,ikibz)),&
&     real(sr%dsigmee0(ib,ikibz)),&
&     real(sr%sigmee(ib,ikibz))*Ha_eV,&
&     real(sr%degw(ib,ikibz))*Ha_eV,&
&     real(sr%egw(ib,ikibz))*Ha_eV
    end if



    write(21,'(i6,3f9.4)') &
&    ib,real(sr%egw(ib,ikibz))*Ha_eV,real(sr%degw(ib,ikibz))*Ha_eV,&
&    aimag(sr%egw(ib,ikibz))*Ha_eV
   end do
   write(6,'(/,a,f8.3)') ' E^0_gap       ',sr%e0gap(ikibz)*Ha_eV
   write(6,'(a,f8.3)') ' E^GW_gap      ',sr%egwgap(ikibz)*Ha_eV
   write(6,'(a,f8.3,/)') ' DeltaE^GW_gap ',sr%degwgap(ikibz)*Ha_eV
   write(ab_out,'(/,a,f8.3)') ' E^0_gap       ',sr%e0gap(ikibz)*Ha_eV
   write(ab_out,'(a,f8.3)') ' E^GW_gap      ',sr%egwgap(ikibz)*Ha_eV
   write(ab_out,'(a,f8.3,/)') ' DeltaE^GW_gap ',sr%degwgap(ikibz)*Ha_eV

   do io=1,sr%nomega
    write(22,'(100(e11.5,2x))')  real(sr%omega(io))*Ha_eV, &
&                (real(sr%sigxcme(ib,ikibz,io))*Ha_eV , &
&                 aimag(sr%sigxcme(ib,ikibz,io))*Ha_eV , &
&                 1./pi*abs(aimag(sr%sigcme(ib,ikibz,io)))&
&                 /( (real(sr%omega(io)-sr%hhartree(ib,ib,ikibz)-sr%sigxcme(ib,ikibz,io)))**2&
&                   +(aimag(sr%sigcme(ib,ikibz,io)))**2) /Ha_eV,&
&                ib=sp%minbnd(ikcalc),sp%maxbnd(ikcalc))
   end do
   do ib=sp%minbnd(ikcalc),sp%maxbnd(ikcalc)
    write(23,'("# ik, ib",2i5)') ikibz,ib
    do io=1,sr%nomegasrd
     write(23,'(100(e11.5,2x))')  real(sr%omegasrd(ib,ikibz,io))*Ha_eV, &
&                real(sr%sigxcmesrd(ib,ikibz,io))*Ha_eV , &
&                aimag(sr%sigxcmesrd(ib,ikibz,io))*Ha_eV
    end do
   end do

end subroutine write_sigma_results
!!***


!!****m* ABINIT/rdgw
!! NAME
!! rdgw
!!
!! FUNCTION
!!
!! PARENTS
!!      screening,sigma
!!
!! CHILDREN
!!      cgemm
!!
!! INPUTS
!!
!! OUTPUT
!!
!! SOURCE
!!

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine rdgw(nk,nb,nbv,kibz,gwenergy)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_05gw, except_this_one => rdgw
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: nb,nbv,nk
!arrays
 real(dp),intent(in) :: kibz(3,nk)
 real(dp),intent(out) :: gwenergy(nk,nb)

!Local variables ------------------------------
!scalars
 integer :: ib,ibr,ik,ikibz,ikr,n,nbr,nkr
 real(dp) :: a,b,degw,egw,smrt
!arrays
 real(dp) :: gwcorr(nk,nb),k(3)

! *************************************************************************
!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifndef HAVE_FORTRAN_INTERFACES
 real(dp) :: linfit
#endif
!End of the abilint section

 gwcorr(:,:)=0
 open(21,file='in.gw')
 read(21,*) nkr
 do ikr=1, nkr
  read(21,*) k
  read(21,*) nbr
  ikibz=0
  do ik=1, nk
   if(all(abs(k(:)-kibz(:,ik))<0.0001)) ikibz=ik
  end do
  do ib=1, nbr
   read(21,*) ibr, egw, degw
   if(ibr<=nb .and. ikibz/=0) gwcorr(ikibz,ibr)=degw/Ha_eV
  end do
 end do
 close(21)
 do ik=1,nk
  n=nb-nbv
  do ib=nbv+1,nb
   if(gwcorr(ik,ib)==0) then
    n=ib-1-nbv
    if(n>1) then
     print *, 'linear extrapolating (conduction) GW corrections beyond the read values'
     smrt=linfit(n,gwenergy(ik,nbv+1:nbv+n),gwcorr(ik,nbv+1:nbv+n),a,b)
    else
     print *, 'assuming constant (conduction) GW corrections beyond the read values'
     a=0
     b=gwcorr(ik,nbv+n)
    end if
    exit
   end if
  end do
  do ib=nbv+n+1,nb
   gwcorr(ik,ib)=a * gwenergy(ik,ib) + b
  end do
  n=nbv
  do ib=nbv,1,-1
   if(gwcorr(ik,ib)==0) then
    n=nbv-ib
    if(n>1) then
     print *, 'linear extrapolating (valence) GW corrections beyond the read values'
     smrt=linfit(n,gwenergy(ik,nbv-n+1:nbv),gwcorr(ik,nbv-n+1:nbv),a,b)
    else
     print *, 'assuming constant (valence) GW corrections beyond the read values'
     a=0
     b=gwcorr(ik,nbv)
    end if
    exit
   end if
  end do
  do ib=1,nbv-n
   gwcorr(ik,ib)=a * gwenergy(ik,ib) + b
  end do
 end do
 print *, ' k       GW corrections [eV]'
 do ik=1, nk
  write(*,'(i3,7x,10f7.2,/,50(10x,10f7.2,/))') ik, (Ha_eV*gwcorr(ik,ib),ib=1,nb)
 end do
 gwenergy(:,:)=gwenergy(:,:)+gwcorr(:,:)
 print *, ' k       GW eigenvalues [eV]'
 write(ab_out,*) ' k       GW eigenvalues [eV]'
 do ik=1, nk
  write(*,'(i3,7x,10f7.2,/,50(10x,10f7.2,/))') ik, (Ha_eV*gwenergy(ik,ib),ib=1,nb)
  write(ab_out,'(i3,7x,10f7.2,/,50(10x,10f7.2,/))') ik, (Ha_eV*gwenergy(ik,ib),ib=1,nb)
 end do
 print *
 write(ab_out,*)
 return
end subroutine rdgw
!!***


!!****m* ABINIT/calc_wf_qp
!! NAME
!! calc_wf_qp
!!
!! FUNCTION
!!
!! PARENTS
!!      screening,sigma
!!
!! CHILDREN
!!      cgemm
!!
!! INPUTS
!!
!! OUTPUT
!!
!! SOURCE
!!

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine calc_wf_qp(nk,nb,npwwfn,nr,m_lda_to_qp,wfg,wfr,wfg_qp,wfr_qp)

 use defs_basis
#ifdef VMS
!DEC$ ATTRIBUTES ALIAS:'CGEMM' :: cgemm
#endif
!in/out

 implicit none

 integer,intent(in) :: nk,nb,npwwfn,nr
 complex,intent(in) :: m_lda_to_qp(nb,nb,nk),wfg(npwwfn,nb,nk),wfr(nr,nb,nk)
 complex,intent(out) :: wfg_qp(npwwfn,nb,nk),wfr_qp(nr,nb,nk)
!local
 integer :: ik
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
#ifdef __VMS
!DEC$ ATTRIBUTES ALIAS:'CGEMM' :: cgemm
#endif
 do ik=1,nk
!  wfg_qp(:,:,ik)=matmul(wfg(:,:,ik),m_lda_to_qp(:,:,ik))
  call cgemm('n','n',npwwfn,nb,nb,(1.,0.),wfg(:,:,ik),npwwfn,m_lda_to_qp(:,:,ik),nb,(0.,0.),wfg_qp(:,:,ik),npwwfn)
!  wfr_qp(:,:,ik)=matmul(wfr(:,:,ik),m_lda_to_qp(:,:,ik))
  call cgemm('n','n',nr,nb,nb,(1.,0.),wfr(:,:,ik),nr,m_lda_to_qp(:,:,ik),nb,(0.,0.),wfr_qp(:,:,ik),nr)
 end do
end subroutine calc_wf_qp
!!***
