!{\src2tex{textfont=tt}}
!!****f* ABINIT/rdqps
!! NAME
!! rdqps
!!
!! FUNCTION
!!  N/D [FIXME]
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (FBruneval)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!
!! INPUTS
!!  argin(sizein)=description
!!
!! OUTPUT
!!  argout(sizeout)=description
!!
!! SIDE EFFECTS
!!
!! NOTES
!!
!! PARENTS
!!      screening,sigma
!!
!! CHILDREN
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine rdqps(dtfil,gwcalctyp,nk,nb,kibz,nscf,en,en_qp,m_lda_to_qp)

 use defs_basis
 use defs_datatypes

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: gwcalctyp,nb,nk
 integer,intent(out) :: nscf
 type(datafiles_type),intent(in) :: dtfil
!arrays
 real(dp),intent(in) :: en(nk,nb),kibz(3,nk)
 real(dp),intent(out) :: en_qp(nk,nb)
 complex,intent(out) :: m_lda_to_qp(nb,nb,nk)

!Local variables-------------------------------
! character(len=4),external :: numtochar
!scalars
 integer,parameter :: unitfile=999
 integer :: ib,ik,nbmin,nbr,nkr
 logical :: lfile
!arrays
 real(dp) :: k(3)
 real(dp),allocatable :: en_tmp(:)
 complex,allocatable :: mtmp(:,:)

! *************************************************************************

!initialize with LDA eigenelements
 m_lda_to_qp(:,:,:)=0.
 do ib=1,nb
  m_lda_to_qp(ib,ib,:)=1.
 end do
 en_qp(:,:)=en(:,:)

!if non self-consistent calculation, exit immediately
 if(gwcalctyp<10) return

!self-consistency: check files
 write(*,*) 'looking for '//trim(dtfil%filqps)
 inquire(file=trim(dtfil%filqps),exist=lfile)
 if(.not.(lfile)) then
  write(*,*) 'file not found'
  write(*,*) '1st iteration'
  write(*,*) 'initialized with LDA eigenelements'
  nscf=0
  return
 else
  open(unit=unitfile,file=trim(dtfil%filqps),form='formatted',status='unknown')

  read(unitfile,*) nscf
  write(*,*) nscf,'iteration(s) already performed'
  read(unitfile,*) nkr
  if(nkr/=nk) stop 'rdqps: wrong number of kpoints'
  read(unitfile,*) nbr
  nbmin=min(nbr,nb)
  allocate(mtmp(nbr,nbr))
  allocate(en_tmp(nbr))

  do ik=1,nk
   write(*,*) 'reading k',ik
   read(unitfile,*) k(:)
   write(*,*) k(:)
   if(any(abs(k(:)-kibz(:,ik))>0.001)) stop 'rdqps: wrong kpoint'
   do ib=1,nbr
    read(unitfile,*) en_tmp(ib)
    read(unitfile,*) mtmp(:,ib)
   end do !ib

   m_lda_to_qp(1:nbmin,1:nbmin,ik)=mtmp(1:nbmin,1:nbmin)
   en_qp(ik,1:nbmin)=en_tmp(1:nbmin)
  end do !ik

  deallocate(mtmp,en_tmp)
  close(unitfile)
 end if


end subroutine rdqps
!***
!!***
