!{\src2tex{textfont=tt}}
!!****f* ABINIT/rdscr
!! NAME
!! rdscr
!!
!! FUNCTION
!! Read screening (epsilon-twiddle**-1) file in the scr format
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (GMR, VO, LR, RWG, XG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  dtfil=filenames (only dtfil%filsrc is used)
!!  npwvec=number of planewaves
!!  nomega=number of frequencies
!!  nq=number of q points
!!
!! OUTPUT
!!  q(3,nq)=coordinates of q points
!!  epsm1(npwvec,npwvec,nomega,nq)=epsilon minus 1 matrix, for each frequency and q point
!!  omega(nomega)=frequencies
!!
!! NOTES
!! If the epsilon matrix read is bigger than NPWVEC x NPWVEC,
!! it will be truncated; if it is smaller, an error will occur
!!
!! PARENTS
!!      mrgscr,sigma
!!
!! CHILDREN
!!      hdr_clean,hdr_io,hdr_io_netcdf
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine rdscr(dtfil,npwvec,nq,nomega,q,omega,epsm1)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_04iowfdenpot
#else
 use defs_interfaces
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: nomega,npwvec,nq
 type(datafiles_type),intent(in) :: dtfil
!arrays
 real(dp),intent(out) :: q(3,nq)
 complex,intent(out) :: epsm1(npwvec,npwvec,nomega,nq),omega(nomega)

!Local variables-------------------------------
!scalars
 integer,parameter :: unitem1=24
 integer :: fform,headform,ii,io,iq,nbndse,nomegae,npwvece,npwwfne,nqe,rdwr
 integer :: readnetcdf
 real(dp) :: dielconst
 type(hdr_type) :: hdr
!arrays
 real(dp) :: qd(3,nq)
 character(len=80) :: titem1(2)
!no_abirules
 complex (kind(0.0d0)),allocatable :: epsm1d(:,:),omegad(:)

! *************************************************************************

 allocate(omegad(nomega))

 write(*,*) ' rdscr : reading screening (epsilon-twiddle^-1) file in the scr format from:'
 write(*,*) trim(dtfil%filscr)

 open(unit=unitem1,file=dtfil%filscr,status='unknown',form='unformatted')

!Read the header of the file
 rdwr=1
 readnetcdf = 0 ! should become input parameter and make EM1 a netcdf file as well
 if (readnetcdf == 0) then
  call hdr_io(fform,hdr,rdwr,unitem1)
 else if (readnetcdf == 1) then
  call hdr_io_netcdf(fform,hdr,rdwr,unitem1)
 end if


 read(unitem1) titem1
 read(unitem1) npwvece,npwwfne,nbndse,nqe,nomegae
 if(npwvece>npwvec) then
   write(*,*) 'dimension of epsm1 matrix         ', npwvece
   write(*,*) 'warning: reading a smaller matrix ', npwvec
 else if(npwvece<npwvec) then
   write(*,*) 'dimension of epsm1 matrix         ', npwvece
   write(*,*) 'error: requiring a too big matrix ', npwvec
   stop 'requiring a too big matrix'
 end if
 if(nqe<nq) stop 'requiring too much q-points'
 if(nomegae<nomega) stop 'requiring too much omega-points'
 read(unitem1) ! skip gvec
 read(unitem1) qd(1:3,1:nq)
 read(unitem1) omegad(1:nomega)
 q(:,:) = qd(:,:)
 omega(:) = omegad(:)

 write(6,'(a,/,(i3,3f14.6))')&
& ' q-points [reciprocal lattice units]:',(iq,(q(ii,iq),ii=1,3),iq=1,nq)
 write(6,'(a,/,(i3,2f7.2))')&
& ' frequencies omega [eV]:',(io,omega(io)*Ha_eV,io=1,nomega)

!read epsilon^-1
 allocate(epsm1d(npwvece,npwvece))
 do iq=1,nq
   do io=1,nomega
     read(unitem1) epsm1d(1:npwvece,1:npwvece)
     epsm1(1:npwvec,1:npwvec,io,iq) = epsm1d(1:npwvec,1:npwvec)
   end do
   do io=nomega+1,nomegae
     read(unitem1) ! skip other omegas
   end do
 end do

!close(unitem1)
 deallocate(epsm1d,omegad)
 call hdr_clean(hdr)

 if(abs(real(omega(1)))<0.01 .and. abs(aimag(omega(1)))<0.01) then
   do iq=1,nq
     if(all(abs(q(:,iq))<0.001)) then
     dielconst = 1.0/real(epsm1(1,1,1,iq))
     write(*,'(a,f6.2)') ' dielectric constant with LF = ', dielconst
     end if
   end do
 end if

 write(*,*) 'epsilon-twiddle^-1 read'
 write(*,*)

end subroutine rdscr
!!***
