!{\src2tex{textfont=tt}}
!!****f* ABINIT/testlda
!! NAME
!! testlda
!!
!! FUNCTION
!! Test QPLDA or ABINIT LDA or KSS type file
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (GMR, VO, LR, RWG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  dtfil=filenames (only filkss is used)
!!
!! OUTPUT
!!  i1= (to be described)
!!  i2= (to be described)
!!  mpsang=1+maximum angular momentum for nonlocal pseudopotential
!!  natom=number of atoms
!!  nbnd=number of bands
!!  nkpt=number of k points
!!  npw=number of plane waves
!!  nsh=number of shells
!!  nsym=number of symmetries
!!  ntypat=number of atom types
!!
!! PARENTS
!!      screening,sigma
!!
!! CHILDREN
!!      hdr_clean,hdr_io,hdr_io_netcdf
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine testlda(dtfil,nsym,nkpt,nbnd,npw,nsh,i1,i2,ntypat,natom,mpsang)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_04iowfdenpot
#else
 use defs_interfaces
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(out) :: i1,i2,mpsang,natom,nbnd,nkpt,npw,nsh,nsym,ntypat
 type(datafiles_type),intent(in) :: dtfil

!Local variables-------------------------------
!scalars
 integer,parameter :: unitkss=23
 integer :: fform,i10,i11,i12,i13,i14,i15,i16,i3,i4,i5,i6,i7,i8,i9,nsym2,rdwr
 integer :: readnetcdf,status,status1,status2,status3
 logical,parameter :: DEBUG=.false.
 type(hdr_type) :: hdr
!arrays
 character(len=80) :: tit(2)

! *************************************************************************

 print *,'testing Kohn-Sham structure file: ',dtfil%filkss

!trying KSS abinit form
 open(unitkss,file=dtfil%filkss,status='unknown',form='unformatted')

!Read the header of the GS wavefunction file
 rdwr=1
 readnetcdf = 0 ! should become input parameter and make KSS a netcdf file as well
 if (readnetcdf == 0) then
  call hdr_io(fform,hdr,rdwr,unitkss)
 else if (readnetcdf == 1) then
  call hdr_io_netcdf(fform,hdr,rdwr,unitkss)
 end if

 natom=hdr%natom
 nkpt=hdr%nkpt
 nsym=hdr%nsym
 ntypat=hdr%ntypat

 if(fform==502.or.fform==602) then
  if(fform==502) then
   print *, 'KSS abinit double precision form'
  else if(fform==602) then
   print *, 'KSS abinit single precision form'
  else
   stop 'internal error'
  end if
  i2 = fform

! XG20030510 : Should be changed, later. Indeed, it is not consistent
! with the definition of the structured datatyp hdr, and the
! associated routines. Nothing should be read directly in the header
! of the file : everything is already in hdr ...
  write(*,'(" generated by ABINIT ",a6," header version ",i3)') hdr%codvsn,hdr%headform
  if(hdr%headform/=23 .and. hdr%headform/=34 .and. &
&    hdr%headform/=40 .and. hdr%headform/=41 .and. hdr%headform/=42 .and. &
&    hdr%headform/=44) stop 'header version unknown'

!--------------------------

  read(unitkss) tit(1)
  read(unitkss) tit(2)
  print *, 'title of file:'
  write(*,'(1x,a79/1x,a79)') tit(1)(:79), tit(2)(:79)
  read(unitkss) nsym2, nbnd, npw, nsh, mpsang
  nsym = nsym2
  print *, 'number of atomic species      ', ntypat
  print *, 'number of atoms               ', natom
  print *, 'number of ang mom components  ', mpsang
  print *, 'number of symmetry operations ', nsym
  print *, 'number of plane waves         ', npw
  print *, 'number of k-points            ', nkpt
  print *, 'number of bands               ', nbnd
  print *
  close(unitkss)
  return
 else
  close(unitkss)
 end if

!Trying STA or qplda form
!open(unitkss,status='unknown',form='unformatted')
 rewind(unitkss)
 read(unitkss,iostat=status1) tit(1)
 if(DEBUG) print *, tit(1)
 read(unitkss,iostat=status2) tit(2)
 if(DEBUG) print *, tit(2)
 read(unitkss,iostat=status3) i1,i2,i3,i4,i5,i6,i7,i8,i9,i10,i11,i12,i13,i14,i15,i16
 write(6,'(1x,a80,/,1x,a80)') tit(1),tit(2)
!flags used so far:
!i1=0 if QPLDA file is formatted, 1 if unformatted
!i2=0 if RWG format, 1 if BF format, 2 ABINIT format
!i3=1 if non-symmorphic operations (+vectors) included, otherwise 0
 if(DEBUG) print *, i1,i2,i3

 if(status1/=0.or.status2/=0.or.status3/=0) then
  if(DEBUG) print *, status1, status2, status3
  stop 'unknown file form, status'
 end if
 if(i2==2) then
  print *, 'STA abinit form'
 else if(i2==0.or.i2==1) then
  print *, 'qplda cp form'
 else
  if(DEBUG) print *, 'i2 ', i2
  stop 'unknown file form, i2'
 end if
 if(i1/=1) then
  print *, 'formatted file'
 else
  print *, 'unformatted file'
 end if
 if(i3==1) then
  print *, 'ERROR testlda 1: check i3'
 end if

 print *, 'title of file:'
 write(*,'(1x,a79/1x,a79)') tit(1)(:79), tit(2)(:79)

!skip real-space lattice vectors
 read(unitkss)

 read(unitkss) nsym
 write(*,*) 'number of symmetry operations ',nsym
!skip symmetry operations
 read(unitkss)

 read(unitkss) npw
 write(*,*) 'number of plane waves         ',npw
!skip g-vector
 read(unitkss)

 read(unitkss) nkpt
 write(*,*) 'number of k-points            ',nkpt
!skip k-points
 read(unitkss)

 read(unitkss) nbnd
 write(*,*) 'number of bands               ',nbnd

!close(unitkss)
 write(*,*)

 call hdr_clean(hdr)

end subroutine testlda
!!***
