!{\src2tex{textfont=tt}}
!!****f* ABINIT/testscr
!! NAME
!! testscr
!!
!! FUNCTION
!! Test epsilon-twiddle**-1 file
!! and return its dimension
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (GMR, VO, LR, RWG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  dtfil=filenames (only dtfil%filscr is used)
!!
!! OUTPUT
!!  fform=file format
!!  nbndse=number of bands
!!  npwvece=number of planewaves for screening matrix
!!  npwwfne=number of planewaves for wavefunctions
!!  nomega=number of frequencies
!!  nq=number of q points
!!  titem1=title of the file
!!
!! PARENTS
!!      mrgscr,sigma
!!
!! CHILDREN
!!      hdr_clean,hdr_io
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine testscr(dtfil,nq,nomega,npwvece,npwwfne,nbndse,titem1,fform)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_04iowfdenpot
#else
 use defs_interfaces
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(out) :: fform,nbndse,nomega,npwvece,npwwfne,nq
 type(datafiles_type),intent(in) :: dtfil
!arrays
 character(len=80),intent(out) :: titem1(2)

!Local variables-------------------------------
!scalars
 integer,parameter :: unitem1=24
 integer :: bantot,date,found_format,headform,intxc,ixc,natom,nkpt,nspden
 integer :: nspinor,nsppol,nsym,rdwr,readnetcdf
 type(hdr_type) :: hdr
!arrays
 integer :: ngfft(3)

! *************************************************************************

 write(*,*) ' testscr : testing epsilon-twiddle^-1 file'

 found_format=0

!try before em1 format

 open(unit=unitem1,file=dtfil%filscr,status='unknown',form='unformatted')
!Read the header
 rdwr=1
 readnetcdf = 0 ! should make EM1 also a netcdf file
 if (readnetcdf == 0) then
  call hdr_io(fform,hdr,rdwr,unitem1)
 else if (readnetcdf == 1) then
  call hdr_io(fform,hdr,rdwr,unitem1)
 end if

 if(fform==1002)then
  call hdr_clean(hdr)
  read(unitem1,err=100) titem1
  read(unitem1,err=100) npwvece,npwwfne,nbndse,nq,nomega
  write(*,*) 'epsilon^-1 file in the format em1'
  write(*,'(1x,a79/1x,a79)') titem1(1)(:79), titem1(2)(:79)
  write(*,*) 'dimension of epsilon^-1 matrix ',npwvece
  write(*,*) 'number of planewaves used      ',npwwfne
  write(*,*) 'number of bands used           ',nbndse
  write(*,*) 'number of q-points             ',nq
  write(*,*) 'number of omega                ',nomega
  write(*,*)
  found_format=1
  100 continue
  close(unitem1)
 end if

 if(found_format==0)then
! Now try old epsm1 format in single and double precision
  open(unitem1,status='unknown',form='unformatted')
  read(unitem1,err=200) titem1
  read(unitem1,err=200) nq
! Skip q-points
  read(unitem1)
  read(unitem1,err=200) npwvece,npwwfne,nbndse
  write(*,*) 'epsilon^-1 file in the format epsm1'
  write(*,'(1x,a79/1x,a79)') titem1(1)(:79), titem1(2)(:79)
  write(*,*) 'dimension of epsm1 matrix ',npwvece
  write(*,*) 'number of planewaves used ',npwwfne
  write(*,*) 'number of bands used      ',nbndse
  write(*,*) 'number of q-points        ',nq
  write(*,*)
  found_format=1
  fform=1003
  200 continue
  close(unitem1)
 end if

 if(found_format==0)then
  write(*,*) 'epsilon^-1 file format unknown'
  stop 'epsilon^-1 file format unknown'
 end if

end subroutine testscr
!!***
