!{\src2tex{textfont=tt}}
!!****f* ABINIT/dyfnl3
!! NAME
!! dyfnl3
!!
!! FUNCTION
!! Compute the frozen-wavefunction non-local contribution to the
!! dynamical matrix.
!!
!! COPYRIGHT
!! Copyright (C) 1998-2006 ABINIT group (DCA, XG, GM, AR, MB)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors.
!!
!! INPUTS
!!  atindx(natom)=index table for atoms (see scfcv.f)
!!  atindx1(natom)=index table for atoms, inverse of atindx (see scfcv.f)
!!  cg(2,mpw*nspinor*mband*mkmem*nsppol)=<G|Cnk>=Fourier coefficients of
!!    wavefunction
!!  ecut=cut-off energy for plane wave basis sphere (Ha)
!!  ecutsm=smearing energy for plane wave kinetic energy (Ha) (NOT NEEDED !)
!!  fform=integer specifier for wf file form
!!  istwfk(nkpt)=input option parameter that describes the storage of wfs
!!  kg(3,mpw*mkmem)=work array for coordinates of G vectors in basis
!!  kptns(3,nkpt)=coordinates of k points in terms of reciprocal space
!!   primitive translations
!!  mband=maximum number of bands
!!  mgfft=maximum size of 1D FFTs
!!  mkmem=number of k points which can fit in memory; set to 0 if use disk
!!  mpi_enreg=informations about MPI parallelization
!!  mpsang= 1+maximum angular momentum for nonlocal pseudopotentials
!!  mpw=maximum dimension for number of planewaves
!!  natom=number of atoms in unit cell
!!  nattyp(ntypat)=array describing how many atoms of each type in cell
!!  nband(nkpt*nsppol)=number of bands being considered per k point
!!  nkpt=number of k points
!!  ngfft(18)=contain all needed information about 3D FFT,
!!     see ~abinit/doc/input_variables/vargs.htm#ngfft
!!  nloalg(5)=governs the choice of the algorithm for non-local operator.
!!  npwarr(nkpt)=number of planewaves at each k point, and boundary
!!  nspinor=number of spinorial components of the wavefunctions
!!  nsppol=1 for unpolarized, 2 for polarized
!!  nsym=number of symmetry elements in space group (at least 1)
!!  ntypat=integer specification of atom type (1, 2, ...)
!!  occ(mband*nkpt*nsppol)=occupation numbers of bands (usually 2) at each
!!    k point
!!  ph1d(2,3*(2*mgfft+1)*natom)=phase information related to structure factor
!!  prtvol=control print volume and debugging output
!!  psps <type(pseudopotential_type)>=variables related to pseudopotentials
!!  rprimd(3,3)=dimensional real space primitive translations (bohr)
!!  unkg=unit number for (k+G) sphere data
!!  wfftgs=struct info for disk file containing GS wavefunctions if mkmem==0
!!  unylm=unit number for disk file containing Ylm''s if mkmem==0
!!  wtk(nkpt)=k point weights
!!  xred(3,natom)=reduced coordinates of atoms (dimensionless)
!!  ylm(mpw*mkmem,mpsang*mpsang*useylm)= real spherical harmonics for
!!    each G and k point
!!
!! OUTPUT
!!  dyfrnl(3,3,natom)=non-symmetrized non-local contribution to the
!!                    dynamical matrix
!!
!! PARENTS
!!      respfn
!!
!! CHILDREN
!!      hdr_skip,leave_test,metric,mkffnl,mkkpg,nonlop,ph1d3d,rdnpw,rwwf
!!      sphereboundary,timab,xcomm_world,xdefineoff,xme_init,xsum_mpi
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine dyfnl3(atindx,atindx1,cg,dyfrnl,ecut,ecutsm,&
&  fform,istwfk,&
&  kg,kptns,mband,mgfft,mkmem,mpi_enreg,mpsang,&
&  mpw,natom,nattyp,nband,&
&  nkpt,ngfft,nloalg,npwarr,nspinor,nsppol,nsym,ntypat,occ,ph1d,&
&  prtvol,psps,rprimd,unkg,wfftgs,unylm,&
&  wtk,xred,ylm)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_00basis
 use interfaces_01managempi
 use interfaces_02ffts
 use interfaces_02geometry
 use interfaces_03nonlocal
 use interfaces_04iowfdenpot
#else
 use defs_xfuncmpi
 use defs_interfaces
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: fform,mband,mgfft,mkmem,mpsang,mpw,natom,nkpt,nsppol
 integer,intent(in) :: nsym,ntypat,prtvol,unkg,unylm
 integer,intent(inout) :: nspinor
 real(dp),intent(in) :: ecut,ecutsm
 type(MPI_type),intent(inout) :: mpi_enreg
 type(pseudopotential_type),intent(in) :: psps
 type(wffile_type),intent(inout) :: wfftgs
!arrays
 integer,intent(in) :: atindx(natom),atindx1(natom),istwfk(nkpt)
 integer,intent(in) :: kg(3,mpw*mkmem),nattyp(ntypat),nband(nkpt*nsppol)
 integer,intent(in) :: ngfft(18),nloalg(5),npwarr(nkpt)
 real(dp),intent(in) :: cg(2,mpw*nspinor*mband*mkmem*nsppol),kptns(3,nkpt)
 real(dp),intent(in) :: occ(mband*nkpt*nsppol),ph1d(2,3*(2*mgfft+1)*natom)
 real(dp),intent(in) :: rprimd(3,3),wtk(nkpt),xred(3,natom)
 real(dp),intent(in) :: ylm(mpw*mkmem,mpsang*mpsang*psps%useylm)
 real(dp),intent(out) :: dyfrnl(3,3,natom)

!Local variables-------------------------------
!scalars
 integer :: bdtot_index,choice,dimffnl,formeig,ia,iatom,iband,icg,ider,idir
 integer :: ierr,ii,ikg,ikpt,ilm,ilmn,iln,iln0,index,iproc,ipw,ipw1,isppol
 integer :: istwf_k,it,master,matblk,mcg_disk,me,n1,n2,n3,nband1,nband_k,nkpg
 integer :: nnlout,npw_k,option,paw_opt,signs,spaceworld,tim_nonlop,tim_rwwf
 real(dp) :: arg,dotr,enl,enlk,ucvol
 character(len=500) :: message
!arrays
 integer,allocatable :: gbound(:,:),kg_dum(:,:),kg_k(:,:)
 real(dp) :: gmet(3,3),gprimd(3,3),kpoint(3),nonlop_dum(1),rmet(3,3),tsec(2)
 real(dp) :: ylmgr_dum(1)
 real(dp),allocatable :: cg_disk(:,:),cwavef(:,:),dyfrnlk(:,:),eig_dum(:)
 real(dp),allocatable :: enlout(:),ffnl(:,:,:,:),kpg_k(:,:),occ_dum(:)
 real(dp),allocatable :: ph3d(:,:,:),phkxred(:,:),ylm_k(:,:)

! *************************************************************************

! DEBUG
!write(6,*)' dyfnl3 : enter '
!stop
! ENDDEBUG

 call timab(159,1,tsec)

!Default for sequential use
 master=0
!BEGIN TF_CHANGES
 call xme_init(mpi_enreg,me)
!END TF_CHANGES
!Init spaceworld
!BEGIN TF_CHANGES
 call xcomm_world(mpi_enreg,spaceworld)
!END TF_CHANGES

!Compute gmet, gprimd and ucvol from rprimd
 call metric(gmet,gprimd,-1,rmet,rprimd,ucvol)

 if (mkmem==0) then

! Read wavefunction file header
  call hdr_skip(wfftgs,ierr)

! Define offsets, in case of MPI I/O
  formeig=0
  call xdefineOff(formeig,wfftgs,mpi_enreg,nband,npwarr,nspinor,nsppol,nkpt)

  mcg_disk=mpw*nspinor*mband
  allocate(cg_disk(2,mcg_disk))

 end if

 enl=0.0d0
 dyfrnl(:,:,:)=0.0d0
 bdtot_index=0
 icg=0

! DEBUG
!write(6,*)' dyfnl3 : before loop over spins '
!stop
! ENDDEBUG

 n1=ngfft(1) ; n2=ngfft(2) ; n3=ngfft(3)
 allocate(kg_k(3,mpw))
 allocate(cwavef(2,mpw*nspinor))
 allocate(dyfrnlk(6,natom))

!Define k-points distribution

!LOOP OVER SPINS
 do isppol=1,nsppol


! Rewind kpgsph data file if needed:
  if (mkmem==0) rewind(unkg)
  if (mkmem==0.and.psps%useylm==1) rewind unylm

  ikg=0

! Loop over k points
  do ikpt=1,nkpt
   nband_k=nband(ikpt+(isppol-1)*nkpt)
   istwf_k=istwfk(ikpt)
   npw_k=npwarr(ikpt)

   if(mpi_enreg%paral_compil_kpt==1)then
!   Skip this k-point if not the proper processor
!BEGIN TF_CHANGES
    if(minval(abs(mpi_enreg%proc_distrb(ikpt,1:nband_k,isppol) &
&        - me))/=0) then
!END TF_CHANGES
     bdtot_index=bdtot_index+nband_k
     cycle
    end if
   end if

   allocate(gbound(2*mgfft+8,2))
   allocate(ylm_k(npw_k,mpsang*mpsang*psps%useylm))
   kpoint(:)=kptns(:,ikpt)

   kg_k(:,:) = 0
   if (mkmem==0) then

    call rdnpw(ikpt,isppol,nband_k,npw_k,nspinor,0,unkg)

!   Read k+g data
    read (unkg) ((kg_k(ii,ipw),ii=1,3),ipw=1,npw_k)

    call sphereboundary(gbound,istwf_k,kg_k,mgfft,npw_k)

!   Eventually read spherical harmonics
    if (psps%useylm==1) then
     read(unylm)
     read(unylm) ((ylm_k(ipw,ilm),ipw=1,npw_k),ilm=1,mpsang*mpsang)
   end if

!   Read the wavefunction block for ikpt,isppol
    tim_rwwf=14
    allocate(eig_dum(mband),kg_dum(3,0),occ_dum(mband))
    call rwwf(cg_disk,eig_dum,0,0,0,ikpt,isppol,kg_dum,mband,mcg_disk,nband_k,nband_k,&
&    npw_k,nspinor,occ_dum,-2,0,tim_rwwf,wfftgs)
    deallocate(eig_dum,kg_dum,occ_dum)

   else

!$OMP PARALLEL DO PRIVATE(ipw) &
!$OMP&SHARED(ikg,kg,kg_k,npw_k)
    do ipw=1,npw_k
     kg_k(1,ipw)=kg(1,ipw+ikg)
     kg_k(2,ipw)=kg(2,ipw+ikg)
     kg_k(3,ipw)=kg(3,ipw+ikg)
    end do
!$OMP END PARALLEL DO
    if (psps%useylm==1) then
!$OMP PARALLEL DO PRIVATE(ipw) &
!$OMP&SHARED(ikg,npw_k,ylm,ylm_k)
     do ilm=1,mpsang*mpsang
      do ipw=1,npw_k
       ylm_k(ipw,ilm)=ylm(ipw+ikg,ilm)
      end do
     end do
!$OMP END PARALLEL DO
    end if

    call sphereboundary(gbound,istwf_k,kg_k,mgfft,npw_k)

!  End if for choice governed by mkmem
   end if

   index=1+icg

!  Compute nonlocal psp energy

!  Compute (k+G) vectors (only if useylm=1)
   nkpg=9*nloalg(5);allocate(kpg_k(npw_k,nkpg))
   if (nkpg>0) call mkkpg(kg_k,kpg_k,kpoint,nkpg,npw_k)

!  Compute nonlocal form factors ffnl at all (k+G):
   ider=0;idir=0;dimffnl=1
   allocate(ffnl(npw_k,dimffnl,psps%lmnmax,ntypat))
   call mkffnl(psps%dimekb,dimffnl,psps%ekb,ffnl,psps%ffspl,&
&   gmet,gprimd,ider,idir,psps%indlmn,kg_k,kpg_k,kpoint,psps%lmnmax,&
&   psps%lnmax,psps%mpsang,psps%mqgrid_ff,nkpg,npw_k,&
&   ntypat,psps%pspso,psps%qgrid_ff,rmet,psps%usepaw,psps%useylm,ylm_k,ylmgr_dum)

   enlk=0.0d0
   dyfrnlk(:,:)=0.0d0

!  Allocate the arrays phkxred and ph3d, compute phkxred
!  and eventually ph3d.
   allocate(phkxred(2,natom))
   do ia=1,natom
    iatom=atindx(ia)
    arg=two_pi*(kpoint(1)*xred(1,ia)+kpoint(2)*xred(2,ia)+kpoint(3)*xred(3,ia))
    phkxred(1,iatom)=cos(arg)
    phkxred(2,iatom)=sin(arg)
   end do
   if(nloalg(1)<=0)then
!   Only the allocation, not the precomputation.
    matblk=nloalg(4)
    allocate(ph3d(2,npw_k,matblk))
   else
!   Here, allocation as well as precomputation
    matblk=natom
    allocate(ph3d(2,npw_k,matblk))
    call ph1d3d(1,natom,kg_k,kpoint,matblk,natom,npw_k,n1,n2,n3,&
&               phkxred,ph1d,ph3d)
   end if

!  DEBUG
!  write(6,*)' dyfnl3 : before nonlop '
!  stop
!  ENDDEBUG

   nnlout=6*natom
   allocate(enlout(nnlout))

   do iband=1,nband_k

    if(mpi_enreg%paral_compil_kpt==1)then
!BEGIN TF_CHANGES
     if(mpi_enreg%proc_distrb(ikpt, iband,isppol) /= me) then
      cycle
!END TF_CHANGES
     end if
    end if

    if(mkmem/=0)then
     cwavef(:,1:npw_k*nspinor)=&
&     cg(:,1+(iband-1)*npw_k*nspinor+icg:iband*npw_k*nspinor+icg)
    else
     cwavef(:,1:npw_k*nspinor)=&
&     cg_disk(:,1+(iband-1)*npw_k*nspinor:iband*npw_k*nspinor)
    end if

    signs=1 ; choice=4 ; idir=0 ; tim_nonlop=6 ; paw_opt=0
    call nonlop(atindx1,choice,psps%dimekb,psps%ntypat,dimffnl,dimffnl,psps%ekb,&
&    enlout,ffnl,ffnl,gmet,gprimd,idir,psps%indlmn,istwf_k,kg_k,kg_k,kpg_k,kpg_k,kpoint,&
&    kpoint,psps%lmnmax,matblk,mgfft,mpi_enreg,mpsang,psps%mpssoang,natom,nattyp,&
&    ngfft,nkpg,nkpg,nloalg,nnlout,npw_k,npw_k,nspinor,ntypat,paw_opt,phkxred,&
&    phkxred,ph1d,ph3d,ph3d,psps%pspso,signs,&
&    nonlop_dum,nonlop_dum,tim_nonlop,ucvol,psps%useylm,cwavef,cwavef)

!   DEBUG
!   write(6,*)' dyfnl3 : after nonlop, stop'
!   stop
!   write(6,*)' dyfnl3 : after nonlop, enlout(2)=',enlout(2)
!   ENDDEBUG

    enlk=enlk+occ(iband+bdtot_index)*enlout(1)
    dyfrnlk(:,:)=dyfrnlk(:,:)+ &
&    occ(iband+bdtot_index)* reshape(enlout(:), (/6,natom/) )

   end do

   deallocate(enlout)

!  DEBUG
!  write(6,*)' dyfnl3 : ikpt,after band loop, dyfrnlk(1,1)',ikpt,dyfrnlk(1,1)
!  write(6,*)' dyfnl3 : after band loop, dyfrnlk(2,1)',dyfrnlk(2,1)
!  ENDDEBUG

!  enl=enl+wtk(ikpt)*enlk
   dyfrnl(1,1,:)=dyfrnl(1,1,:)+wtk(ikpt)*dyfrnlk(1,:)/ucvol
   dyfrnl(2,2,:)=dyfrnl(2,2,:)+wtk(ikpt)*dyfrnlk(2,:)/ucvol
   dyfrnl(3,3,:)=dyfrnl(3,3,:)+wtk(ikpt)*dyfrnlk(3,:)/ucvol
   dyfrnl(2,3,:)=dyfrnl(2,3,:)+wtk(ikpt)*dyfrnlk(4,:)/ucvol
   dyfrnl(1,3,:)=dyfrnl(1,3,:)+wtk(ikpt)*dyfrnlk(5,:)/ucvol
   dyfrnl(1,2,:)=dyfrnl(1,2,:)+wtk(ikpt)*dyfrnlk(6,:)/ucvol

   deallocate(gbound)

   bdtot_index=bdtot_index+nband_k

   if (mkmem/=0) then
!   Handle case in which kg, cg, are kept in core
    icg=icg+npw_k*nspinor*nband_k
    ikg=ikg+npw_k
   end if

   deallocate(ffnl,kpg_k,phkxred,ph3d,ylm_k)

! End loops on isppol and ikpt
  end do
 end do

!DEBUG
! write(6,*)' dyfnl3 : after kpt loop, enl=',enl
!stop
! write(6,*)' dyfnl3 : after kpt loop, dyfrnl(2,1,1)',dyfrnl(2,1,1)
!ENDDEBUG

 dyfrnl(2,1,:)=dyfrnl(1,2,:)
 dyfrnl(3,1,:)=dyfrnl(1,3,:)
 dyfrnl(3,2,:)=dyfrnl(2,3,:)

 if(mkmem==0)then
  deallocate(cg_disk)
 end if
! DEBUG
!write(6,*)' dyfnl3 : after loop on kpts and spins '
!stop
! ENDDEBUG

 if(mpi_enreg%paral_compil_kpt==1)then
  call timab(62,1,tsec)
!BEGIN TF_CHANGES
  call leave_test(mpi_enreg)
!END TF_CHANGES
  call timab(48,1,tsec)
! Accumulate dyfrnl on all proc.
  call xsum_mpi(dyfrnl,spaceworld,ierr)
  call timab(48,2,tsec)
 end if

 call timab(159,2,tsec)

 deallocate(cwavef)
 deallocate(dyfrnlk)
 deallocate(kg_k)

! DEBUG
!write(6,*)' dyfnl3 : exit '
!stop
! ENDDEBUG

end subroutine dyfnl3
!!***
