!{\src2tex{textfont=tt}}
!!****f* ABINIT/dielmore9
!!
!! NAME
!! dielmore9
!!
!! FUNCTION
!! Get the dielectric tensor under different experimental conditions,
!! Now only treat the relaxed-ion dielectric tensor.
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (XW,XG)
!! This file is distributed under the terms of the
!! GNU General Public Licence, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!! d2cart(2,3,mpert,3,mpert)=
!!  dynamical matrix, effective charges, dielectric tensor,....
!!  all in cartesian coordinates
!! dieflag=3 calculate relaxed-ion dielectric tensor
!! iout=unit number for outputs
!! mpert =maximum number of ipert
!! natom=number of atoms in unit cell
!! ucvol=unit cell volume
!!
!! OUTPUT
!! dielt_rlx= relaxed ion(zero frequency)(zero frequency) dielectric tensor.
!!
!! NOTES
!! Now only treat the relaxed-ion dielectric tensor, more to be added
!! such as free stree dielectric tenor,et al.
!! Please note that the relaxed-ion dielectric tensor computed
!! here can also be obtained as the zero-frequency limit of the
!! frequency-dependent dielectric tensor using flags dieflag=1 and
!! frmin=0.0.  (The results obtained using these two approaches
!! should agree to good numerical precision.)  The ability to compute
!! and print the static dielectric tensor here is provided for
!! completeness and consistency with the other tensor quantities
!! that are computed in this section of the code.

!!
!! PARENTS
!!      diel9
!!
!! CHILDREN
!!      wrtout,zhpev
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine dielmore9(d2cart,dieflag,dielt_rlx,iout,mpert,natom,ucvol)

 use defs_basis

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
#endif
!End of the abilint section

 implicit none

!Arguments -------------------------------
!scalars
 integer,intent(in) :: dieflag,iout,mpert,natom
 real(dp),intent(in) :: ucvol
!arrays
 real(dp),intent(in) :: d2cart(2,3,mpert,3,mpert)
 real(dp),intent(out) :: dielt_rlx(3,3)

!Local variables -------------------------
!scalars
 integer :: idir1,idir2,ier,ii1,ii2,ipert1,ipert2,ivarA,ivarB
 character(len=500) :: message
!arrays
 real(dp) :: Amatr(3*natom-3,3*natom-3),Apmatr(3*natom,3*natom)
 real(dp) :: Bmatr(2,((3*natom-3)*(3*natom-2))/2)
 real(dp) :: Bpmatr(2,(3*natom*(3*natom+1))/2),Cmatr(3*natom-3,3*natom-3)
 real(dp) :: Cpmatr(3*natom,3*natom),Nmatr(3*natom,3*natom)
 real(dp) :: d2cart_relaxed(2,3,mpert,3,mpert),die_correction(3,3)
 real(dp) :: die_relaxed(3,3),eigval(3*natom-3),eigvalp(3*natom)
 real(dp) :: eigvec(2,3*natom-3,3*natom-3),eigvecp(2,3*natom,3*natom)
 real(dp) :: kmatrix(3*natom,3*natom),zhpev1(2,2*3*natom-4)
 real(dp) :: zhpev1p(2,2*3*natom-1),zhpev2(3*3*natom-5),zhpev2p(3*3*natom-2)
 real(dp) :: zstar1(3,3*natom),zstar2(3,3*natom),zstar3(3*natom,3)

! *********************************************************************

#ifdef VMS
!DEC$ ATTRIBUTES ALIAS:'ZHPEV' :: zhpev
#endif

 if(dieflag==1 .or. dieflag==3 .or. dieflag==4)then
! adding the part for relaxed ion dielectric tensor
  write(message,'(a,a)') ch10,&
&  ' Relaxed ion dielectric tensor'
  call wrtout(6,message,'COLL')
  call wrtout(iout,message,'COLL')
! transform the dielectric and effective tensors back to real
  d2cart_relaxed(:,:,:,:,:)=d2cart(:,:,:,:,:)

  do idir1=1,3
    d2cart_relaxed(1,idir1,natom+2,idir1,natom+2)=&
&    d2cart_relaxed(1,idir1,natom+2,idir1,natom+2)-1.0d0
   end do
   do idir1=1,3
    do idir2=1,3
     do ii1=1,2
      d2cart_relaxed(ii1,idir1,natom+2,idir2,natom+2)=&
&      d2cart_relaxed(ii1,idir1,natom+2,idir2,natom+2)/four_pi
     end do
    end do
   end do

! DEBUG
! do ipert1=1,natom
!  do idir1=1,3
!   d2cart_relaxed(1,idir1,ipert1,idir1,natom+2)=&
!&   d2cart_relaxed(1,idir1,ipert1,idir1,natom+2)-zion(type(ipert1))
!   end do
!  end do
!  do ipert2=1,natom
!   do idir2=1,3
!    d2cart_relaxed(1,idir2,natom+2,idir2,ipert2)=&
!&    d2cart_relaxed(1,idir2,natom+2,idir2,ipert2)-zion(type(ipert2))
!   end do
!  end do
! ENDDEBUG

! Extracting the force constant at gamma point
  do ipert1=1,natom
   do idir1=1,3
    ivarA=idir1+3*(ipert1-1)
    do ipert2=1,natom
     do idir2=1,3
      ivarB=idir2+3*(ipert2-1)
      kmatrix(ivarA,ivarB)=d2cart_relaxed(1,idir1,ipert1,idir2,ipert2)
     end do
    end do
   end do
  end do

! DEBUG
! write(6,'(/,a,/)')'the kmatrix before inverse'
! do ii1=1,3*natom
!  write(6,'(6es16.3)')kmatrix(ii1,1),kmatrix(ii1,2),kmatrix(ii1,3),&
!&  kmatrix(ii1,4),kmatrix(ii1,5),kmatrix(ii1,6)
!  end do
! write(6,'(/)')
! ENDDEBUG

  Apmatr(:,:)=kmatrix(:,:)

! DEBUG
! kmatrix
! write(6,'(/,a,/)')'the force constant matrix'
! do ivarA=1,3*natom
!  write(6,'(/)')
!  do ivarB=1,3*natom
!   write(6,'(es16.6)')kmatrix(ivarB,ivarA)
!  end do
! end do
! ENDDEBUG

  Nmatr(:,:)=0.0d0
  do ivarA=1,3*natom
   do ivarB=1,3*natom
    if (mod(ivarA,3)==0 .and. mod(ivarB,3)==0)then
     Nmatr(ivarA,ivarB)=1
    end if
    if (mod(ivarA,3)==1 .and. mod(ivarB,3)==1)then
     Nmatr(ivarA,ivarB)=1
    end if
    if (mod(ivarA,3)==2 .and. mod(ivarB,3)==2)then
     Nmatr(ivarA,ivarB)=1
    end if
   end do
  end do

! DEBUG
! do ivarA=1,3*natom
!  write(6,'(/)')
!  do ivarB=1,3*natom
!   write(6,'(es16.6)')Nmatr(ivarB,ivarA)
!  end do
! end do
! ENDDEBUG

! strarting the pseudoinervering processes
! then get the eigenvectors of the big matrix,give values to matrixBp
  ii1=1
  do ivarA=1,3*natom
   do ivarB=1,ivarA
    Bpmatr(1,ii1)=Nmatr(ivarB,ivarA)
    ii1=ii1+1
   end do
  end do
  Bpmatr(2,:)=0.0d0
! Bpmatr(2,:) is the imaginary part of the force matrix
! then call the subroutines CHPEV and ZHPEV to get the eigenvectors
  call ZHPEV ('V','U',3*natom,Bpmatr,eigvalp,eigvecp,3*natom,&
&  zhpev1p,zhpev2p,ier)

! DEBUG
! the eigenval and eigenvec
! write(6,'(/,a,/)')'the eigenvalues and eigenvectors'
! do ivarA=1,3*natom
!  write(6,'(/)')
!  write(6,'(es16.6)')eigvalp(ivarA)
! end do
!  do ivarA=1,3*natom
!  write(6,'(/)')
!  do ivarB=1,3*natom
!   write(6,'(es16.6)')eigvecp(1,ivarB,ivarA)
!  end do
! end do
! ENDDEBUG

! then do the muplication to get the reduced matrix,in two steps
! After this the force constant matrix is decouple in two bloks,
! accoustic and optical ones
  Cpmatr(:,:)=0.0d0
  do ivarA=1,3*natom
   do ivarB=1,3*natom
    do ii1=1,3*natom
     Cpmatr(ivarA,ivarB)=Cpmatr(ivarA,ivarB)+eigvecp(1,ii1,ivarA)*&
&     Apmatr(ii1,ivarB)
    end do
   end do
  end do
  Apmatr(:,:)=0.0d0
  do ivarA=1,3*natom
   do ivarB=1,3*natom
    do ii1=1,3*natom
     Apmatr(ivarA,ivarB)=Apmatr(ivarA,ivarB)+Cpmatr(ivarA,ii1)*&
&     eigvecp(1,ii1,ivarB)
    end do
   end do
  end do

! DEBUG
! the blok diago
! write(6,'(/,a,/)')'Apmatr'
!  do ivarA=1,3*natom
!   write(6,'(/)')
!   do ivarB=1,3*natom
!    write(6,'(es16.6)')Apmatr(ivarA,ivarB)
!   end do
!  end do
! ENDDEBUG

! check the last three eigenvalues whether too large or not
! and print out the warning message
  ivarB=0
  do ivarA=3*natom-2,3*natom
   if (abs(Apmatr(ivarA,ivarA))>tol6)then
    ivarB=1
   end if
  end do
  if(ivarB==1)then
   write(message,'(a,a,a,a,a,a,a,a,a,a,3es16.6)')ch10,&
&   ' dielmore9 : WARNING - :',ch10,&
&   '  Acoustic sum rule violation met : the eigenvalues of accoustic mode',&
&   ch10,' are too large at Gamma point.',ch10,&
&   '  Increase cutoff energy or k-points sampling.',ch10,&
&   '  The three eigenvalues are:',Apmatr(3*natom-2,3*natom-2),&
&   Apmatr(3*natom-1,natom-1),Apmatr(3*natom,3*natom)
   call wrtout(06, message, 'COLL')
   call wrtout(iout,message,'COLL')
  end if

! give the value of reduced matrix form Apmatr to Amatr
   do ivarA=1,3*natom-3
    do ivarB=1,3*natom-3
     Amatr(ivarA,ivarB)=Apmatr(ivarA,ivarB)
    end do
   end do
! now the reduced matrix is in the Amatr, the convert it
! first give the give the value of Bmat from Amatr
  ii1=1
  do ivarA=1,3*natom-3
   do ivarB=1,ivarA
    Bmatr(1,ii1)=Amatr(ivarB,ivarA)
    ii1=ii1+1
   end do
  end do
  Bmatr(2,:)=0.0d0
! call the subroutines CHPEV and ZHPEV to get the eigenvectors and the
! eigenvalues
  call ZHPEV ('V','U',3*natom-3,Bmatr,eigval,eigvec,3*natom-3,&
&  zhpev1,zhpev2,ier)

! check the unstable phonon modes, if the first is negative then print
! warning message
  if(eigval(1)<-1.0*tol8)then
   write(message,'(a,a,a,a,a,a)') ch10,&
&   'phonon modes warning- :',ch10,&
&   'unstable eigenvalue detected in force constant matrix at Gamma point',&
&   ch10,'the system under calculation is physically unstabale.'
   call wrtout(06, message, 'COLL')
   call wrtout(iout,message,'COLL')
  end if

! do the matrix muplication to get pseudoinverse inverse matrix
  Cmatr(:,:)=0.0d0
  Amatr(:,:)=0.0d0
  do ivarA=1,3*natom-3
   Cmatr(ivarA,ivarA)=1.0d0/eigval(ivarA)
  end do

  do ivarA=1,3*natom-3
   do ivarB=1,3*natom-3
    do ii1=1,3*natom-3
     Amatr(ivarA,ivarB)=Amatr(ivarA,ivarB)+eigvec(1,ivarA,ii1)*&
&     Cmatr(ii1,ivarB)
     end do
    end do
   end do
! the second mulplication
  Cmatr(:,:)=0.0d0
  do ivarA=1,3*natom-3
   do ivarB=1,3*natom-3
    do ii1=1,3*natom-3
     Cmatr(ivarA,ivarB)=Cmatr(ivarA,ivarB)+&
&     Amatr(ivarA,ii1)*eigvec(1,ivarB,ii1)
    end do
   end do
  end do

! DEBUG
! write(6,'(/,a,/)')'the pseudo inverse of the force matrix'
! do ivarA=1,3*natom
!  write(6,'(/)')
!   do ivarB=1,3*natom
!    write(6,'(es16.6)')Cmatr(ivarA,ivarB)
!   end do
!  end do
! ENDDEBUG

! so now the inverse of the reduced matrix is in the matrixC
! now do another mulplication to get the pseudoinverse of the original
  Cpmatr(:,:)=0.0d0
  Apmatr(:,:)=0.0d0
  do ivarA=1,3*natom-3
   do ivarB=1,3*natom-3
    Cpmatr(ivarA,ivarB)=Cmatr(ivarA,ivarB)
   end do
  end do
! now times the eigvecp
  do ivarA=1,3*natom
   do ivarB=1,3*natom
    do ii1=1,3*natom
     Apmatr(ivarA,ivarB)=Apmatr(ivarA,ivarB)+eigvecp(1,ivarA,ii1)*&
&     Cpmatr(ii1,ivarB)
    end do
   end do
  end do

  Cpmatr(:,:)=0.0d0
  do ivarA=1,3*natom
   do ivarB=1,3*natom
    do ii1=1,3*natom
     Cpmatr(ivarA,ivarB)=Cpmatr(ivarA,ivarB)+&
&     Apmatr(ivarA,ii1)*eigvecp(1,ivarB,ii1)
    end do
   end do
  end do

! now the inverse in in Cpmatr
  kmatrix(:,:)=Cpmatr(:,:)
! transfer the inverse of k-matrix back to the k matrix
! so now the inverse of k matrix is in the kmatrix
! ending the part for pseudoinversing the K matrix
! so up to now the pseudoinverse matrix of Kmatrix is obtained in kmatrix
! the do the matrix multiplication Zma*(K)^-1*Znb
  do ivarA=1,3
   idir1=ivarA
   ipert1=natom+2
   do ipert2=1,natom
    do idir2=1,3
     ivarB=idir2+3*(ipert2-1)
     zstar1(ivarA,ivarB)=d2cart_relaxed(1,idir1,ipert1,&
&     idir2,ipert2)
    end do
   end do
  end do

! DEBUG
! write(6,'(/,a,/)')'debug of the zstar1 matrix'
! do varA=1,3
!  write(6,'(6es16.3)')zstar1(ivarA,1),zstar1(ivarA,2),&
!   &zstar1(ivarA,3),zstar1(ivarA,4),&
!   &zstar1(ivarA,5),zstar1(ivarA,6)
! end do
! ENDDEBUG

  zstar2(:,:)=0.0d0
  do ii1=1,3
   do ii2=1,3*natom
    do ivarA=1,3*natom
     zstar2(ii1,ii2)=zstar2(ii1,ii2)+zstar1(ii1,ivarA)*&
&     kmatrix(ivarA,ii2)
    end do
   end do
  end do

  zstar3(:,:)=0.0d0
  do ipert1=1,natom
   do idir1=1,3
    ivarA=idir1+3*(ipert1-1)
    do ivarB=1,3
     idir2=ivarB
     ipert2=natom+2
     zstar3(ivarA,ivarB)=d2cart_relaxed(1,idir1,ipert1,&
&     idir2,ipert2)
    end do
   end do
  end do

  die_correction(:,:)=0.0d0
  do ii1=1,3
   do ii2=1,3
    do ivarA=1,3*natom
     die_correction(ii1,ii2)=die_correction(ii1,ii2)+&
&     zstar2(ii1,ivarA)*zstar3(ivarA,ii2)
    end do
   end do
  end do

! get the corrected relaxed-ion diectric tensor,consider unit cell volume
  do idir1=1,3
   do idir2=1,3
    die_relaxed(idir1,idir2)=d2cart_relaxed(1,idir1,&
&    natom+2,idir2,natom+2)+&
&    die_correction(idir1,idir2)/ucvol
    die_relaxed(idir1,idir2)=four_pi*&
&    die_relaxed(idir1,idir2)
   end do
  end do
! restore the vacume constant 1
  do idir1=1,3
   die_relaxed(idir1,idir1)=1.0d0+&
&   die_relaxed(idir1,idir1)
  end do
  do idir1=1,3
   do idir2=1,3
   end do
   write(message,'(3f16.8)')(die_relaxed(idir1,idir2),idir2=1,3)
   call wrtout(6,message,'COLL')
   call wrtout(iout,message,'COLL')
  end do
  write(iout,'(a)')' '
  write(6,'(a)')' '
! ending the part of adding the relaxed ion electronic dielectric tensor

 end if
! before end give the relaxed ion value to dielt_rlx matrix for later use
  dielt_rlx(:,:)=die_relaxed(:,:)
!(this end if for the if dieflag==1 .or. dieflag==3 .or. dieflag==4)
!***********************************************************************

end subroutine dielmore9
!!***
