!{\src2tex{textfont=tt}}
!!****f* ABINIT/csigme
!! NAME
!! csigme
!!
!! FUNCTION
!! Calculating diagonal matrix elements or all matrix elements of self-energy operator
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (FB, GMR, VO, LR, RWG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  efermi=Fermi energy
!!  en(sp%nk,sp%nb)=KS energies
!!  ep=epsilonm1_parameters (see the definition of this structured datatype)
!!  er=epsilonm1_results (see the definition of this structured datatype)
!!  grottb=(to be described)
!!  gvec(3,npwvec)=integer coordinates of each plane wave in reciprocal space
!!  igfft(npwvec,5,5,5)=index of G-G0 planewaves (see cigfft routine)
!!  jk=k point where to calculate the matrix element (might be redundant with sp)
!!  kbz(3,sp%nkbz)=k-point coordinates, full Brillouin zone
!!  kibz(3,sp%nk)=k-point coordinates, irreducible Brillouin zone
!!  ktab(sp%nkbz)=(to be described)
!!  ktabi(sp%nkbz)=(to be described)
!!  ktabr(sp%nkbz)=(to be described)
!!  minbnd,maxbnd=indices of the lowest and highest bands for which the calculation
!!    of the matrix element is to be done
!!  mpi_enreg=informations about MPI parallelization (to be completed)
!!  ngfft1,ngfft1a,ngfft2,ngfft3=FFT grid dimensions
!!  nop=number of symmetry operations
!!  nr=number of points of FFT grid
!!  occ(sp%nk,sp%nb)=occupation numbers, for each k point in IBZ, and each band
!!  op(3,3,nop)=symmetry operations in reciprocal space
!!  q=q points at which matrix elements must be computed
!!  qbz(3,sp%nqbz)=coordinates of all q points in BZ
!!  qpg(sp%npwx,sp%nq)=|q+G| norm
!!  qtab(sp%nqbz)=(to be described)
!!  qtabi(sp%nqbz)=(to be described)
!!  qtabo(sp%nqbz)=(to be described)
!!  sp=sigma_parameters (see the definition of this structured datatype)
!!  ucvol=unit cell volume
!!  wfr(nr,sp%nb,sp%nk)=wavefunctions in real space
!!
!! OUTPUT
!!  sr=sigma_results (see the definition of this structured datatype)
!!
!! NOTES
!! The treatment of the divergence of Gygi+Baldereschi (PRB 1986) is included.
!! The calculation of energy derivative is based on finite elements.
!!
!! TODO
!! One should eliminate the automatic arrays, and use allocatable ones
!!
!! PARENTS
!!      sigma
!!
!! CHILDREN
!!      calc_coh,calc_sig_noppm,calc_sig_ppm,cgemv,cggfft,diago_hamilt,distrb2
!!      findqg0,mpi_barrier,prep_coh,rho_tw_g,timab,xcomm_init,xmaster_init
!!      xme_init,xsum_mpi
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine csigme(sp,ep,jk,minbnd,maxbnd,&
& q,gvec,npwvec,op,nop,kibz,ktab,ktabr,ktabi,kbz,&
& ngfft1,ngfft1a,ngfft2,ngfft3,igfft,nr,en,occ,qbz,qtab,qtabi,&
& qtabo,qpg,ucvol,grottb,wfr,efermi,&
& er,sr,mpi_enreg,ppmodel,eigpot,b1,b2,b3)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_00basis
 use interfaces_01managempi
 use interfaces_05gw
#else
 use defs_xfuncmpi
#endif
!End of the abilint section

 implicit none
#if defined MPI || defined MPI_FFT
           include 'mpif.h'
#endif

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: jk,maxbnd,minbnd,ngfft1,ngfft1a,ngfft2,ngfft3,nop,npwvec
 integer,intent(in) :: nr,ppmodel
 real(dp),intent(in) :: efermi,ucvol
 type(epsilonm1_parameters),intent(in) :: ep
 type(epsilonm1_results),intent(in) :: er
 type(sigma_parameters),intent(in) :: sp
 type(sigma_results),intent(inout) :: sr
 type(MPI_type),intent(inout) :: mpi_enreg
!arrays
 integer,intent(in) :: grottb(npwvec,2,nop),gvec(3,npwvec),ktab(sp%nkbz)
 integer,intent(in) :: ktabi(sp%nkbz),ktabr(nr,sp%nkbz),qtab(sp%nqbz)
 integer,intent(in) :: qtabi(sp%nqbz),qtabo(sp%nqbz)
 integer,target :: igfft(npwvec,5,5,5)
 real(dp),intent(in) :: en(sp%nk,sp%nb),kbz(3,sp%nkbz),kibz(3,sp%nk),b1(3),b2(3),b3(3)
 real(dp),intent(in) :: occ(sp%nk,sp%nb),op(3,3,nop),q(3,sp%nq),qbz(3,sp%nqbz)
 real(dp),intent(in) :: qpg(sp%npwx,sp%nq)
 complex,intent(in) :: wfr(nr,sp%nb,sp%nk)
 complex,intent(in) :: eigpot(sp%npwc,sp%npwc,sp%nq)

!Local variables ------------------------------
!(To be ordered)
!Warning : there are automatic arrays
! bz_geometry_factor: (see gwa.pdf, appendix A.4)
! sphere=7.79, fcc=7.44, sc=6.188, bcc=6.946, wz=5.255 (Lu Fu-Fa)
! grid on the omega real axis
!For the calculation of the kinetic and
!Coulomb contributions to the bandgap energy.
!scalars
 integer :: ff,i,ib,ig,ig1,iggp,igp,iik,iiq,ik,ikbz,ikibz,io,ioe0j,iop,iopk,npwc1,npwc2
 integer :: iopq,iq,iq0bz,iqbz,iqibz,isless,j,jb,jik,jkbz,jkibz,nomega,nrb,jj
 integer :: theta_fact,tim_fourdp,ii1
 integer :: twofm1,ii,k_index1,k_index2
 real(dp),parameter :: bz_geometry_factor=7.44,domegareal=0.5/Ha_eV
 real(dp) :: a,b,den
 real(dp) :: den_coh,den_sex,domegasi,e0i,e0j,i_sz,imdsigmee0,inv_den
 real(dp) :: kincontrib,omegasi,otw,q0vol,redsigmee0,reomegame0i,smrt,sqrt_i_sz
 real(dp) :: twofm1_zcut,z2,theta_mu_minus_e0i
 complex :: ccoh,csex,ct,dct,dsigc,full_den,idelta,ieta,inv_full_den,num
 complex :: rhotwgdp_igp,sigc,twofm1_idelta,z0,zz,numf
 logical :: cohsex,kinclb,am_master
!arrays
 integer :: g0(3),g01(3),irottb(nr,nop)
 integer,pointer :: igfftg0(:)
 real(dp) :: e0pde(sp%nomegasrd,sp%nb),ki(3),kj(3),kjmki(3),kk(3)
 real(dp) :: qbzpg(sp%npwx)
 real(dp) :: scme(sp%nomegasrd),tsec(2)
 complex :: rhotwg(sp%npwx),rhotwgdpcc(sp%npwx)
 complex :: epsm1q(sp%npwc,sp%npwc,ep%nomega),epsm1q_trcc(sp%npwc,sp%npwc,ep%nomega)
 complex,allocatable :: ket(:,:),sigccoh(:),sigctmp(:),ket1(:,:),ket2(:,:),eig(:,:),rhotwg_1(:,:,:)
 complex,allocatable :: sigckin(:),sigcme_tmp(:,:,:),sigxme_tmp(:,:),sigcsex(:),rhotwgdpccc(:),botsq(:,:)
 real(dp),allocatable :: omegame0i(:),otq(:,:)
 integer:: mband,nbdblock,nkpt,me_loc,nsppol,nsize
!FBruneval: added variables
 integer :: kb
 complex :: rhotwgp(sp%npwx)
 complex :: wfg2(nr,minbnd:maxbnd,minbnd:maxbnd)
 complex :: sigxme,sigsex(sp%npwc),sigcohme
 real(dp),parameter :: tol_empty=0.01 !below this value the state is assumed empty
! complex :: rhotwg_k(sp%npwx,minbnd:maxbnd,sp%nb)
 complex,allocatable :: sigma_phi(:,:),eig_1(:)
 complex,external :: cdotc
 integer,allocatable::iggfft(:,:)
 complex,allocatable::sigcme2(:,:),rhotwg1(:),sum(:),sigcme_3(:)
 character(len=500) :: message
 integer::ierr,spaceComm,me,master
 integer,allocatable:: nband_t(:)
 integer::conv
 complex,allocatable::sigcme_new(:)
!no_abirules
#if defined MPI || defined MPI_FFT
           complex,allocatable::xsum1(:,:,:),xsum2(:,:)
           real(dp),allocatable::xsum3(:,:)
#endif

! *************************************************************************

#ifdef VMS
!DEC$ ATTRIBUTES ALIAS:'CDOTC' :: cdotc
!DEC$ ATTRIBUTES ALIAS:'CGEMV' :: cgemv
#endif

#ifdef VMS
!DEC$ ATTRIBUTES ALIAS:'CDOTC' :: cdotc
!DEC$ ATTRIBUTES ALIAS:'CGEMV' :: cgemv
#endif

!DEBUG
! write(6,*)' csigme : enter ',minbnd,maxbnd
!ENDDEBUG

!These lines added by Shaltaf for parallelization 10/08/05
!parallization is on k points only, one must include the bands
!too in the future
!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifndef HAVE_FORTRAN_INTERFACES
 real(dp) :: linfit
#endif
!End of the abilint section

 allocate(nband_t(sp%nkbz*1))
 nband_t(:)=sp%nb

 mpi_enreg%parareel=0
 mpi_enreg%paralbd=0


 if (mpi_enreg%parareel==0)then
  mpi_enreg%paral_level=2
  ! WARNING! this allocation is never deallocated, see v4/test85.
  allocate(mpi_enreg%proc_distrb(sp%nkbz,sp%nb,1))
  call distrb2(sp%nb,nband_t(:),sp%nkbz,1,mpi_enreg)
 end if

 deallocate(nband_t)

!Init mpi_comm
 call xcomm_init(mpi_enreg,spaceComm)
!Init me
 call xme_init(mpi_enreg,me)
!Init master
 call xmaster_init(mpi_enreg,master)

!End of parallelization initialisation

 if(mod(sp%gwcalctyp,10)==1) write(*,*) 'standard GW with PPM'
 if(mod(sp%gwcalctyp,10)==2) write(*,*) 'standard GW without PPM'
 if(mod(sp%gwcalctyp,10)==5) write(*,*) 'Hartree-Fock calculation'
 if(mod(sp%gwcalctyp,10)==6) write(*,*) 'Screened Exchange calculation'
 if(mod(sp%gwcalctyp,10)==7) write(*,*) 'COHSEX calculation'
 if(mod(sp%gwcalctyp,10)==8) write(*,*) 'model GW with PPM'
 if(mod(sp%gwcalctyp,10)==9) write(*,*) 'model GW without PPM'

 if(sp%gwcalctyp<10) then
  write(*,*) 'Perturbative Calculation'
 else if(sp%gwcalctyp<20) then
  write(*,*) 'Self-Consistent on Energies only'
 else
  write(*,*) 'Self-Consistent on Energies and Wavefunctions'
 end if


 if(sr%nomega/=sp%nomegasr) stop 'internal error nomegasr'

 call timab(421,1,tsec)
 call timab(422,1,tsec)

!These lines added by GMR on 04/05/05 for the calculation
!of the decomposition of the correlation part of sigma into
!Coulomb-hole (coh) and screened-exchange (sex)
 cohsex=.false.
 if(mod(sp%splitsigc,2)==1) cohsex=.true.
!Kinetic (kin) and Coulomb (clb)
 kinclb=.false.
 if(int(sp%splitsigc/2)==1) kinclb=.true.

 tim_fourdp=2
 idelta=cmplx(0,sp%zcut)

 ! analytic integration of q**-2 over the volume element:
 ! \int_V d^3q 1/q^2 = bz_geometric_factor V^(-2/3)
 q0vol=(8* pi*pi*pi)/(ucvol*sp%nkbz) ! V_BZ / N_k
 i_sz = bz_geometry_factor * q0vol**(-two_thirds)
 sqrt_i_sz = sqrt(i_sz)

 nrb=ngfft1*ngfft2*ngfft3 ! FFT factor

!  print info
if(mpi_enreg%me==0)&
& write(6,'(a,/,a,3f8.3,/,a,i3,a,i3,/)') ' calculating <nk|sigma|nk>',&
& ' k = ',(kbz(i,jk),i=1,3),' bands n = from ',minbnd,' to ',maxbnd

 jkbz=jk
 jkibz=ktab(jkbz)
 jik=(3-ktabi(jkbz))/2
 kj(:)=kbz(:,jkbz)
 sr%sigxme(:,jkibz)=0
 sr%sigcme(:,jkibz,:)=0

 ioe0j=sp%nomegasrd/2+1
 do jb=1,sp%nb
   do io=1,sp%nomegasrd
     e0pde(io,jb)=sr%egw(jb,jkibz)+sp%deltae*(io-ioe0j)
     sr%omegasrd(jb,jkibz,io) = e0pde(io,jb)
   end do
 end do

 nomega=sp%nomegasr+sp%nomegasrd
 allocate(sigcme2(nomega,sp%nb),sigcme_3(nomega))
 allocate(omegame0i(nomega))
 allocate(sigcme_tmp(nomega,sp%nb,sp%nb),sigxme_tmp(sp%nb,sp%nb))
 allocate(ket(sp%npwc,nomega),sigctmp(nomega))
 allocate(ket1(sp%npwc,nomega),ket2(sp%npwc,nomega))
 sigcme2(:,:)=zero !zero matrix elements
 sigxme_tmp(:,:)=zero !zero matrix elements
 sigcme_tmp(:,:,:)=zero !zero matrix elements

!These lines added by GMR on 04/05/05 for the calculation
!of the decomposition of the correlation part of sigma into
!Coulomb-hole (coh) and screened-exchange (sex)
 if (cohsex) then
  allocate(sigccoh(sp%nb))
  allocate(sigcsex(sp%nb))
  sigccoh(:)=zero !zero matrix elements
  sigcsex(:)=zero !zero matrix elements
 end if

!These lines added by YMN on 07/04/04 for the calculation
!of the kinetic and Coulomb contributions to the bandgap energy.

 if (kinclb) then
  allocate(sigckin(sp%nb))
  sigckin(:) = 0.d0
 end if

 call timab(422,2,tsec)

 if(mpi_enreg%me==0)write(*,'(" calculation status (",i6," to be completed):")') sp%nkbz

#if defined MPI
           call MPI_BARRIER(spaceComm,ierr)
#endif

 allocate(eig(sp%npwc,sp%npwc))
 allocate(iggfft(npwvec,npwvec))
 call cggfft(npwvec,ngfft1,ngfft2,ngfft3,gvec,iggfft)


!Prepare the static COHSEX calculation:
!calculate the Fourier transform of \phi_j^*(r)\phi_k(r)
 if(mod(sp%gwcalctyp,10)==7)&
&  call prep_coh(sp%nb,nr,wfr(:,:,jkibz),ktabr(:,jkibz),minbnd,maxbnd,&
&                ngfft1,ngfft2,ngfft3,tim_fourdp,wfg2,mpi_enreg)

 allocate(rhotwg_1(sp%npwx,minbnd:maxbnd,sp%nb))

 if(ppmodel==1.or.ppmodel==2)then
  npwc1=sp%npwc;npwc2=sp%npwc
 else if(ppmodel==4)then
 npwc1=sp%npwc;npwc2=1
 else ! for ppmodel3 and noppmodel
  npwc1=1;npwc2=1
 end if

 allocate(botsq(sp%npwc,npwc1),otq(sp%npwc,npwc2))

do ikbz=1,sp%nkbz ! loop over k_i in BZ

! This line added by Shaltaf for parallelization

   if(minval(abs(mpi_enreg%proc_distrb(ikbz,:,:)-mpi_enreg%me))/=0) cycle

   call timab(423,1,tsec)
   if(mpi_enreg%me==0)write(*,'(i3)',advance='yes') ikbz

   write(*,'(i3)',advance='yes') ikbz
   ikibz=ktab(ikbz)
   iik=(3-ktabi(ikbz))/2
   ki(:)=kbz(:,ikbz)

   kjmki(:)=kj(:)-ki(:)
   call findqg0(iq,g0,kjmki,sp%nqbz,qbz) ! identify q and G0 where q+G0=k_j-k_i
   iqibz=qtab(iq)
   iopq=qtabo(iq)
   iiq=(3-qtabi(iq))/2
   igfftg0=>igfft(:,g0(1)+3,g0(2)+3,g0(3)+3)

  if(mod(sp%gwcalctyp,10)==0.or.mod(sp%gwcalctyp,10)==8) then

!calculate plasmonpole parameters for this qBZ (converting from qIBZ to qBZ)


   if(ppmodel==1.or.ppmodel==2)then
   do j=1,sp%npwc
    do i=1,sp%npwc
      botsq(grottb(i,iiq,iopq),grottb(j,iiq,iopq))=er%bigomegatwsq(i,j,iqibz)
      otq(grottb(i,iiq,iopq),grottb(j,iiq,iopq))=er%omegatw(i,j,iqibz)
    end do
   end do
   else if(ppmodel==3)then
   do ii=1,sp%npwc         !! ii: DM bands
    otq(ii,1)=er%omegatw(ii,1,iqibz)
    botsq(ii,1)=er%bigomegatwsq(ii,1,iqibz)
     do j=1,sp%npwc
      eig(grottb(j,iiq,iopq),ii)=eigpot(j,ii,iqibz)
    end do
   end do
   else if(ppmodel==4)then
    do ii=1,sp%npwc     !! ii: DM bands
     otq(ii,1)=er%omegatw(ii,1,iqibz)
    do j=1,sp%npwc
      botsq(grottb(j,iiq,iopq),ii)=er%bigomegatwsq(j,ii,iqibz) ! ii is the band index of DM
    end do
   end do
  end if

   if(iiq==2)then
   botsq(:,:)=conjg(botsq(:,:))
   eig(:,:)=conjg(eig(:,:))
   end if

  else if(mod(sp%gwcalctyp,10)==2.or.mod(sp%gwcalctyp,10)==9) then
   do io=1,ep%nomega
    do i=1,sp%npwc
     do j=1,sp%npwc
      epsm1q(grottb(i,iiq,iopq),grottb(j,iiq,iopq),io)=er%epsm1(i,j,io,iqibz)
     end do
    end do
   end do
   if(iiq==2) epsm1q(:,:,:)=conjg(epsm1q(:,:,:))
! minus exchange contribution
   do io=1,ep%nomega
    do i=1,sp%npwc
      epsm1q(i,i,io)=epsm1q(i,i,io)-1.
    end do
   end do
  else if(mod(sp%gwcalctyp,10)==6.or.mod(sp%gwcalctyp,10)==7) then  ! SEX or COHSEX
!only the \omega=0 is needed here
   do i=1,sp%npwc
    do j=1,sp%npwc
     epsm1q(grottb(i,iiq,iopq),grottb(j,iiq,iopq),1)=er%epsm1(i,j,1,iqibz)
    end do
   end do
   if(iiq==2) epsm1q(:,:,1)=conjg(epsm1q(:,:,1))

!minus exchange contribution
   do i=1,sp%npwc
     epsm1q(i,i,1)=epsm1q(i,i,1)-1.
   end do
  end if

!create transpose(conjg(epsm1q))
  if(mod(sp%gwcalctyp,10)==9) then
   do io=1,ep%nomega
    epsm1q_trcc(:,:,io)=transpose(conjg(epsm1q(:,:,io)))
   end do
  end if

!  set up table of |q+G| in BZ
   do ig=1,sp%npwx
     qbzpg(grottb(ig,iiq,iopq))=qpg(ig,iqibz)
   end do


   call timab(423,2,tsec)
! the following lines commented by Rshaltaf and moved down for
! saving memory rhotwg_k(npwx,min:max,nb) is a huge matrix
! dont you think that Fabian??

!   do ib=1,sp%nb
!!skip empty state ib for HF, SEX, and COHSEX
!    if(occ(ikibz,ib)<tol_empty.and.&
!&      (mod(sp%gwcalctyp,10)==5.or.mod(sp%gwcalctyp,10)==6&
!&       .or.mod(sp%gwcalctyp,10)==7)) cycle
!
!     do jb=minbnd,maxbnd
!!calculate all rho-twiddle(G) at once
!      call rho_tw_g(sp%npwx,nr,nrb,ngfft1a,ngfft1,ngfft2,ngfft3,igfftg0,&
!&                   wfr(:,ib,ikibz),iik,ktabr(:,ikbz),wfr(:,jb,jkibz),jik,ktabr(:,jkbz),&
!&                   rhotwg_k(:,jb,ib),tim_fourdp)
!divide rho-twiddle(G) by |q+G|
!      rhotwg_1(:,jb,ib)=rhotwg_k(:,jb,ib)
!      rhotwg_k(:,jb,ib)=rhotwg_k(:,jb,ib)/qbzpg(:)
!treat analytically the case q->0
!     if(ikbz==jkbz) then
!     if(ib==jb) then
!      rhotwg_k(1,jb,ib)=sqrt_i_sz
!     else
!      rhotwg_k(1,jb,ib)=0 !  ignore always
!     end if
!    end if

 do ib=1,sp%nb
!skip empty state ib for HF, SEX, and COHSEX
    if(occ(ikibz,ib)<tol_empty.and.&
&      (mod(sp%gwcalctyp,10)==5.or.mod(sp%gwcalctyp,10)==6&
&       .or.mod(sp%gwcalctyp,10)==7)) cycle

     e0i=en(ikibz,ib)
     theta_mu_minus_e0i=0.5*occ(ikibz,ib)

     if(sp%nomegasr>0) omegame0i(1:sr%nomega)=real(sr%omega(1:sr%nomega))-e0i


     do kb=minbnd,maxbnd

      call rho_tw_g(sp%npwx,nr,nrb,ngfft1a,ngfft1,ngfft2,ngfft3,igfftg0,&
&                   wfr(:,ib,ikibz),iik,ktabr(:,ikbz),wfr(:,kb,jkibz),jik,ktabr(:,jkbz),&
&                   rhotwgp(:),tim_fourdp)
      rhotwgp(:)=rhotwgp(:)/qbzpg(:)
!treat analytically the case q->0
      if(ikbz==jkbz) then
       if(ib==kb) then
        rhotwgp(1)=sqrt_i_sz
       else
        rhotwgp(1)=0
       end if
      end if

      call timab(424,1,tsec)

      do io=sp%nomegasr+1,nomega
       omegame0i(io) = real(sr%omegasrd(kb,jkibz,io-sp%nomegasr)) - e0i
      end do

!     rhotwgp(:)=rhotwg_k(:,kb,ib)

!First calculate the ket  \Sigma | \phi_k >

      ket(:,:)=0
      ket1(:,:)=0
      ket2(:,:)=0

      if(mod(sp%gwcalctyp,10)==0) then
! GW calculation WITH Plasmon-Pole Model
       call calc_sig_ppm(sp%npwc,nomega,rhotwgp,botsq,otq,omegame0i,sp%zcut,&
&       theta_mu_minus_e0i,ket,ppmodel,eig,sigcme_3,sp%npwx,npwc1,npwc2)
       if(ppmodel==3.or.ppmodel==4)then
        sigcme2(:,kb)=sigcme2(:,kb)+sigcme_3(:) ! only relevant if ppm3 or ppm4
       end if

      else if(mod(sp%gwcalctyp,10)==2) then
! GW calculation numerical integration
       call calc_sig_noppm(sp%npwc,nomega,ep%nomega,ep%nomegaer,ep%nomegaei,rhotwgp(1:sp%npwc),&
&                          er%omega,epsm1q,omegame0i,theta_mu_minus_e0i,ket)

      else if(mod(sp%gwcalctyp,10)==6.or.mod(sp%gwcalctyp,10)==7) then

       call cgemv('N',sp%npwc,sp%npwc,(1.,0.),epsm1q(:,:,1),sp%npwc,rhotwgp(1:sp%npwc),1,(0.,0.),sigsex,1)
       sigsex(:)=-theta_mu_minus_e0i*sigsex(:)

!static SEX is energy independent
       do io=1,nomega
        ket(:,io)=sigsex(:)
       end do

      else if(mod(sp%gwcalctyp,10)==8) then
! MODEL GW calculation WITH Plasmon-Pole Model
!calculate \Sigma(E_k) | k > to obtain < j | \Sigma(E_k) | k >
         allocate(sigcme_new(nomega))
         call calc_sig_ppm(sp%npwc,nomega,rhotwgp(1:sp%npwc),botsq,otq,omegame0i,sp%zcut,&
&                         theta_mu_minus_e0i,ket1,ppmodel,eig,sigcme_new,sp%npwx,npwc1,npwc2)
         !calculate < k | \Sigma(E_k) to obtain < k | \Sigma(E_k) | j >^*
         if(sp%gwcalctyp==28) then
            call calc_sig_ppm(sp%npwc,nomega,rhotwgp(1:sp%npwc),conjg(transpose(botsq(:,:))),&
&        transpose(otq(:,:)),omegame0i,sp%zcut,theta_mu_minus_e0i,ket2,ppmodel,eig,sigcme_3,sp%npwx,npwc1,npwc2)
            ket(:,:)=(ket1(:,:)+ket2(:,:))*0.5
         else
            ket(:,:)=ket1(:,:)
         end if
         deallocate(sigcme_new)
      else if(mod(sp%gwcalctyp,10)==9) then
! MODEL GW calculation numerical integration
!calculate \Sigma(E_k) | k > to obtain < j | \Sigma(E_k) | k >
       call calc_sig_noppm(sp%npwc,nomega,ep%nomega,ep%nomegaer,ep%nomegaei,rhotwgp(1:sp%npwc),&
&                          er%omega,epsm1q,omegame0i,theta_mu_minus_e0i,ket1)
!calculate < k | \Sigma(E_k) to obtain < k | \Sigma(E_k) | j >^*
       if(sp%gwcalctyp==29) then
        call calc_sig_noppm(sp%npwc,nomega,ep%nomega,ep%nomegaer,ep%nomegaei,rhotwgp(1:sp%npwc),&
&                           er%omega,epsm1q_trcc,omegame0i,theta_mu_minus_e0i,ket2)
        ket(:,:)=(ket1(:,:)+ket2(:,:))*0.5
       else
        ket(:,:)=ket1(:,:)
       end if

      end if

!FBruneval 05/12/15
!we could use hermitianity for HF, SEX, COHSEX
!to reduce next loop to:   do jb=minbnd,kb
      do jb=minbnd,maxbnd
!check self-consistent or not?
       if(sp%gwcalctyp<20.and.jb/=kb) cycle
       call rho_tw_g(sp%npwx,nr,nrb,ngfft1a,ngfft1,ngfft2,ngfft3,igfftg0,&
&                   wfr(:,ib,ikibz),iik,ktabr(:,ikbz),wfr(:,jb,jkibz),jik,ktabr(:,jkbz),&
&                   rhotwg(:),tim_fourdp)
     rhotwg(:)=rhotwg(:)/qbzpg(:)
!treat analytically the case q->0
    if(ikbz==jkbz) then
       if(ib==jb) then
      rhotwg(1)=sqrt_i_sz
      else
      rhotwg(1)=0
      end if
      end if

!       rhotwg(:)=rhotwg_k(:,jb,ib)

!Second calculate the bra ket < \phi_j | \Sigma | \phi_k >
       do io=1,nomega
        sigctmp(io) = cdotc(sp%npwc,rhotwg(1:sp%npwc),1,ket(:,io),1)
       end do

!Set up bare exchange matrix element
!must be multiplied later by 4*PI/(ucvol*nkbz)
       sigxme=-cdotc(sp%npwx,rhotwg,1,rhotwgp,1)*theta_mu_minus_e0i
       sigxme_tmp(jb,kb) = sigxme_tmp(jb,kb) + sigxme

       call timab(424,2,tsec)
       call timab(425,1,tsec)

!the static COH is calculated only once, since it is independent with respect to
!the band index ib
       if(mod(sp%gwcalctyp,10)==7.and.ib==1) then
        call calc_coh(nr,sp%npwx,sp%npwc,ngfft1a,ngfft1,ngfft2,ngfft3,&
&                     gvec,epsm1q(:,:,1),qbzpg,i_sz,iqibz,jb,kb,wfg2(:,jb,kb),sigcohme)
!static COH is energy independent
        sigctmp(:)=sigctmp(:)+sigcohme
       end if


!must be multiplied later by 4*PI/(ucvol*nkbz)
       sigcme_tmp(:,jb,kb) = sigcme_tmp(:,jb,kb) + sigctmp(:)

!These lines added by GMR on 04/05/05 for the calculation
!of the decomposition of the correlation part of sigma into
!Coulomb-hole (coh) and screened-exchange (sex)
         if(theta_mu_minus_e0i>0.5) then
          ff=1
         else
          ff=0
         end if
         twofm1=2*ff-1
         twofm1_zcut=twofm1*sp%zcut
         twofm1_idelta=twofm1*idelta
!      Now, introduce rhotwgdpcc, for speed reasons
         rhotwgdpcc(:)=conjg(rhotwg(:))
         reomegame0i=omegame0i(ioe0j)
         if ((cohsex).and.(io == sr%nomega+ioe0j)) then
          ccoh=0
          csex=0
          do igp = 1, sp%npwc
           rhotwgdp_igp=rhotwg(igp)
           do ig = 1, sp%npwc
            if(ppmodel==3.and.ig/=igp)cycle
            otw=dble(otq(ig,igp)) ! in principle otw -> otw - ieta
            num = rhotwgdpcc(ig)*botsq(ig,igp)*rhotwgdp_igp

            den_coh = reomegame0i-otw
            if(den_coh**2>sp%zcut**2)then
             ccoh = ccoh + num / (den_coh * otw)
            else ! if den is small
             ccoh = ccoh + num*cmplx(den_coh,twofm1_zcut)/ &
&                         ((den_coh**2+twofm1_zcut**2)*otw)
            end if

            den_sex = reomegame0i**2-otw**2
            if(den_sex**2>sp%zcut**2)then
             csex = csex - 2 * ff * num / den_sex
            else ! if den is small
             csex = csex - 2*ff*num*cmplx(den_sex,twofm1_zcut)/ &
&                           ((den_sex**2+twofm1_zcut**2)*otw)
            end if

           end do
          end do
!         Must be multiplied later by 4*pi/(ucvol*nkbz).
          sigccoh(jb) = sigccoh(jb) + ccoh / 2.0d0
          sigcsex(jb) = sigcsex(jb) + csex / 2.0d0
         end if

!Added by YMN on 07/04/04.
!Calculation of the kinetic contribution to the bandgap energy.

!         if ((kinetic).and.(io == sr%nomega+ioe0j)) then
!!         print *,' omega = ',sr%omegasrd(jb,jkibz,io-sp%nomegasr)
!          do igp = 1, sp%npwc
!           do ig = 1, sp%npwc
!            dct = 0.d0
!            do ig1 = 1, sp%npwc
!             call fkin(ff,kincontrib,reomegame0i,otq(ig,ig1),otq(ig1,igp),sp%zcut)
!             dct = dct+botsq(ig,ig1)*botsq(ig1,igp)*kincontrib
!            end do
!            ct = ct-rhotwgdpcc(ig)*dct*rhotwg(igp)
!           end do
!          end do
!          sigckin(jb) = sigckin(jb)-ct/2.d0  !Must be multiplied later by 4*pi/(ucvol*nkbz).
!         end if
!
!        end do

       call timab(425,2,tsec)
      end do ! jb

! shaltaf (030406): this has to be done in a clean way later
       if(mod(sp%gwcalctyp,10)==0) then
        if(ppmodel==3.or.ppmodel==4)then
         sigcme_tmp(:,kb,kb)=sigcme2(:,kb)
        end if
       end if
     end do ! kb
   end do ! ib
 end do !ikbz

 deallocate(sigcme2,sigcme_3)


!! These lines added by Shaltaf for parallelization 10/08/05
!! modefied by shaltaf 01/03/06
!! Rewritten using upper level primitives by XG 20060628
 call xsum_mpi(sigcme_tmp,spaceComm,ierr)
 call xsum_mpi(sigxme_tmp,spaceComm,ierr)

!#          if defined MPI
!  if(mpi_enreg%nproc>1)then       ! collect data from proccessors
!  call MPI_BARRIER(spaceComm,ierr)
!  allocate(xsum1(nomega,sp%nb,sp%nb))
!  call MPI_REDUCE(sigcme_tmp,xsum1,nomega*sp%nb*sp%nb,MPI_COMPLEX,&
!          &  MPI_SUM,master,spaceComm,ierr)
!  sigcme_tmp(:,:,:)=xsum1(:,:,:)
!  deallocate(xsum1)
!  allocate(xsum2(sp%nb,sp%nb))
!  call MPI_REDUCE(sigxme_tmp,xsum2,sp%nb*sp%nb,MPI_COMPLEX,&
!          &  MPI_SUM,master,spaceComm,ierr)
!  sigxme_tmp(:,:)=xsum2(:,:)
!  deallocate(xsum2)
!  end if
!#          end if

! parallelization ends here

 call timab(426,1,tsec)

! multiply by constants
  sigxme_tmp(:,:)=(4*pi/(ucvol*sp%nkbz))*sigxme_tmp(:,:)
  sigcme_tmp(:,:,:)=(4*pi/(ucvol*sp%nkbz))*sigcme_tmp(:,:,:)

! if non self-consistent, erase all off-diagonal elements
  if(sp%gwcalctyp<20) then
   do jb=minbnd,maxbnd
    do kb=minbnd,maxbnd
     if(jb==kb) cycle
     sr%hhartree(jb,kb,jkibz)=0
    end do
   end do
  end if

  call diago_hamilt(minbnd,maxbnd,sr%hhartree(minbnd:maxbnd,minbnd:maxbnd,jkibz),&
&  sigxme_tmp(minbnd:maxbnd,minbnd:maxbnd),sigcme_tmp(sr%nomega+ioe0j,minbnd:maxbnd,minbnd:maxbnd),&
&  sr%eigvec_qp(minbnd:maxbnd,minbnd:maxbnd,jkibz),sr%en_qp_diago(minbnd:maxbnd,jkibz))

 do jb=minbnd,maxbnd

! bare exchange diagonal element
  sr%sigxme(jb,jkibz) = real(sigxme_tmp(jb,jb))
! correlation matrix elements calculated at energy E0
  sr%sigcmee0(jb,jkibz)=sigcme_tmp(sr%nomega+ioe0j,jb,jb)
! the values of SigC are linearly interpolated
! and the fit parameter a is assumed as derivative dSigC/dE
  scme(:)=real(sigcme_tmp(sr%nomega+1:sr%nomega+sp%nomegasrd,jb,jb))
  e0pde(:,jb)=sr%omegasrd(jb,jkibz,:)
  if(sp%nomegasrd==1) then
   smrt=0.
   a=0.
  else
   smrt=linfit(sp%nomegasrd,e0pde(:,jb),scme(:),a,b)
  end if
  if( smrt>0.1/Ha_eV) then
   write(*,*) '**WARNING: the values of Re sigc are not linear'
   write(*,*) smrt,a
   write(*,*) 'jb = ',jb,scme(:)*Ha_eV
  end if
  sr%dsigmee0(jb,jkibz)=cmplx(a,0)
! calculate Z = ( 1 - dSigma/domega(E0) )^-1
  sr%ze0(jb,jkibz) = 1 / ( 1 - sr%dsigmee0(jb,jkibz) )
! calculate DeltaE_GW = E - E0 = (Sigma(E0) - V_xc) / (1 - dSigma/domega)
  sr%degw(jb,jkibz) = ( sr%sigxme(jb,jkibz)+sr%sigcmee0(jb,jkibz)-sr%e0(jb,jkibz)+sr%hhartree(jb,jb,jkibz) ) / &
&                      ( 1 - sr%dsigmee0(jb,jkibz) )
  sr%egw(jb,jkibz) = sr%e0(jb,jkibz) + sr%degw(jb,jkibz)
! calculate Sigma(E) = Sigma(E0) + (E-E0) dSigma/dE
  sr%sigmee(jb,jkibz) = sr%sigxme(jb,jkibz)+sr%sigcmee0(jb,jkibz) + &
&                        sr%degw(jb,jkibz) * sr%dsigmee0(jb,jkibz)

! spectra of Sigma
  do io=1,sr%nomega
   sr%sigcme(jb,jkibz,io) = sigcme_tmp(io,jb,jb)
   sr%sigxcme(jb,jkibz,io) = sr%sigxme(jb,jkibz) + sr%sigcme(jb,jkibz,io)
  end do

  do io=1,sp%nomegasrd
   sr%sigcmesrd(jb,jkibz,io) = sigcme_tmp(sr%nomega+io,jb,jb)
   sr%sigxcmesrd(jb,jkibz,io) = sr%sigxme(jb,jkibz) + sr%sigcmesrd(jb,jkibz,io)
  end do

  write (6,'(i5,9f8.3)') jb,sr%e0(jb,jkibz)*Ha_eV,&
&  sr%vxcme(jb,jkibz)*Ha_eV,sr%sigxme(jb,jkibz)*Ha_eV,&
&  real(sr%sigcmee0(jb,jkibz))*Ha_eV,&
&  real(sr%ze0(jb,jkibz)),real(sr%dsigmee0(jb,jkibz)),&
&  real(sr%sigmee(jb,jkibz))*Ha_eV,&
&  real(sr%degw(jb,jkibz))*Ha_eV,real(sr%egw(jb,jkibz))*Ha_eV
  write (6,'(i5,9f8.3)') jb,0.0,0.0,0.0,&
&  aimag(sr%sigcmee0(jb,jkibz))*Ha_eV,&
&  aimag(sr%ze0(jb,jkibz)),aimag(sr%dsigmee0(jb,jkibz)),&
&  aimag(sr%sigmee(jb,jkibz))*Ha_eV,&
&  aimag(sr%degw(jb,jkibz))*Ha_eV,aimag(sr%egw(jb,jkibz))*Ha_eV

 end do


!These lines added by GMR on 04/05/05 for the calculation
!of the decomposition of the correlation part of sigma into
!Coulomb-hole (coh) and screened-exchange (sex)
 if (cohsex) then
  sigccoh(:)=(4*pi/(ucvol*sp%nkbz))*sigccoh(:)
  sigcsex(:)=(4*pi/(ucvol*sp%nkbz))*sigcsex(:)
  write (6,'(/,a)') " COH and SEX decomposition of Sig_c(E0) (eV):"
  write (6,'(a5,3a10)') " band","     Sig_c","   Sig_coh","   Sig_sex"

  do jb = minbnd,maxbnd

   write (6,'(i5,3f10.5," (Re)")') jb,real(sr%sigcmee0(jb,jkibz))*Ha_eV, &
&                                     real(sigccoh(jb))*Ha_eV, &
&                                     real(sigcsex(jb))*Ha_eV

   write (6,'(5x,3f10.5," (Im)")') aimag(sr%sigcmee0(jb,jkibz))*Ha_eV, &
&                                  aimag(sigccoh(jb))*Ha_eV, &
&                                  aimag(sigcsex(jb))*Ha_eV

  end do
 end if

!These lines added by YMN on 07/04/04 for the calculation
!of the kinetic and Coulomb contributions to the bandgap energy.

 if (kinclb) then

  sigckin(:) = (4.d0*pi/(ucvol*sp%nkbz))*sigckin(:)

  write (6,'(/,a)') " Kinetic and Coulomb contributions to Sig_c(E0) (eV):"
  write (6,'(a5,3a10)') " band","     Sig_c","   Sig_c^k","   Sig_c^c"

  do jb = minbnd,maxbnd

   write (6,'(i5,3f10.5," (Re)")') jb,real(sr%sigcmee0(jb,jkibz))*Ha_eV, &
&                                     real(sigckin(jb))*Ha_eV, &
&                                    (real(sr%sigcmee0(jb,jkibz))-real(sigckin(jb)))*Ha_eV

   write (6,'(5x,3f10.5," (Im)")') aimag(sr%sigcmee0(jb,jkibz))*Ha_eV, &
&                                  aimag(sigckin(jb))*Ha_eV, &
&                                 (aimag(sr%sigcmee0(jb,jkibz))-aimag(sigckin(jb)))*Ha_eV

  end do

  deallocate(sigckin)

 end if

 call timab(426,2,tsec)
 call timab(421,2,tsec)

 deallocate(omegame0i,sigcme_tmp,ket,ket1,ket2,otq,botsq)
 ! on suggestion by Deyu Lu (PMA)
 if(allocated(sigctmp)) deallocate(sigctmp )
 if(allocated(sigccoh )) deallocate(sigccoh )
 if(allocated(sigcsex )) deallocate(sigcsex )
 if(allocated(eig )) deallocate(eig )
 if(allocated(iggfft )) deallocate(iggfft )
 if(allocated(rhotwg_1 )) deallocate(rhotwg_1 )
 !  allocate(mpi_enreg%proc_distrb(sp%nkbz,sp%nb,1)) is not deallocated. 
 ! Don't know if this is a feature or a bug (PMA)
!DEBUG
!write(6,*)' csigme : exit '
!ENDDEBUG

end subroutine csigme
!!***
