!{\src2tex{textfont=tt}}
!!****f* ABINIT/ctocprj
!! NAME
!! ctocprj
!!
!! FUNCTION
!! 1) Compute all <Proj_i|Cnk> for every wave function |Cnk> expressed
!!    in reciprocal space.
!!    |Proj_i> is a non-local projector (for each atom and each l,m,n)
!!
!! COPYRIGHT
!! Copyright (C) 1998-2005 ABINIT group (MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  atindx(natom)=index table for atoms
!!  cg(2,mpw*nspinor*mband*mkmem*nsppol)=planewave coefficients of wavefunctions
!!  dtfil <type(datafiles_type)>=variables related to files
!!  dtset <type(dataset_type)>=all input variables for this dataset
!!  gmet(3,3)=reciprocal space metric tensor in bohr**-2
!!  gprimd(3,3)=dimensional reciprocal space primitive translations
!!  kg(3,mpw*mkmem)=reduced planewave coordinates
!!  mband=maximum number of bands
!!  mgfft=maximum size of 1D FFTs
!!  mkmem=number of k points which can fit in memory; set to 0 if use disk
!!  mpi_enreg=informations about MPI parallelization
!!  mpj=total number of non-local projectors
!!  mpsang=1+maximum angular momentum for nonlocal pseudopotentials
!!  mpw=maximum dimensioned size of npw
!!  natom=number of atoms in cell
!!  nattyp(ntypat)= # atoms of each type
!!  nkpt=number of k points
!!  npwarr(nkpt)=number of planewaves in basis at this k point
!!  nspinor=number of spinorial components of the wavefunctions
!!  nsppol=1 for unpolarized, 2 for spin-polarized
!!  ntypat=number of types of atoms in unit cell
!!  ph1d(2,3*(2*mgfft+1)*natom)=1-dim structure factor phase information
!!  psps <type(pseudopotential_type)>=variables related to pseudopotentials
!!  rmet(3,3)=real space metric (bohr**2)
!!  tim_ctocprj=timing code of the calling routine
!!  wffnow=struct infos for wf disk file
!!  xred(3,natom)=reduced dimensionless atomic coordinates
!!  ylm(mpw*mkmem,mpsang*mpsang)=real spherical harmonics for each G and k point
!!
!! OUTPUT
!!  cp(2,mpj*nspinor,mband*mkmem*nsppol)=<Proj_i|Cnk> scalars (projected wave functions)
!!
!! PARENTS
!!      optics_paw
!!
!! CHILDREN
!!      getcprj,leave_new,leave_test,mkffnl,ph1d3d,status,wrtout,xcomm_init
!!      xmaster_init,xme_init
!!
!! SOURCE

 subroutine ctocprj(atindx,cg,cp,dtfil,dtset,gmet,gprimd,kg,mband,mgfft,mkmem,mpi_enreg,mpj,mpsang,&
&                   mpw,natom,nattyp,nkpt,npwarr,nspinor,nsppol,ntypat,ph1d,psps,rmet,&
&                   xred,ylm,ucvol)
!VR
!&                   tom_ctocprj,wffnow,xred,ylm)

 use defs_basis
 use defs_datatypes
#          if defined NETCDF
 use netcdf
#          endif

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_01util
 use interfaces_03nonlocal
#endif
!End of the abilint section

 implicit none

!Arguments -------------------------------
!scalars
 integer,intent(in) :: mband,mgfft,mkmem,mpj,mpsang,mpw,natom,nkpt,nspinor,nsppol,ntypat
 real(dp),intent(in) :: ucvol
 type(datafiles_type),intent(in) :: dtfil
 type(dataset_type),intent(in) :: dtset
 type(MPI_type),intent(inout) :: mpi_enreg
 type(pseudopotential_type),intent(in) :: psps
!arrays
 integer,intent(in) :: atindx(natom),nattyp(ntypat),npwarr(nkpt),kg(3,mpw*mkmem)
 real(dp),intent(in) :: cg(2,mpw*nspinor*mband*mkmem*nsppol)
 real(dp),intent(in) :: gmet(3,3),gprimd(3,3),ph1d(2,3*(2*mgfft+1)*natom),rmet(3,3)
 real(dp),intent(in) :: ylm(mpw*mkmem,mpsang*mpsang),xred(3,natom)
 real(dp),intent(out) :: cp(2,mpj*nspinor*mband*mkmem*nsppol)

!Local variables-------------------------------
!scalars
 integer,parameter :: level=7
 integer :: counter,dimffnl,formeig,ia,ia1,iband,icg,icgb,icp,icpb,ider,ierr
 integer :: iexit,ig,ikg,ikpt,ilm,ip,isppol,istwf_k,master,matblk,mcg_disk,mcp_disk
 integer :: me,muig,nband_k,nkpg,npw_k,SpaceComm,tim_rwwf
 real(dp) :: arg,wt,wt_tr
 character(len=500) :: message
 real(dp),parameter :: ili(7)=(/1.d0,-1.d0,0.d0,1.d0,0.d0,-1.d0,0.d0/)
 real(dp),parameter :: ilr(7)=(/0.d0,0.d0,-1.d0,0.d0,1.d0,0.d0,-1.d0/)
!arrays
 integer,allocatable :: kg_dum(:,:),kg_k(:,:)
 real(dp) :: kpoint(3),tsec(2),ylmgr_dum(1)
 real(dp),allocatable :: cg_disk(:,:),cp_disk(:,:),cwavef(:,:),cwavep(:,:)
 real(dp),allocatable :: eig_dum(:), ffnl(:,:,:,:),kpg_dum(:,:)
 real(dp),allocatable :: occ_dum(:),ph3d(:,:,:),phkxred(:,:),ylm_k(:,:)

! *********************************************************************

!DEBUG
! write(6,*)' ctocprj : enter'
!ENDDEBUG

 wt=four_pi/sqrt(ucvol)
 if (psps%useylm==0) then
  write(message, '(4a)' ) ch10,&
&  ' ctocprj : ERROR -',ch10,&
&  '  Not yet available for useylm=0 !'
  call wrtout(06,message,'PERS')
  call leave_new('PERS')
 end if

! call timab(561+tim_ctocprj,1,tsec)
 call status(0,dtfil%filstat,iexit,level,'enter         ')

!Init parallelism
 call xcomm_init(mpi_enreg,spaceComm)
 call xme_init(mpi_enreg,me)
 call xmaster_init(mpi_enreg,master)

!Initialize some variables
 icg=0;icp=0
!VR
! if (mkmem==0) then
!  mcg_disk=mpw*nspinor*mband
!  mcp_disk=mpj*nspinor*mband
! end if

!VR
!Prepare temporary files if mkmem==0
! if (mkmem==0) then
! Read wffnow header
!  call hdr_skip(wffnow,ierr)
! Define offsets, in case of MPI I/O
!  formeig=0
!  call xdefineOff(formeig,wffnow,mpi_enreg,dtset%nband,npwarr,nspinor,nsppol,nkpt)
! Rewind temporary file <P|c>
!  rewind(dtfil%unwfp1)
! Allocate the work space
!  allocate(cg_disk(2,mcg_disk))
!  allocate(cp_disk(2,mcp_disk))
! end if

!LOOP OVER SPINS
 do isppol=1,nsppol
  ikg=0

!VR
! Rewind temporary files if needed
!  if (mkmem==0) rewind(dtfil%unkg)
!  if (mkmem==0) rewind(dtfil%unylm)

! BIG FAT k POINT LOOP
  do ikpt=1,nkpt

   counter=100*ikpt+isppol
   call status(counter,dtfil%filstat,iexit,level,'loop ikpt     ')
   nband_k=dtset%nband(ikpt+(isppol-1)*nkpt)
   istwf_k=dtset%istwfk(ikpt)
   npw_k=npwarr(ikpt)

   if(mpi_enreg%paral_compil_kpt==1)then
    if (mpi_enreg%parareel == 0) then
     if(minval(abs(mpi_enreg%proc_distrb(ikpt,1:nband_k,isppol)-mpi_enreg%me))/=0) cycle
    else
     if(mpi_enreg%proc_distrb_para(mpi_enreg%ipara,ikpt)/=mpi_enreg%me) cycle
    end if
   end if

   allocate(ylm_k(npw_k,mpsang*mpsang),kg_k(3,npw_k))
   allocate(cwavef(2,npw_k*nspinor),cwavep(2,mpj*nspinor*natom))

   kpoint(:)=dtset%kptns(:,ikpt)
   if (istwf_k>1) then
     wt_tr=2.d0*wt
   else
     wt_tr=wt
   endif

!VR
!   if (mkmem==0) then
!   Read (k+G) basis sphere data (same for each spin)
!    call rdnpw(ikpt,isppol,nband_k,npw_k,nspinor,0,dtfil%unkg)
!   Read k+g data
!    read (dtfil%unkg) kg_k(1:3,1:npw_k)
!   Read spherical harmonics
!    read(dtfil%unylm)
!    read(dtfil%unylm) ((ylm_k(muig,ilm),muig=1,npw_k),ilm=1,mpsang*mpsang)
!   Read the wavefunction block for ikpt,isppol
!    call status(counter,dtfil%filstat,iexit,level,'read wfs      ')
!    tim_rwwf=1;allocate(eig_dum(mband),kg_dum(3,0),occ_dum(mband))
!    call rwwf(cg_disk,eig_dum,0,0,0,ikpt,isppol,kg_dum,mband,mcg_disk,nband_k,nband_k,&
!&    npw_k,nspinor,occ_dum,-2,0,tim_rwwf,wffnow)
!    deallocate(kg_dum)
!
!   else
    kg_k(:,1:npw_k)=kg(:,1+ikg:npw_k+ikg)
    do ilm=1,mpsang*mpsang
     ylm_k(1:npw_k,ilm)=ylm(1+ikg:npw_k+ikg,ilm)
    end do

!  End if for choice governed by mkmem
!   end if

!  Allocate and compute the arrays phkxred and ph3d
   allocate(phkxred(2,natom))
   do ia=1,natom
    ia1=atindx(ia)
    arg=two_pi*(kpoint(1)*xred(1,ia)+kpoint(2)*xred(2,ia)+kpoint(3)*xred(3,ia))
    phkxred(1,ia1)=cos(arg);phkxred(2,ia1)=sin(arg)
   end do
   if(dtset%nloalg(1)<=0)then
!   Here, only the allocation of ph3d , not the precomputation
    matblk=dtset%nloalg(4);allocate(ph3d(2,npw_k,matblk))
   else
!   Here, allocation as well as precomputation
    matblk=natom;allocate(ph3d(2,npw_k,matblk))
    call ph1d3d(1,natom,kg_k,kpoint,matblk,natom,npw_k,dtset%ngfft(1),&
&               dtset%ngfft(2),dtset%ngfft(3),phkxred,ph1d,ph3d)
   end if

!  Compute nonlocal form factors ffnl at all (k+G)
   call status(0,dtfil%filstat,iexit,level,'call mkffnl   ')
   ider=0;dimffnl=1;nkpg=0
   allocate(ffnl(npw_k,dimffnl,psps%lmnmax,ntypat))
   call mkffnl(psps%dimekb,dimffnl,psps%ekb,ffnl,psps%ffspl,&
&   gmet,gprimd,ider,ider,psps%indlmn,kg_k,kpg_dum,kpoint,psps%lmnmax,&
&   psps%lnmax,psps%mpsang,psps%mqgrid_ff,nkpg,npw_k,ntypat,&
&   psps%pspso,psps%qgrid_ff,rmet,psps%usepaw,psps%useylm,ylm_k,ylmgr_dum)

!  Loop over bands
   icgb=icg;icpb=icp
   do iband=1,nband_k

!VR
!   Extract wavefunction information
!    if (mkmem==0) then
!$OMP PARALLEL DO PRIVATE(ig) &
!$OMP&SHARED(cg_disk,cwavef,icgb,npw_k,nspinor)
!     do ig=1,npw_k*nspinor
!      cwavef(1,ig)=cg_disk(1,ig+icgb)
!      cwavef(2,ig)=cg_disk(2,ig+icgb)
!     end do
!$OMP END PARALLEL DO
!   else
!$OMP PARALLEL DO PRIVATE(ig) &
!$OMP&SHARED(cg,cwavef,icg,npw_k,nspinor)
     do ig=1,npw_k*nspinor
      cwavef(1,ig)=cg(1,ig+icgb)
      cwavef(2,ig)=cg(2,ig+icgb)
     end do
!$OMP END PARALLEL DO
!    end if

!   Compute scalar of wavefunction with all NL projectors
!   Compute C(k+G)*exp(-i.G.R)*ffnl(k+G)*i^l
    call getcprj(cwavef,cwavep,psps%dimekb,ntypat,dimffnl,psps%ekb,ffnl,psps%indlmn,istwf_k,kg_k,kpoint,&
&                psps%lmnmax,matblk,mgfft,mpi_enreg,mpj,natom,nattyp,dtset%ngfft,dtset%nloalg,npw_k,nspinor,&
&                ntypat,phkxred,ph1d,ph3d,psps%usepaw,psps%useylm,ucvol)
!VR
!    if (mkmem==0) then
!$OMP PARALLEL DO PRIVATE(ip) &
!$OMP&SHARED(cp_disk,cwavep,icp,mpj,nspinor)
!     do ip=1,mpj*nspinor
!      cp_disk(1,ip+icpb)=cwavep(1,ip)
!      cp_disk(2,ip+icpb)=cwavep(2,ip)
!     end do
!$OMP END PARALLEL DO
!    else
!$OMP PARALLEL DO PRIVATE(ip) &
!$OMP&SHARED(cp,cwavep,icp,mpj,nspinor)
     do ip=1,mpj*nspinor
      cp(1,ip+icpb)=cwavep(1,ip)*wt_tr
      cp(2,ip+icpb)=cwavep(2,ip)*wt_tr
     end do
!$OMP END PARALLEL DO
!    end if

!   End loop over bands
    icgb=icgb+npw_k*nspinor
    icpb=icpb+mpj*nspinor
   enddo

!VR
!   if (mkmem==0) then

!   Write new <P|c> to disk if needed (if mkmem==0)
!    write(dtfil%unwfp1) cp_disk(:,:)
!   else

!   Shift array memory (if mkmem/=0)
    icg=icg+npw_k*nspinor*nband_k
    icp=icp+mpj*nspinor*nband_k
    ikg=ikg+npw_k
!   end if

! End big k point loop
  deallocate(ffnl,ph3d,phkxred,kg_k,ylm_k,cwavef,cwavep)
  end do

!End loop over spins
 end do

 if(mpi_enreg%paral_compil_kpt==1)then
  if (mpi_enreg%parareel == 0) call leave_test
  write(message,*) 'ctocprj: loop on k-points and spins done in parallel'
  call wrtout(06,message,'COLL')
 end if

!VR
!Deallocate temporary storage
! if(mkmem==0) deallocate(cg_disk,cp_disk)

! call timab(561+tim_ctocprj,2,tsec)

!DEBUG
! write(6,*)' ctocprj : exit'
! write(6,*)cp(1,:)/wt
! write(6,*)cp(2,:)/wt
!ENDDEBUG

 end subroutine ctocprj
!!***
