!{\src2tex{textfont=tt}}
!!****f* abinit/prep_nonlop
!! NAME
!! prep_nonlop
!!
!! FUNCTION
!! this routine prepares the data to the call of nonlop.
!!
!! COPYRIGHT
!! Copyright (C) 1998-2006 ABINIT group (MT)
!! this file is distributed under the terms of the
!! gnu general public license, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! for the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  atindx1(natom)=index table for atoms, inverse of atindx
!!  choice: chooses possible output:
!!    choice=1 => a non-local energy contribution
!!          =2 => a gradient with respect to atomic position(s)
!!          =3 => a gradient with respect to strain(s)
!!          =23=> a gradient with respect to atm. pos. and strain(s)
!!          =4 => a gradient and 2nd derivative with respect to atomic pos.
!!          =5 => a gradient with respect to k wavevector
!!          =6 => 2nd derivatives with respect to strain and atm. pos.
!!  blocksize= size of block for FFT
!!  cwavef(2,npw*nspinor*ndat)=planewave coefficients of wavefunction.
!!  dimenl1,dimenl2=dimensions of enl (see enl)
!!  dimffnl=second dimension of ffnl (1+number of derivatives)
!!  enl(dimenl1,dimenl2)=
!!  ->Norm conserving : ==== when paw_opt=0 ====
!!                      (Real) Kleinman-Bylander energies (hartree)
!!                      dimenl1=lmnmax  -  dimenl2=ntypat
!!  ->PAW :             ==== when paw_opt=1 or 4 ====
!!                      (Real, symmetric) Dij coefs to connect projectors
!!                      dimenl1=lmnmax*(lmnmax+1)/2  -  dimenl2=natom
!!  ffnl(npw,dimffnl,lmnmax,ntypat)=nonlocal form factors on basis sphere.
!!  gmet(3,3)=metric tensor for G vecs (in bohr**-2)
!!  gprimd(3,3)=dimensional reciprocal space primitive translations
!!  gvnlc=matrix elements <G|Vnonlocal|C>
!!  kg_k(3,npw_k)=reduced planewave coordinates.
!!  kpg(npw,nkpg)= if nkpg==3 (k+G) components
!!                 if nkpg==9 [(k+G)_a].[(k+G)_b] quantities
!!  kpt(3)=k point in terms of recip. translations
!!  icall = order of call of this routine in lobpcgccwf
!!  idir=direction of the - atom to be moved in the case (choice=2,signs=2),
!!                        - k point direction in the case (choice=5,signs=2)
!!                        - strain component (1:6) in the case (choice=2,signs=2) or (choice=6,signs=1)
!!  indlmn(6,i,ntypat)= array giving l,m,n,ln,lm,s for i=ln  (if useylm=0)
!!                                                  or i=lmn (if useylm=1)
!!  istwf_k=option parameter that describes the storage of wfs
!!  lmnmax=if useylm=1, max number of (l,m,n) comp. over all type of psps
!!        =if useylm=0, max number of (l,n)   comp. over all type of psps
!!  matblk=dimension of the array ph3d
!!  mgfft=maximum size of 1d ffts
!!  mpi_enreg=informations about mpi parallelization
!!  mpsang= 1+maximum angular momentum for nonlocal pseudopotentials
!!  mpssoang= 1+maximum (spin*angular momentum) for nonlocal pseudopotentials
!!  natom=number of atoms in cell.
!!  nattyp(ntypat)=number of atoms of each type
!!  nband_k=number of bands at this k point for that spin polarization
!!  nbdblock=
!!  ngfft(18)=contain all needed information about 3D FFT, see ~abinit/doc/input_variables/vargs.htm#ngfft
!!  nkpg=second dimension of array kpg
!!  nloalg(5)=governs the choice of the algorithm for nonlocal operator
!!  nnlout=dimension of enlout (when signs=1):
!!         ==== if paw_opt=0 or 1 ====
!!         choice=1=>nnlout=1   choice=2=>nnlout=3*natom
!!         choice=3=>nnlout=6   choice=4=>nnlout=6*natom
!!         choice=5=>nnlout=1   choice=6=>nnlout=6*(3*natom+6)
!!         choice=23=>nnlout=6+3*natom
!!         ==== if paw_opt=2 ====
!!         choice=1 =>nnlout=Sum_over_atoms(1*lmn_size)
!!         choice=2 =>nnlout=Sum_over_atoms(4*lmn_size)
!!         choice=3 =>nnlout=Sum_over_atoms(7*lmn_size)
!!         choice=23=>nnlout=Sum_over_atoms(10*lmn_size)
!!         ==== if paw_opt=3 ====
!!         choice=1 =>nnlout=1
!!  npw_k=number of plane waves at this k point
!!  nspinor=number of spinorial components of the wavefunctions
!!  ntypat=number of types of atoms in cell
!!  paw_opt= define the nonlocal operator concerned with:
!!           paw_opt=0 : Norm-conserving Vnl (use of Kleinman-Bylander ener.)
!!           paw_opt=1 : PAW nonlocal part of H (use of Dij coeffs)
!!           paw_opt=2 : PAW augmentation occuppancies (rhoij)
!!           paw_opt=3 : PAW overlap matrix (Sij)
!!           paw_opt=4 : both PAW nonlocal part of H (Dij) and overlap matrix (Sij)
!!  phkxred(2,natom)=phase factors exp(2 pi kpt.xred)
!!  ph1d(2,3*(2*mgfft+1)*natom)=1D structure factors phase information
!!  ph3d(2,npw,matblk)=3-dim structure factors, for each atom and plane wave.
!!  prtvol=control print volume and debugging output
!!  pspso(ntypat)=spin-orbit characteristic for each atom type
!!  signs= if 1, get contracted elements (energy, forces, stress, ...)
!!         if 2, applies the non-local operator to a function in reciprocal space
!!  sij(dimenl1,ntypat*(paw_opt/3))=overlap matrix components (only if paw_opt=3 or 4)
!!  tim_nonlop=timing code of the calling routine (can be set to 0 if not attributed)
!!  ucvol=unit cell volume (bohr^3)
!!  useylm=governs the way the nonlocal operator is to be applied:
!!         1=using Ylm, 0=using Legendre polynomials
!!
!! OUTPUT
!!  ==== if (signs==1) ====
!!  enlout(nnlout)=
!!    if paw_opt==0 or 1: contribution of this state to the nl part of various properties
!!    if paw_opt==2 :     contribution of this state to various PAW Rhoij quantities
!!    if paw_opt==3:      contribution of this state to <c|S|c>  (where S=overlap when PAW)
!!  ==== if (signs==2) ====
!!    if paw_opt==0, 1 or 4:
!!       gvnlc(2,nspinor*npw)=result of the aplication of the nl operator
!!                        or one of its derivative to the input vect.
!!    if paw_opt==3 or 4:
!!       gsc(2,nspinor*npw*(paw_opt/3))=result of the aplication of (I+S)
!!                        to the input vect. (where S=overlap when PAW)
!!
!! SIDE EFFECTS
!!
!! PARENTS
!!      lobpcgccwf,vtowfk
!!
!! CHILDREN
!!      fourwf,sphereboundary,timab,xallgather_mpi,xallgatherv_mpi
!!      xalltoallv_mpi,xcomm_init
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine prep_nonlop(atindx1,choice,dimenl1,dimenl2,dimffnl,enl,enlout_block,&
&                       ffnl,gmet,gprimd,iblock,icall,idir,indlmn,istwf_k,kg_k,&
&                       kpg,kpt,lmnmax,matblk,blocksize,mgfft,mpi_enreg,mpsang,mpssoang,&
&                       natom,nattyp,nbdblock,nband_k,ngfft,nkpg,nloalg,nnlout,npw_k,&
&                       nspinor,ntypat,paw_opt,phkxred,ph1d,ph3d,prtvol,pspso,signs,sij,gsc,&
&                       tim_nonlop,ucvol,useylm,cwavef,gvnlc)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_00basis
 use interfaces_01managempi
 use interfaces_03nonlocal
#else
 use defs_xfuncmpi
#endif
!End of the abilint section

 implicit none

#if defined MPI_FFT
          include 'mpif.h'
#endif
!Arguments ------------------------------------
 integer,intent(in) :: blocksize,choice,dimenl1,dimenl2,dimffnl,iblock,icall,idir,istwf_k
 integer :: lmnmax,matblk,mgfft,mpsang,mpssoang,signs
 integer :: natom,nband_k,nbdblock,nkpg,nnlout,npw_k,nspinor,ntypat,paw_opt,prtvol,useylm
 real(dp),intent(in) :: ucvol
 type(mpi_type),intent(inout) :: mpi_enreg
 integer,intent(in) :: atindx1(natom),indlmn(6,lmnmax,ntypat),kg_k(3,npw_k)
 integer,intent(in) :: nattyp(ntypat),ngfft(18),nloalg(5),pspso(ntypat)
 real(dp),intent(in) :: enl(dimenl1,dimenl2)
 real(dp),intent(in) :: ffnl(npw_k,dimffnl,lmnmax,ntypat)
 real(dp),intent(in) :: gmet(3,3),gprimd(3,3)
 real(dp),intent(in) :: kpt(3)
 real(dp),intent(in) :: kpg(npw_k,nkpg*useylm)
 real(dp),intent(in) :: ph1d(2,3*(2*mgfft+1)*natom),phkxred(2,natom)
 real(dp),intent(in) :: sij(dimenl1,ntypat*(paw_opt/3))
 real(dp),intent(out) :: enlout_block(nnlout*blocksize),gvnlc(2,npw_k*nspinor*blocksize)
 real(dp),intent(out) :: gsc(2,npw_k*nspinor*blocksize*(paw_opt/3))
 real(dp),intent(inout) :: cwavef(2,npw_k*nspinor*blocksize),ph3d(2,npw_k,matblk)

!Local variables-------------------------------
 integer :: spacecomm=0
 integer :: ier,ipw,ii
 integer :: old_paral_level,tim_nonlop
 complex(dp), allocatable :: dummy2(:,:)
 real(dp) :: tsec(2)

!local variables for mpialltoallv
 real(dp), allocatable :: enlout(:)
 real(dp), allocatable :: cwavef_alltoall(:,:),gvnlc_alltoall(:,:),&
 gsc_alltoall(:,:),ffnl_little(:,:,:,:),ffnl_little_gather(:,:,:,:),&
 ph3d_little(:,:,:),ph3d_little_gather(:,:,:)
 integer, allocatable,save :: kg_k_gather(:,:),kpg_little(:,:)
 integer, allocatable,save :: kpg_little_gather(:,:)
 real(dp), allocatable, save :: kpg_gather(:,:)
 real(dp), allocatable,save :: ffnl_gather(:,:,:,:),&
 ph3d_gather(:,:,:)
 integer,save :: iproc,ndatarecv,ndatarecvloc,npw_tot
 integer,  allocatable :: recvcounts(:)
 integer,  allocatable :: sendcounts(:),sdispls(:),rdispls(:)
 integer,  allocatable :: sendcountsloc(:),sdisplsloc(:),recvcountsloc(:),rdisplsloc(:)
!no_abirules
!correspondence with abinit. here for real wf but in complex mode
!this is the index of a given band

! *************************************************************************
 old_paral_level= mpi_enreg%paral_level
 mpi_enreg%paral_level=3
 call xcomm_init(mpi_enreg,spaceComm)
 if(mpi_enreg%mode_para=='b') spaceComm=mpi_enreg%comm_band

 allocate(sendcountsloc(blocksize))
 allocate(sdisplsloc(blocksize))
 allocate(sdispls(blocksize))
 allocate(sendcounts(blocksize))
 allocate(recvcountsloc(blocksize))
 allocate(rdisplsloc(blocksize))
 allocate(rdispls(blocksize))
 allocate(recvcounts(blocksize))
 call timab(582,1,tsec)
 call xallgather_mpi(npw_k,recvcounts,spaceComm,ier)
 call timab(582,2,tsec)
 rdispls(1)=0
 do iproc=2,blocksize
  rdispls(iproc)=rdispls(iproc-1)+recvcounts(iproc-1)
 end do
 ndatarecv=rdispls(blocksize)+recvcounts(blocksize)

 if (icall==1 .and. iblock==1) then
  if (allocated(ffnl_gather)) deallocate(ffnl_gather)
  allocate(ffnl_gather(ndatarecv,dimffnl,lmnmax,ntypat))
  allocate(ffnl_little(dimffnl,lmnmax,ntypat,npw_k))
  allocate(ffnl_little_gather(dimffnl,lmnmax,ntypat,ndatarecv))
  do ipw=1,npw_k
   ffnl_little(:,:,:,ipw)=ffnl(ipw,:,:,:)
  end do
  recvcountsloc(:)=recvcounts(:)*dimffnl*lmnmax*ntypat
  rdisplsloc(:)=rdispls(:)*dimffnl*lmnmax*ntypat
  call timab(582,1,tsec)
  call xallgatherv_mpi(ffnl_little,npw_k*dimffnl*lmnmax*ntypat,ffnl_little_gather,&
  & recvcountsloc(:),rdisplsloc,spaceComm,ier)
  call timab(582,2,tsec)
  do ipw=1,ndatarecv
   ffnl_gather(ipw,:,:,:)=ffnl_little_gather(:,:,:,ipw)
  end do
  deallocate(ffnl_little,ffnl_little_gather)

  if (allocated(ph3d_gather)) deallocate(ph3d_gather)
  allocate(ph3d_gather(2,ndatarecv,matblk))
  allocate(ph3d_little(2,matblk,npw_k),ph3d_little_gather(2,matblk,ndatarecv))
  recvcountsloc(:)=recvcounts(:)*2*matblk
  rdisplsloc(:)=rdispls(:)*2*matblk
  do ipw=1,npw_k
   ph3d_little(:,:,ipw)=ph3d(:,ipw,:)
  end do
  call timab(582,1,tsec)
  call xallgatherv_mpi(ph3d_little,npw_k*2*matblk,ph3d_little_gather,recvcountsloc(:),rdisplsloc,spaceComm,ier)
  call timab(582,2,tsec)
  do ipw=1,ndatarecv
   ph3d_gather(:,ipw,:)=ph3d_little_gather(:,:,ipw)
  end do
  deallocate(ph3d_little_gather,ph3d_little)

  if (allocated(kg_k_gather)) deallocate(kg_k_gather)
  allocate(kg_k_gather(3,ndatarecv))
  recvcountsloc(:)=recvcounts(:)*3
  rdisplsloc(:)=rdispls(:)*3
  call timab(582,1,tsec)
  call xallgatherv_mpi(kg_k(1,:),npw_k,kg_k_gather(1,:),recvcounts(:),rdispls,spaceComm,ier)
  call xallgatherv_mpi(kg_k(2,:),npw_k,kg_k_gather(2,:),recvcounts(:),rdispls,spaceComm,ier)
  call xallgatherv_mpi(kg_k(3,:),npw_k,kg_k_gather(3,:),recvcounts(:),rdispls,spaceComm,ier)
  call timab(582,2,tsec)

  if (allocated(kpg_gather)) deallocate(kpg_gather)
  allocate(kpg_gather(ndatarecv,nkpg*useylm))
  if (useylm==1) then
   allocate(kpg_little(nkpg,npw_k),kpg_little_gather(nkpg,ndatarecv))
   recvcountsloc(:)=recvcounts(:)*nkpg
   rdisplsloc(:)=rdispls(:)*nkpg
   do ipw=1,npw_k
    kpg_little(:,ipw)=kpg(ipw,:)
   end do
   call timab(582,1,tsec)
   call xallgatherv_mpi(kpg_little,npw_k*nkpg,kpg_little_gather,recvcountsloc(:),rdisplsloc,spaceComm,ier)
   call timab(582,2,tsec)
   do ipw=1,ndatarecv
    kpg_gather(ipw,:)=real(kpg_little_gather(:,ipw), dp)
   end do
   deallocate(kpg_little_gather,kpg_little)
  end if

!  if (nkpg>0) call mkkpg(kg_k,kpg_k,kpt,nkpg,npw_k)

 end if !End of the icall=1 and iblock=1 conditions

 sendcounts(:)=npw_k
 do iproc=1,blocksize
  sdispls(iproc)=(iproc-1)*npw_k
 end do

 allocate(cwavef_alltoall(2,ndatarecv*nspinor))
 allocate(gsc_alltoall(2,ndatarecv*nspinor*(paw_opt/3)))
 allocate(gvnlc_alltoall(2,ndatarecv*nspinor))
 allocate(enlout(nnlout))
 recvcountsloc(:)=recvcounts(:)*2*nspinor
 rdisplsloc(:)=rdispls(:)*2*nspinor
 sendcountsloc(:)=sendcounts(:)*2*nspinor
 sdisplsloc(:)=sdispls(:)*2*nspinor
 call timab(581,1,tsec)
 call xalltoallv_mpi(cwavef,sendcountsloc,sdisplsloc,cwavef_alltoall,&
&         recvcountsloc,rdisplsloc,spaceComm,ier)
 call timab(581,2,tsec)

 call nonlop(atindx1,choice,dimenl1,dimenl2,dimffnl,dimffnl,&
&            enl,enlout,ffnl_gather,ffnl_gather,gmet,gprimd,idir,indlmn,&
&            istwf_k,kg_k_gather,kg_k_gather,kpg_gather,kpg_gather,kpt,kpt,lmnmax,matblk,mgfft,&
&            mpi_enreg,mpsang,mpssoang,natom,nattyp,ngfft,nkpg,nkpg,nloalg,&
&            nnlout,ndatarecv,ndatarecv,nspinor,ntypat,paw_opt,phkxred,&
&            phkxred,ph1d,ph3d_gather,ph3d_gather,pspso,signs,sij,gsc_alltoall,&
&            tim_nonlop,ucvol,useylm,cwavef_alltoall,gvnlc_alltoall)

!Transpose the gsc_alltoall or gvlnc_alltoall tabs
!according to the paw_opt and signs values
 call timab(581,1,tsec)
 if (signs==2 .and. (paw_opt==0 .or. paw_opt==1 .or. paw_opt==4)) then
  call xalltoallv_mpi(gvnlc_alltoall,recvcountsloc,rdisplsloc,gvnlc,&
&  sendcountsloc,sdisplsloc,spaceComm,ier)
 end if
 if (signs==2 .and. (paw_opt==3 .or. paw_opt==4)) then
  call xalltoallv_mpi(gsc_alltoall,recvcountsloc,rdisplsloc,gsc,&
&  sendcountsloc,sdisplsloc,spaceComm,ier)
 end if
 call timab(581,2,tsec)

#if defined MPI_FFT
 call MPI_ALLGATHER(enlout,nnlout,MPI_DOUBLE_PRECISION,enlout_block,nnlout, &
                    MPI_DOUBLE_PRECISION,spaceComm,ier)
#else
 enlout_block(:) = 0.
#endif
 deallocate(enlout)

 mpi_enreg%paral_level= old_paral_level
 deallocate(sendcounts,recvcounts,sdispls,rdispls)
 deallocate(sendcountsloc,sdisplsloc)
 deallocate(recvcountsloc,rdisplsloc)
 deallocate(cwavef_alltoall,gvnlc_alltoall,gsc_alltoall)
end subroutine prep_nonlop
!!***

!{\src2tex{textfont=tt}}
!!****f* abinit/prep_getghc
!! NAME
!! prep_getghc
!!
!! FUNCTION
!! this routine prepares the data to the call of getghc.
!!
!! COPYRIGHT
!! Copyright (C) 1998-2006 ABINIT group (MT)
!! this file is distributed under the terms of the
!! gnu general public license, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! for the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  blocksize= size of block for FFT
!!  cwavef(2,npw*nspinor*ndat)=planewave coefficients of wavefunction.
!!  dimffnl=second dimension of ffnl (1+number of derivatives)
!!  dtfil <type(datafiles_type)>=variables related to files
!!  ffnl(npw,dimffnl,lmnmax,ntypat)=nonlocal form factors on basis sphere.
!!  gs_hamk <type(gs_hamiltonian_type)>=all data for the hamiltonian at k
!!  gvnlc=matrix elements <G|Vnonlocal|C>
!!  kg_k(3,npw_k)=reduced planewave coordinates.
!!  kinpw(npw)=(modified) kinetic energy for each plane wave (hartree)
!!  icall = order of call of this routine in lobpcgccwf
!!  lmnmax=if useylm=1, max number of (l,m,n) comp. over all type of psps
!!        =if useylm=0, max number of (l,n)   comp. over all type of psps
!!  matblk=dimension of the array ph3d
!!  mgfft=maximum size of 1d ffts
!!  mpi_enreg=informations about mpi parallelization
!!  mpsang= 1+maximum angular momentum for nonlocal pseudopotentials
!!  mpssoang= 1+maximum (spin*angular momentum) for nonlocal pseudopotentials
!!  natom=number of atoms in cell.
!!  nband_k=number of bands at this k point for that spin polarization
!!  nbdblock=
!!  npw_k=number of plane waves at this k point
!!  nspinor=number of spinorial components of the wavefunctions
!!  ntypat=number of types of atoms in unit cell.
!!  nvloc=final dimension of vlocal (usually 1, but 4 for non-collinear)
!!  n4,n5,n6 used for dimensionning of vlocal
!!  ph3d(2,npw,matblk)=3-dim structure factors, for each atom and plane wave.
!!  prtvol=control print volume and debugging output
!!  vlocal(n4,n5,n6,nvloc)= local potential in real space, on the augmented fft grid
!!
!! OUTPUT
!!  gwavef=(2,npw*nspinor*ndat)=matrix elements <G|H|C>.
!!
!! SIDE EFFECTS
!!
!! PARENTS
!!      lobpcgccwf,lobpcgwf
!!
!! CHILDREN
!!      fourwf,sphereboundary,timab,xallgather_mpi,xallgatherv_mpi
!!      xalltoallv_mpi,xcomm_init
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine prep_getghc(cwavef,dimffnl,dtfil,ffnl,gs_hamk,gvnlc,gwavef,iblock,icall,istwf_k,kg_k,&
& kinpw,lmnmax,matblk,blocksize,mgfft,mpi_enreg,mpsang,mpssoang,natom,nbdblock,nband_k,npw_k,&
& nspinor,ntypat,nvloc,n4,n5,n6,ph3d,prtvol,vlocal)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_00basis
 use interfaces_01managempi
 use interfaces_02ffts
 use interfaces_04wfs
#else
 use defs_xfuncmpi
#endif
!End of the abilint section

 implicit none

#if defined MPI_FFT
          include 'mpif.h'
#endif
!Arguments ------------------------------------
 type(gs_hamiltonian_type) :: gs_hamk
 integer :: blocksize
 integer :: dimffnl,iblock,icall,istwf_k,lmnmax,matblk,mgfft,mpsang,mpssoang,n4,n5
 integer :: n6,natom,nband_k,nbdblock,npw_k,nspinor,ntypat,nvloc,prtvol
 type(datafiles_type) :: dtfil
 type(mpi_type) :: mpi_enreg
 integer :: kg_k(3,npw_k)
 real(dp) :: ffnl(npw_k,dimffnl,lmnmax,ntypat),gvnlc(2,npw_k*nspinor*blocksize)
 real(dp) :: kinpw(npw_k),ph3d(2,npw_k,matblk)
 real(dp) :: vlocal(n4,n5,n6,nvloc),cwavef(2,npw_k*nspinor*blocksize),gwavef(2,npw_k*nspinor*blocksize)

!Local variables-------------------------------
 integer :: oldspaceComm,spacecomm=0
  integer:: ier,ipw,npw_k3
 integer :: old_me_g0,old_num_group_fft,old_paral_compil_fft,old_paral_level,sij_opt,tim_getghc
 integer :: old_ngfft(18)
  real(dp), allocatable :: dummy2(:,:)
 real(dp) :: tsec(2)

!local variables for mpialltoallv
 real(dp), allocatable :: cwavef_alltoall(:,:),gwavef_alltoall(:,:),gvnlc_alltoall(:,:),&
 ffnl_little(:,:,:,:),ffnl_little_gather(:,:,:,:),&
 ph3d_little(:,:,:),ph3d_little_gather(:,:,:)
 integer, allocatable,save :: kg_k_gather(:,:),kg_k_gather_all(:,:),rdispls_all(:),npw_per_proc(:)
 real(dp), allocatable,save :: kinpw_gather(:),ffnl_gather(:,:,:,:),vlocal_allgather(:,:,:,:),&
 ph3d_gather(:,:,:)
 integer,save :: iproc,ndatarecv,ndatarecvloc,npw_tot
 integer,  allocatable :: recvcounts(:)
 integer,  allocatable :: sendcounts(:),sdispls(:),rdispls(:)
 integer,  allocatable :: sendcountsloc(:),sdisplsloc(:),recvcountsloc(:),rdisplsloc(:)
!no_abirules
!correspondence with abinit. here for real wf but in complex mode
!this is the index of a given band

! *************************************************************************

 tim_getghc=6 ; sij_opt=0
 old_paral_level= mpi_enreg%paral_level
 mpi_enreg%paral_level=3
 call xcomm_init(mpi_enreg,spaceComm)
 if(mpi_enreg%mode_para=='b') spaceComm=mpi_enreg%comm_band

 allocate(sendcountsloc(blocksize))
 allocate(sdisplsloc(blocksize))
 allocate(sdispls(blocksize))
 allocate(sendcounts(blocksize))
 allocate(recvcountsloc(blocksize))
 allocate(rdisplsloc(blocksize))
 allocate(rdispls(blocksize))
 allocate(recvcounts(blocksize))
 call timab(546,1,tsec)
 call xallgather_mpi(npw_k,recvcounts,spaceComm,ier)
 call timab(546,2,tsec)
 rdispls(1)=0
 do iproc=2,blocksize
  rdispls(iproc)=rdispls(iproc-1)+recvcounts(iproc-1)
 end do
 ndatarecv=rdispls(blocksize)+recvcounts(blocksize)

 if (icall==1 .and. iblock==1) then
  if (allocated(ffnl_gather)) deallocate(ffnl_gather)
  allocate(ffnl_gather(ndatarecv,dimffnl,lmnmax,ntypat))
  allocate(ffnl_little(dimffnl,lmnmax,ntypat,npw_k))
  allocate(ffnl_little_gather(dimffnl,lmnmax,ntypat,ndatarecv))
  do ipw=1,npw_k
   ffnl_little(:,:,:,ipw)=ffnl(ipw,:,:,:)
  end do
  recvcountsloc(:)=recvcounts(:)*dimffnl*lmnmax*ntypat
  rdisplsloc(:)=rdispls(:)*dimffnl*lmnmax*ntypat
  call timab(546,1,tsec)
  call xallgatherv_mpi(ffnl_little,npw_k*dimffnl*lmnmax*ntypat,ffnl_little_gather,&
  & recvcountsloc(:),rdisplsloc,spaceComm,ier)
  call timab(546,2,tsec)
  do ipw=1,ndatarecv
   ffnl_gather(ipw,:,:,:)=ffnl_little_gather(:,:,:,ipw)
  end do
  deallocate(ffnl_little,ffnl_little_gather)

  if (allocated(kinpw_gather)) deallocate(kinpw_gather)
  allocate(kinpw_gather(ndatarecv))
  recvcountsloc(:)=recvcounts(:)
  rdisplsloc(:)=rdispls(:)
  call timab(546,1,tsec)
  call xallgatherv_mpi(kinpw,npw_k,kinpw_gather,recvcountsloc(:),rdisplsloc,spaceComm,ier)
  call timab(546,2,tsec)

  if (allocated(ph3d_gather)) deallocate(ph3d_gather)
  allocate(ph3d_gather(2,ndatarecv,matblk))
  allocate(ph3d_little(2,matblk,npw_k),ph3d_little_gather(2,matblk,ndatarecv))
  recvcountsloc(:)=recvcounts(:)*2*matblk
  rdisplsloc(:)=rdispls(:)*2*matblk
  do ipw=1,npw_k
   ph3d_little(:,:,ipw)=ph3d(:,ipw,:)
  end do
  call timab(546,1,tsec)
  call xallgatherv_mpi(ph3d_little,npw_k*2*matblk,ph3d_little_gather,recvcountsloc(:),rdisplsloc,spaceComm,ier)
  call timab(546,2,tsec)
  do ipw=1,ndatarecv
   ph3d_gather(:,ipw,:)=ph3d_little_gather(:,:,ipw)
  end do
  deallocate(ph3d_little_gather,ph3d_little)

  if (allocated(kg_k_gather)) deallocate(kg_k_gather)
  allocate(kg_k_gather(3,ndatarecv))
  recvcountsloc(:)=recvcounts(:)*3
  rdisplsloc(:)=rdispls(:)*3
  call timab(546,1,tsec)
  call xallgatherv_mpi(kg_k(1,:),npw_k,kg_k_gather(1,:),recvcounts(:),rdispls,spaceComm,ier)
  call xallgatherv_mpi(kg_k(2,:),npw_k,kg_k_gather(2,:),recvcounts(:),rdispls,spaceComm,ier)
  call xallgatherv_mpi(kg_k(3,:),npw_k,kg_k_gather(3,:),recvcounts(:),rdispls,spaceComm,ier)
! I now recollect all the kg to have a common sphereboundary.
! First get the dimension of the whole kg array
  oldspacecomm=mpi_enreg%comm_fft
! Get dimension information
  allocate(npw_per_proc(mpi_enreg%nproc_fft),rdispls_all(mpi_enreg%nproc_fft))
  call xallgather_mpi(ndatarecv,npw_per_proc,oldspacecomm,ier)
  rdispls_all(1)=0
  do iproc=2,mpi_enreg%nproc_fft
   rdispls_all(iproc)=rdispls_all(iproc-1)+npw_per_proc(iproc-1)
  end do
  npw_tot=rdispls_all(mpi_enreg%nproc_fft)+npw_per_proc(mpi_enreg%nproc_fft)
! Transfer the kg on each proc to the whole array
  allocate(kg_k_gather_all(3,npw_tot))
  call xallgatherv_mpi&
&  (kg_k_gather(1,:),ndatarecv,kg_k_gather_all(1,:),npw_per_proc(:),rdispls_all,oldspaceComm,ier)
  call xallgatherv_mpi&
&  (kg_k_gather(2,:),ndatarecv,kg_k_gather_all(2,:),npw_per_proc(:),rdispls_all,oldspaceComm,ier)
  call xallgatherv_mpi&
&  (kg_k_gather(3,:),ndatarecv,kg_k_gather_all(3,:),npw_per_proc(:),rdispls_all,oldspaceComm,ier)
!  call leave_new("COLL")
  call timab(546,2,tsec)
  call sphereboundary(gs_hamk%gbound,istwf_k,kg_k_gather_all,mgfft,npw_tot)
  deallocate(kg_k_gather_all,npw_per_proc,rdispls_all)
 end if !End of the icall=1 and iblock=1 conditions

 sendcounts(:)=npw_k
 do iproc=1,blocksize
  sdispls(iproc)=(iproc-1)*npw_k
 end do

 allocate(cwavef_alltoall(2,ndatarecv*nspinor))
 allocate(gwavef_alltoall(2,ndatarecv*nspinor))
 allocate(gvnlc_alltoall(2,ndatarecv*nspinor))
 recvcountsloc(:)=recvcounts(:)*2*nspinor
 rdisplsloc(:)=rdispls(:)*2*nspinor
 sendcountsloc(:)=sendcounts(:)*2*nspinor
 sdisplsloc(:)=sdispls(:)*2*nspinor
 call timab(545,1,tsec)
 call xalltoallv_mpi(cwavef,sendcountsloc,sdisplsloc,cwavef_alltoall,&
&         recvcountsloc,rdisplsloc,spaceComm,ier)
 call timab(545,2,tsec)
 if(mpi_enreg%mode_para /= 'b') then !I collect on this processor the whole local potential, and perform scalar fft
  if (.not.allocated(vlocal_allgather) .and. icall==1 .and. iblock==1) allocate(vlocal_allgather(n4,n5,n6,nvloc))
  if (allocated(vlocal_allgather)  .and. icall==1 .and. iblock==1) deallocate(vlocal_allgather)
  if (.not.allocated(vlocal_allgather)) then
   allocate(vlocal_allgather(n4,n5,n6,nvloc))
   call timab(546,1,tsec)
   call xallgather_mpi(vlocal(:,:,n6/mpi_enreg%nproc_fft*mpi_enreg%me_fft+1:n6/mpi_enreg%nproc_fft*(mpi_enreg%me_fft+1),:)&
&  ,n4*n5*n6*nvloc/mpi_enreg%nproc_fft,vlocal_allgather,spaceComm,ier)
   call timab(546,2,tsec)
  end if
  old_ngfft(:)=gs_hamk%ngfft(:)
  gs_hamk%ngfft(11)=0;gs_hamk%ngfft(10)=1
  old_num_group_fft=mpi_enreg%num_group_fft
  mpi_enreg%num_group_fft=0
  old_paral_compil_fft=mpi_enreg%paral_compil_fft
  mpi_enreg%paral_compil_fft=0
  if (gs_hamk%istwf_k==2) old_me_g0=mpi_enreg%me_g0
  if (gs_hamk%istwf_k==2) mpi_enreg%me_g0=1
  mpi_enreg%me_fft=0;mpi_enreg%nproc_fft=1

  call getghc(cwavef_alltoall,dimffnl,ffnl_gather,dtfil%filstat,gwavef_alltoall(:,:),&
&  dummy2,gs_hamk,gvnlc_alltoall,kg_k_gather,&
&  kinpw_gather,lmnmax,matblk,mgfft,mpi_enreg,mpsang,mpssoang,natom,1,ndatarecv,nspinor,ntypat,&
&  nvloc,n4,n5,n6,ph3d_gather,prtvol,sij_opt,tim_getghc,vlocal_allgather)

  gs_hamk%ngfft(:)=old_ngfft(:)
  mpi_enreg%paral_compil_fft=old_paral_compil_fft
  mpi_enreg%num_group_fft=old_num_group_fft
  mpi_enreg%nproc_fft=old_ngfft(10)
  mpi_enreg%me_fft=old_ngfft(11)
 else !case band fft (use vlocal as fft_distributed, and the fft_parallel mode)

  call getghc(cwavef_alltoall,dimffnl,ffnl_gather,dtfil%filstat,gwavef_alltoall,&
&  dummy2,gs_hamk,gvnlc_alltoall,kg_k_gather,&
&  kinpw_gather,lmnmax,matblk,mgfft,mpi_enreg,mpsang,mpssoang,natom,1,ndatarecv,nspinor,ntypat,&
&  nvloc,n4,n5,n6,ph3d_gather,prtvol,sij_opt,tim_getghc,vlocal)

 end if
 if (gs_hamk%istwf_k==2) mpi_enreg%me_g0=old_me_g0
 call timab(545,1,tsec)
 call xalltoallv_mpi(gwavef_alltoall,recvcountsloc,rdisplsloc,gwavef,&
 &         sendcountsloc,sdisplsloc,spaceComm,ier)
 call xalltoallv_mpi(gvnlc_alltoall,recvcountsloc,rdisplsloc,gvnlc,&
 &         sendcountsloc,sdisplsloc,spaceComm,ier)
 call timab(545,2,tsec)

 mpi_enreg%paral_level= old_paral_level
 deallocate(sendcounts,recvcounts,sdispls,rdispls)
 deallocate(sendcountsloc,sdisplsloc)
 deallocate(recvcountsloc,rdisplsloc)
 deallocate(cwavef_alltoall,gwavef_alltoall,gvnlc_alltoall)
end subroutine prep_getghc
!!***

!{\src2tex{textfont=tt}}
!!****f* abinit/prep_fourwf
!! NAME
!! prep_fourwf
!!
!! FUNCTION
!! this routine prepares the data to the call of fourwf.
!!
!! COPYRIGHT
!! copyright (c) 1998-2005 abinit group (MT)
!! this file is distributed under the terms of the
!! gnu general public license, see ~abinit/infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! for the initials of contributors, see ~abinit/infos/contributors .
!!
!! INPUTS
!!  blocksize= size of block for FFT
!!  cwavef(2,npw*nspinor*ndat)=planewave coefficients of wavefunction.
!!  dimffnl=second dimension of ffnl (1+number of derivatives)
!!  dtfil <type(datafiles_type)>=variables related to files
!!  ffnl(npw,dimffnl,lmnmax,ntypat)=nonlocal form factors on basis sphere.
!!  gs_hamk <type(gs_hamiltonian_type)>=all data for the hamiltonian at k
!!  gvnlc=matrix elements <G|Vnonlocal|C>
!!  kg_k(3,npw_k)=reduced planewave coordinates.
!!  icall = order of call of this routine in lobpcgccwf
!!  lmnmax=if useylm=1, max number of (l,m,n) comp. over all type of psps
!!        =if useylm=0, max number of (l,n)   comp. over all type of psps
!!  matblk=dimension of the array ph3d
!!  mgfft=maximum size of 1d ffts
!!  mpi_enreg=informations about mpi parallelization
!!  mpsang= 1+maximum angular momentum for nonlocal pseudopotentials
!!  mpssoang= 1+maximum (spin*angular momentum) for nonlocal pseudopotentials
!!  natom=number of atoms in cell.
!!  nband_k=number of bands at this k point for that spin polarization
!!  nbdblock=
!!  npw_k=number of plane waves at this k point
!!  nspinor=number of spinorial components of the wavefunctions
!!  ntypat=number of types of atoms in unit cell.
!!  nvloc=final dimension of vlocal (usually 1, but 4 for non-collinear)
!!  n4,n5,n6 used for dimensionning of vlocal
!!  ph3d(2,npw,matblk)=3-dim structure factors, for each atom and plane wave.
!!  prtvol=control print volume and debugging output
!!  vlocal(n4,n5,n6,nvloc)= local potential in real space, on the augmented fft grid
!!
!! OUTPUT
!!  gwavef=(2,npw*nspinor*ndat)=matrix elements <G|H|C>.
!!
!! SIDE EFFECTS
!!
!! PARENTS
!!      mkrho,vtowfk
!!
!! CHILDREN
!!      fourwf,sphereboundary,timab,xallgather_mpi,xallgatherv_mpi
!!      xalltoallv_mpi,xcomm_init
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine prep_fourwf(rhoaug,blocksize,cwavef,wfraug,gs_hamk,istwf_k,iblock,icall,kg_k,&
& mgfft,mpi_enreg,nbdblock,nband_k,npw_k,n4,n5,n6,occ_k,wtk)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_00basis
 use interfaces_01managempi
 use interfaces_02ffts
#else
 use defs_xfuncmpi
#endif
!End of the abilint section

 implicit none

#if defined MPI_FFT
          include 'mpif.h'
#endif
!Arguments ------------------------------------
 type(gs_hamiltonian_type) :: gs_hamk
 integer:: blocksize
 integer :: iblock,icall,istwf_k,mgfft,n4,n5
 integer :: n6,nband_k,nbdblock,npw_k
 type(mpi_type) :: mpi_enreg
 integer :: kg_k(3,npw_k)
 real(dp) :: wtk,cwavef(2,npw_k*blocksize)
 real(dp) :: occ_k(nband_k),rhoaug(n4,n5,n6),wfraug(2,n4,n5,n6)
!Local variables-------------------------------
  integer :: oldspacecomm,spacecomm=0
  integer:: ier,ipw
  integer:: old_me_g0,old_num_group_fft,old_paral_compil_fft,old_paral_level,tim_fourwf
  integer:: old_ngfft(18)
  complex(dp), allocatable :: dummy2(:,:)
  real(dp) :: dummy(2,1),weight,tsec(2)

!local variables for mpialltoallv
  real(dp), allocatable :: cwavef_alltoall(:,:)
  integer, allocatable,save :: kg_k_gather(:,:),kg_k_gather_all(:,:),rdispls_all(:),npw_per_proc(:)
  integer, save :: npw_tot
  integer :: iproc,ndatarecv,ndatarecvloc
  integer,  allocatable :: recvcounts(:)
  integer,  allocatable :: sendcounts(:),sdispls(:),rdispls(:)
  integer,  allocatable :: sendcountsloc(:),sdisplsloc(:),recvcountsloc(:),rdisplsloc(:)
!no_abirules
!correspondence with abinit. here for real wf but in complex mode
!this is the index of a given band

! *************************************************************************
 old_paral_level= mpi_enreg%paral_level
 mpi_enreg%paral_level=3
 call xcomm_init(mpi_enreg,spaceComm)
 if(mpi_enreg%mode_para=='b') spaceComm=mpi_enreg%comm_band

 allocate(sendcounts(blocksize))
 allocate(sdispls(blocksize))
 allocate(sendcountsloc(blocksize))
 allocate(sdisplsloc(blocksize))
 allocate(recvcountsloc(blocksize))
 allocate(rdisplsloc(blocksize))
 allocate(rdispls(blocksize))
 allocate(recvcounts(blocksize))
 call timab(548,1,tsec)
 call xallgather_mpi(npw_k,recvcounts,spaceComm,ier)
 call timab(548,2,tsec)
 rdispls(1)=0
 do iproc=2,blocksize
  rdispls(iproc)=rdispls(iproc-1)+recvcounts(iproc-1)
 end do
 ndatarecv=rdispls(blocksize)+recvcounts(blocksize)

 if (icall==1 .and. iblock==1) then
  if (allocated(kg_k_gather)) deallocate(kg_k_gather)
  allocate(kg_k_gather(3,ndatarecv))
  recvcountsloc(:)=recvcounts(:)*3
  rdisplsloc(:)=rdispls(:)*3
  call timab(548,1,tsec)
  call xallgatherv_mpi(kg_k(1,:),npw_k,kg_k_gather(1,:),recvcounts(:),rdispls,spaceComm,ier)
  call xallgatherv_mpi(kg_k(2,:),npw_k,kg_k_gather(2,:),recvcounts(:),rdispls,spaceComm,ier)
  call xallgatherv_mpi(kg_k(3,:),npw_k,kg_k_gather(3,:),recvcounts(:),rdispls,spaceComm,ier)
  call timab(548,2,tsec)
! I now recollect all the kg to have a common sphereboundary.
! First get the dimension of the whole kg array
  oldspacecomm=mpi_enreg%comm_fft
! Get dimension information
  allocate(npw_per_proc(mpi_enreg%nproc_fft),rdispls_all(mpi_enreg%nproc_fft))
  call xallgather_mpi(ndatarecv,npw_per_proc,oldspacecomm,ier)
  rdispls_all(1)=0
  do iproc=2,mpi_enreg%nproc_fft
   rdispls_all(iproc)=rdispls_all(iproc-1)+npw_per_proc(iproc-1)
  end do
  npw_tot=rdispls_all(mpi_enreg%nproc_fft)+npw_per_proc(mpi_enreg%nproc_fft)
! Transfer the kg on each proc to the whole array
  allocate(kg_k_gather_all(3,npw_tot))
  call timab(548,1,tsec)
  call xallgatherv_mpi&
&  (kg_k_gather(1,:),ndatarecv,kg_k_gather_all(1,:),npw_per_proc(:),rdispls_all,oldspaceComm,ier)
  call xallgatherv_mpi&
&  (kg_k_gather(2,:),ndatarecv,kg_k_gather_all(2,:),npw_per_proc(:),rdispls_all,oldspaceComm,ier)
  call xallgatherv_mpi&
&  (kg_k_gather(3,:),ndatarecv,kg_k_gather_all(3,:),npw_per_proc(:),rdispls_all,oldspaceComm,ier)
  call timab(548,2,tsec)
  call sphereboundary(gs_hamk%gbound,istwf_k,kg_k_gather_all,mgfft,npw_tot)
  deallocate(kg_k_gather_all,npw_per_proc,rdispls_all)
 end if !End of the icall=1 and iblock=1 conditions

 sendcounts(:)=npw_k
 do iproc=1,blocksize
  sdispls(iproc)=(iproc-1)*npw_k
 end do

 allocate(cwavef_alltoall(2,ndatarecv))
 recvcountsloc(:)=recvcounts(:)*2
 rdisplsloc(:)=rdispls(:)*2
 sendcountsloc(:)=sendcounts(:)*2
 sdisplsloc(:)=sdispls(:)*2
 call timab(547,1,tsec)
 call xalltoallv_mpi(cwavef,sendcountsloc,sdisplsloc,cwavef_alltoall,&
&         recvcountsloc,rdisplsloc,spaceComm,ier)
 call timab(547,2,tsec)
!Attention, c'est pour les essais. Le test est a remettre par la suite.
 if(abs(occ_k(mpi_enreg%coords(2)+1+(iblock-1)*blocksize)) >=tol8) then
  tim_fourwf=16
  weight=occ_k(mpi_enreg%coords(2)+1+(iblock-1)*blocksize)*wtk/gs_hamk%ucvol
  call fourwf(1,rhoaug,cwavef_alltoall,dummy,wfraug,&
&  gs_hamk%gbound,gs_hamk%gbound,&
&  istwf_k,kg_k_gather,kg_k_gather,mgfft,mpi_enreg,1,gs_hamk%ngfft,ndatarecv,1,n4,n5,n6,1,tim_fourwf,weight)
 end if
 if (gs_hamk%istwf_k==2) mpi_enreg%me_g0=old_me_g0

 mpi_enreg%paral_level= old_paral_level
 deallocate(recvcounts,sdispls,rdispls)
 deallocate(cwavef_alltoall)
 deallocate(sendcountsloc,sdisplsloc)
 deallocate(recvcountsloc,rdisplsloc)
end subroutine prep_fourwf
!!***
