!{\src2tex{textfont=tt}}
!!****f* ABINIT/afterscfloop
!! NAME
!! afterscfloop
!!
!! FUNCTION
!! Perform all calculations needed after the SCF loop, independent of the
!! call to scfcv (with or without atomic displacements), and exclusive
!! of print or write purposes, or deallocations.
!!
!! COPYRIGHT
!! Copyright (C) 2005-2006 ABINIT group (XG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!!
!! INPUTS
!!  atindx(natom)=index table for atoms (see scfcv.f)
!!  atindx1(natom)=index table for atoms, inverse of atindx (see scfcv.f)
!!  cg(2,mpw*dtset%nspinor*mband*mkmem*nsppol)=wavefunctions
!!                  (may be read from disk instead of input)
!!  cpus= cpu time limit in seconds
!!  deltae=change in energy between the previous and present SCF cycle
!!  dielar(7)=input parameters for dielectric matrix:
!!                diecut,dielng,diemac,diemix,diegap,dielam.
!!  dielstrt=number of the step at which the dielectric preconditioning begins.
!!  dtfil <type(datafiles_type)>=variables related to files
!!  dtset <type(dataset_type)>=all input variables in this dataset
!!   | mband=maximum number of bands
!!   | mgfft=maximum size of 1D FFTs (see NOTES at beginning of scfcv)
!!   | mkmem=maximum number of k points in core memory
!!   | mpw = maximum number of plane waves
!!   | natom=number of atoms in cell
!!   | nfft=(effective) number of FFT grid points (for this processor) (see NOTES at beginning of scfcv)
!!   | nkpt=number of k points in Brillouin zone
!!   | nspden=number of spin-density components
!!   | nsppol=1 for unpolarized, 2 for spin-polarized
!!   | nsym=number of symmetries in space group
!!  eei=local pseudopotential part of Etot (hartree)
!!  eeig=Sum of the eigenvalues - Band energy (Hartree)
!!  eew=Ewald energy (hartree)
!!  ehart=Hartree energy (hartree)
!!  eigen(mband*nkpt*nsppol)=array for holding eigenvalues (hartree)
!!  eii=pseudoion core correction energy part of Etot (hartree)
!!  ek=kinetic energy part of total energy
!!  enl=nonlocal pseudopotential part of total energy.
!!  entropy=entropy due to the occupation number smearing (if metal)
!!  enxc=exchange-correlation energy (hartree)
!!  enxcdc=exchange-correlation double-counting energy (hartree)
!!  epaw=PAW spherical part energy
!!  epawdc=PAW spherical part double-counting energy
!!  fermie=fermi energy (Hartree)
!!  filapp character(len=fnlen)=generic output root name, with appendix
!!  filfft character(len=fnlen) =temporary FFT file, to be deleted
!!  grewtn(3,natom)=d(Ewald)/d(xred) (hartree)
!!  gsqcut=cutoff value on G**2 for (large) sphere inside FFT box.
!!                       gsqcut=(boxcut**2)*dtset%ecut/(2.d0*(Pi**2)
!!  hdr <type(hdr_type)>=the header of wf, den and pot files
!!  indsym(4,nsym,natom)=index showing transformation of atom labels
!!                       under symmetry operations (computed in symatm)
!!  initialized= if 0, the initialization of the gstate run is not yet finished
!!  ispmix=0 if mixing is done in real space, 1 if mixing is done in reciprocal space
!!  istep=number of the SCF iteration
!!  i_rhor(n_index)=indices of the density in the array f_fftgr
!!  i_vresid(n_index)=indices of the potential/density residuals in the array f_fftgr
!!  i_vrespc(n_index)=indices of the preconditioned potential/density residuals in the array f_fftgr
!!  i_vtrial(n_index)=indices of the potential/density in the array f_fftgr
!!  kg(3,mpw*mkmem)=reduced (integer) coordinates of G vecs in basis sphere
!!  kg_diel(3,npwdiel)=reduced planewave coordinates for the dielectric matrix.
!!  kxc(nfftf,nkxc)=XC kernel
!!  mgfftf= - PAW only - maximum size of 1D FFTs for the "fine" grid (see NOTES at beginning of scfcv)
!!  moved_atm_inside: if==1, the atoms are allowed to move.
!!  mpi_enreg=informations about MPI parallelization
!!  n3xccc=dimension of the xccc3d array (0 or nfft).
!!  nattyp(dtset%ntypat)=number of atoms of each type
!!  nfftf= - PAW only - number of FFT grid points for the "fine" grid (see NOTES at beginning of scfcv)
!!  nfftmix=dimension of FFT grid used to mix potentials/densities (used in PAW only)
!!  ngfft(18)=contain all needed information about 3D FFT (see NOTES at beginning of scfcv)
!!  ngfftf(18)= - PAW only - contain all needed information about 3D FFT  for the "fine" grid
!!  ngfftmix(18)= -contain all needed information about 3D FFT  for the grid corresponding to nfftmix
!!  nhat(nfftf,nspden*psps%usepaw)= compensation charge density on rectangular grid in real space
!!  nkxc=dimension of kxc
!!  npawmix=-PAW only- number of spherical part elements to be mixed
!!  npwarr(nkpt)=number of planewaves in basis and on boundary for each k
!!  npwdiel=number of planewaves for dielectric matrix
!!  n1xccc=dimension of xccc1d ; 0 if no XC core correction is used
!!  nvresid(nfftf,nspden)=array for the residual of the density/potential
!!  n_fftgr=third dimension of the array f_fftgr
!!  n_index=dimension for indices of potential/density (see ivrespc, i_vtrial...)
!!  occ(mband*nkpt*nsppol)=occupancies of bands at various k points
!!  optres=0: the potential residual has been computed in scfcv
!!         1: the density residual has been computed in scfcv
!!  optxc=option for XC
!!  paw_ij(natom*usepaw) <type(paw_ij_type)>=paw arrays given on (i,j) channels
!!  pawang <type(pawang_type)>=paw angular mesh and related data
!!  pawfgr <type(pawfgr_type)>=fine grid parameters and related data
!!  pawfgrtab(natom*usepaw) <type(pawfgrtab_type)>=atomic data given on fine rectangular grid
!!  pawtab(dtset%ntypat) <type(pawtab_type)>=paw tabulated starting data
!!  pel(3)=reduced coordinates of the electronic polarization (a. u.)
!!  pel_cg(3) = reduced coordinates of the electronic polarization (a. u.)
!!             computed in the SCF loop
!!  ph1df(2,3*(2*mgfftf+1)*natom)= - PAW only - 1-dim structure factor phases for the "fine" grid
!!      (see NOTES at beginning of scfcv)
!!  pion(3)=reduced coordinates of the ionic polarization (a. u.)
!!  prtfor=1 only if forces have to be printed (0 otherwise)
!!  psps <type(pseudopotential_type)>=variables related to pseudopotentials
!!   | mpsang= 1+maximum angular momentum
!!  pwind(pwind_alloc,2,3) = array used to compute
!!           the overlap matrix smat between k-points (see initberry.f)
!!  pwind_alloc = first dimension of pwind
!!  pwnsfac(2,pwind_alloc) = phase factors for non-symmorphic translations
!!  res2=density/potential residual (squared)
!!  resid(mband*nkpt*nsppol)=residuals for each band over all k points and spins
!!  residm=maximum value from resid array (except for nbdbuf highest bands)
!!  rhocore= (to be described)
!!  rhog(2,nfftf)=Fourier transform of total electron density (including compensation density in PAW)
!!  rhor(nfftf,nspden)=total electron density (including compensation density in PAW)
!!  rhore= (to be described)
!!  rhototp= (to be described)
!!  rprimd(3,3)=dimensional primitive translations in real space (bohr)
!!  stress_needed=1 if stresses are needed, 0 otherwise
!!  strsxc(6)=xc correction to stress
!!  susmat(2,npwdiel,nspden,npwdiel,nspden)=
!!   the susceptibility (or density-density response) matrix in reciprocal space
!!  symrec(3,3,nsym)=symmetries in reciprocal space, reduced coordinates
!!  tollist(12)=list of tolerances
!!  usexcnhat= -PAW only- flag controling use of compensation density in Vxc
!!  vhartr(nfftf)=Hartree potential
!!  vpsp(nfftf)=array for holding local psp
!!  vtrial(nfftf,nspden)=INPUT potential Vtrial(r).
!!  vxc(nfftf,nspden)=exchange-correlation potential (hartree) in real space
!!  vxcavg=vxc average
!!  wffnow=unit number for current wf disk file
!!  xccc3d(n3xccc)=3D core electron density for XC core correction, bohr^-3
!!  xred(3,natom)=reduced dimensionless atomic coordinates
!!  ylm(mpw*mkmem,mpsang*mpsang*useylm)= real spherical harmonics for each G and k point
!!  ylmgr(mpw*mkmem,3,mpsang*mpsang*useylm)= gradients of real spherical harmonics
!!
!! OUTPUT
!! atmrhoij(natom*usepaw) <type(atmrhoij_type)>= -PAW only- atomic occupancies
!!  dbl_nnsclo=1 if nnsclo has to be doubled to secure the convergence.
!!  results_gs <type(results_gs_type)>=results (energy and its components,
!!   forces and its components, the stress tensor) of a ground-state computation
!!   (should be made a pure output quantity)
!!  xred_old(3,natom)=reduced dimensionless atomic coordinates, from input xred
!!  ==== if forces are required ====
!!   diffor=maximal absolute value of changes in the components of
!!          force between the input and the output.
!!   favg(3)=mean of the forces before correction for translational symmetry
!!   fcart(3,natom)=forces in cartesian coordinates (Ha/Bohr)
!!     at input, previous value of forces,
!!     at output, new value.
!!     Note : unlike fred, this array has been corrected by enforcing
!!     the translational symmetry, namely that the sum of force
!!     on all atoms is zero.
!!   fred(3,natom)=symmetrized grtn = d(etotal)/d(xred)
!!   gresid(3,natom)=forces due to the residual of the potential
!!   grhat(3,natom)=-PAW ONLY- Gradients of energy due to compensation charge
!!   grhf(3,natom)=Hellman-Feynman derivatives of the total energy
!!   grxc(9+3*natom)=d(Exc)/d(xred) if core charges are used
!!   maxfor=maximal absolute value of the output array force.
!!   synlgr(3,natom)=symmetrized gradients of energy due to nonlocal contributions
!!  ==== if stress tensor is required ====
!!   strten(6)=components of the stress tensor (hartree/bohr^3) for the
!!    6 unique components of this symmetric 3x3 tensor:
!!    Given in order (1,1), (2,2), (3,3), (3,2), (3,1), (2,1).
!!
!! SIDE EFFECTS
!! computed_forces=1 if forces have been computed, 0 otherwise
!! dtefield <type(efield_type)> = variables related to Berry phase
!!       and electric field calculations (see initberry.f).
!!       In case dtset%berryopt = 4, the overlap matrices computed
!!       in this routine are stored in dtefield%smat in order
!!       to be used in the electric field calculation.
!! enefield=field energy
!! etotal=total energy, might be correct by improved polarization computation
!! forold(3,natom)=old forces
!! ===== if dtset%iprcch==3 .and. moved_atm_inside==1 =====
!!   ph1d(2,3*(2*mgfft+1)*natom)=1-dim structure factor phases
!! ===== if psps%usepaw==1
!!   paw_ij(iatom)%grhoij(ngrhoij,lmn2_size,nspden)= gradients of rhoij quantities for each atom
!!                                       with respect to atomic positions
!! ==== if (dtset%iscf>=10
!!  dielinv(2,npwdiel,nspden,npwdiel,nspden)=inverse of the dielectric matrix in rec. space
!!  dtn_pc(3,natom)=preconditioned change of atomic position, in reduced coordinates
!!  f_atm(3,natom,n_fftgr)=different functions defined for each atom
!!  f_fftgr((2-(nfftmix/nfftf))*nfftmix,nspden,n_fftgr*dtset%mffmem)=different functions defined on the fft grid
!!   (see prcref, scfeig, scfopt, and scfcge for a detailed explanation).
!!   If dtset%mffmem=0, these data are kept on disk.
!!  f_paw(npawmix,n_fftgr*dtset%mffmem*usepaw)=different functions used for PAW
!!                                         (same as f_fftgr but for spherical part)
!!  rhor(nfftf,nspden),rhog(2,nfftf)= at input, it is the density that gave nvresid
!!                                    at output, it is an updated (mixed) density
!!
!! NOTES
!!
!! PARENTS
!!      scfcv
!!
!! CHILDREN
!!      calc_lifetime,elpolariz,forstr,getph,hartre1,hdr_update,metric,newrho
!!      rhohxc,scprqt,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine afterscfloop(atindx,atindx1,atmrhoij,cg,computed_forces,cpus,dbl_nnsclo,&
& deltae,dielar,dielinv,dielstrt,diffor,dtefield,dtfil,dtn_pc,dtset,eei,eeig,eew,&
& ehart,eigen,eii,ek,enefield,enl,entropy,enxc,enxcdc,epaw,epawdc,etotal,&
& f_atm,f_fftgr,f_paw,favg,fcart,fermie,filapp,filfft,forold,fred,gresid,grewtn,grhat,grhf,&
& grxc,gsqcut,hdr,i_rhor,i_vresid,i_vrespc,i_vtrial,indsym,initialized,&
& ispmix,istep,kg,kg_diel,kxc,maxfor,mgfftf,mgfftdiel,&
& moved_atm_inside,mpi_enreg,npwdiel,&
& n1xccc,n3xccc,nattyp,n_fftgr,n_index,&
& nfftf,nfftmix,ngfft,ngfftf,ngfftmix,nhat,nkxc,npawmix,npwarr,nvresid,&
& occ,optres,optxc,paw_ij,pawang,pawfgr,pawfgrtab,pawtab,pel,pel_cg,&
& ph1d,ph1df,pion,prtfor,psps,pwind,pwind_alloc,pwnsfac,res2,resid,residm,results_gs,&
& rhocore,rhog,rhor,rhore,rhototp,&
& rprimd,stress_needed,strsxc,strten,susmat,symrec,synlgr,tollist,usexcnhat,&
& vhartr,vpsp,vtrial,vxc,vxcavg,wffnow,xccc3d,xred,xred_old,ylm,ylmgr)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01managempi
 use interfaces_01util
 use interfaces_02geometry
 use interfaces_03paw
 use interfaces_03recipspace
 use interfaces_03xc
 use interfaces_04iowfdenpot
 use interfaces_05common
 use interfaces_11drive, except_this_one => afterscfloop
#else
 use defs_xc
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: dielstrt,initialized,ispmix,istep,mgfftdiel,mgfftf
 integer,intent(in) :: moved_atm_inside,n1xccc,n3xccc,n_fftgr,n_index,nfftf
 integer,intent(in) :: nfftmix,nkxc,npawmix,npwdiel,optres,optxc,prtfor
 integer,intent(in) :: pwind_alloc,stress_needed,usexcnhat
 integer,intent(inout) :: computed_forces
 integer,intent(out) :: dbl_nnsclo
 real(dp),intent(in) :: cpus,deltae,eei,eeig,eew,ehart,eii,ek,enl,entropy,enxc
 real(dp),intent(in) :: enxcdc,epaw,epawdc,fermie,gsqcut,res2,residm
 real(dp),intent(inout) :: diffor,enefield,etotal,maxfor,vxcavg
 character(len=fnlen),intent(in) :: filapp,filfft
 type(MPI_type),intent(inout) :: mpi_enreg
 type(datafiles_type),intent(in) :: dtfil
 type(dataset_type),intent(inout) :: dtset
 type(efield_type),intent(inout) :: dtefield
 type(hdr_type),intent(inout) :: hdr
 type(pawang_type),intent(in) :: pawang
 type(pawfgr_type),intent(in) :: pawfgr
 type(pseudopotential_type),intent(in) :: psps
 type(results_gs_type),intent(inout) :: results_gs
 type(wffile_type),intent(inout) :: wffnow
!arrays
 integer,intent(in) :: atindx(dtset%natom),atindx1(dtset%natom)
 integer,intent(in) :: indsym(4,dtset%nsym,dtset%natom)
 integer,intent(in) :: kg(3,dtset%mpw*dtset%mkmem),kg_diel(3,npwdiel)
 integer,intent(in) :: nattyp(dtset%ntypat),ngfft(18),ngfftf(18),ngfftmix(18)
 integer,intent(in) :: npwarr(dtset%nkpt),pwind(pwind_alloc,2,3)
 integer,intent(in) :: symrec(3,3,dtset%nsym)
 integer,intent(inout) :: i_rhor(n_index),i_vresid(n_index),i_vrespc(n_index)
 integer,intent(inout) :: i_vtrial(n_index)
 real(dp),intent(in) :: cg(2,dtset%mpw*dtset%nspinor*dtset%mband*dtset%mkmem*dtset%nsppol)
 real(dp),intent(in) :: dielar(7),eigen(dtset%mband*dtset%nkpt*dtset%nsppol)
 real(dp),intent(in) :: grewtn(3,dtset%natom)
 real(dp),intent(in) :: occ(dtset%mband*dtset%nkpt*dtset%nsppol),pel_cg(3)
 real(dp),intent(in) :: pwnsfac(2,pwind_alloc)
 real(dp),intent(in) :: resid(dtset%mband*dtset%nkpt*dtset%nsppol)
 real(dp),intent(in) :: rhocore(nfftf),rhore(nfftf,dtset%nspden),rhototp(nfftf)
 real(dp),intent(in) :: rprimd(3,3)
 real(dp),intent(in) :: susmat(2,npwdiel,dtset%nspden,npwdiel,dtset%nspden)
 real(dp),intent(in) :: tollist(12),vpsp(nfftf),vtrial(nfftf,dtset%nspden)
 real(dp),intent(in) :: ylm(dtset%mpw*dtset%mkmem,psps%mpsang*psps%mpsang*psps%useylm)
 real(dp),intent(in) :: ylmgr(dtset%mpw*dtset%mkmem,3,psps%mpsang*psps%mpsang*psps%useylm)
 real(dp),intent(inout) :: dielinv(2,npwdiel,dtset%nspden,npwdiel,dtset%nspden)
 real(dp),intent(inout) :: dtn_pc(3,dtset%natom),f_atm(3,dtset%natom,n_fftgr)
 real(dp),intent(inout) :: f_fftgr((2-(nfftmix/nfftf))*nfftmix,dtset%nspden,n_fftgr*dtset%mffmem)
 real(dp),intent(inout) :: f_paw(npawmix,n_fftgr*dtset%mffmem*psps%usepaw)
 real(dp),intent(inout) :: forold(3,dtset%natom)
 real(dp),intent(inout) :: nhat(nfftf,dtset%nspden*psps%usepaw)
 real(dp),intent(inout) :: nvresid(nfftf,dtset%nspden),pel(3)
 real(dp),intent(inout) :: ph1d(2,3*(2*dtset%mgfft+1)*dtset%natom)
 real(dp),intent(inout) :: ph1df(2,3*(2*dtset%mgfft+1)*dtset%natom),pion(3)
 real(dp),intent(inout) :: rhog(2,nfftf),rhor(nfftf,dtset%nspden),strsxc(6)
 real(dp),intent(inout) :: vhartr(dtset%nfft),vxc(nfftf,dtset%nspden)
 real(dp),intent(inout) :: xccc3d(n3xccc),xred(3,dtset%natom)
 real(dp),intent(out) :: favg(3),fcart(3,dtset%natom),fred(3,dtset%natom)
 real(dp),intent(out) :: gresid(3,dtset%natom),grhat(3,dtset%natom)
 real(dp),intent(out) :: grhf(3,dtset%natom),grxc(3,dtset%natom)
 real(dp),intent(out) :: kxc(nfftf,nkxc),strten(6),synlgr(3,dtset%natom)
 real(dp),intent(out) :: xred_old(3,dtset%natom)
 type(atmrhoij_type),intent(out) :: atmrhoij(dtset%natom*psps%usepaw)
 type(paw_ij_type),intent(inout) :: paw_ij(dtset%natom*psps%usepaw)
 type(pawfgrtab_type),intent(in) :: pawfgrtab(dtset%ntypat*psps%usepaw)
 type(pawtab_type),intent(in) :: pawtab(dtset%ntypat*psps%usepaw)

!Local variables-------------------------------
!scalars
 integer,parameter :: response=0
 integer :: bantot,choice,iatom,ii,irhoij,ispden,nhatgrdim,optfor,optstr,quit
 real(dp) :: dum,enxcsr,lifetime,rcut_coulomb,rcut_coulomb1,ucvol
 logical :: ex
 character(len=500) :: message
 type(dataset_type) :: dtLocal
!arrays
 real(dp) :: gmet(3,3),gprimd(3,3),rhodum(1),rmet(3,3)
 real(dp),allocatable :: ehart1(:),nhatgr(:,:,:),qphon(:),vhart1(:)

! *************************************************************************

!DEBUG
!write(6,*)' afterscfloop : enter '
!ENDDEBUG

!Compute different geometric tensor, as well as ucvol, from rprimd
 call metric(gmet,gprimd,-1,rmet,rprimd,ucvol)

!Perform the positron lifetime calculation
 if (dtset%positron/=0) then
  call calc_lifetime(dtset%ixcpositron,lifetime,nfftf,dtset%nspden,dtset%positron,rhocore,rhore,rhototp,ucvol)
 end if

!Before leaving the present routine, save the current value of xred.
 xred_old(:,:)=xred(:,:)

!Recompute structure factor phases if atomic positions have changed
 if (moved_atm_inside==1) then
  if (psps%usepaw==1.and.pawfgr%usefinegrid==1) then
   call getph(atindx,dtset%natom,ngfft(1),ngfft(2),ngfft(3),ph1d,xred)
  else
   ph1d(:,:)=ph1df(:,:)
  end if
 end if

!----------------------------------------------------------------------
! Polarization Calculation
!----------------------------------------------------------------------

 if(dtset%berryopt/=0)then
  call elpolariz(atindx1,cg,dtefield,dtfil,dtset,etotal,enefield,gprimd,hdr,&
&  kg,dtset%mband,mgfftf,dtset%mkmem,mpi_enreg,dtset%mpw,dtset%natom,nattyp,dtset%nkpt,&
&  npwarr,dtset%nspinor,dtset%nsppol,psps%ntypat,pel,pel_cg,pion,psps,pwind,pwind_alloc,&
&  pwnsfac,rprimd,ucvol,wffnow,xred)
 end if ! dtset%berryopt/=0

!######################################################################
! Compute forces (if they were not computed during the elec. iterations)
! and stresses (if requested by user)
!----------------------------------------------------------------------

 optfor=0
 if (computed_forces==0.and.dtset%optforces>0.and.dtset%iscf>0) then
  if (dtset%nstep>0.or.dtfil%ireadwf==1) optfor=1
 end if

 call forstr(atindx,atindx1,cg,diffor,dtset,eei,&
&             ehart,eigen,eii,ek,favg,fcart,forold,fred,gresid,grewtn,grhat,&
&             grhf,grxc,gsqcut,indsym,&
&             kg,kxc,maxfor,mgfftf,mpi_enreg,&
&             n3xccc,nattyp,nfftf,ngfftf,nhat,nkxc,&
&             npwarr,dtset%nspinor,psps%ntypat,nvresid,occ,optfor,optres,&
&             paw_ij,pawang,pawfgr,pawfgrtab,pawtab,pel_cg,ph1d,ph1df,pion,&
&             psps,rhog,rhor,rprimd,stress_needed,strsxc,strten,symrec,synlgr,&
&             ucvol,dtfil%unkg,dtfil%unpaw,dtfil%unylm,vhartr,vpsp,vxc,wffnow,&
&             xccc3d,xred,ylm,ylmgr)
 if (optfor==1) computed_forces=1
 if (stress_needed==0) strten(:)=9.9999999999D99
 if (computed_forces==0) fcart(:,:)=9.9999999999D99
 if (dtset%prtstm/=0) strten(:)=zero
 if (dtset%positron/=0) strten(:)=zero

!Berry phase: compute stress tensor imposing a constant potential
 if (dtset%berryopt == 4 .and. stress_needed/=0) then
  write(message,'(a,a,a)')ch10,&
&  ' Stress tensor imposing a constant potential drop across',&
&  '  each lattice vector:'
   call wrtout(6,message,'COLL')
   call wrtout(ab_out,message,'COLL')

! Compute stress tensor
  call dtsetCopy(dtLocal, dtset)
  dtLocal%berryopt = 0
  optfor=0
  call forstr(atindx,atindx1,cg,diffor,dtLocal,eei,&
&              ehart,eigen,eii,ek,favg,fcart,forold,fred,gresid,grewtn,grhat,&
&              grhf,grxc,gsqcut,indsym,&
&              kg,kxc,maxfor,mgfftf,mpi_enreg,&
&              n3xccc,nattyp,nfftf,&
&              ngfftf,rhodum,nkxc,npwarr,&
&              dtset%nspinor,psps%ntypat,nvresid,occ,optfor,optres,paw_ij,pawang,pawfgr,&
&              pawfgrtab,pawtab,pel_cg,ph1d,ph1df,pion,psps,&
&              rhog,rhor,rprimd,stress_needed,strsxc,&
&              strten,symrec,synlgr,ucvol,dtfil%unkg,dtfil%unpaw,&
&              dtfil%unylm,vhartr,vpsp,vxc,wffnow,xccc3d,xred,ylm,ylmgr)
  call dtsetFree(dtLocal)
 end if


!If SCF convergence was not reached (for dtset%nstep>0),
!print a warning to the output file (non-dummy arguments: dtset%nstep,
!residm, diffor - infos from tollist have been saved inside )
 choice=3
 call scprqt(dtset%chkexit,choice,cpus,deltae,diffor,&
&            eigen,dtset%enunit,etotal,favg,fcart,fermie,filapp,dtfil%filnam_ds(1),&
&            dtset%ionmov,dtset%iscf,istep,dtset%kptns,dtset%kptopt,maxfor,dtset%mband,&
&            moved_atm_inside,mpi_enreg,dtset%natom,dtset%nband,dtset%nkpt,dtset%nnsclo,&
&            dtset%nsppol,dtset%nstep,occ,dtset%occopt,optres,dtset%outputXML,dtset%prteig,prtfor,dtset%prtstm,dtset%prtvol,quit,&
&            res2,resid,residm,response,tollist,psps%usepaw,vxcavg,dtset%wtk,xred)

 if(dtset%nfreqsus>0)then
! At the end of the SCF cycle compute the short-range correlation energy
! in RPA-LSD (dtset%ixc==10). Note: after call to rhohxc, vxc indeed correponds to dtset%ixc==10.
  call dtsetCopy(dtLocal, dtset)
  dtLocal%ixc = 10
  nhatgrdim=0
  call rhohxc(dtLocal,enxcsr,gsqcut,psps%usepaw,kxc,mpi_enreg,nfftf,ngfftf,&
&  nhat,psps%usepaw,nhatgr,nhatgrdim,nkxc,dtset%nspden,n3xccc,optxc,rhog,rhor,rprimd,strsxc,usexcnhat,vhartr,vxc,vxcavg,xccc3d)
  write(message,'(4a,1x,es16.10,2a)') ch10,&
&    ' scfcv: beyond-RPA short-range correlation energy in LSDA ---', ch10,&
&    '  LSD-RPA+ correlation energy=', enxcsr, ' hartree',ch10
  call wrtout(ab_out,message,'COLL')
  call wrtout(6,message,'COLL')
! Restore the xc potential.
  if (psps%usepaw==1.and.usexcnhat>0.and.dtset%ixc>=11.and.dtset%ixc<=16) then
   nhatgrdim=1;allocate(nhatgr(dtset%nfft,dtset%nspden,3))
   call pawmknhat(dum,1,0,mpi_enreg,dtset%natom,dtset%nfft,ngfft,nhatgrdim,dtset%nspden,dtset%ntypat,paw_ij,&
&                 pawang,pawfgrtab,nhatgr,nhat,pawtab,dtset%typat,ucvol)
  end if
  call rhohxc(dtset,enxcsr,gsqcut,psps%usepaw,kxc,mpi_enreg,nfftf,ngfftf,&
&  nhat,psps%usepaw,nhatgr,nhatgrdim,nkxc,dtset%nspden,n3xccc,optxc,rhog,rhor,rprimd,strsxc,&
&  usexcnhat,vhartr,vxc,vxcavg,xccc3d)
  if (nhatgrdim>0) deallocate(nhatgr)
! Also check the Hartree energy with a real-space cutoff for the Coulomb interaction
  allocate(ehart1(3),qphon(3),vhart1(nfftf))
  vhart1(:)=zero;qphon(:)=zero;rcut_coulomb=1.d20
  do ii=1,3; rcut_coulomb=min(rcut_coulomb,sum(rprimd(:,ii)*rprimd(:,ii))); end do
  rcut_coulomb=0.5d0*sqrt(rcut_coulomb)
  write(6,*) '%scfcv: Check cutoff Coulomb interaction, show Hartree energy:'
  write(6,'(1x,a,1x,a,1x,a,6x,a)') 'cutoff radius',&
&  ' with cutoff (with G=0)','(without G=0)','no cutoff'
  rcut_coulomb1=max(0.5*rcut_coulomb,rcut_coulomb-2.d0)
  do while (rcut_coulomb1<min(2.0*rcut_coulomb,rcut_coulomb+2.d0))
   call hartre1(1,gmet,gsqcut,nfftf,ngfftf,qphon,rhog,vhart1,ehart1,&
&               rcut_coulomb1,ucvol)
   write(6,'(f14.8,1x,3(3x,es14.7))') rcut_coulomb1,ehart1(3),ehart1(1),ehart1(2)
   rcut_coulomb1=rcut_coulomb1+0.5d0
  end do
  call hartre1(1,gmet,gsqcut,nfftf,ngfftf,qphon,rhog,vhart1,ehart1,&
&              rcut_coulomb,ucvol)
  write(message,'(4a,1x,es16.8,3a,1x,es16.8,2a)') ch10,&
&   ' scfcv: Hartree energy with real-space cutoff for Coulomb interaction ---', ch10,&
&   '   Cutoff radius=', rcut_coulomb, ' bohr',ch10,&
&   '  Hartree energy=', ehart1(3)   , ' hartree',ch10
  call wrtout(ab_out,message,'COLL')
  call wrtout(6,message,'COLL')
  call dtsetFree(dtLocal)
  if(allocated(ehart1)) deallocate(ehart1)
  if(allocated(qphon))  deallocate(qphon)
  if(allocated(vhart1))  deallocate(vhart1)
 end if

!If density mixing was required, has to mix here the density
!in order to optimize a restart from current density
 if (dtset%iscf>=10.and.dtset%nstep>0) then
  call newrho(atindx,dbl_nnsclo,dielar,dielinv,dielstrt,dtn_pc,dtset,etotal,fcart,pawfgr%fintocoa,filfft,&
&    f_atm,f_fftgr,f_paw,gmet,grhf,gsqcut,initialized,&
&    ispmix,istep,i_rhor,i_vresid,i_vrespc,i_vtrial,kg_diel,kxc,mgfftf,mgfftdiel,pawfgr%coatofin,&
&    moved_atm_inside,mpi_enreg,nattyp,nfftf,nfftmix,ngfftf,ngfftmix,nkxc,npawmix,npwdiel,&
&    nvresid,psps%ntypat,n_fftgr,n_index,n1xccc,paw_ij,&
&    ph1df,psps,rhog,rhor,rprimd,susmat,psps%usepaw,vtrial,xred)
 end if

!Delete eventual _FFT file
 if(dtset%mffmem==0)then
  inquire (file=filfft,exist=ex)
  if(ex)then
   open(unit=tmp_unit,file=filfft,form='unformatted',status='old')
   close(unit=tmp_unit,status='DELETE')
  end if
 end if

!PAW: update rhoij occupancies
 if (psps%usepaw==1) then
  do iatom=1,dtset%natom
   do ispden=1,dtset%nspden
    irhoij=paw_ij(iatom)%nrhoijsel(ispden)
    atmrhoij(iatom)%nrhoijsel(ispden)=irhoij
    atmrhoij(iatom)%rhoij(1:irhoij,ispden)=paw_ij(iatom)%rhoijp(1:irhoij,ispden)
    atmrhoij(iatom)%rhoijselect(1:irhoij,ispden)=paw_ij(iatom)%rhoijselect(1:irhoij,ispden)
   end do
  end do
 end if

!Update the content of the header (evolving variables)
 bantot=hdr%bantot
 call hdr_update(atmrhoij,bantot,etotal,fermie,hdr,dtset%natom,residm,rprimd,occ,psps%usepaw,xred)

 results_gs%eei        =eei
 results_gs%eeig       =eeig
 results_gs%eew        =eew
 results_gs%ehart      =ehart
 results_gs%eii        =eii
 results_gs%ek         =ek
 results_gs%enefield   =enefield
 results_gs%enl        =enl
 results_gs%enxc       =enxc
 results_gs%enxcdc     =enxcdc
 results_gs%etotal     =etotal
 results_gs%fcart(:,:) =fcart(:,:)
 results_gs%fred(:,:)  =fred(:,:)
 results_gs%gresid(:,:)=gresid(:,:)
 results_gs%grewtn(:,:)=grewtn(:,:)
 results_gs%grhat(:,:) =grhat(:,:)
 results_gs%grxc(:,:)  =grxc(:,:)
 results_gs%pel(1:3)   =pel(1:3)
 results_gs%residm     =residm
 results_gs%strten(1:6)=strten(1:6)
 results_gs%synlgr(:,:)=synlgr(:,:)
 results_gs%vxcavg     =vxcavg
 if (psps%usepaw==1) then
  results_gs%epaw      =epaw
  results_gs%epawdc    =epawdc
 end if
 if (dtset%nstep>0) then
  results_gs%entropy    =entropy
  results_gs%fermie     =fermie
 else
  if (dtset%occopt>=3.and.dtset%occopt<=7) results_gs%etotal=results_gs%etotal-dtset%tsmear*results_gs%entropy
 end if

!DEBUG
!write(6,*)' afterscfloop : exit'
!stop
!ENDDEBUG

end subroutine afterscfloop
!!***
