!{\src2tex{textfont=tt}}
!!****f* ABINIT/int_ang
!! NAME
!! int_ang
!!
!! FUNCTION
!! routine for evaluation of angular part for <phi_i|nabla|phi_j> and <tphi_i|nabla|tphi_j>
!! Modification 02/06 VR
!! COPYRIGHT
!! Copyright (C) 2005-2006 ABINIT group (VR)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!!
!! INPUTS
!!
!!
!! OUTPUT
!!  ang_phipphj :: angular part for <phi_i|nabla|phi_j> and <tphi_i|nabla|tphi_j>
!!  ang_phipphj(i,j,1)=\int sin\theta cos\phi Si Sj d\omega
!!  ang_phipphj(i,j,2)=\int cos\theta cos\phi Si \frac{d}{d\theta}Sj d\Omega
!!  ang_phipphj(i,j,3)=\int -sin\phi  Si \frac{d}{d\phi}Sj d\Omega
!!  ang_phipphj(i,j,4)=\int sin\theta sin\phi Si Sj d\Omega
!!  ang_phipphj(i,j,5)=\int cos\theta sin\phi Si \frac{d}{d\theta}Sj d\Omega
!!  ang_phipphj(i,j,6)=\int cos\phi Si \frac{d}{d\phi}Sj d\Omega
!!  ang_phipphj(i,j,7)=\int cos\theta  Si Sj d\Omega
!!  ang_phipphj(i,j,8)=\int -sin\theta Si \frac{d}{d\theta}Sj d\Omega
!!
!! SIDE EFFECTS
!!  (only writing, printing)
!!
!! NOTES
!!
!! PARENTS
!!      optics_paw
!!
!! CHILDREN
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

 subroutine int_ang(ang_phipphj)

 use defs_basis
 use defs_datatypes

 implicit none

!Arguments ------------------------------------
!arrays
 real(dp) :: ang_phipphj(16,16,8)

!Local variables-------------------------------

! ************************************************************************
!
!DEBUG
! write(*,*)' int_ang : enter'
!ENDDEBUG

 ang_phipphj=zero
!
 ang_phipphj(1,2,4)=one/sqrt(three)
 ang_phipphj(1,3,7)=one/sqrt(three)
 ang_phipphj(1,4,1)=one/sqrt(three)
 ang_phipphj(2,1,4)=one/sqrt(three)
 ang_phipphj(2,5,1)=one/sqrt(five)
 ang_phipphj(2,6,7)=one/sqrt(five)
 ang_phipphj(2,7,4)=-one/sqrt(15.d0)
 ang_phipphj(2,9,4)=-one/sqrt(five)
 ang_phipphj(3,1,7)=one/sqrt(three)
 ang_phipphj(3,6,4)=one/sqrt(five)
 ang_phipphj(3,7,7)=two/sqrt(15.d0)
 ang_phipphj(3,8,1)=one/sqrt(five)
 ang_phipphj(4,1,1)=one/sqrt(three)
 ang_phipphj(4,5,4)=one/sqrt(five)
 ang_phipphj(4,7,1)=-one/sqrt(15.d0)
 ang_phipphj(4,8,7)=one/sqrt(five)
 ang_phipphj(4,9,1)=one/sqrt(five)
 ang_phipphj(5,2,1)=one/sqrt(five)
 ang_phipphj(5,4,4)=one/sqrt(five)
 ang_phipphj(5,10,1)=sqrt(three)/sqrt(14.d0)
 ang_phipphj(5,11,7)=one/sqrt(seven)
 ang_phipphj(5,12,1)=-one/sqrt(70.d0)
 ang_phipphj(5,14,4)=-one/sqrt(70.d0)
 ang_phipphj(5,16,4)=-sqrt(three)/sqrt(14.d0)
 ang_phipphj(6,2,7)=one/sqrt(five)
 ang_phipphj(6,3,4)=one/sqrt(five)
 ang_phipphj(6,11,1)=one/sqrt(seven)
 ang_phipphj(6,12,7)=two*sqrt(two)/sqrt(35.d0)
 ang_phipphj(6,13,4)=-sqrt(three)/sqrt(35.d0)
 ang_phipphj(6,15,4)=-one/sqrt(seven)
 ang_phipphj(7,2,4)=-one/sqrt(15.d0)
 ang_phipphj(7,3,7)=two/sqrt(15.d0)
 ang_phipphj(7,4,1)=-one/sqrt(15.d0)
 ang_phipphj(7,12,4)=sqrt(six)/sqrt(35.0d0)
 ang_phipphj(7,13,7)=three/sqrt(35.0d0)
 ang_phipphj(7,14,1)=sqrt(six)/sqrt(35.0d0)
 ang_phipphj(8,3,1)=one/sqrt(five)
 ang_phipphj(8,4,7)=one/sqrt(five)
 ang_phipphj(8,11,4)=one/sqrt(seven)
 ang_phipphj(8,13,1)=-sqrt(three)/sqrt(35.d0)
 ang_phipphj(8,14,7)=two*sqrt(two)/sqrt(35.0d0)
 ang_phipphj(8,15,1)=one/sqrt(seven)
 ang_phipphj(9,2,4)=-one/sqrt(five)
 ang_phipphj(9,4,1)=one/sqrt(five)
 ang_phipphj(9,10,4)=sqrt(three)/sqrt(14.d0)
 ang_phipphj(9,12,4)=one/sqrt(70.d0)
 ang_phipphj(9,14,1)=-one/sqrt(70.d0)
 ang_phipphj(9,15,7)=one/sqrt(seven)
 ang_phipphj(9,16,1)=sqrt(three)/sqrt(14.d0)
 ang_phipphj(10,5,1)=sqrt(three)/sqrt(14.d0)
 ang_phipphj(10,9,4)=sqrt(three)/sqrt(14.d0)
 ang_phipphj(11,5,7)=one/sqrt(seven)
 ang_phipphj(11,6,1)=one/sqrt(seven)
 ang_phipphj(11,8,4)=one/sqrt(seven)
 ang_phipphj(12,5,1)=-one/sqrt(70.d0)
 ang_phipphj(12,6,7)=two*sqrt(two)/sqrt(35.d0)
 ang_phipphj(12,7,4)=sqrt(six)/sqrt(35.0d0)
 ang_phipphj(12,9,4)=one/sqrt(70.0d0)
 ang_phipphj(13,6,4)=-sqrt(three)/sqrt(35.d0)
 ang_phipphj(13,7,7)=three/sqrt(35.0d0)
 ang_phipphj(13,8,1)=-sqrt(three)/sqrt(35.d0)
 ang_phipphj(14,5,4)=-one/sqrt(70.d0)
 ang_phipphj(14,7,1)=sqrt(six)/sqrt(35.0d0)
 ang_phipphj(14,8,7)=two*sqrt(two)/sqrt(35.d0)
 ang_phipphj(14,9,1)=-one/sqrt(70.d0)
 ang_phipphj(15,6,4)=-one/sqrt(seven)
 ang_phipphj(15,8,1)=one/sqrt(seven)
 ang_phipphj(15,9,7)=one/sqrt(seven)
 ang_phipphj(16,5,4)=-sqrt(three)/sqrt(14.d0)
 ang_phipphj(16,9,1)=sqrt(three)/sqrt(14.d0)
!
 ang_phipphj(1,2,5)=one/two/sqrt(three)
 ang_phipphj(1,3,8)=two/sqrt(three)
 ang_phipphj(1,4,2)=one/two/sqrt(three)
 ang_phipphj(1,12,5)=-sqrt(21.0d0)/six/sqrt(two)
 ang_phipphj(1,14,2)=-sqrt(21.0d0)/six/sqrt(two)
 ang_phipphj(2,5,2)=one/two/sqrt(five)
 ang_phipphj(2,6,8)=three/sqrt(five)
 ang_phipphj(2,7,5)=-sqrt(three/five)
 ang_phipphj(2,9,5)=-one/two/sqrt(five)
 ang_phipphj(3,6,5)=one/two/sqrt(five)
 ang_phipphj(3,7,8)=two/sqrt(three)
 ang_phipphj(3,8,2)=one/two/sqrt(five)
 ang_phipphj(4,5,5)=one/two/sqrt(five)
 ang_phipphj(4,7,2)=-sqrt(three/five)
 ang_phipphj(4,8,8)=three/sqrt(five)
 ang_phipphj(4,9,2)=one/two/sqrt(five)
 ang_phipphj(5,2,2)=one/four/sqrt(five)
 ang_phipphj(5,4,5)=one/four/sqrt(five)
 ang_phipphj(5,10,2)=sqrt(three)/two/sqrt(14.0d0)
 ang_phipphj(5,11,8)=four/sqrt(seven)
 ang_phipphj(5,12,2)=-two*sqrt(two)/sqrt(35.0d0)
 ang_phipphj(5,14,5)=-two*sqrt(two)/sqrt(35.0d0)
 ang_phipphj(5,16,5)=-sqrt(three)/two/sqrt(14.0d0)
 ang_phipphj(6,2,8)=-one/sqrt(five)
 ang_phipphj(6,3,5)=-one/sqrt(five)
 ang_phipphj(6,11,2)=one/two/sqrt(seven)
 ang_phipphj(6,12,8)=eight*sqrt(two)/sqrt(35.0d0)
 ang_phipphj(6,13,5)=-four*sqrt(three)/sqrt(35.0d0)
 ang_phipphj(6,15,5)=-one/two/sqrt(seven)
 ang_phipphj(7,2,5)=one/sqrt(15.0d0)
 ang_phipphj(7,3,8)=-two/sqrt(15.0d0)
 ang_phipphj(7,4,2)=one/sqrt(15.0d0)
 ang_phipphj(7,12,5)=0.4485426136d0
 ang_phipphj(7,13,8)=12.0d0/sqrt(35.0d0)
 ang_phipphj(7,14,2)=0.4485426136d0
 ang_phipphj(8,3,2)=-one/sqrt(five)
 ang_phipphj(8,4,8)=one/sqrt(five)
 ang_phipphj(8,11,5)=one/two/sqrt(seven)
 ang_phipphj(8,13,2)=-four*sqrt(three)/sqrt(35.0d0)
 ang_phipphj(8,14,8)=eight*sqrt(two)/sqrt(35.0d0)
 ang_phipphj(8,15,2)=one/two/sqrt(seven)
 ang_phipphj(9,2,5)=-one/four/sqrt(five)
 ang_phipphj(9,4,2)=one/four/sqrt(five)
 ang_phipphj(9,10,5)=sqrt(three)/two/sqrt(14.0d0)
 ang_phipphj(9,12,5)=two*sqrt(two)/sqrt(35.0d0)
 ang_phipphj(9,14,2)=-two*sqrt(two)/sqrt(35.0d0)
 ang_phipphj(9,15,8)=four/sqrt(seven)
 ang_phipphj(9,16,2)=sqrt(three)/two/sqrt(14.0d0)
 ang_phipphj(10,5,2)=one/sqrt(42.0d0)
 ang_phipphj(10,9,5)=one/sqrt(42.0d0)
 ang_phipphj(11,5,8)=-one/four/sqrt(seven)
 ang_phipphj(11,6,2)=-one/four/sqrt(seven)
 ang_phipphj(11,8,5)=-one/four/sqrt(seven)
 ang_phipphj(12,5,2)=sqrt(two)/sqrt(35.0d0)
 ang_phipphj(12,6,8)=-four*sqrt(two)/sqrt(35.0d0)
 ang_phipphj(12,7,5)=-two*sqrt(six)/sqrt(35.0d0)
 ang_phipphj(12,9,5)=-sqrt(two)/sqrt(35.0d0)
 ang_phipphj(13,6,5)=two*sqrt(three)/sqrt(35.0d0)
 ang_phipphj(13,7,8)=-six/sqrt(35.0d0)
 ang_phipphj(13,8,2)=two*sqrt(three)/sqrt(35.0d0)
 ang_phipphj(14,5,5)=sqrt(two)/sqrt(35.0d0)
 ang_phipphj(14,7,2)=-two/sqrt(six)/sqrt(35.0d0)
 ang_phipphj(14,8,8)=-four*sqrt(two)/sqrt(35.0d0)
 ang_phipphj(14,9,2)=sqrt(two)/sqrt(35.0d0)
 ang_phipphj(15,6,5)=one/four/sqrt(seven)
 ang_phipphj(15,8,2)=-one/four/sqrt(seven)
 ang_phipphj(15,9,8)=-two/sqrt(seven)
 ang_phipphj(16,5,5)=-one/sqrt(42.0d0)
 ang_phipphj(16,9,2)=one/sqrt(42.0d0)
!
 ang_phipphj(1,2,6)=sqrt(three)/two
 ang_phipphj(1,4,3)=sqrt(three)/two
 ang_phipphj(1,12,6)=sqrt(21.0d0)/six/sqrt(two)
 ang_phipphj(1,14,3)=sqrt(21.0d0)/six/sqrt(two)
 ang_phipphj(2,5,3)=sqrt(five)/two
 ang_phipphj(2,9,6)=-sqrt(five)/two
 ang_phipphj(3,6,6)=sqrt(five)/two
 ang_phipphj(3,8,3)=sqrt(five)/two
 ang_phipphj(4,5,6)=sqrt(five)/two
 ang_phipphj(4,9,3)=sqrt(five)/two
 ang_phipphj(5,2,3)=-sqrt(five)/four
 ang_phipphj(5,4,6)=-sqrt(five)/four
 ang_phipphj(5,10,3)=sqrt(21.0d0)/two/sqrt(two)
 ang_phipphj(5,16,6)=-sqrt(21.0d0)/two/sqrt(two)
 ang_phipphj(6,11,3)=sqrt(seven)/two
 ang_phipphj(6,15,6)=-sqrt(seven)/two
 ang_phipphj(7,12,6)=sqrt(35.0d0)/two/sqrt(six)
 ang_phipphj(7,14,3)=sqrt(35.0d0)/two/sqrt(six)
 ang_phipphj(8,11,6)=sqrt(seven)/two
 ang_phipphj(8,15,3)=sqrt(seven)/two
 ang_phipphj(9,2,6)=sqrt(five)/four
 ang_phipphj(9,4,3)=-sqrt(five)/four
 ang_phipphj(9,10,6)=sqrt(21.0d0)/two/sqrt(two)
 ang_phipphj(9,16,3)=sqrt(21.0d0)/two/sqrt(two)
 ang_phipphj(10,5,3)=-sqrt(21.0d0)/three/sqrt(two)
 ang_phipphj(10,9,6)=-sqrt(21.0d0)/two/sqrt(two)
 ang_phipphj(11,6,3)=-sqrt(seven)/four
 ang_phipphj(11,8,6)=-sqrt(seven)/four
 ang_phipphj(15,6,6)=sqrt(seven)/four
 ang_phipphj(15,8,3)=-sqrt(seven)/four
 ang_phipphj(16,5,6)=sqrt(21.0d0)/three/sqrt(two)
 ang_phipphj(16,9,3)=-sqrt(21.0d0)/three/sqrt(two)

!DEBUG
!write(6,*)' int_ang : exit '
!stop
!ENDDEBUG

 end subroutine int_ang
!!***
