!{\src2tex{textfont=tt}}
!!****f* ABINIT/optics_paw
!! NAME
!! optics_paw
!!
!! FUNCTION
!! Output routine for the outscfcv.F90 routine for optical conductivity
!!
!! COPYRIGHT
!! Copyright (C) 2005-2006 ABINIT group (FJ,VR,MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!!
!! INPUTS
!!  atindx(natom)=index table for atoms (see scfcv.f)
!!  cg(2,mpw*nspinor*mband*mkmem*nsppol)=planewave coefficients of wavefunctions.
!!  dtfil <type(datafiles_type)>=variables related to files
!!  dtset <type(dataset_type)>=all input variables for this dataset
!!  ecut=cut-off energy for plane wave basis sphere (Ha)
!!  eigen(mband*nkpt*nsppol)=array for holding eigenvalues (hartree)
!!  filapp character(len=fnlen)=generic output root name, with appendix
!!  gmet(3,3)=reciprocal space metric tensor in bohr**-2.
!!  gprimd(3,3)=dimensional reciprocal space primitive translations
!!  gsqcut=cutoff on (k+G)^2 (bohr^-2)
!!  hdr <type(hdr_type)>=the header of wf, den and pot files
!!  kg(3,mpw*mkmem)=reduced planewave coordinates.
!!  mband=maximum number of bands
!!  mkmem =number of k points which can fit in memory; set to 0 if use disk
!!  mpw=maximum dimensioned size of npw.
!!  natom=number of atoms in cell.
!!  nattyp(ntypat)= # atoms of each type.
!!  nkpt=number of k points.
!!  npwarr(nkpt)=number of planewaves in basis at this k point
!!  nspden=number of spin-density components
!!  nsppol=1 for unpolarized, 2 for spin-polarized
!!  occ(mband*nkpt*nsppol)=occupation number for each band (usually 2) for each k.
!!  pawrad(ntypat) <type(pawrad_type)>=paw radial mesh and related data:
!!     %mesh_size=Dimension of radial mesh
!!  pawrad(ntypat) <type(pawrad_type)>=paw radial mesh and related data:
!!     %mesh_size=Dimension of radial mesh
!!  pawtab(ntypat*usepaw) <type(pawtab_type)>=paw tabulated starting data
!!  ph1d(2,3*(2*mgfft+1)*natom)=one-dimensional structure factor information
!!  psps <type(pseudopotential_type)>=variables related to pseudopotentials
!!  rmet(3,3)=real space metric (bohr**2)
!!  ucvol=unit cell volume (bohr**3)
!!  xred(3,natom)=reduced dimensionless atomic coordinates
!!  ylm(mpw*mkmem,mpsang*mpsang*useylm)=real spherical harmonics for each G and k point
!!
!! OUTPUT
!!  (only writing, printing)
!!
!! SIDE EFFECTS
!!  cp(2,mpj*nspinor*mband*mkmem*nsppol)=<p_i|psi_n>
!!
!! NOTES
!!
!! PARENTS
!!      outscfcv
!!
!! CHILDREN
!!      ctocprj,int_ang,nderiv_gen,simp_gen
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

 subroutine optics_paw(atindx,atindx1,cg,dtfil,dtset,ecut,eigen,fildata,gmet,gprimd,gsc,hdr,kg,mband,mgfft,mkmem,&
&               mpi_enreg,mpsang,mpj,mpw,natom,nkpt,npwarr,nspinor,nsppol,nattyp,&
&               occ,pawrad,pawtab,ph1d,psps,rmet,ucvol,xred,ylm)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_01util
 use interfaces_03paw
 use interfaces_08seqpar
 use interfaces_11drive, except_this_one => optics_paw
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: mband,mgfft,mkmem,mpj,mpsang,mpw,natom,nkpt,nspinor
 integer,intent(in) :: nsppol
 real(dp),intent(in) :: ecut,ucvol
 character(len=fnlen),intent(in) :: fildata
 type(MPI_type),intent(inout) :: mpi_enreg
 type(datafiles_type),intent(in) :: dtfil
 type(dataset_type),intent(in) :: dtset
 type(hdr_type),intent(inout) :: hdr
 type(pseudopotential_type),intent(in) :: psps
!arrays
 integer,intent(in) :: atindx(natom),atindx1(natom),kg(3,mpw*mkmem)
 integer,intent(in) :: nattyp(natom),npwarr(nkpt)
 real(dp),intent(in) :: eigen(mband*nkpt*nsppol),gmet(3,3),gprimd(3,3)
 real(dp),intent(in) :: occ(mband*nkpt*nsppol),ph1d(2,3*(2*mgfft+1)*natom)
 real(dp),intent(in) :: rmet(3,3),xred(3,natom),ylm(mpw*mkmem,mpsang*mpsang)
 real(dp),intent(inout) :: cg(2,mpw*nspinor*mband*mkmem*nsppol)
 real(dp),intent(inout) :: gsc(2,mpw*nspinor*mband*mkmem*nsppol*psps%usepaw)
 type(pawrad_type),intent(in) :: pawrad(psps%ntypat*psps%usepaw)
 type(pawtab_type),intent(in) :: pawtab(psps%ntypat*psps%usepaw)

!Local variables-------------------------------
! integer :: npwarr(nkpt)
!scalars
 integer :: basis_size,bdtot_index,iatom,iband,ic_lmn,ic_spin,icat,icb,icg,icnk
 integer :: icp,icpb,icspol,ictyp,idir,ii,ij_size,ikg,ikpt,ilm,ilmn,ilmn2,iln
 integer :: ind,ip,ip1,ip2,ipw,ispinor,isppol,itypat,j0lm,j0lmn,j0ln,jband,jj
 integer :: jl,jlm,jlmn,jln,kk,klm,klmn,kln,lmn2_size,lmn_size,mesh_size
 integer :: nband_k,npw_k
 real(dp) :: cgnm1,cgnm2,intg,sum_cg,test_ij,test_ijk
 character(len=500) :: message
!arrays
 integer,allocatable :: indlmn_(:,:)
 real(dp) :: ang_phipphj(16,16,8),cp(2,mpj*nspinor*mband*mkmem*nsppol)
 real(dp) :: kpoint(3),kptg(3,mpw),occ_k(mband),prod_im(3),prod_re(3),tnm_im(3)
 real(dp) :: tnm_re(3),tpsi_nabla_tpsi(mband,mband,3)
 real(dp),allocatable :: dphi(:),dtphi(:),ff(:),int1(:),int2(:),phidphj(:,:)
 real(dp),allocatable :: phipphj(:,:),rad(:),tphidtphj(:,:)
!no_abirules
!
 type coeff_type    ! gives the phipphj
  real(dp), pointer :: phipphj(:,:)
 end type coeff_type
 type(coeff_type), allocatable :: typatom_fj(:)
!
 type cp_type    ! gives the cp for each n and each k for an atom
  real(dp), pointer :: cpnk(:,:,:,:,:,:)
 end type cp_type
 type(cp_type), allocatable :: atom_fj(:)
!
 type matrix_elts
  real(dp),pointer :: eigen11(:,:,:)
  real(dp),pointer :: eigen12(:,:,:)
  real(dp),pointer :: eigen13(:,:,:)
 end type matrix_elts
 type(matrix_elts), allocatable :: psinablapsi(:)

! ************************************************************************
!DEBUG
!write(*,*)' optics_paw : enter'
!ENDDEBUG
 open(123,file=fildata,form='unformatted')
! Write header
! call hdr_io(2,hdr,2,123)

!------------------------------------------------------------------------------------------------
! 1 - Calcul de <p_i|psi_n>
!------------------------------------------------------------------------------------------------
! 1.a Appel des subroutines donnes par MT et legerement midifiee
  call ctocprj(atindx,cg,cp,dtfil,dtset,gmet,gprimd,kg,mband,mgfft,mkmem,mpi_enreg,mpj,mpsang,&
&                   mpw,natom,nattyp,nkpt,npwarr,nspinor,nsppol,dtset%ntypat,ph1d,psps,rmet,&
&                   xred,ylm,ucvol)
!
!DEBUG
! write(77,*)'sortie ctocprj,mpj=',mpj
! write(77,*)'ii,cp(1,ii),cp(2,ii)'
! do ii=1,mpj*nspinor*mband*mkmem*nsppol
!  write(77,*)ii,cp(1,ii),cp(2,ii)
! enddo
!Verification du calcul de rhoij (ok)
!Calcul de rho_ij
!    do ip1=1,mpj
!    do ip2=1,mpj
!    icp=0
!    test_ij=zero
!    bdtot_index=zero
!    do isppol=1,nsppol
!    do ikpt=1,nkpt
!      nband_k=dtset%nband(ikpt+(isppol-1)*nkpt)
!      occ_k(:)=occ(1+bdtot_index:nband_k+bdtot_index)
!      test_ijk=zero
!      icpb=icp
!      do iband=1,nband_k
!        test_ijk=test_ijk+occ_k(iband)*(cp(1,ip1+icpb)*cp(1,ip2+icpb)+cp(2,ip1+icpb)*cp(2,ip2+icpb))
!        icpb=icpb+mpj
!      enddo
!      test_ij =test_ij  + dtset%wtk(ikpt)*test_ijk
!      icp=icp+mpj*nspinor*nband_k
!      bdtot_index=bdtot_index+nband_k
!     enddo
!     enddo
!     write(6,*)'rho_ij',ip1,ip2,test_ij
!     enddo
!     enddo
!ENDEBUG

! 1.b - Transfert du Cp dans une variable structuree
 allocate(atom_fj(natom))
 do iatom=1,natom
  itypat=dtset%typat(iatom)
  lmn_size=pawtab(itypat)%lmn_size
  allocate(atom_fj(iatom)%cpnk(2,nsppol,mkmem,mband,nspinor,lmn_size))
 end do
!
 ind=0
 icspol=0
 do isppol=1,nsppol
 icnk=0
 do ikpt=1,nkpt
  nband_k=dtset%nband(ikpt+(isppol-1)*nkpt)
  icb=0
  do iband=1,nband_k
  ic_spin=0
  do ispinor=1,nspinor
!
   icat=1
   ictyp=0
    do itypat=1,dtset%ntypat
     ic_lmn=0
     lmn_size=pawtab(itypat)%lmn_size
     do iatom=icat,nattyp(itypat)
      do ilmn=1,lmn_size
!        atom_fj(atindx1(iatom))%cpnk(:,isppol,ikpt,iband,ispinor,ilmn)=cp(:,ilmn+ictyp+ic_lmn+ic_spin+icb+icnk+icspol)
        ind=ind+1
        atom_fj(atindx1(iatom))%cpnk(:,isppol,ikpt,iband,ispinor,ilmn)=cp(:,ind)
      end do !ilmn
!       ic_lmn=ic_lmn+lmn_size
     end do !iatom
     icat=icat+nattyp(itypat)
!     ictyp=ictyp+nattyp(itypat)*lmn_size
    end do !itypat
!    ic_spin=ic_spin+(nspinor-1)*ictyp
   end do !ispinor
!   icb=icb+nspinor*ictyp*nband_k
   end do !iband
!   icnk=icnk+icb*(nkpt-1)
   end do !ikpt
!   icspol=icspol+icnk*(isppol-1)
   end do !isppol
!
!DEBUG
!Verification du calcul de rhoij avec la variable structuree (ok)
!test pour 4 kpts, 4 atomes, 10 bandes et occopt=3
!
! write(78,*)'ip1,ip2,test_ij'
!  icat=1
!  do itypat=1,dtset%ntypat
!  do iatom=icat,nattyp(itypat)
!   do ip1=1,pawtab(itypat)%lmn_size
!   do ip2=1,pawtab(itypat)%lmn_size
!   test_ij=zero
!   bdtot_index=zero
!   do isppol=1,nsppol
!   do ikpt=1,nkpt
!     nband_k=dtset%nband(ikpt+(isppol-1)*nkpt)
!     occ_k(:)=occ(1+bdtot_index:nband_k+bdtot_index)
!     test_ijk=zero
!     do iband=1,nband_k
!     do ispinor=1,nspinor
!      test_ijk=test_ijk+occ_k(iband)*(atom_fj(iatom)%cpnk(1,isppol,ikpt,iband,ispinor,ip1)*atom_fj(iatom)%cpnk(1,isppol,ikpt,iband,ispinor,ip2)&
!&              +atom_fj(iatom)%cpnk(2,isppol,ikpt,iband,ispinor,ip1)*atom_fj(iatom)%cpnk(2,isppol,ikpt,iband,ispinor,ip2))
!     enddo
!     enddo
!     bdtot_index=bdtot_index+nband_k
!     test_ij=test_ij + dtset%wtk(ikpt)*test_ijk
!   enddo
!   enddo
!   write(78,*)ip1,ip2,test_ij
!   enddo
!   enddo
!  enddo
!  icat=icat+nattyp(itypat)
!  enddo
!ENDDEBUG
!------------------------------------------------------------------------------------------------
! 2 - phipphj=<phi_i|nabla|phi_j>-<tphi_i|nabla|tphi_j>
!------------------------------------------------------------------------------------------------
! 2-a Integration of the radial part : les integrales ont toutes ete calculees par ailleurs et les
!valeurs sont tabulees pour toutes les valeurs de l et m.
 call int_ang(ang_phipphj)
!DEBUG
! write(79,*)'ang_phipphj'
! write(79,*)ang_phipphj
!ENDDEBUG

 allocate(typatom_fj(dtset%ntypat))
!loop on atoms type
 do itypat=1,dtset%ntypat
!Integration of the radial part
  mesh_size=pawrad(itypat)%mesh_size

  lmn_size=pawtab(itypat)%lmn_size
  lmn2_size=pawtab(itypat)%lmn2_size
  basis_size=pawtab(itypat)%basis_size
  ij_size=pawtab(itypat)%ij_size
!
  allocate(indlmn_(6,psps%lmnmax))
  allocate(ff(mesh_size),rad(mesh_size))
  allocate(int2(ij_size),int1(ij_size))
  allocate(dphi(mesh_size),dtphi(mesh_size),phidphj(mesh_size,ij_size),tphidtphj(mesh_size,ij_size))
  allocate(typatom_fj(itypat)%phipphj(lmn2_size,3))
!
  indlmn_(:,:)=psps%indlmn(:,:,itypat)
  rad(1:mesh_size)=pawrad(itypat)%rad(1:mesh_size)
!
! 2-b  int1=\int phi/r phj/r dr - \int tphi/r tphj/r dr
  ff(1)=zero
  do jln=1,basis_size
   j0ln=jln*(jln-1)/2
   do iln=1,jln
    kln=j0ln+iln
    ff(2:mesh_size)=(pawtab(itypat)%phiphj  (1:mesh_size,kln)&
&                   -pawtab(itypat)%tphitphj(1:mesh_size,kln))&
&                   /rad(2:mesh_size)**2
    call simp_gen(intg,ff,pawrad(itypat))
    int1(kln)=intg
   end do
  end do
!
! 2-c int2=\int phi/r d/dr(phj/r) dr - \int tphi/r d/dr(tphj/r) dr
  do jln=1,basis_size
   ff(1:mesh_size)=pawtab(itypat)%phi(1:mesh_size,jln)
   call nderiv_gen(dphi,ff,1,pawrad(itypat))
   ff(1:mesh_size)=pawtab(itypat)%tphi(1:mesh_size,jln)
   call nderiv_gen(dtphi,ff,1,pawrad(itypat))
   j0ln=jln*(jln-1)/2
   do iln=1,jln
    kln=j0ln+iln
    phidphj(1:mesh_size,kln)=pawtab(itypat)%phi (1:mesh_size,iln)&
&                                   *dphi (1:mesh_size)
    tphidtphj(1:mesh_size,kln)=pawtab(itypat)%tphi(1:mesh_size,iln)&
&                                   *dtphi(1:mesh_size)
   end do
  end do
!
  ff(1)=zero
  do jln=1,basis_size
   j0ln=jln*(jln-1)/2
   do iln=1,jln
    kln=j0ln+iln
    ff(2:mesh_size)=(phidphj(2:mesh_size,kln)-tphidtphj(2:mesh_size,kln))&
&                   /rad(2:mesh_size)
    call simp_gen(intg,ff,pawrad(itypat))
    int2(kln)=intg
   end do
  end do
!
! 2-c Integrale de la partie radiale
  do jlmn=1,lmn_size
   ilm=indlmn_(5,jlmn)
   jl=indlmn_(1,jlmn)
   j0lmn=jlmn*(jlmn-1)/2
   do ilmn=1,lmn_size
    jlm=indlmn_(5,ilmn)
    klmn=j0lmn+ilmn
    kln=pawtab(itypat)%indklmn(2,klmn)
!
    typatom_fj(itypat)%phipphj(klmn,1)= int2(kln)*ang_phipphj(ilm,jlm,1)&
&                  + int1(kln)*(ang_phipphj(ilm,jlm,2)+ang_phipphj(ilmn,jlmn,3))
    typatom_fj(itypat)%phipphj(klmn,2)= int2(kln)*ang_phipphj(ilm,jlm,4)&
&                  + int1(kln)*(ang_phipphj(ilm,jlm,5)+ang_phipphj(ilmn,jlmn,6))
    typatom_fj(itypat)%phipphj(klmn,3)= int2(kln)*ang_phipphj(ilm,jlm,7)&
&                  + int1(kln)*ang_phipphj(ilm,jlm,8)
   end do
  end do
!
!DEBUG
! write(80,*)'itypat,typatom_fj(itypat)%phipphj(klmn,1:3)',itypat
! do klmn=1,lmn2_size
!  write(80,*)klmn,itypat
!  write(80,*)typatom_fj(itypat)%phipphj(klmn,1),typatom_fj(itypat)%phipphj(klmn,2),typatom_fj(itypat)%phipphj(klmn,3)
! enddo
!ENDDEBUG
!
!3-c operateur p=-i*nablaATTENTION phipphj is a imaginary
  typatom_fj(itypat)%phipphj=-one*typatom_fj(itypat)%phipphj
!
  deallocate(indlmn_,ff,rad)
  deallocate(int2,int1)
  deallocate(dphi,dtphi,phidphj,tphidtphj)
!end loop on atoms type
 end do
!
!
!---------------------------------------------------------------------------------------------
! 3 Calcul de <tpsi_n|-i/nabla|tpsi_m> pour chaque k
!---------------------------------------------------------------------------------------------
 sum_cg=0.0d0
!
 allocate(psinablapsi(nkpt))
 do isppol=1,nsppol
  icg = 0
  ind = 0
  ikg = 0
!
  do ikpt=1,nkpt
!
   kpoint(:)=dtset%kptns(:,ikpt)
   nband_k=dtset%nband(ikpt+(isppol-1)*nkpt)
   npw_k=npwarr(ikpt)
   allocate(psinablapsi(ikpt)%eigen11(2,nband_k,nband_k))
   allocate(psinablapsi(ikpt)%eigen12(2,nband_k,nband_k))
   allocate(psinablapsi(ikpt)%eigen13(2,nband_k,nband_k))
!
!DEBUG
!   write(6,*)'coordonnees du point k'
!   write(6,'(3(2x,e12.5))')kpoint(:)
!   write(6,*)'nband_k,npw_k',nband_k,npw_k,nsppol
!ENDDEBUG
!
! 3-a Calcul de k+G en coordonnees cartesiennes
   do ipw=1,npw_k
    kptg(1,ipw)=(kpoint(1)+kg(1,ipw+ikg))*gprimd(1,1)&
&              +(kpoint(2)+kg(2,ipw+ikg))*gprimd(1,2)&
&              +(kpoint(3)+kg(3,ipw+ikg))*gprimd(1,3)
    kptg(2,ipw)=(kpoint(1)+kg(1,ipw+ikg))*gprimd(2,1)&
&              +(kpoint(2)+kg(2,ipw+ikg))*gprimd(2,2)&
&              +(kpoint(3)+kg(3,ipw+ikg))*gprimd(2,3)
    kptg(3,ipw)=(kpoint(1)+kg(1,ipw+ikg))*gprimd(3,1)&
&              +(kpoint(2)+kg(2,ipw+ikg))*gprimd(3,2)&
&              +(kpoint(3)+kg(3,ipw+ikg))*gprimd(3,3)
   end do !ipw
!
   do iband=1,nband_k
!
!DEBUG
! Normalisation des coef des ondes planes
!     sum_cg=0.0d0
!     do ipw=1,npw_k
!       sum_cg=sum_cg+(cg(1,ipw+(iband-1)*npw_k+icg)*gsc(1,ipw+(iband-1)*npw_k+icg))&
!&                   +(cg(2,ipw+(iband-1)*npw_k+icg)*gsc(2,ipw+(iband-1)*npw_k+icg))
!     enddo
!    write(6,*)'optics_paw:sum_cg=',sum_cg
!ENDEBUG

    do jband=1,nband_k
     tnm_re=zero
     tnm_im=zero
!3-b Calcul de (C_nk*C_mk^*)*(k+g) en coordonnees cartesiennes
     do ipw=1,npw_k
      cgnm1=cg(1,ipw+(iband-1)*npw_k+icg)*cg(1,ipw+(jband-1)*npw_k+icg)+&
&           cg(2,ipw+(iband-1)*npw_k+icg)*cg(2,ipw+(jband-1)*npw_k+icg)
      tnm_re(1)=tnm_re(1)+kptg(1,ipw)*cgnm1
      tnm_re(2)=tnm_re(2)+kptg(2,ipw)*cgnm1
      tnm_re(3)=tnm_re(3)+kptg(3,ipw)*cgnm1
!
      cgnm2=cg(1,ipw+(iband-1)*npw_k+icg)*cg(2,ipw+(jband-1)*npw_k+icg)-&
&           cg(2,ipw+(iband-1)*npw_k+icg)*cg(1,ipw+(jband-1)*npw_k+icg)
      tnm_im(1)=tnm_im(1)+kptg(1,ipw)*cgnm2
      tnm_im(2)=tnm_im(2)+kptg(2,ipw)*cgnm2
      tnm_im(3)=tnm_im(3)+kptg(3,ipw)*cgnm2
     end do !ipw
     tnm_im=two_pi*tnm_im
     tnm_re=two_pi*tnm_re
!
!DEBUG
!    write(81,'(i4,2x,i4,2x,i4,2x,es21.14,2x,es21.14,2x,es21.14)')&
!&               ikpt,iband,jband,tnm_re(1),tnm_re(2),tnm_re(3)
!    write(81,'(i4,2x,i4,2x,i4,2x,es21.14,2x,es21.14,2x,es21.14)')&
!&               ikpt,iband,jband,tnm_im(1),tnm_im(2),tnm_im(3)
!ENDDEBUG
!
!
!---------------------------------------------------------------------------------------------
! 4 - Calcul de <psi_n|p_i><p_j|psi_m>(<phi_i|nabla|phi_j>-<tphi_i|nabla|tphi_j>)
!---------------------------------------------------------------------------------------------
    ispinor=1
     prod_im=zero
     prod_re=zero
     icat=1
     do itypat=1,dtset%ntypat
      lmn_size=pawtab(itypat)%lmn_size
      lmn2_size=pawtab(itypat)%lmn2_size
      do iatom=icat,nattyp(itypat)
       do jlmn=1,lmn_size
       ilm=psps%indlmn(5,jlmn,itypat)
       jl=psps%indlmn(1,jlmn,itypat)
       j0lmn=jlmn*(jlmn-1)/2
       do ilmn=1,lmn_size
        jlm=psps%indlmn(5,ilmn,itypat)
        klmn=j0lmn+ilmn
!
        prod_im(1)=prod_im(1)+&
&         (atom_fj(atindx1(iatom))%cpnk(1,isppol,ikpt,iband,ispinor,ilmn)* &
&          atom_fj(atindx1(iatom))%cpnk(1,isppol,ikpt,jband,ispinor,jlmn)  &
&         +atom_fj(atindx1(iatom))%cpnk(2,isppol,ikpt,iband,ispinor,ilmn)* &
&          atom_fj(atindx1(iatom))%cpnk(2,isppol,ikpt,jband,ispinor,jlmn)) &
&         *typatom_fj(itypat)%phipphj(klmn,1)
        prod_im(2)=prod_im(2)+&
&         (atom_fj(atindx1(iatom))%cpnk(1,isppol,ikpt,iband,ispinor,ilmn)* &
&          atom_fj(atindx1(iatom))%cpnk(1,isppol,ikpt,jband,ispinor,jlmn)  &
&         +atom_fj(atindx1(iatom))%cpnk(2,isppol,ikpt,iband,ispinor,ilmn)* &
&          atom_fj(atindx1(iatom))%cpnk(2,isppol,ikpt,jband,ispinor,jlmn)) &
&         *typatom_fj(itypat)%phipphj(klmn,2)
        prod_im(3)=prod_im(3)+&
&         (atom_fj(atindx1(iatom))%cpnk(1,isppol,ikpt,iband,ispinor,ilmn)* &
&          atom_fj(atindx1(iatom))%cpnk(1,isppol,ikpt,jband,ispinor,jlmn)  &
&         +atom_fj(atindx1(iatom))%cpnk(2,isppol,ikpt,iband,ispinor,ilmn)* &
&          atom_fj(atindx1(iatom))%cpnk(2,isppol,ikpt,jband,ispinor,jlmn)) &
&         *typatom_fj(itypat)%phipphj(klmn,3)
!
       prod_re(1)=prod_re(1)+&
&         (atom_fj(atindx1(iatom))%cpnk(1,isppol,ikpt,iband,ispinor,ilmn)* &
&          atom_fj(atindx1(iatom))%cpnk(2,isppol,ikpt,jband,ispinor,jlmn)  &
&         -atom_fj(atindx1(iatom))%cpnk(2,isppol,ikpt,iband,ispinor,ilmn)* &
&          atom_fj(atindx1(iatom))%cpnk(1,isppol,ikpt,jband,ispinor,jlmn)) &
&         *typatom_fj(itypat)%phipphj(klmn,1)
        prod_re(2)=prod_re(2)+&
&         (atom_fj(atindx1(iatom))%cpnk(1,isppol,ikpt,iband,ispinor,ilmn)* &
&          atom_fj(atindx1(iatom))%cpnk(2,isppol,ikpt,jband,ispinor,jlmn)  &
&         -atom_fj(atindx1(iatom))%cpnk(2,isppol,ikpt,iband,ispinor,ilmn)* &
&          atom_fj(atindx1(iatom))%cpnk(1,isppol,ikpt,jband,ispinor,jlmn)) &
&         *typatom_fj(itypat)%phipphj(klmn,2)
        prod_re(3)=prod_re(3)+&
&         (atom_fj(atindx1(iatom))%cpnk(1,isppol,ikpt,iband,ispinor,ilmn)* &
&          atom_fj(atindx1(iatom))%cpnk(2,isppol,ikpt,jband,ispinor,jlmn)  &
&         -atom_fj(atindx1(iatom))%cpnk(2,isppol,ikpt,iband,ispinor,ilmn)* &
&          atom_fj(atindx1(iatom))%cpnk(1,isppol,ikpt,jband,ispinor,jlmn)) &
&         *typatom_fj(itypat)%phipphj(klmn,3)

       end do !ilmn
      end do !jlmn
    end do !iatom
    icat=icat+nattyp(itypat)
    end do !itypat
!
    psinablapsi(ikpt)%eigen11(1,iband,jband)=prod_re(1)+tnm_re(1)
    psinablapsi(ikpt)%eigen12(1,iband,jband)=prod_re(2)+tnm_re(2)
    psinablapsi(ikpt)%eigen13(1,iband,jband)=prod_re(3)+tnm_re(3)
!
    psinablapsi(ikpt)%eigen11(2,iband,jband)=prod_im(1)+tnm_im(1)
    psinablapsi(ikpt)%eigen12(2,iband,jband)=prod_im(2)+tnm_im(2)
    psinablapsi(ikpt)%eigen13(2,iband,jband)=prod_im(3)+tnm_im(3)
!DEBUG
!    write(82,*)'prod_im',prod_im(1)+tnm_im(1),prod_im(2)+tnm_im(2),prod_im(3)+tnm_im(3)
!    write(82,*)'prod_re',prod_re(1)+tnm_re(1),prod_re(2)+tnm_re(2),prod_re(3)+tnm_re(3)
!ENDDEBUG
    end do ! jband
   end do !iband
   ind = ind +2*nband_k**2*nsppol
   icg = icg + npw_k*nband_k*nsppol
   ikg = ikg + npw_k
!
!---------------------------------------------------------------------------------------------
! 5 - Write  data
!---------------------------------------------------------------------------------------------
   write(123)psinablapsi(ikpt)%eigen11
   write(123)psinablapsi(ikpt)%eigen12
   write(123)psinablapsi(ikpt)%eigen13
   end do ! ikpt
  end do !isppol
  close (123)
!
!DEBUG
! do isppol=1,nsppol
! do ikpt=1,nkpt
!  nband_k=dtset%nband(ikpt+(isppol-1)*nkpt)
!  do iband=1,nband_k
!  do jband=1,nband_k
!  write(82,*)psinablapsi(ikpt)%eigen11(1,iband,jband)&
!&           ,psinablapsi(ikpt)%eigen12(1,iband,jband),psinablapsi(ikpt)%eigen13(1,iband,jband)
!  write(82,*)psinablapsi(ikpt)%eigen11(2,iband,jband)&
!&            ,psinablapsi(ikpt)%eigen12(2,iband,jband),psinablapsi(ikpt)%eigen13(2,iband,jband)
!  enddo
!  enddo
! enddo
! enddo
!ENDDEBUG
!
  do ikpt=1,nkpt
   deallocate(psinablapsi(ikpt)%eigen11,psinablapsi(ikpt)%eigen12,psinablapsi(ikpt)%eigen13)
  end do
  do iatom=1,natom
   deallocate(atom_fj(iatom)%cpnk)
  end do
  do itypat=1,dtset%ntypat
   deallocate(typatom_fj(itypat)%phipphj)
  end do
  deallocate(psinablapsi)
  deallocate(typatom_fj,atom_fj)
!DEBUG
!write(6,*)' optics_paw : exit '
!stop
!ENDDEBUG

 end subroutine optics_paw
!!***
