!{\src2tex{textfont=tt}}
!!****f* ABINIT/outscfcv
!! NAME
!! outscfcv
!!
!! FUNCTION
!! Output routine for the scfcv.F90 routine
!!
!! COPYRIGHT
!! Copyright (C) 2005-2006 ABINIT group (XG)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!!
!! INPUTS
!!  atindx(natom)=index table for atoms (see scfcv.f)
!!  atindx1(natom)=index table for atoms, inverse of atindx (see scfcv.f)
!!  cg(2,mpw*nspinor*mband*mkmem*nsppol)=planewave coefficients of wavefunctions.
!!  compch_fft=compensation charge, from FFT grid
!!  compch_sph=compensation charge, from sphere
!!  dtfil <type(datafiles_type)>=variables related to files
!!  dtset <type(dataset_type)>=all input variables for this dataset
!!  ecut=cut-off energy for plane wave basis sphere (Ha)
!!  eigen(mband*nkpt*nsppol)=array for holding eigenvalues (hartree)
!!  etotal=total energy
!!  fermie= Fermi energy
!!  filapp character(len=fnlen)=generic output root name, with appendix
!!  gmet(3,3)=reciprocal space metric tensor in bohr**-2.
!!  gprimd(3,3)=dimensional reciprocal space primitive translations
!!  gsc(2,mpw*nspinor*mband*mkmem*nsppol*usepaw)=<g|S|c> matrix elements (S=overlap)
!!  gsqcut=cutoff on (k+G)^2 (bohr^-2)
!!  hdr <type(hdr_type)>=the header of wf, den and pot files
!!  kg(3,mpw*mkmem)=reduced planewave coordinates.
!!  kssform=govern the Kohn-Sham Structure file format
!!  mband=maximum number of bands
!!  mgfft=maximum size of 1D FFTs
!!  mkmem =number of k points which can fit in memory; set to 0 if use disk
!!  mpi_enreg=informations about MPI parallelization
!!  mpsang= 1+maximum angular momentum for nonlocal pseudopotentials
!!  mpw=maximum dimensioned size of npw.
!!  natom=number of atoms in cell.
!!  nattyp(ntypat)= # atoms of each type.
!!  nfft=(effective) number of FFT grid points (for this processor) (see NOTES at beginning of scfcv)
!!  ngfft(18)=contain all needed information about 3D FFT (see NOTES at beginning of scfcv)
!!  nhat(nfftf,nspden*usepaw)= compensation charge density  (PAW)
!!  nkpt=number of k points.
!!  npwarr(nkpt)=number of planewaves in basis at this k point
!!  nspden=number of spin-density components
!!  nspinor=number of spinorial components of the wavefunctions
!!  nsppol=1 for unpolarized, 2 for spin-polarized
!!  nsym=number of symmetries in space group
!!  ntypat=number of types of atoms in unit cell.
!!  n3xccc=dimension of the xccc3d array (0 or nfft).
!!  occ(mband*nkpt*nsppol)=occupation number for each band (usually 2) for each k.
!!  pawang <type(pawang_type)>=paw angular mesh and related data
!!  pawfgr(natom) <type(pawfgr_type)>=fine grid parameters and related data
!!  pawfgrtab(natom) <type(pawfgrtab_type)>=atomic data given on fine rectangular grid
!!  pawrad(ntypat*usepaw) <type(pawrad_type)>=paw radial mesh and related data
!!  pawtab(ntypat*usepaw) <type(pawtab_type)>=paw tabulated starting data
!!  paw_ij(natom) <type(paw_ij_type)>=paw arrays given on (i,j) channels
!!  ph1d(2,3*(2*mgfft+1)*natom)=one-dimensional structure factor information
!!  prtvol=control print volume and debugging output
!!  psps <type(pseudopotential_type)>=variables related to pseudopotentials
!!  rhog(nfft,nspden)=total electron density in electrons/bohr**3, reciprocal space.
!!  rhor(nfft,nspden)=total electron density in electrons/bohr**3, real space.
!!  rmet(3,3)=real space metric (bohr**2)
!!  rprimd(3,3)=dimensional primitive translations for real space (bohr)
!!  ucvol=unit cell volume (bohr**3)
!!  usexcnhat= flag controling use of compensation density in the computation of Vxc
!!  vhartr(nfft)=Hartree potential
!!  vxc(nfft,nspden)=xc potential
!!  vxcavg=vxc average
!!  wffnow=information about wf disk file
!!  vtrial(nfft,nsppol)=the trial potential
!!  xccc3d(n3xccc)=3D core electron density for XC core correction (bohr^-3)
!!  xred(3,natom)=reduced dimensionless atomic coordinates
!!  ylm(mpw*mkmem,mpsang*mpsang*useylm)=real spherical harmonics for each G and k point
!!
!! OUTPUT
!!  (only writing, printing)
!!
!! SIDE EFFECTS
!!  (only writing, printing)
!!
!! NOTES
!!
!! PARENTS
!!      scfcv
!!
!! CHILDREN
!!      bonds_lgth_angles,ioarr,mlwfovlp,optics_paw,out1dm,outkss,outwant
!!      partial_dos_fractions,pawmknhat,pawprt,prt_cml2,rhohxc,tetrahedron
!!      timab,wrtout,xcomm_init
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine outscfcv(atindx,atindx1,cg,compch_fft,compch_sph,dtfil,dtset,ecut,eigen,etotal,&
& fermie,filapp,gmet,gprimd,gsc,gsqcut,hdr,kg,&
& kssform,mband,mgfft,mkmem,mpi_enreg,mpsang,mpw,natom,&
& nattyp,nfft,ngfft,nhat,nkpt,npwarr,nspden,nspinor,nsppol,nsym,ntypat,n3xccc,occ,&
& pawang,pawfgr,pawfgrtab,pawrad,pawtab,paw_ij,ph1d,prtvol,psps,rhog,rhor,rmet,rprimd,&
& ucvol,usexcnhat,wffnow,vhartr,vtrial,vxc,vxcavg,xccc3d,xred,ylm)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_00basis
 use interfaces_01managempi
 use interfaces_02geometry
 use interfaces_03paw
 use interfaces_03xc
 use interfaces_03xml
 use interfaces_04iowfdenpot
 use interfaces_04occeig
 use interfaces_05common
 use interfaces_08seqpar
 use interfaces_11drive, except_this_one => outscfcv
#else
 use defs_xc
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: kssform,mband,mgfft,mkmem,mpsang,mpw,n3xccc,natom,nfft
 integer,intent(in) :: nkpt,nspden,nsppol,nsym,ntypat,prtvol,usexcnhat
 integer,intent(inout) :: nspinor
 real(dp),intent(in) :: compch_fft,compch_sph,ecut,fermie,gsqcut,ucvol
 real(dp),intent(inout) :: etotal,vxcavg
 character(len=fnlen),intent(inout) :: filapp
 type(MPI_type),intent(inout) :: mpi_enreg
 type(datafiles_type),intent(in) :: dtfil
 type(dataset_type),intent(inout) :: dtset
 type(hdr_type),intent(inout) :: hdr
 type(pawang_type),intent(in) :: pawang
 type(pawfgr_type),intent(in) :: pawfgr
 type(pseudopotential_type),intent(in) :: psps
 type(wffile_type),intent(inout) :: wffnow
!arrays
 integer :: kg(3,mpw*mkmem),nattyp(ntypat),ngfft(18),npwarr(nkpt)
 integer,intent(in) :: atindx(natom),atindx1(natom)
 real(dp),intent(in) :: eigen(mband*nkpt*nsppol),gmet(3,3),gprimd(3,3)
 real(dp),intent(in) :: occ(mband*nkpt*nsppol),ph1d(2,3*(2*mgfft+1)*natom)
 real(dp),intent(in) :: rmet(3,3),rprimd(3,3),vhartr(nfft),xccc3d(n3xccc)
 real(dp),intent(in) :: ylm(mpw*mkmem,mpsang*mpsang*psps%useylm)
 real(dp),intent(inout) :: cg(2,mpw*nspinor*mband*mkmem*nsppol)
 real(dp),intent(inout) :: gsc(2,mpw*nspinor*mband*mkmem*nsppol*psps%usepaw)
 real(dp),intent(inout) :: nhat(nfft,nspden*psps%usepaw),rhog(nfft,nspden)
 real(dp),intent(inout) :: rhor(nfft,nspden),vtrial(nfft,nsppol)
 real(dp),intent(inout) :: vxc(nfft,nsppol),xred(3,natom)
 type(paw_ij_type),intent(in) :: paw_ij(natom)
 type(pawfgrtab_type),intent(in) :: pawfgrtab(natom)
 type(pawrad_type),intent(in) :: pawrad(psps%ntypat*psps%usepaw)
 type(pawtab_type),intent(in) :: pawtab(ntypat*psps%usepaw)

!Local variables-------------------------------
!scalars
 integer :: accessfil,coordn,fformr,fformv,ierr,ifft,ikpt,ilmn,ispden,itypat
 integer :: mbesslang,mpj,ndosfraction,nhatgrdim,optxc,partial_dos_flag,prt1dm
 integer :: prtcml,prtden,prtdos,prtgeo,prtnabla,prtpot,prtstm,prtvha,prtvhxc
 integer :: prtvxc,rdwr,rdwrpaw,spaceComm
 real(dp) :: dum,enxc_dum
 character(len=500) :: message
 character(len=fnlen) :: fildata
!arrays
 integer,allocatable :: npwarr1(:)
 real(dp) :: strsxc_dum(6),tsec(2)
 real(dp),allocatable :: dos_fractions(:,:,:,:),kxc_dum(:,:),nhatgr(:,:,:)
 real(dp),allocatable :: rhocorval(:,:),vhartr_tmp(:),vwork(:,:),vxc_dum(:,:)

! *************************************************************************

!DEBUG
!write(6,*)' outscfcv : enter '
!ENDDEBUG

   call xcomm_init(mpi_enreg,spaceComm)


! begin wannier
 if (dtset%prtwant==2) then
  call mlwfovlp(atindx,atindx1,cg,compch_fft,compch_sph,dtfil,dtset,ecut,eigen,etotal,&
  & fermie,filapp,gmet,gprimd,gsqcut,hdr,kg,&
  & kssform,mband,mgfft,mkmem,mpi_enreg,mpsang,mpw,natom,&
  & nattyp,nfft,ngfft,nkpt,npwarr,nspden,nspinor,nsppol,nsym,ntypat,n3xccc,occ,&
  & pawang,pawfgr,paw_ij,pawrad,pawtab,ph1d,prtvol,psps,rhog,rhor,rmet,rprimd,&
  & ucvol,wffnow,vhartr,vtrial,vxc,vxcavg,xccc3d,xred,ylm)
 end if
! end wannier

!
!  if accesswff == 2 then set all outputs to netcdf format
!
 accessfil = 0
 if (dtset%accesswff == 2) accessfil = 1

  prtden=dtset%prtden ; prtpot=dtset%prtpot ; prtgeo=dtset%prtgeo
  prtcml=dtset%prtcml ; prtdos=dtset%prtdos ; prtstm=dtset%prtstm
  prt1dm=dtset%prt1dm ; prtvha=dtset%prtvha ; prtvhxc=dtset%prtvhxc
  prtvxc=dtset%prtvxc ; prtnabla=dtset%prtnabla

!Warnings :
! - core charge is excluded from the charge density;
! - the potential is the INPUT vtrial.
 if(  mpi_enreg%paral_compil_kpt==0                         .or. &
&    (mpi_enreg%me==0 .and. mpi_enreg%parareel == 0)        .or. &
&    (mpi_enreg%me_group_para==0 .and. mpi_enreg%parareel == 1)) then

  if (prtden/=0 .or. prtpot>0 .or. prtgeo>0 .or. prt1dm>0 .or. prtstm>0 .or. &
&     prtvha>0 .or. prtvhxc>0.or. prtvxc>0 .or. prtcml>0 .or. prtdos>=2 )then
  end if

  if (prtden/=0) then
   rdwr=2 ; fformr=52 ; rdwrpaw=0
!  set to 1 for netcdf output
   fildata=trim(filapp)//'_DEN'
   if (dtset%positron==3) then
    allocate(rhocorval(nfft,nspden))
    do ifft=1,nfft
     rhocorval(ifft,1)=rhor(ifft,1)+xccc3d(ifft)
    end do
    if(nspden==2) then
     do ifft=1,nfft
      rhocorval(ifft,2)=rhor(ifft,2)+0.5d0*xccc3d(ifft)
     end do
    end if
    call ioarr(accessfil,rhocorval,etotal,fformr,fildata,hdr,nfft,nspden,rdwr,rdwrpaw)
    deallocate(rhocorval)
   else if (dtset%positron==1) then
    call ioarr(accessfil,rhor,etotal,fformr,fildata,hdr,nfft,nspden,rdwr,rdwrpaw)
   else
    call ioarr(accessfil,rhor,etotal,fformr,fildata,hdr,nfft,nspden,rdwr,rdwrpaw)
   end if
  end if

  if (prtpot>0) then
   fildata=trim(filapp)//'_POT'
   rdwr=2 ; fformv=102 ; rdwrpaw=0
!  set to 1 for netcdf output
   accessfil = 0
   call ioarr(accessfil,vtrial,etotal,fformv,fildata,hdr,nfft,nspden,rdwr,rdwrpaw)
  end if

  if (prtgeo>0) then
   coordn=prtgeo
   call bonds_lgth_angles(coordn,filapp,natom,psps%ntypat,&
&   rprimd,dtset%typat,xred,dtset%znucl)
  end if

  if (prtcml>0) then
   call prt_cml2(filapp,natom,dtset%nsym,psps%ntypat,&
&   rprimd,dtset%spgroup,dtset%symrel,dtset%tnons,dtset%typat,xred,dtset%znucl)
  end if

  if (prtstm>0) then
   rdwr=2 ; fformr=52 ; rdwrpaw=0
!  set to 1 for netcdf output
   accessfil = 0
   fildata=trim(filapp)//'_STM'
   call ioarr(accessfil,rhor,etotal,fformr,fildata,hdr,nfft,nspden,rdwr,rdwrpaw)
  end if

  if (prt1dm>0) then
   call out1dm(filapp,natom,nfft,ngfft,nspden,psps%ntypat,&
&   rhor,rprimd,dtset%typat,ucvol,vtrial,xred,dtset%znucl)
  end if

  if (prtvha>0) then
   fildata=trim(filapp)//'_VHA'
   rdwr=2 ; fformv=102 ; rdwrpaw=0
!  set to 1 for netcdf output
   allocate(vwork(nfft,nspden))
!  In the SCF part of the positron, we have to compute Vhartree acting on electrons
   if (dtset%positron==1.or.dtset%positron==2)  then
    allocate(vhartr_tmp(nfft),kxc_dum(nfft,0),vxc_dum(nfft,nspden))
    optxc = 1 ; nhatgrdim=0
    if (psps%usepaw==1.and.usexcnhat>0.and.dtset%ixc>=11.and.dtset%ixc<=16) then
     nhatgrdim=1;allocate(nhatgr(nfft,nspden,3))
     call pawmknhat(dum,1,0,mpi_enreg,natom,nfft,ngfft,nhatgrdim,nspden,ntypat,paw_ij,&
&                   pawang,pawfgrtab,nhatgr,nhat,pawtab,dtset%typat,ucvol)
    end if
    call rhohxc(dtset,enxc_dum,gsqcut,psps%usepaw,kxc_dum,mpi_enreg,nfft,ngfft,nhat,1,&
&               nhatgr,nhatgrdim,0,nspden,n3xccc,optxc,rhog,rhor,rprimd,strsxc_dum,usexcnhat,vhartr_tmp,vxc_dum,vxcavg,xccc3d)
    if (nhatgrdim>0) deallocate(nhatgr)
    do ispden=1,nspden
     vwork(:,ispden)=vhartr_tmp(:)
    end do
    deallocate(vhartr_tmp,kxc_dum,vxc_dum)
   else
    do ispden=1,nspden
     vwork(:,ispden)=vhartr(:)
    end do
   end if
   call ioarr(accessfil,vwork,etotal,fformv,fildata,hdr,nfft,nspden,rdwr,rdwrpaw)
   deallocate(vwork)
  end if

  if (prtvhxc>0) then
   fildata=trim(filapp)//'_VHXC'
   rdwr=2 ; fformv=102 ; rdwrpaw=0
!  set to 1 for netcdf output
   allocate(vwork(nfft,nspden))
   do ispden=1,nspden
    vwork(:,ispden)=vhartr(:)+vxc(:,ispden)
   end do
   call ioarr(accessfil,vwork,etotal,fformv,fildata,hdr,nfft,nspden,rdwr,rdwrpaw)
   deallocate(vwork)
  end if

  if (prtvxc>0) then
   fildata=trim(filapp)//'_VXC'
   rdwr=2 ; fformv=102 ; rdwrpaw=0
!  set to 1 for netcdf output
   call ioarr(accessfil,vxc,etotal,fformv,fildata,hdr,nfft,nspden,rdwr,rdwrpaw)
  end if

 end if ! if master

! Generate DOS using the tetrahedron method
 if (prtdos>=2) then

  if(prtdos==2)partial_dos_flag = 0
  if(prtdos==3)partial_dos_flag = 1

  ndosfraction = 1
  if(partial_dos_flag==1)then
   mbesslang = 5
   ndosfraction=dtset%natsph*mbesslang
  end if

!  For other types of partial DOSs, should use a pointer or something
!  to be able to allocate dos_fractions inside partial_dos_fractions. XG20030506 : Mmmm... not sure !
  allocate(dos_fractions(dtset%nkpt,dtset%mband,dtset%nsppol,ndosfraction))

  if( partial_dos_flag==1)then
!   Generate fractions for partial DOSs if needed
!   partial_dos 1,2,3,4  give different decompositions
   call partial_dos_fractions(cg,dos_fractions,dtfil,dtset,hdr,mbesslang,mpi_enreg, &
&      ndosfraction,partial_dos_flag,wffnow)
  else
   dos_fractions(:,:,:,1)=one
  end if

!  Here, computation and output of DOS and partial DOS
  fildata=trim(filapp)//'_DOS'
  call tetrahedron (dos_fractions,dtset,fermie,eigen,fildata,&
&                  partial_dos_flag,ndosfraction,rprimd)

  deallocate(dos_fractions) ! inserted by MM

 end if ! prtdos > 1


!If PAW, provide additional outputs
 if (psps%usepaw==1) then
! Output of compensation charge
  if ((dtset%nstep>0.or.dtfil%ireadwf/=0).and.usexcnhat>0) then
   write(message, '(8a,f22.15,a)' )ch10,&
&    ' PAW TEST:',ch10,&
&    ' ==== Compensation charge inside spheres ============',ch10,&
&    ' The following values must be equal...',ch10,&
&    ' Compensation charge over spherical meshes = ',compch_sph,ch10
   if (pawfgr%usefinegrid==1) then
    write(message, '(2a,f22.15)' ) trim(message),&
&     ' Compensation charge over fine fft grid    = ',compch_fft
   else
    write(message, '(2a,f22.15)' ) trim(message),&
&     ' Compensation charge over fft grid         = ',compch_fft
   end if
   call wrtout(ab_out,message,'COLL')
   call wrtout(6,message,'COLL')
  end if
! Output of pseudopotential strength Dij and augmentation occupancies Rhoij
  call pawprt(dtset%enunit,natom,paw_ij)

  if (prtnabla>0) then
   fildata=trim(filapp)//'_OPT'
   mpj=0
    do itypat=1,dtset%ntypat
     if (psps%useylm==0) ilmn=maxval(psps%indlmn(4,:,itypat))
     if (psps%useylm==1) ilmn=count(psps%indlmn(3,:,itypat)>0)
     mpj=mpj+ilmn*nattyp(itypat)
    end do
   call optics_paw(atindx,atindx1,cg,dtfil,dtset,ecut,eigen,fildata,gmet,gprimd,&
&               gsc,hdr,kg,mband,mgfft,mkmem,&
&               mpi_enreg,mpsang,mpj,mpw,natom,nkpt,npwarr,nspinor,nsppol,nattyp,&
&               occ,pawrad,pawtab,ph1d,psps,rmet,ucvol,xred,ylm)
  end if

 end if

!Optionally provide output for GW part of ABINIT
 if (dtset%nbandkss/=0) then
  call timab(233,1,tsec)
  call outkss(atindx,atindx1,dtfil,dtset,ecut,gmet,&
&  gprimd,hdr,kg,dtset%kssform,mband,mgfft,mkmem,&
&  mpi_enreg,mpsang,mpw,natom,&
&  nattyp,nfft,nkpt,npwarr,nspinor,nsppol,nsym,psps%ntypat,occ,&
&  ph1d,prtvol,psps,rmet,rprimd,ucvol,wffnow,vtrial,xred,ylm,cg,eigen)
  call timab(233,2,tsec)
 end if

!Optionally provide output for WanT
 if (dtset%prtwant==1) then
  call outwant(dtfil,dtset,eigen,cg,kg,npwarr,mband,nkpt,nsppol,&
& nspinor,mkmem,mpw,wffnow,dtset%prtwant)
 end if

!DEBUG
!write(6,*)' outscfcv : exit'
!stop
!ENDDEBUG

end subroutine outscfcv
!!***
