!{\src2tex{textfont=tt}}
!!****f* ABINIT/screening
!! NAME
!! screening
!!
!! FUNCTION
!!
!! Calculate screening and dielectric functions
!!
!! COPYRIGHT
!! Copyright (C) 2001-2006 ABINIT group (GMR, VO, LR, RWG, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  acell(3)=length scales of primitive translations (bohr)
!!  dtfil <type(datafiles_type)>=variables related to files
!!  rprim(3,3)=dimensionless real space primitive translations
!!
!! OUTPUT
!!  output is written in a file
!!
!! SIDE EFFECTS
!!  dtset <type(dataset_type)>=all input variables for this dataset
!!
!! NOTES
!!
!! PARENTS
!!      driver,drivergw
!!
!! CHILDREN
!!      calc_wf_qp,ccgradvnl,cchi0,cchi0q0,cigfft,ckxcldag,cvc,density,distrb2
!!      fermi,fftwfn,findnq,findq,findshells,hdr_clean,hermitianize,identk
!!      lattice,leave_new,matcginv,matrginv,metric,mkrdim,pclock,printcm,printv
!!      rdgw,rdkss,rdlda,rdldaabinit,rdqps,setmesh,setshells,surot,testlda
!!      timab,wrscr,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine screening(acell,dtfil,dtset,mpi_enreg,rprim)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_00basis
 use interfaces_01managempi
 use interfaces_01util
 use interfaces_02geometry
 use interfaces_04iowfdenpot
 use interfaces_05gw
#else
 use defs_interfaces
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 type(MPI_type),intent(inout) :: mpi_enreg
 type(datafiles_type),intent(in) :: dtfil
 type(dataset_type),intent(inout) :: dtset
!arrays
 real(dp),intent(in) :: acell(3),rprim(3,3)

!Local variables ------------------------------
 character(len=4),parameter :: ctype='RPA '
!scalars
 integer,parameter :: NOMEGAGAUSS=30,NOMEGAREAL=201,unitf=0,unitwfg=25
 integer,parameter :: unitwfr=26
 integer :: dpbytes,fermiocc,i,i1,i2,i3,ia,ib,ig,ig1,ig2,ig3,ig4,ig4x,ig4y,ig4z
 integer :: ik,inclvkb,io,iomega,iq,iqp,ir,istat,mpsang,natom,nbnds,nbr,nbv
 integer :: nel=0,ngfft1,ngfft1a,ngfft2,ngfft2a,ngfft3,ngfft3a,ngr,ninv,nkbz
 integer :: nkbzx,nkibz,nkibzr,nomega,nop,nopr,npwvec,nq,nqptdm,nr,nshr,ntypat
 integer :: tim_fourdp
!no_abirules
! etadelta distance poles G from poles W
 real(dp),parameter :: OMEGAERMAX=100.0/Ha_eV,etadelta=0.1/Ha_eV
 real(dp) :: bzvol,domegareal,e0,efermi,epsilon0,epsilon0nlf,omegaplasma,tpula
 real(dp) :: ucvol,ula
 complex :: ctmp
 logical,parameter :: lda=.false.,rpa=.true.,testelectron=.false.
 logical,parameter :: testparticle=.true.
 logical :: analytic_continuation=.false.,contour_deformation=.false.,static=.false.
 logical :: found,ltemp,plasmon_pole_model=.true.,qeq0
 logical :: update_energies=.false.
 character(len=fnlen) :: filewfg,filewfr
 type(epsilonm1_parameters) :: ep
 type(hdr_type) :: hdr
 integer,allocatable :: grottb(:,:,:),grottbm1(:,:,:),gvec(:,:),igfft(:,:,:,:)
 integer,allocatable :: irottb(:,:),ktab(:),ktabi(:),ktabo(:),ktabr(:,:)
 integer,allocatable :: typat(:)
 real(dp) :: a1(3),a2(3),a3(3),b1(3),b2(3),b3(3),bcc2rl(3,3),brl2cc(3,3)
 real(dp) :: gmet(3,3),gprimd(3,3),qcart(3),qcc(3),rmet(3,3),rprimd(3,3)
 real(dp) :: tsec(2),qtemp(3)
 real(dp),allocatable :: energy(:,:),gwenergy(:,:),kbz(:,:),kibz(:,:),occ(:,:)
 real(dp),allocatable :: op(:,:,:),q(:,:),qplusg(:),rho2(:),vkb(:,:,:,:),qptdm(:,:)
 real(dp),allocatable :: vkbd(:,:,:,:),vkbsign(:,:),wtk(:),xcart(:,:),xred(:,:)
!the next to call gaulec which has fixed double precision arguments
 real(kind(0.d0)),allocatable :: z(:),zw(:)
!Kxclda in G,G'' space dimension nr
 complex,allocatable :: chitmp(:,:),gradvnl(:,:,:,:),kxclda(:),omega(:)
 complex,allocatable :: wfg(:,:,:),wfr(:,:,:)
 complex,allocatable,target :: chi0(:,:,:)
 complex,pointer :: chi(:,:,:),eps(:,:,:),epsm1(:,:,:)
 character(len=80) :: title(2)
 character(len=500) :: message
           integer,allocatable::nband_t(:)
           integer::nband,ierr,spaceComm,me,master
 integer :: nscf
 real(dp),allocatable :: en_qp(:,:)
 complex,allocatable :: m_lda_to_qp(:,:,:),wfg_qp(:,:,:),wfr_qp(:,:,:)
!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifndef HAVE_FORTRAN_INTERFACES
 integer :: modx
#endif
!End of the abilint section

!************************************************************************
!BEGIN EXECUTABLE SECTION
 call timab(301,1,tsec)
 call timab(302,1,tsec)

 write(message,'(7a)')&
& ' SCREENING: Calculation of the susceptibility and dielectric matrices',ch10,ch10,&
& ' Based on a program developped by R.W. Godby, V. Olevano, G. Onida, and L. Reining.',ch10,&
& ' Incorporated in ABINIT by V. Olevano, G.-M. Rignanese, and M. Torrent.',ch10
 call wrtout(ab_out,message,'COLL')

!start clock
 call pclock(0)

 ep%gwcalctyp=dtset%gwcalctyp
 if(mod(ep%gwcalctyp,10)/=0.and.mod(ep%gwcalctyp,10)/=8) plasmon_pole_model=.false.
 if(mod(ep%gwcalctyp,10)==1) analytic_continuation=.true.
 if(mod(ep%gwcalctyp,10)==2.or.mod(ep%gwcalctyp,10)==9) contour_deformation=.true.
 if(mod(ep%gwcalctyp,10)==5.or.mod(ep%gwcalctyp,10)==6.or.mod(ep%gwcalctyp,10)==7) static=.true.
! write(message,'(a,i4)') 'gw calculation type', ep%gwcalctyp
! call wrtout(ab_out,message,'COLL')

!XG 020209 : Valerio, the value of dp is NOT in general the length
!of a real. It is a pure convention, despite the fact
!that some constructors have chosen to use the length of a real ...
!write(*,*) 'length of a real on this machine ',dp
!The following coding is safer.
!VO 030411: dpbytes is used in the opening of a direct access file
!to establish the length of the record (recl=...). It represents the
!length of real to be used in a recl statement. For example on Dec
!it should be 1 (even if a real is 4 bytes)
!because recl is based on "word" units.
!On aix it should be 4 because it is based on byte units.
!Originally to establish this machine dependent length, a function
!opening a direct access file and trying to write and reread a real (pi or e)
!was called and was returning this machine dependent length.
!However 8 is safe even if you get file sizes which can be 8 times the required.
 dpbytes=8
#if defined T3E
 dpbytes=16
#endif
 write(message,'(a,i4,a,i4,a)')'length of a real on this machine ',dpbytes,' ; dp=',dp,ch10
 call wrtout(6,message,'COLL')

!Set up the parameters of the calculation (incl. q points)
 nbnds=dtset%nband(1)

!Compute dimensional primitive translations rprimd
 call mkrdim(acell,rprim,rprimd)

!Obtain dimensional translations in reciprocal space gprimd,
!metrics and unit cell volume, from rprimd.
!Also output rprimd, gprimd and ucvol
 call metric(gmet,gprimd,ab_out,rmet,rprimd,ucvol)

!Define consistently npw, nsh, and ecut
 call setshells(dtset%ecutwfn,dtset%npwwfn,dtset%nshwfn,dtset%nsym,gmet,&
& gprimd,dtset%symrel,'wfn',ucvol)
 call setshells(dtset%ecuteps,dtset%npweps,dtset%nsheps,dtset%nsym,gmet,&
& gprimd,dtset%symrel,'eps',ucvol)

!call rdchiin(dtset%npweps,dtset%npwwfn,nbnds,nomega,omegai,omegae,model)
!calculate npwvec as the biggest between dtset%npweps and dtset%npwwfn
 if(dtset%npwwfn>dtset%npweps) then
   npwvec=dtset%npwwfn
 else
   npwvec=dtset%npweps
 end if

 write(message,'(a)')' screening : will call testlda '
 call wrtout(6,message,'COLL')

!read parameters of the qplda file and verifify them
 call testlda(dtfil,nop,nkibz,nbr,ngr,nshr,i1,i2,ntypat,natom,mpsang)
 if(i2/=0.and.i2/=1.and.i2/=2.and.i2/=502.and.i2/=602) then
  stop 'unknown file form'
 end if
 ninv=2
 inquire(file='nop.in',exist=ltemp)
 if(ltemp) then
  open(99,file='nop.in')
  read(99,*) nop, ninv
  close(99)
 end if

 if(npwvec>ngr) then
  write(message,'(a)') 'warning: number of g-vectors found less then required;'
   call wrtout(6,message,'COLL')
   npwvec=ngr
   if(dtset%npwwfn>ngr) dtset%npwwfn=ngr
   if(dtset%npweps>ngr) dtset%npweps=ngr
   write(message,'(a,i6,a,a,i6,a,a,i6,a)') '         calculation will proceed with NPWVEC = ',npwvec,&
 & ch10,'                                       NPWEPS = ',dtset%npweps,ch10,&
 & '                                       NPWWFN = ',dtset%npwwfn,ch10
  call wrtout(6,message,'COLL')
 end if

 if(nbnds>nbr) then
   write(message,'(a,a,a,i4,a)') 'warning: number of bands found less then required;',ch10,&
  &'         calculation will proceed with NBNDS = ',nbr,ch10
   call wrtout(6,message,'COLL')
   nbnds=nbr
 end if
 allocate(qplusg(dtset%npweps),stat=istat)
 if(istat/=0) stop 'out of memory'

!allocate LDA electronic structure variables
 allocate(op(3,3,nop),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(kibz(3,nkibz),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(gvec(3,npwvec),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(energy(nkibz,nbnds),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(occ(nkibz,nbnds),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(gwenergy(nkibz,nbnds),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(wfg(dtset%npwwfn,nbnds,nkibz))
 if(istat/=0) stop 'wavefunctions(g) out of memory'

 write(message,'(a)')' screening : will call rdlda or rdldaabinit '
 call wrtout(6,message,'COLL')
!read in LDA band structure and information about material
 if(i2==0.or.i2==1) then
! file unformatted -> i1=1
  i1 = 1
   call rdlda(10,nop,nbnds,nkibz,npwvec,dtset%npwwfn,nopr,nbr,nkibzr,ngr,&
&   title,i1,i2,i3,a1,a2,a3,op,gvec,kibz,energy,occ,wfg)
 else if(i2==2) then
   call rdldaabinit(10,nop,nbnds,nkibz,npwvec,dtset%npwwfn,&
&   title,a1,a2,a3,op,gvec,kibz,energy,occ,wfg)
 else if(i2==502.or.i2==602) then
  allocate(typat(natom),xred(3,natom),xcart(3,natom))
  allocate(vkbsign(mpsang,ntypat))
  allocate(vkb(dtset%npwwfn,ntypat,mpsang,nkibz),stat=istat)
  if(istat.ne.0) stop 'out of memory'
  allocate(vkbd(dtset%npwwfn,ntypat,mpsang,nkibz),stat=istat)
  if(istat.ne.0) stop 'out of memory'
  call rdkss(dtfil,hdr,nop,nbnds,nkibz,npwvec,dtset%npwwfn,&
&            title,a1,a2,a3,op,gvec,kibz,energy,occ,wfg,&
&            ntypat,natom,mpsang,typat,xred,vkbsign,vkb,vkbd,nel)
  do ia = 1, natom
   xcart(:,ia) = xred(1,ia)*a1(:) + xred(2,ia)*a2(:) + xred(3,ia)*a3(:)
  end do
 end if
 call pclock(10)

 call lattice(a1,a2,a3,b1,b2,b3,ucvol,bzvol)
!note that ULA is not guaranteed to be the same as that used by
!RJN; it is chosen to be sqrt(2)*|a1|
 ula=sqrt(2.0)*sqrt(a1(1)**2+a1(2)**2+a1(3)**2)
!ula should be the lattice parameter, and tpula=2pi/a
 tpula=2.0*pi/ula
 brl2cc(:,1)=b1(:) ; brl2cc(:,2)=b2(:) ; brl2cc(:,3)=b3(:)
 bcc2rl(:,:)=brl2cc(:,:)
 call matrginv(bcc2rl,3,3)
 call pclock(20)

 call findshells(b1,b2,b3,npwvec,dtset%npweps,gvec)
!set real space mesh
 call setmesh(gmet,gvec,ngfft1,ngfft2,ngfft3,ngfft1a,ngfft2a,ngfft3a,npwvec,dtset%npwwfn,nr)

!NOTE : The following call to setmesh.f must be used if method=2 or method=3 in setmesh.f (see Src_3gw/setmesh.f).
!write(std_out,*) ' npweps = ',dtset%npweps
!call setmesh(gmet,gvec,ngfft1,ngfft2,ngfft3,ngfft1a,ngfft2a,ngfft3a,dtset%npweps,dtset%npwwfn,nr)

!set up tables for FFT igfft
 allocate(igfft(npwvec,5,5,5),stat=istat)
 if(istat/=0) stop 'out of memory'
 call cigfft(npwvec,ngfft1a,ngfft1,ngfft2,ngfft3,gvec,igfft)
 call pclock(30)

!set up table indicating rotations of r-points
 allocate(irottb(nr,nop),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(grottb(npwvec,2,nop),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(grottbm1(npwvec,2,nop),stat=istat)
 if(istat/=0) stop 'out of memory'
call surot(op,nop,ninv,ngfft1,ngfft1a,ngfft2,ngfft3,nr,npwvec,gvec,grottb,irottb,&
& grottbm1)
 call pclock(40)

!set up required k-points in whole BZ; nkbzx maximum number of them
 nkbzx=nkibz*nop*2
 allocate(kbz(3,nkbzx),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(wtk(nkibz),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(ktab(nkbzx),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(ktabi(nkbzx),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(ktabo(nkbzx),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(ktabr(nr,nkbzx),stat=istat)
 if(istat/=0) stop 'out of memory'
 call identk(kibz,nkibz,nkbzx,nr,nop,ninv,irottb,op,kbz,ktab,ktabr,ktabi,&
& ktabo,nkbz,wtk)
 call pclock(50)

!find q-points q=k-kfirst
 call findnq(nkbz,kbz,nop,op,nq,ninv)
 allocate(q(3,nq))
 call findq(nkbz,kbz,nop,op,nq,q,ninv,b1,b2,b3)
 call pclock(60)

 call timab(302,2,tsec)
 call timab(303,1,tsec)

!calculate LDA wavefunctions in real space using FFT
 allocate(wfr(nr,nbnds,nkibz),stat=istat)
 if(istat/=0) stop 'wavefunctions(r) out of memory'
 wfr(:,:,:)=zero
 tim_fourdp=4
 call fftwfn(dtset%npwwfn,nbnds,nkibz,nr,wfg,wfr,igfft(:,3,3,3),ngfft1,ngfft1a,&
& ngfft2,ngfft3,tim_fourdp)

 call timab(303,2,tsec)
 call timab(304,1,tsec)

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! FBruneval 05/12/15
! read QP wavefunctions of the previous step
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

!read self-consistent transformation matrices and QP energies
 allocate(m_lda_to_qp(nbnds,nbnds,nkibz))
 allocate(en_qp(nkibz,nbnds))
! call read_scf(dtfil,ep%gwcalctyp,nkibz,nbnds,kibz,nscf,energy,en_qp,m_lda_to_qp)
 call rdqps(dtfil,ep%gwcalctyp,nkibz,nbnds,kibz,nscf,energy,en_qp,m_lda_to_qp)

!computes QP wfr and wfg
 allocate(wfg_qp(dtset%npwwfn,nbnds,nkibz))
 allocate(wfr_qp(nr,nbnds,nkibz))
 call calc_wf_qp(nkibz,nbnds,dtset%npwwfn,nr,m_lda_to_qp,wfg,wfr,wfg_qp,wfr_qp)
 energy(:,:)=en_qp(:,:)
 wfr(:,:,:)=wfr_qp(:,:,:)
 wfg(:,:,:)=wfg_qp(:,:,:)

 deallocate(m_lda_to_qp,en_qp,wfg_qp,wfr_qp)

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! FBruneval 05/12/15
! everything else remains unchanged
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!


!open scratch file for wavefunctions (r,b,k)
 filewfr=trim(dtfil%filnam_ds(5))//'_WFR'
 open(unit=unitwfr,file=filewfr,status='unknown',access='direct',&
& recl=nr*nbnds*dpbytes)
 do ik=1,nkibz
   write(unitwfr,rec=ik) ((wfr(ir,ib,ik),ir=1,nr),ib=1,nbnds)
 end do
 deallocate(wfr)
!open scratch file for wavefunction(n,G)
 filewfg=trim(dtfil%filnam_ds(5))//'_WFG'
!DEBUG
!write(6,*)' screening : will open file="',trim(filewfg),'"'
!write(6,*)' screening : dtset%npwwfn=',dtset%npwwfn
!write(6,*)' screening : nbnds=',nbnds
!write(6,*)' screening : dpbytes=',dpbytes
!write(6,*)' screening : nkibz=',nkibz
!ENDDEBUG
 open(unit=unitwfg,file=filewfg,status='unknown',access='direct',&
& recl=dtset%npwwfn*nbnds*2*dpbytes)
!DEBUG
!write(6,*)' screening : file is open'
!ENDDEBUG
 do ik=1,nkibz
   write(unitwfg,rec=ik) ((wfg(ig,ib,ik),ig=1,dtset%npwwfn),ib=1,nbnds)
 end do
 deallocate(wfg)
 call pclock(70)

 call timab(304,2,tsec)
 call timab(305,1,tsec)

 call fermi(hdr,nbnds,nkibz,dtset%nsppol,wtk,energy,occ,nel,nbv,efermi)

!if(nel==0) then
! do ik=1,nkibz
!  do ib=1,nbnds
!   nel=nel+int(occ(ik,ib))
!  end do
! end do
! nel=nel/nkibz
!end if
!write(*,*) 'total number of electrons = ',nel
!call fermi(energy,wtk,nkibz,nbnds,nel,efermi,fermiocc)
!do ik=1,nkibz
!  do ib=1,nbnds
!    if(energy(ik,ib)<efermi) occ(ik,ib)=2.0
!    if(energy(ik,ib)>efermi) occ(ik,ib)=0.0
!    if(abs(energy(ik,ib)-efermi)<=1e-5) occ(ik,ib)=fermiocc
!  end do
!end do
!nbv=nel/2

 gwenergy(:,:)=energy(:,:)
 inquire(file='in.gw',exist=update_energies)
 ep%soenergy=dtset%soenergy
 if(ep%soenergy>0.1d-4) then
 write(message,'(a,a,a,a,a,f7.3,a)')'performing a first self-consistency',ch10,&
&  'update of the energies in W by a scissor operator',ch10,&
&  'applying a scissor operator of [eV] ', ep%soenergy*Ha_eV,ch10
   call wrtout(06,message,'COLL')
   call wrtout(ab_out,message,'COLL')
  gwenergy(:,nbv+1:nbnds)=energy(:,nbv+1:nbnds)+ep%soenergy
 else if(update_energies) then
  write(message,'(a,a,a,a)')'performing a first self-consistency',ch10,&
&  'update of the energies in W by a previous GW calculation',ch10
   call wrtout(06,message,'COLL')
   call wrtout(ab_out,message,'COLL')

  call rdgw(nkibz,nbnds,nbv,kibz,gwenergy)
 end if

!calculate electron density
 allocate(rho2(nr),stat=istat)
 if(istat/=0) stop 'out of memory'
 call density(nbnds,nkibz,nkibz,nkbz,nop,ninv,nr,ngfft1,ngfft1a,ngfft2,&
& ngfft3,irottb,ucvol,wtk,occ,rho2,omegaplasma)
 call pclock(80)

 ep%nomegaer=1
 ep%nomegaei=1

! RShaltaf(030306):since on three diffrent ppmdels, the DM only on zero omega is needed
! one can save cpu time by calculating the DM on one frequency
! provided that the user use nfreqre=1
  if(plasmon_pole_model)then
  if(dtset%nfreqre==1.and.dtset%nfreqim==0)then
   ep%nomegaer=1
   ep%nomegaei=0
   write(message,'(a,a,a,a,a,a)')'the DM will be calculated on zero frequency only',ch10,&
 & 'please note that the calculated DM will not be suitable if you chose to calculate self energy',ch10,&
 &  ' using plasmon pole model (ppmodel 1)',ch10
  call wrtout(06,message,'COLL')
  call wrtout(ab_out,message,'COLL')
  end if
 end if

 if(static) ep%nomegaer=0
 if(analytic_continuation .or. contour_deformation) then
  ep%nomegaei=dtset%nfreqim
  if(ep%nomegaei==0) ep%nomegaei=NOMEGAGAUSS
 end if
 if(contour_deformation) then
  ep%nomegaer=dtset%nfreqre
  ep%omegaermax=dtset%freqremax
  if(ep%nomegaer==0) ep%nomegaer=NOMEGAREAL
  if(ep%omegaermax<0.1d-4) ep%omegaermax=OMEGAERMAX
  domegareal=ep%omegaermax/(ep%nomegaer-1)
 end if
 nomega=ep%nomegaer+ep%nomegaei
 allocate(omega(nomega))

 omega(1)=0 ! first omega is always zero without broadening
 do io=2,ep%nomegaer
  omega(io)=cmplx((io-1)*domegareal,0)
  ! probably here we are wrong as omega is neither 0 nor imag pure
 end do

 if(plasmon_pole_model) then
  if(nomega==2)then
  e0=dtset%ppmfrq
  if(e0<0.1d-4) e0 = omegaplasma
  omega(2)=cmplx(0.0,e0)
 end if
 end if
 if(analytic_continuation .or. contour_deformation) then
!  allocate(z(ep%nomegaei),zw(ep%nomegaei))
!  ! calculate Gauss-Legendre Quadrature knots and weights
!  ! to calulate \int_0^\infty dx f(x)
!  ! we calculate \int_0^1 dz f(1/z - 1)/z^2
!  call coeffs_gausslegint(0.0d0,1.0d0,z,zw,ep%nomegaei)
!  do io=1, ep%nomegaei
!   omega(ep%nomegaer+io)=cmplx(0.0,1/z(io)-1)
!  end do
!  deallocate(z,zw)
  e0=dtset%ppmfrq
  if(e0<0.1d-4) e0 = omegaplasma
  do io=1, ep%nomegaei
   omega(ep%nomegaer+io)=cmplx(0.0,e0/3.*(exp(2./(ep%nomegaei+1)*log(4.)*io)-1.))
  end do
 end if
 write(message,'(a,a)')ch10,&
&  ' calculating at frequencies omega [eV]:'
  call wrtout(06,message,'COLL')
  call wrtout(ab_out,message,'COLL')
 do io=1,nomega
  write(message,'(i3,2es16.6)')io,omega(io)*Ha_eV
  call wrtout(06,message,'COLL')
  call wrtout(ab_out,message,'COLL')
 end do
 allocate(chitmp(dtset%npweps,dtset%npweps),stat=istat)
 if(istat/=0) stop 'out of memory chitmp'
 if(lda) then
!  calculate exchange-correlation kernel Kxclda
!  calculate Kxclda in G-space and put it into Kxclda(1+igx+igy*...)
   allocate(kxclda(nr),stat=istat)
   if(istat/=0) stop 'out of memory'

   call ckxcldag(ngfft1,ngfft1a,ngfft2,ngfft3,nr,rho2,kxclda)
   do ig=1,dtset%npweps
     chitmp(ig,1)=kxclda(igfft(ig,3,3,3))
   end do
   write(*,*) 'kxclda(g)'
   call printv(chitmp,dtset%npweps)

 end if

 allocate(chi0(dtset%npweps,dtset%npweps,nomega),stat=istat)
 if(istat/=0) stop 'out of memory chi0'
 chi=>chi0
 epsm1=>chi0
 eps=>chi0

 write(*,*) 'end of initialization'
 write(*,*)
 call pclock(90)

! the following lines added by R.Shaltaf to enable the calculations of
! DM on one or more selected q points

 if(dtset%nqptdm>0)then
  write(*,'(3a)') 'Dielectric matrix will be calculated on some ',&
&  'selected q points provided by the user through the input variables ',&
&  'nqptdm and qptdm'
  write(ab_out,'(3a)') 'Dielectric matrix will be calculated on some ',&
&  'selected q points provided by the user through the input variables ',&
&  'nqptdm and qptdm'
  if(dtset%nqptdm>nq)then
   write(message, '(a,a,a,a,a)' ) ch10,&
&   ' screening: ERROR -',ch10,&
&   '  nqptdm should not exceed the actual number of q points that alrady exist in BZ',ch10
   call wrtout(6,message,'COLL')
   call leave_new('COLL')
  end if
  allocate(qptdm(3,dtset%nqptdm))
  qptdm(:,:)=dtset%qptdm(:,:)
! check whether the q points privided by the user are already exist in the set of q points'
  do iq=1,dtset%nqptdm
   found=.false.
   do iqp=1,nq
    qtemp(:)=qptdm(:,iq)-q(:,iqp)
    if(all(abs(qtemp(:))<1.0e-3))found=.true.
    if(found)exit
   end do
   if(.not.found)then
   write(message, '(a,a,a,a,a)' ) ch10,&
&   ' screening: ERROR -',ch10,&
&   ' one or more qptdm cannot be identified as regular q-points satisfying q = k - k1',ch10
   call wrtout(6,message,'COLL')
   call leave_new('COLL')
   end if
  end do
 end if

! These lines added by Shaltaf for parallelization 10/08/05
! parallization is on k points only

  allocate(nband_t(nkbz*1))
  nband_t(:)=nbnds
  mpi_enreg%parareel=0
  mpi_enreg%paralbd=0
  if(mpi_enreg%parareel==0)then
   mpi_enreg%paral_level=2
   allocate(mpi_enreg%proc_distrb(nkbz,nbnds,1))
   call distrb2(nbnds,nband_t,nkbz,1,mpi_enreg)
  end if
  deallocate(nband_t)



! at this stage we are sure that all q pints provided by user
! satisfy the conditions
!-----------------------------------------------------------------------
!calculate screening function and save on disc for each q-point
 write(message,'(a,a,a,a)') '----------------------',ch10,&
& 'beginning of main loop',ch10
 call wrtout(06,message,'COLL')
 call timab(305,2,tsec)

 do iq=1,nq


! added by R. Shaltaf for the selective q points calaculation

  found=.false.
   if(dtset%nqptdm>0)then
    do iqp=1,dtset%nqptdm
    qtemp(:)=q(:,iq)-dtset%qptdm(:,iqp)
    if(all(abs(qtemp(:))<1.0e-3))found=.true.
    if(found)exit ! iqp
   end do
   if(.not.found)cycle ! iq
   end if

! Shaltaf part ends here

   call timab(306,1,tsec)

   qeq0=.false.
   if(all(abs(q(:,iq))<1.0e-3)) qeq0=.true.

   qcc(:)=matmul(brl2cc,q(:,iq))
   qcart(:)=qcc(:)/tpula
   if(dtset%nqptdm==0)then
   write(message,'(a,i2,a,f9.6,2(",",f9.6),a,a)')&
&   ' q-point number ',iq,'        q = (',(q(i,iq),i=1,3),') [r.l.u.]',ch10
    call wrtout(06,message,'COLL')
   else
    write(message,'(a,i2,a,f9.6,2(",",f9.6),a,a)')&
&   ' q-point number ',iqp,'        q = (',(q(i,iq),i=1,3),') [r.l.u.]',ch10
    call wrtout(06,message,'COLL')
    end if
!  calculates qplusg(G)=|q+G| table for coulombian potential
   call cvc(nq,iq,q,b1,b2,b3,dtset%npweps,gvec,qplusg)

   call pclock(100*iq)

   call timab(306,2,tsec)

!  calculates chi0
   if(qeq0) then

     call timab(307,1,tsec)

!    different treatment of the case q=0
     inclvkb=dtset%inclvkb
     if(inclvkb==1) then
      allocate(gradvnl(3,dtset%npwwfn,dtset%npwwfn,nkibz),stat=istat)
      if(istat/=0) stop 'out of memory'
      call ccgradvnl(dtset%npwwfn,nkibz,b1,b2,b3,gvec,kibz,ntypat,&
&                     natom,mpsang,typat,xcart,vkbsign,vkb,vkbd,gradvnl)
     end if
     call cchi0q0(q(:,iq),nomega,omega,gvec,npwvec,dtset%npweps,dtset%npwwfn,op,nop,&
&     kibz,nkibz,nkibz,nbnds,nbv,occ,ktab,ktabr,ktabi,ktabo,kbz,nkbz,&
&     irottb,ngfft1,ngfft1a,ngfft2,ngfft3,igfft,nr,energy,gwenergy,etadelta,chi0,b1,b2,b3,&
&     ucvol,wtk,grottb,inclvkb,gradvnl,mpi_enreg)
     if(inclvkb==1)deallocate(gradvnl)

     call timab(307,2,tsec)

   else

     call timab(308,1,tsec)
     call cchi0(q(:,iq),nomega,omega,npwvec,dtset%npweps,dtset%npwwfn,nkibz,nkibz,nbnds,&
&     nbv,occ,ktab,ktabr,ktabi,kbz,nkbz,ngfft1,ngfft1a,ngfft2,ngfft3,&
&     igfft,nr,energy,gwenergy,etadelta,chi0,mpi_enreg)

     call timab(308,2,tsec)

   end if

   call timab(309,1,tsec)

!  print chi0(q,G,G'',omega)
   if(mpi_enreg%me==0)then
!XG 060124 : apparently changed by FB on top of v4.6.5 . Why ?
!  do iomega=1,2
   do iomega=1,1
     if(dtset%nqptdm>0)then
      write(message,'(a,i2,a,i1,a)') ' chi0(q=',iqp,',omega=',iomega,',G,G")'
     call wrtout(06,message,'COLL')
     else
      write(message,'(a,i2,a,i1,a)') ' chi0(q=',iq,',omega=',iomega,',G,G")'
     call wrtout(06,message,'COLL')
     end if
      call printcm(chi0(:,:,iomega),dtset%npweps,dtset%npweps)
   end do
   end if

   call pclock(100*iq+10)

   if(rpa) then
     chi0(:,:,:)=chi0(:,:,:)/ucvol
!    calculate epsilon=(1-Vc*chi0)
     do io=1,nomega
     do ig2=1,dtset%npweps
       chitmp(:,ig2)=(-(4.0*pi)/(qplusg(:)*qplusg(ig2)))*chi0(:,ig2,io)
       chitmp(ig2,ig2)=1+chitmp(ig2,ig2)
     end do
     eps(:,:,io)=chitmp(:,:)
     end do

     if(mpi_enreg%me==0)then
      write(*,*) 'epsilon(G,G") at the first omega'
      call printcm(eps(:,:,1),dtset%npweps,dtset%npweps)
     end if

     if(qeq0) epsilon0nlf=real(eps(1,1,1))

     do io=1,nomega
       call matcginv(eps(:,:,io),dtset%npweps,dtset%npweps)
     end do

     if(mpi_enreg%me==0)then
      write(*,*) 'epsilon^-1(G,G") at the first omega'
      call printcm(epsm1(:,:,1),dtset%npweps,dtset%npweps)
     end if

!    calculate macroscopic dielectric constant
!    epsmlf=1/epsm1(G=0,G''=0)
     if(qeq0) epsilon0=real(1.0/epsm1(1,1,1))

     if(qeq0 .and. .not.plasmon_pole_model) then
      open(69,file='out.elf')
      do io=1,ep%nomegaer
       write(69,*) real(omega(io))*Ha_eV, -aimag(epsm1(1,1,io))
      end do
      close(69)
     end if


   else ! of if(rpa)

   do iomega=1,nomega

     if(rpa) then
!      zeroes chitmp
       chitmp(:,:)=0.0

     else if(lda) then
!      calculate chi0*KxcLDA and put it in chitmp
!      calculate chi0*Kxc in G-space
       do ig1=1,dtset%npweps
         do ig2=1,dtset%npweps
           ctmp=(0.0,0.0)
           do ig3=1,dtset%npweps
             ig4x=modx(gvec(1,ig3)-gvec(1,ig2),ngfft1)
             ig4y=modx(gvec(2,ig3)-gvec(2,ig2),ngfft2)
             ig4z=modx(gvec(3,ig3)-gvec(3,ig2),ngfft3)
             ig4=1+ig4x+ig4y*ngfft1a+ig4z*ngfft1a*ngfft2
             ctmp=ctmp+chi0(ig1,ig3,iomega)*kxclda(ig4)
           end do
           chitmp(ig1,ig2)=ctmp
         end do
       end do
     end if

     if(.not.rpa) then
!      write(6,'(a,i2,a,i1,a)') ' chi0*Kxc(q=',iq,',omega=',iomega,',G,G")'
!      call printcm(chitmp,dtset%npweps,dtset%npweps)
     end if

!    calculate chi
!    write(*,*)
!&    'calculating chi=(1-chi0*Vc-chi0*Kxc)^-1 chi0'

!    calculate (1-chi0*Vc-chi0*Kxc ) and put it in chitmp
     do ig1=1,dtset%npweps
       do ig2=1,dtset%npweps
         chitmp(ig1,ig2)=(-(4.0*pi)/(qplusg(ig2)**2))*&
&          chi0(ig1,ig2,iomega)-chitmp(ig1,ig2)
       end do
       chitmp(ig1,ig1)=chitmp(ig1,ig1)+ucvol
     end do

!    invert (1-chi0*Vc-chi0*Kxc)
     call matcginv(chitmp,dtset%npweps,dtset%npweps)

!    multiply for chi0
!     call cdotm(chitmp,chi0(1,1,iomega),dtset%npweps)
     chitmp=matmul(chitmp,chi0(:,:,iomega))

!    must multiply by ucvol (see notes-due to conversion of r->G in
!    matrix definitions)
     chi(:,:,iomega)=chitmp(:,:)*ucvol

   end do ! iomega

!  print chi
!XG 060124 : apparently changed by FB on top of v4.6.5 . Why ?
!  do iomega=1,2
   do iomega=1,1
     write (6,'(a,i2,a,i1,a)') ' chi(q=',iq,',omega=',iomega,',G,G")'
     call printcm(chi(:,:,iomega),dtset%npweps,dtset%npweps)
   end do

!  calculate epsilon-twiddle^-1
!  write(*,*)  'calculating epsilon^-1(G,G")=1+(Vc+Kxc)*chi'
   do iomega=1,nomega
     if(.not.testparticle) then
       if(rpa) then
!        zeroes chitmp
         chitmp(:,:)=(0.0,0.0)
       else if(lda) then
!        calculate Kxclda*chi and put in chitmp
         do ig1=1,dtset%npweps
           do ig2=1,dtset%npweps
             ctmp=(0.0,0.0)
             do ig3=1,dtset%npweps
               ig4x=modx(gvec(1,ig1)-gvec(1,ig3),ngfft1)
               ig4y=modx(gvec(2,ig1)-gvec(2,ig3),ngfft2)
               ig4z=modx(gvec(3,ig1)-gvec(3,ig3),ngfft3)
               ig4=1+ig4x+ig4y*ngfft1a+ig4z*ngfft1a*ngfft2
               ctmp=ctmp+kxclda(ig4)*chi(ig3,ig2,iomega)
             end do
             chitmp(ig1,ig2)=ctmp
           end do
         end do
       end if
!      perform hermitianization
       call hermitianize(chitmp,dtset%npweps)
     else
!      zeroes chitmp
       chitmp(:,:)=(0.0,0.0)
     end if
     do ig1=1,dtset%npweps
         epsm1(ig1,:,iomega)=(4*pi/(qplusg(ig1)*qplusg(:)*ucvol))*&
&          chi(ig1,:,iomega)+chitmp(ig1,:)/ucvol
!          chitmp=Kxc*chi must be divided by ucvol see notes on fft r->G
       epsm1(ig1,ig1,iomega)=1.0+epsm1(ig1,ig1,iomega)
     end do
   end do

   if(mpi_enreg%me==0)then
!  print epsilon-twiddle^-1
!XG 060124 : apparently changed by FB on top of v4.6.5 . Why ?
!  do iomega=1,2
   do iomega=1,1
     write (6,'(a,i2,a,i1,a)') ' epsilon-twiddle^-1(q=',iq,',omega=',&
&     iomega,',G,G")'
     call printcm(epsm1(:,:,iomega),dtset%npweps,dtset%npweps)
   end do
   end if


!  find dielectric constant epsilon0 with lf
   if(qeq0) then
     do io=1,nomega
       if(abs(real(omega(io)))<1.e-3) then
       if(abs(aimag(omega(io)))<1.e-3) then
         epsilon0=real(1.0/epsm1(1,1,io))
       end if
       end if
     end do
   end if

   end if ! of if(rpa)

   call timab(309,2,tsec)
   call timab(310,1,tsec)

   if(mpi_enreg%me==0)then ! only master should write

!   write epsilon^-1 on file
!   on title(1) it is better to write the name of the system (e.g. Silicon bulk..)
    title(1)='em1 file: epsilon^-1'
    if(testparticle) then
     title(2)='TESTPARTICLE'
    else
     title(2)='TESTELECTRON'
    end if
    title(2)(14:17)=ctype

    call wrscr(dtfil,hdr,dtset,dtset%npweps,dtset%npwwfn,npwvec,nbnds,nq,nomega,q,omega,&
&   gvec,iq,epsm1,title,unitf,nop,op)

    if(qeq0) then
     do io=1,nomega
       if(abs(real(omega(io)))<1.e-3) then
        if(abs(aimag(omega(io)))<1.e-3) then
         write(*,'(a,f8.4)')&
&         ' dielectric constant = ',epsilon0
         write(ab_out,'(a,f8.4)')&
&         ' dielectric constant = ',epsilon0
         write(*,'(a,f8.4)')&
&         ' dielectric constant without local fields = ',epsilon0nlf
         write(ab_out,'(a,f8.4)')&
&         ' dielectric constant without local fields = ',epsilon0nlf
         write(*,*)
         write(ab_out,*)
        end if
       end if
     end do
    end if

  end if  ! master

   call pclock(100*iq+90)
   call timab(310,2,tsec)

   write(*,*)
 end do ! iq

 call pclock(9999)

 if(i2==502.or.i2==602) then
  call hdr_clean(hdr)
 end if

 close (unitwfg)
 close (unitwfr)

 deallocate(chitmp,chi0,energy,grottb,grottbm1)
 deallocate(gvec,gwenergy,igfft,irottb,kibz)
 deallocate(occ,omega,op,q,qplusg,rho2)
 deallocate(kbz)
 deallocate(wtk)
 deallocate(ktab)
 deallocate(ktabi)
 deallocate(ktabo)
 deallocate(ktabr)
 deallocate(mpi_enreg%proc_distrb)
 if(i2==502.or.i2==602) deallocate(typat,xred,xcart,vkb,vkbd,vkbsign)
 if(lda) deallocate(kxclda)

 write(*,*) 'chi ended'

 call timab(301,2,tsec)

end subroutine screening
!!***
