!{\src2tex{textfont=tt}}
!!****f* ABINIT/sigma
!! NAME
!! sigma
!!
!! FUNCTION
!!
!! Calculate self-energy operator matrix elements
!!
!! COPYRIGHT
!! Copyright (C) 1999-2006 ABINIT group (GMR, VO, LR, RWG, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~abinit/COPYING
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  acell(3)=length scales of primitive translations (bohr)
!!  dtfil <type(datafiles_type)>=variables related to files
!!  dtset <type(dataset_type)>=all input variables for this dataset
!!  mpi_enreg=informations about MPI parallelization (to be completed)
!!  rprim(3,3)=dimensionless real space primitive translations
!!
!! OUTPUT
!!  output is written in a file
!!
!! PARENTS
!!      driver,drivergw
!!
!! NOTES
!!
!! files used:
!! input:
!! 10: LDA band structure and material info for sigma operator
!! 12: Epsilon-twiddle**-1 (plasmon-pole form) file EPSM1
!! stdin: parameters of calculation (incl. which
!!        k-points to calc. Sigma for) file sig.in
!! output:
!! 21: gw file, available for exciton calculation
!!
!! CHILDREN
!!      calc_wf_qp,cigfft,clcqpg,cmevxclda,cppm1par,cppm2par,cppm3par,cppm4par
!!      crho,csigme,fermi,fftwfn,findk,ham_changebasis,hartrham,hdr_clean
!!      identk,identq,lattice,leave_new,metric,mkrdim,pclock,rdgw,rdkss,rdlda
!!      rdldaabinit,rdqps,rdscr,setmesh,setshells,surot,testlda,testscr,timab
!!      write_sigma_results,write_sigma_results_header,wrqps,wrtout
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine sigma(acell,dtfil,dtset,mpi_enreg,rprim)

 use defs_basis
 use defs_datatypes

!This section has been created automatically by the script Abilint (TD). Do not modify these by hand.
#ifdef HAVE_FORTRAN_INTERFACES
 use interfaces_00basis
 use interfaces_01managempi
 use interfaces_02geometry
 use interfaces_04iowfdenpot
 use interfaces_05gw
 use interfaces_08seqpar
#endif
!End of the abilint section

 implicit none

!Arguments ------------------------------------
!scalars
 type(MPI_type),intent(inout) :: mpi_enreg
 type(datafiles_type),intent(in) :: dtfil
 type(dataset_type),intent(inout) :: dtset
!arrays
 real(dp),intent(in) :: acell(3),rprim(3,3)

!Local variables-------------------------------
!scalars
 integer,parameter :: eunit=12,iunit=10,unitem1=24
 integer :: fermiocc,fform,i,i1,i2,i3,ib,ibr,ig,ik,ikcalc,ikibz,io,istat,j
 integer :: mpsang,natom,nbr,nbv,nel=0,ngfft1,ngfft1a,ngfft2,ngfft2a,ngfft3
 integer :: ngfft3a,ngr,ninv,nkbzx,nkibzr,nop,nopr,npwvec,nqbzx,nqibzx,nr,nrb
 integer :: nscf,nshr,ntypat,tim_fourdp
 real(dp) :: absimsig,bzvol,condbottom,domegas,efermi,efermi_qp,oldefermi
 real(dp) :: omega_m_e_resig,omegaplasma,ucvol,valencetop
 logical :: ltemp,update_energies=.false.
 character(len=500) :: message
 type(epsilonm1_parameters) :: ep
 type(epsilonm1_results) :: er
 type(hdr_type) :: hdr
 type(sigma_parameters) :: sp
 type(sigma_results) :: sr
!arrays
 integer,allocatable :: grottb(:,:,:),grottbm1(:,:,:),gvec(:,:),igfft(:,:,:,:)
 integer,allocatable :: irottb(:,:),ktab(:),ktabi(:),ktabo(:),ktabr(:,:)
 integer,allocatable :: qtab(:),qtabi(:),qtabo(:),typat(:)
 real(dp) :: a1(3),a2(3),a3(3),b1(3),b2(3),b3(3),gmet(3,3),gprimd(3,3)
 real(dp) :: rmet(3,3),rprimd(3,3),tsec(2)
 real(dp),allocatable :: en(:,:),en_qp(:,:),kbz(:,:),kibz(:,:),occ(:,:)
 real(dp),allocatable :: occ_qp(:,:),op(:,:,:),q(:,:),qbz(:,:),qpg(:,:)
 real(dp),allocatable :: qratio(:,:,:),rho(:),rho_qp(:),sr_gwenergy(:,:)
 real(dp),allocatable :: vkb(:,:,:,:),vkbd(:,:,:,:),vkbsign(:,:),wtk(:)
 real(dp),allocatable :: xred(:,:)
 complex,allocatable :: eigpot(:,:,:),hbare(:,:,:),hlda(:,:,:)
 complex,allocatable :: m_lda_to_qp(:,:,:),temp_omegatw(:,:),vhartr(:,:,:)
 complex,allocatable :: vxc(:,:,:),wfg(:,:,:),wfg_qp(:,:,:),wfr(:,:,:)
 complex,allocatable :: wfr_qp(:,:,:)
 character(len=80) :: titem1(2),title(2)

!******************************************************************
!BEGIN EXECUTABLE SECTION

 call timab(401,1,tsec)
 call timab(402,1,tsec)
 write(ab_out,'(a,/,/,a,/,a,/)') &
& ' SIGMA: Calculation of the GW corrections',&
& ' Based on a program developped by R.W. Godby, V. Olevano, G. Onida, and L. Reining.',&
& ' Incorporated in ABINIT by V. Olevano, G.-M. Rignanese, and M. Torrent.'

!start clock
 call pclock(0)

 sp%gwcalctyp=dtset%gwcalctyp
 print *, 'gw calculation type', sp%gwcalctyp

 sp%splitsigc=dtset%splitsigc
 sp%ppmodel=dtset%ppmodel
 if(mod(sp%gwcalctyp,10)==5.or.mod(sp%gwcalctyp,10)==6.or.mod(sp%gwcalctyp,10)==7) sp%ppmodel=2
 if(mod(sp%gwcalctyp,10)<5) then
  sp%nomegasrd=dtset%nomegasrd
  sp%omegasrdmax=dtset%omegasrdmax
  sp%deltae=(2*sp%omegasrdmax)/(sp%nomegasrd-1)
 else
  sp%nomegasrd=1
  sp%omegasrdmax=0.
  sp%deltae=0.
 end if
 print *, 'number of point to evaluate derivative' , sp%nomegasrd
 print *, 'omegasrdmax [eV]', sp%omegasrdmax*Ha_eV
 print *, 'deltae [eV]', sp%deltae*Ha_eV

 sp%nomegasr=dtset%nfreqsp
 sp%omegasrmax=dtset%freqspmax
 if(sp%nomegasr>0) then
  print *, 'calculating spectral functions'
  domegas = 2*sp%omegasrmax / (sp%nomegasr-1)
  allocate(sr%omega(sp%nomegasr))
  do io=1, sp%nomegasr
   sr%omega(io) = - sp%omegasrmax + domegas * (io-1)
  end do
 else
!  sp%nomegasr=1 ! to not disturb calculate at least in 0
!  allocate(sr%omega(sp%nomegasr))
!  sr%omega(1)=0
 end if
 print *, 'nomegasr [eV]',sp%nomegasr, sp%omegasrmax*Ha_eV

 sp%nb=dtset%nband(1)

 sp%zcut=dtset%zcut
 write(6,'(a,f8.4)')&
& ' zcut for avoiding poles in sigma  [eV] ',sp%zcut*Ha_eV

!Compute dimensional primitive translations rprimd
 call mkrdim(acell,rprim,rprimd)

!Obtain dimensional translations in reciprocal space gprimd,
!metrics and unit cell volume, from rprimd.
!Also output rprimd, gprimd and ucvol
 call metric(gmet,gprimd,ab_out,rmet,rprimd,ucvol)

!Define consistently npw, nsh, and ecut
 call setshells(dtset%ecutwfn,dtset%npwwfn,dtset%nshwfn,dtset%nsym,gmet,&
& gprimd,dtset%symrel,'wfn',ucvol)
 call setshells(dtset%ecutsigx,dtset%npwsigx,dtset%nshsigx,dtset%nsym,gmet,&
& gprimd,dtset%symrel,'mat',ucvol)

 sp%npwwfn=dtset%npwwfn
 sp%npwx=dtset%npwsigx
 npwvec=sp%npwwfn
 if(sp%npwx>sp%npwwfn) npwvec=sp%npwx

 call testlda(dtfil,nop,nkibzr,nbr,ngr,nshr,i1,i2,ntypat,natom,mpsang)
 if(i2/=0.and.i2/=1.and.i2/=2.and.i2/=502.and.i2/=602) then
   stop 'unknown file form'
 end if
 sp%nk=nkibzr
 ninv=2
 inquire(file='nop.in',exist=ltemp)
 if(ltemp) then
   open(99,file='nop.in')
   read(99,*) nop, ninv
   close(99)
 end if
 sp%nop=nop
 if(npwvec>ngr) then
   write(*,*) 'warning: number of g-vectors found less then required;'
   npwvec=ngr
   if(sp%npwwfn>ngr) sp%npwwfn=ngr
   if(sp%npwx>ngr) sp%npwx=ngr
   write(*,*) '         calculation will proceed with npwvec=',npwvec
   write(*,*) '         calculation will proceed with npwsigx=',sp%npwx
   write(*,*) '                                       npwwfn=',sp%npwwfn
   write(*,*)
 end if
 if(sp%nb>nbr) then
   write(*,*) 'warning: number of bands found less then required;'
   write(*,*) '         calculation will proceed with nbnds=',nbr
   write(*,*)
   sp%nb=nbr
 end if

!allocate LDA electronic structure variables
 allocate(op(3,3,nop),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(kibz(3,sp%nk),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(gvec(3,npwvec),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(en(sp%nk,sp%nb),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(occ(sp%nk,sp%nb),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(wfg(sp%npwwfn,sp%nb,sp%nk),stat=istat)
 if(istat/=0) then
   write(*,*) 'wavefunctions(g) out of memory'
   write(*,*) 'requiring ',sp%npwwfn,sp%nb,sp%nk*8,' bytes'
   stop 'wavefunctions(g) out of memory'
 end if

!read in LDA band structure for sigma operator
 if(i2==0.or.i2==1) then
   call rdlda(iunit,nop,sp%nb,sp%nk,npwvec,sp%npwwfn,nopr,nbr,sp%nk,ngr,&
&   title,i1,i2,i3,a1,a2,a3,op,gvec,kibz,en,occ,wfg)
 else if(i2==2) then
   call rdldaabinit(iunit,nop,sp%nb,sp%nk,npwvec,sp%npwwfn,&
&   title,a1,a2,a3,op,gvec,kibz,en,occ,wfg)
 else if(i2==502.or.i2==602) then
   allocate(typat(natom),xred(3,natom))
   allocate(vkbsign(mpsang,ntypat))
   allocate(vkb(sp%npwwfn,ntypat,mpsang,sp%nk),stat=istat)
   if(istat/=0) stop 'out of memory'
   allocate(vkbd(sp%npwwfn,ntypat,mpsang,sp%nk),stat=istat)
   if(istat/=0) stop 'out of memory'
   call rdkss(dtfil,hdr,nop,sp%nb,sp%nk,npwvec,sp%npwwfn,&
&    title,a1,a2,a3,op,gvec,kibz,en,occ,wfg,&
&    ntypat,natom,mpsang,typat,xred,vkbsign,vkb,vkbd,nel)
 end if
 call pclock(10)

!read screening (epsilon^-1) file
 call testscr(dtfil,ep%nq,ep%nomega,ep%npwe,ep%npwwfn,ep%nb,titem1,fform)
 sp%nq=ep%nq
 sp%npwc=ep%npwe
 er%nq=ep%nq
 er%nomega=ep%nomega
 if(sp%npwc>sp%npwx) sp%npwc=sp%npwx
 er%npwe=sp%npwc
 allocate(q(3,sp%nq))
 if(fform==1002) then
  allocate(er%omega(ep%nomega))
  allocate(er%epsm1(sp%npwc,sp%npwc,ep%nomega,sp%nq),stat=istat)
  if(istat/=0) then
   write(*,*) 'epsilon^-1 out of memory'
   write(*,*) 'requiring ',sp%npwc*sp%npwc*ep%nomega*sp%nq*8,' bytes'
   stop 'epsilon^-1 out of memory'
  end if
  call rdscr(dtfil,sp%npwc,sp%nq,ep%nomega,q,er%omega,er%epsm1)
  if(ep%nomega==2) then
   ep%nomegaer=1
   ep%nomegaei=1
  else
   ep%nomegaer=1
   do io=1,ep%nomega
     if(real(er%omega(io))>0.001*Ha_eV) ep%nomegaer=io
   end do
   ep%nomegaei=ep%nomega-ep%nomegaer
  end if
 else if(fform==1003) then
   stop 'em1 file format not any more compatible'
 else
   stop 'unknown epsilon^-1 file format'
 end if
 print *, 'nomegaer, nomegaei', ep%nomegaer, ep%nomegaei

 call pclock(70)

!calculate b1, b2, b3 and ucvol, bzvol
 call lattice(a1,a2,a3,b1,b2,b3,ucvol,bzvol)

!set real space mesh
 call setmesh(gmet,gvec,ngfft1,ngfft2,ngfft3,ngfft1a,ngfft2a,ngfft3a,npwvec,sp%npwwfn,nr)

!NOTE : The following call to setmesh.F90 must be used if method=2 or method=3 in setmesh.F90
!write(std_out,*) ' npwx = ',sp%npwx,' npwc = ',sp%npwc
!call setmesh(gmet,gvec,ngfft1,ngfft2,ngfft3,ngfft1a,ngfft2a,ngfft3a,max(sp%npwx,sp%npwc),sp%npwwfn,nr)

 nrb=ngfft1*ngfft2*ngfft3

!set up tables for FFT igfft
 allocate(igfft(npwvec,5,5,5),stat=istat)
 if(istat/=0) stop 'out of memory'
 call cigfft(npwvec,ngfft1a,ngfft1,ngfft2,ngfft3,gvec,igfft)
 call pclock(20)

 call timab(402,2,tsec)
 call timab(403,1,tsec)

!calculate LDA wavefunctions in real space using FFT
 allocate(wfr(nr,sp%nb,sp%nk),stat=istat)
 if(istat/=0) then
   write(*,*) 'wavefunctions(r) out of memory'
   write(*,*) 'requiring ',nr,sp%nb,sp%nk*8,' bytes'
   stop 'wavefunctions(r) out of memory'
 end if
 wfr(:,:,:)=zero
 tim_fourdp=5
 call fftwfn(sp%npwwfn,sp%nb,sp%nk,nr,wfg,wfr,igfft(:,3,3,3),ngfft1,ngfft1a,&
& ngfft2,ngfft3,tim_fourdp)
 call pclock(30)

 call timab(403,2,tsec)
 call timab(404,1,tsec)

!set up table indicating rotations of r-points
 allocate(irottb(nr,nop),grottb(npwvec,2,nop),grottbm1(npwvec,2,nop),stat=istat)
 if(istat/=0) stop 'out of memory'
 call surot(op,nop,ninv,ngfft1,ngfft1a,ngfft2,ngfft3,nr,npwvec,gvec,grottb,irottb,&
& grottbm1)
 call pclock(40)

!set up required k-points in whole BZ; nkbzx maximum number of them
 nkbzx=sp%nk*nop*ninv
 allocate(kbz(3,nkbzx),wtk(sp%nk),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(ktab(nkbzx),ktabi(nkbzx),ktabo(nkbzx),ktabr(nr,nkbzx),stat=istat)
 if(istat/=0) stop 'out of memory'

 call identk(kibz,sp%nk,nkbzx,nr,nop,ninv,irottb,op,kbz,ktab,ktabr,ktabi,&
& ktabo,sp%nkbz,wtk)
 call pclock(50)

 call fermi(hdr,sp%nb,sp%nk,hdr%nsppol,wtk,en,occ,nel,nbv,efermi)

 if(dtset%nkptgw==0) then
  sp%nkcalc=sp%nk
  allocate(sp%xkcalc(3,sp%nkcalc),sp%kcalc(sp%nkcalc))
  allocate(sp%minbnd(sp%nkcalc),sp%maxbnd(sp%nkcalc))
  sp%xkcalc(:,:)=kibz(:,:)
  sp%minbnd(:)=1
  sp%maxbnd(:)=nbv*2
  if(nbv*2>sp%nb) sp%maxbnd(:)=sp%nb
 else
  sp%nkcalc=dtset%nkptgw
  allocate(sp%xkcalc(3,sp%nkcalc),sp%kcalc(sp%nkcalc))
  allocate(sp%minbnd(sp%nkcalc),sp%maxbnd(sp%nkcalc))
  sp%xkcalc(:,:)=dtset%kptgw(:,:)
  sp%minbnd(:)=dtset%bdgw(1,:)
  sp%maxbnd(:)=dtset%bdgw(2,:)
  if(any(sp%maxbnd(:)>sp%nb)) stop 'increase number of bands'
 end if
 call findk(sp%nkcalc,sp%nkbz,sp%xkcalc,kbz,sp%kcalc)
 call pclock(60)

 allocate(rho(nr),stat=istat)
 if(istat/=0) stop 'out of memory'
 call crho(irottb,sp%nb,ninv,sp%nkbz,sp%nk,sp%nk,nop,nr,nrb,occ,omegaplasma,rho,ucvol,wfr,wtk)

!set up q-points in whole BZ
 nqbzx=sp%nq*nop*ninv
 allocate(qbz(3,nqbzx),qtab(nqbzx),qtabo(nqbzx),qtabi(nqbzx),stat=istat)
 if(istat/=0) stop 'out of memory'
 call identq(q,sp%nq,nqbzx,op,nop,ninv,qbz,qtab,qtabi,qtabo,sp%nqbz)
 call pclock(80)

!calculate |q+G| for all q(IBZ) and G
 allocate(qpg(sp%npwx,sp%nq),stat=istat)
 if(istat/=0) stop 'out of memory'
 allocate(qratio(sp%npwc,sp%npwc,sp%nq),stat=istat)
 if(istat/=0) stop 'out of memory'
 call clcqpg(sp%npwx,sp%npwc,gvec,q,sp%nq,b1,b2,b3,qpg,qratio)
 call pclock(90)

 if(sp%ppmodel==1.or.sp%ppmodel==2)then
 allocate(er%bigomegatwsq(sp%npwc,sp%npwc,sp%nq), &
 &         er%omegatw(sp%npwc,sp%npwc,sp%nq),stat=istat)
 else if(sp%ppmodel==3)then
  allocate(er%bigomegatwsq(sp%npwc,1,sp%nq), &
 &         er%omegatw(sp%npwc,1,sp%nq),stat=istat)
 else if(sp%ppmodel==4)then
 allocate(er%bigomegatwsq(sp%npwc,sp%npwc,sp%nq), &
 &         er%omegatw(sp%npwc,1,sp%nq),stat=istat)
 end if

 if(istat/=0) then
   write(*,*) 'big-omega-twiddle-squared omega-twiddle out of memory'
   write(*,*) 'requiring ',2*sp%npwc*sp%npwc*sp%nq*8,' bytes'
   stop 'big-omega-twiddle-squared omega-twiddle out of memory'
 end if
 ! calculate plasmonpole model parameters
 allocate(eigpot(sp%npwc,sp%npwc,sp%nq))
 if(sp%ppmodel==1)then
  call cppm1par(sp%npwc,sp%nq,ep%nomega,er%epsm1,er%omega,er%bigomegatwsq, &
&  er%omegatw,omegaplasma)
 elseif(sp%ppmodel==2)then
  call cppm2par(sp%npwc,sp%nq,ep%nomega,er%epsm1,er%bigomegatwsq, &
&  er%omegatw,ngfft1,ngfft2,ngfft3,gvec,qratio,rho,nr,q,b1,b2,b3)
 elseif(dtset%ppmodel==3)then
  call cppm3par(sp%npwc,sp%nq,ep%nomega,er%epsm1,er%bigomegatwsq, &
&  er%omegatw,ngfft1,ngfft2,ngfft3,gvec,rho,nr,eigpot,q,b1,b2,b3)
 elseif(dtset%ppmodel==4)then
  call cppm4par(sp%npwc,sp%nq,er%epsm1,ep%nomega,er%bigomegatwsq, &
&  er%omegatw,ngfft1,ngfft2,ngfft3,gvec,rho,nr,q,b1,b2,b3)
 else
  write(message, '(a,a,a,a,a)' ) ch10,&
&   ' sigma: ERROR -',ch10,&
&   '  The ppmodel can only be 1, 2, 3 or 4 ',ch10
  call wrtout(6,message,'COLL')
  call leave_new('COLL')
 end if
 if(dtset%ppmodel==1.or.dtset%ppmodel==2)then
 print *, 'omega twiddle minval ', minval(abs(er%omegatw(:,:,:)))*Ha_eV
 else
  allocate(temp_omegatw(sp%npwc,sp%nq))
  do ig=1,sp%npwc
   temp_omegatw(ig,:)=er%omegatw(ig,1,:)
  end do
  print *, 'omega twiddle minval ',minval(abs(temp_omegatw(:,:)))*Ha_eV
  deallocate(temp_omegatw)
  end if
 sr%nk=sp%nk
 sr%nb=sp%nb
 sr%nomega=sp%nomegasr

 deallocate(qratio)

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! FBruneval 05/12/15
! read QP wavefunctions of the previous step
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

!read self-consistent transformation matrices and QP energies
 allocate(m_lda_to_qp(sr%nb,sr%nb,sr%nk))
 allocate(en_qp(sp%nk,sp%nb))
! call read_scf(dtfil,sp%gwcalctyp,sr%nk,sr%nb,kibz,nscf,en,en_qp,m_lda_to_qp)
 call rdqps(dtfil,sp%gwcalctyp,sr%nk,sr%nb,kibz,nscf,en,en_qp,m_lda_to_qp)

!computes QP wfr and wfg
 allocate(wfg_qp(sp%npwwfn,sp%nb,sp%nk))
 allocate(wfr_qp(nr,sp%nb,sp%nk))
 call calc_wf_qp(sp%nk,sp%nb,sp%npwwfn,nr,m_lda_to_qp,wfg,wfr,wfg_qp,wfr_qp)

!compute QP occupation numbers
 allocate(occ_qp(sp%nk,sp%nb))
 occ_qp(:,:)=occ(:,:)
 call fermi(hdr,sp%nb,sp%nk,hdr%nsppol,wtk,en_qp,occ_qp,nel,nbv,efermi_qp)

!compute QP density
 allocate(rho_qp(nr))
 call crho(irottb,sp%nb,ninv,sp%nkbz,sp%nk,sp%nk,nop,nr,nrb,occ_qp,omegaplasma,rho_qp,ucvol,wfr_qp,wtk)

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! FBruneval 05/12/15
! setup hartree hamiltonian
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

! 1)  setup lda hamiltonian
! allocate(hlda(sr%nb,sr%nb,sr%nk))
! hlda(:,:,:)=0
! do ik=1,sp%nk
!  do ib=1,sp%nb
!   hlda(ib,ib,ik)=en(ik,ib)
!  end do
! end do


! 2)  calculate xc potential
 allocate(vxc(sr%nb,sr%nb,sr%nk))
 call cmevxclda(dtset,dtset%ixc,mpi_enreg,sr%nb,ngfft1,ngfft2,ngfft3,sr%nk,nr,nrb,rho,rprimd,wfr,vxc)

 ! 1)  setup lda hamiltonian
 allocate(hlda(sr%nb,sr%nb,sr%nk))
 hlda(:,:,:)=0
 do ik=1,sp%nk
  do ib=1,sp%nb
   hlda(ib,ib,ik)=en(ik,ib)
  end do
 end do

! 3)  calculate LDA Hartree potential
 allocate(vhartr(sr%nb,sr%nb,sr%nk))
 write(*,*) '*************** LDA Energies *******************'
 call hartrham(dtset,sp,gmet,ucvol,ngfft1,ngfft2,ngfft3,nr,&
& npwvec,gvec,kibz,wtk,wfr,wfg,rho,occ,en,vhartr,mpi_enreg)
! 4)  calculate the bare Hamiltonian
 allocate(hbare(sr%nb,sr%nb,sr%nk))
!computes Hbare = -p^2/2 + vpsp_loc + vpsp_nonloc on lda wfs basis
 hbare(:,:,:)=hlda(:,:,:)-vhartr(:,:,:)-vxc(:,:,:)
! 5)  change the basis from LDA to QP
 call ham_changebasis(sr%nb,sr%nk,m_lda_to_qp,hbare)

! 6)  calculate the QP Hartree potential
 write(*,*) '*************** QP Energies *******************'
 call hartrham(dtset,sp,gmet,ucvol,ngfft1,ngfft2,ngfft3,nr,&
& npwvec,gvec,kibz,wtk,wfr_qp,wfg_qp,rho_qp,occ_qp,en_qp,vhartr,mpi_enreg)
! 7) obtain the QP Hartree Hamiltonian
 allocate(sr%hhartree(sr%nb,sr%nb,sr%nk))
 sr%hhartree(:,:,:)=hbare(:,:,:)+vhartr(:,:,:)
! 8) prepare the storage of the new wavefunctions and new energies
 allocate(sr%eigvec_qp(sr%nb,sr%nb,sr%nk),sr%en_qp_diago(sr%nb,sr%nk))
!initialize with LDA wavefunctions and en energies
 sr%eigvec_qp(:,:,:)=0
 do ib=1,sr%nb
  sr%eigvec_qp(ib,ib,:)=1.
  sr%en_qp_diago(ib,:)=en(:,ib)
 end do
deallocate(vhartr,hbare,hlda)

!store < nk | Vxc | nk >
 allocate(sr%vxcme(sr%nb,sr%nk))
 do ib=1,sr%nb
  sr%vxcme(ib,:)=vxc(ib,ib,:)
 end do

! deallocate(vxc,vhartr,hbare,hlda)
  deallocate(vxc)
 call pclock(100)
 deallocate(wfg,wfg_qp)
 deallocate(rho,rho_qp)

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

 allocate(sr%sigcme(sr%nb,sr%nk,sr%nomega),stat=istat)
 if(istat/=0) stop 'out of memory sigcme'
 allocate(sr%sigxme(sr%nb,sr%nk),stat=istat)
 if(istat/=0) stop 'out of memory sigxme'
 allocate(sr%sigxcme(sr%nb,sr%nk,sr%nomega),stat=istat)
 if(istat/=0) stop 'out of memory sigxcme'
 allocate(sr%sigcmee0(sr%nb,sr%nk),sr%ze0(sr%nb,sr%nk),sr%dsigmee0(sr%nb,sr%nk),sr%sigmee(sr%nb,sr%nk),stat=istat)
 if(istat/=0) stop 'out of memory sig'
 allocate(sr%e0(sr%nb,sr%nk),sr%degw(sr%nb,sr%nk),sr%egw(sr%nb,sr%nk),stat=istat)
 ! Next line added by YP
 allocate(sr_gwenergy(sr%nb,sr%nk),stat=istat)

 if(istat/=0) stop 'out of memory e0,egw,degw'
 allocate(sr%e0gap(sr%nk),sr%degwgap(sr%nk),sr%egwgap(sr%nk))
 sr%nomegasrd=sp%nomegasrd
 allocate(sr%omegasrd(sr%nb,sr%nk,sr%nomegasrd))
 allocate(sr%sigcmesrd(sr%nb,sr%nk,sr%nomegasrd))
 allocate(sr%sigxcmesrd(sr%nb,sr%nk,sr%nomegasrd))


 do ik=1,sr%nk
  do ib=1,sr%nb
   sr%e0(ib,ik)=en_qp(ik,ib)
   sr%egw(ib,ik)=en_qp(ik,ib) ! first guess for gw energy
  end do
  sr%e0gap(ik)=sr%e0(nbv+1,ik)-sr%e0(nbv,ik)
 end do

 ep%soenergy=dtset%soenergy

 if(ep%soenergy>0.1d-4) then
  print *, 'performing a first self-consistency'
  print *, 'update of the energies in G by a scissor operator'
  print *, 'applying a scissor operator of [eV] ', ep%soenergy*Ha_eV
  print *
  write(ab_out,*) 'performing a first self-consistency'
  write(ab_out,*) 'update of the energies in G by a scissor operator'
  write(ab_out,*) 'applying a scissor operator of [eV] ', ep%soenergy*Ha_eV
  write(ab_out,*)
  sr%egw(nbv+1:sr%nb,:)=sr%egw(nbv+1:sr%nb,:)+ep%soenergy
 else if(update_energies) then
  print *, 'performing a first self-consistency'
  print *, 'update of the energies in G by a previous GW calculation'
  write(ab_out,*) 'performing a first self-consistency'
  write(ab_out,*) 'update of the energies in W by a previous GW calculation'
  ! BEGIN WRAPPED CALL (YP)
  call rdgw(nkibzr,sr%nb,nbv,kibz,sr_gwenergy)
  do ik=1,sr%nk
   do ib=1,sr%nb
    sr%egw(ib,ik) = sr_gwenergy(ik,ib)
   end do
  end do
  ! END WRAPPED CALL (YP)
 end if

 call write_sigma_results_header(sp,ep)

 call timab(404,2,tsec)
 call timab(405,1,tsec)

! calculate self-energy and save on disc for each k-point
 do ikcalc=1,sp%nkcalc

   ikibz=ktab(sp%kcalc(ikcalc))

   call csigme(sp,ep,sp%kcalc(ikcalc),sp%minbnd(ikcalc),sp%maxbnd(ikcalc),&
&   q,gvec,npwvec,op,nop,kibz,&
&   ktab,ktabr,ktabi,kbz,ngfft1,ngfft1a,ngfft2,ngfft3,igfft,nr,en_qp,&
&   occ_qp,qbz,qtab,qtabi,qtabo,qpg,ucvol,grottb,wfr_qp,efermi_qp,&
&   er,sr,mpi_enreg,dtset%ppmodel,eigpot,b1,b2,b3)

   sr%egwgap(ikibz)=sr%egw(nbv+1,ikibz)-sr%egw(nbv,ikibz)
   sr%degwgap(ikibz)=sr%degw(nbv+1,ikibz)-sr%degw(nbv,ikibz)

!  print out results matrix elements
   call write_sigma_results(sp,sr,ikcalc,ikibz,en)

!! write out scf data
!   call write_scf(dtfil,sp%gwcalctyp,sr%nk,sr%nb,ikibz,kibz(:,ikibz),&
!&   nscf,sr%en_qp_diago(:,ikibz),sr%eigvec_qp(:,:,ikibz))

   call pclock(200+ikcalc)
 end do ! ikcalc

! write out scf data
  call wrqps(dtfil,sp%gwcalctyp,sr%nk,sr%nb,kibz,nscf,sr%en_qp_diago,sr%eigvec_qp,m_lda_to_qp)

 call timab(405,2,tsec)

 close(21)
 close(22)
 close(unitem1)

 call pclock(9999)

!DEBUG
!write(6,*)' sigma : debug, stop '
!write(6,*)allocated(sr%sigxme),allocated(sr%sigcme),allocated(sr%sigxcme)
!write(6,*)allocated(sr%vxcme),allocated(sr%e0)
!write(6,*)allocated(sr%omega)
!write(6,*)allocated(sr%sigcmee0),allocated(sr%dsigmee0),allocated(sr%sigmee)
!write(6,*)allocated(sr%degw),allocated(sr%egw)
!write(6,*)allocated(sr%e0gap),allocated(sr%degwgap),allocated(sr%egwgap)
!write(6,*)allocated(sp%kcalc),allocated(sp%xkcalc),allocated(sp%minbnd),allocated(sp%maxbnd)
!stop
!ENDDEBUG

 ! Next line added by YP
 deallocate(sr_gwenergy)
 deallocate(er%omega,er%epsm1)
 deallocate(sr%sigcme,sr%sigxcme,sr%sigxme)
 deallocate(sr%vxcme,sr%e0)
 if(sp%nomegasr>0) deallocate(sr%omega)
 deallocate(sr%sigcmee0,sr%dsigmee0,sr%sigmee,sr%ze0)
 deallocate(sr%degw,sr%egw)
 deallocate(sr%e0gap,sr%degwgap,sr%egwgap)
 deallocate(sp%kcalc,sp%xkcalc,sp%minbnd,sp%maxbnd)

 if(i2==502.or.i2==602)then
  call hdr_clean(hdr)
 end if

 call timab(401,2,tsec)

 write(*,*) 'sigma ended'

end subroutine sigma
!!***
