
use warnings;
use strict;

use lib "./util/subs/common";
use abinit_variables;

my $type = "";
my $cont = 0;
my $wait = 1;

my ($var,$grp,$i,@tmp1,@tmp2,%vars,%dims);

%vars = extract_variables("src/defs/defs_datatypes.F90","dataset_type");

open(OUT,">src/03ionetcdf/netcdf_def_dtset.F90")
or die "Could not open src/03ionetcdf/netcdf_def_dtset.F90 for writing";

print OUT <<EOF
!{\\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_def_dtset
!! NAME
!! netcdf_def_dtset
!!
!! FUNCTION
!!  Prepares a specified NetCDF file to store a dataset.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (Y. Pouillon)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!  dims <type(vardims_type)> = dimensions of dataset variables
!!
!! OUTPUT
!!  (no direct output : data written to a NetCDF file)
!!
!! NOTES
!!  Pouring data into the file is performed by the netcdf_put_dtset routine.
!!
!!  Please do not edit this file. Since it is automatically generated (see
!!  the makencdf script), your changes would be systematically overwritten.
!!  Instead you should directly modify the generating script itself
!!  (~abinit/scripts/netcdf/netcdf_def_dtset.pl) to suit your needs.
!!
!! PARENTS
!!
!! CHILDREN
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_def_dtset(ncid,dims)

#if defined HAVE_NETCDF
 use netcdf
#endif
 use defs_basis
 use defs_datatypes

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid
 type(vardims_type),intent(in) :: dims

!Local variables-------------------------------
!scalars
 character(len=*),parameter :: my_name = 'netcdf_def_dtset'
 integer :: ncerr,ncvar
 character(len=500) :: message
!arrays
 integer,allocatable :: ncdims(:)

! ***************************************************************************

#if defined HAVE_NETCDF
EOF
;

foreach $var (sort keys %vars)
{
	SWITCH:
	{
		( $vars{$var} eq "integer" ) && do{ $type = "NF90_INT"; last SWITCH; };
		( $vars{$var} eq "real(dp)" ) && do{ $type = "NF90_DOUBLE"; last SWITCH; };
	}

	if ( $var =~ /^([^\(]*)\(([^\)]*)\)/ )
	{
		$var  = $1;
		@tmp1 = split(/,/,$2);

		printf OUT "  ! Define dimensions of %s\n",$var;
		printf OUT "  allocate(ncdims(%d))\n",$#tmp1+1;

		for ($i=0;$i<=$#tmp1;$i++)
		{
			$_ = $tmp1[$i];
			if ( /[a-z]/ )
			{
				s/\*/_/g;
				$tmp1[$i] =~ s/\*/\*dims\%/g;
				$tmp1[$i] = "dims\%".$tmp1[$i];

				if ( $dims{$_} )
				{
					printf OUT "  ncerr = nf90_inq_dimid(ncid,name='%s',dimid=ncdims(%d))\n",$_,$i+1;
					print OUT "  call netcdf_handle_error('INQ','DIM','$_',my_name,ncerr)\n";
					$dims{$_}++;
				}
				else
				{
					printf OUT "  ncerr = nf90_def_dim(ncid,name='%s',len=%s,dimid=ncdims(%d))\n",$_,$tmp1[$i],$i+1;
					print OUT "  call netcdf_handle_error('DEF','DIM','$_',my_name,ncerr)\n";
					$dims{$_} = 1;
				}
			}
			else
			{
				printf OUT "  ncerr = nf90_def_dim(ncid,name='%s%d',len=%s,dimid=ncdims(%d))\n",$var."_dim",$i+1,$_,$i+1;
				printf OUT "  call netcdf_handle_error('DEF','DIM','%s%d',my_name,ncerr)\n",
				 $var."_dim",$i+1;
			}
		}

		print OUT "  ! Define $var\n";
		print OUT "  ncerr = nf90_def_var(ncid,name='$var',xtype=$type,dimids=ncdims,varid=ncvar)\n";
		print OUT "  deallocate(ncdims)\n";
	}
	else
	{
		print OUT "  ! Define $var\n";
		print OUT "  ncerr = nf90_def_var(ncid,name='$var',xtype=$type,varid=ncvar)\n";
	}

	print OUT "  call netcdf_handle_error('DEF','VAR','$var',my_name,ncerr)\n";
}

print OUT <<EOF
#else
 write(message,'(4a)') ch10,' netcdf_def_dtset - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_def_dtset
!!***
EOF
;

close(OUT);
