
use warnings;
use strict;

use lib "./util/subs/common";
use abinit_variables;

my ($dim,%dims);

%dims  = extract_variables("src/defs/defs_netcdf.F90","vardims_type");

open(OUT,">src/03ionetcdf/netcdf_get_dims_dtset.F90")
or die "Could not open src/03ionetcdf/netcdf_get_dims_dtset.F90 for writing";

print OUT <<EOF
!{\\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_get_dims_dtset
!! NAME
!! netcdf_get_dims_dtset
!!
!! FUNCTION
!!  Reads the dimensions of the arrays present in a dataset from
!!  a specified NetCDF file.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (Y. Pouillon)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!
!! OUTPUT
!!  dims <type(vardims_type)> = dimensions of dataset variables
!!
!! NOTES
!!  Please do not edit this file. Since it is automatically generated (see
!!  the makencdf script), your changes would be systematically overwritten.
!!  Instead you should directly modify the generating script itself
!!  (~abinit/scripts/netcdf/netcdf_get_dims_dtset.pl) to suit your needs.
!!
!! PARENTS
!!
!! CHILDREN
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_get_dims_dtset(ncid,dims)

#if defined HAVE_NETCDF
 use netcdf
#endif
 use defs_basis
 use defs_datatypes

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid
 type(vardims_type),intent(inout) :: dims

!Local variables-------------------------------
!scalars
 character(len=*),parameter :: my_name = 'netcdf_get_dims_dtset'
 integer :: ncdim,ncerr,ncvar
 character(len=500) :: message

! ***************************************************************************

#if defined HAVE_NETCDF
EOF
;

foreach $dim (sort keys %dims)
{
	$dim =~ s/\(.*//;

	print OUT " ! Get $dim\n";
	print OUT " ncerr = nf90_inq_dimid(ncid,name='$dim',dimid=ncdim)\n";
	print OUT " call netcdf_handle_error('INQ','DID','$dim',my_name,ncerr)\n";
	print OUT " ncerr = nf90_inquire_dimension(ncid,dimid=ncdim,len=dims\%$dim)\n";
	print OUT " call netcdf_handle_error('GET','DIM','$dim',my_name,ncerr)\n";
}

print OUT <<EOF
#else
 write(message,'(4a)') ch10,' netcdf_get_dims_dtset - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_get_dims_dtset
!!***
EOF
;

close(OUT);
