
use warnings;
use strict;

use lib "./util/subs/common";
use abinit_variables;

my ($var,%vars);

%vars = extract_variables("src/defs/defs_datatypes.F90","dataset_type");

open(OUT,">src/03ionetcdf/netcdf_get_dtset.F90")
or die "Could not open src/03ionetcdf/netcdf_get_dtset.F90 for writing";

print OUT <<EOF
!{\\src2tex{textfont=tt}}
!!****f* ABINIT/netcdf_get_dtset
!! NAME
!! netcdf_get_dtset
!!
!! FUNCTION
!!  Reads a dataset from a specified NetCDF file.
!!
!! COPYRIGHT
!!  Copyright (C) 2005-2006 ABINIT group (Y. Pouillon)
!!  This file is distributed under the terms of the
!!  GNU General Public License, see ~abinit/COPYING
!!  or http://www.gnu.org/copyleft/gpl.txt .
!!  For the initials of contributors, see ~abinit/doc/developers/contributors .
!!
!! INPUTS
!!  ncid = identifier of an open NetCDF file
!!
!! OUTPUT
!!  dtset <type(dataset_type)> = the dataset where the data will be stored
!!
!! NOTES
!!  This routines assumes that all arrays within the dataset have already
!!  been allocated (array sizes are obtained through netcdf_get_dims_dtset).
!!
!!  Please do not edit this file. Since it is automatically generated (see
!!  the makencdf script), your changes would be systematically overwritten.
!!  Instead you should directly modify the generating script itself
!!  (~abinit/scripts/netcdf/netcdf_get_dtset.pl) to suit your needs.
!!
!! PARENTS
!!
!! CHILDREN
!!
!! SOURCE

#if defined HAVE_CONFIG_H
#include "config.h"
#endif

subroutine netcdf_get_dtset(ncid,dtset)

#if defined HAVE_NETCDF
 use netcdf
#endif
 use defs_basis
 use defs_datatypes

 implicit none

!Arguments ------------------------------------
!scalars
 integer,intent(in) :: ncid
 type(dataset_type),intent(inout) :: dtset

!Local variables-------------------------------
!scalars
 character(len=*),parameter :: my_name = 'netcdf_get_dtset'
 integer :: ncdim,ncerr,ncvar
 character(len=500) :: message

! ***************************************************************************

#if defined HAVE_NETCDF
EOF
;

foreach $var (sort keys %vars)
{
	$var =~ s/\(.*//;

	print OUT " ! Get $var\n";
	print OUT " ncerr = nf90_inq_varid(ncid,name='$var',varid=ncvar)\n";
	print OUT " call netcdf_handle_error('INQ','VID','$var',my_name,ncerr)\n";
	print OUT " ncerr = nf90_get_var(ncid,ncvar,dtset\%$var)\n";
	print OUT " call netcdf_handle_error('GET','VAR','$var',my_name,ncerr)\n";
}

print OUT <<EOF
#else
 write(message,'(4a)') ch10,' netcdf_get_dtset - ERROR',ch10,&
&  'This version has not been compiled with NetCDF support'
 call wrtout(std_out,message,'COLL')
 call leave_new('COLL')
#endif

end subroutine netcdf_get_dtset
!!***
EOF
;

close(OUT);
